from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

my_lt1083 = SchLib(tool=SKIDL).add_parts(*[
        Part(name='LT1083-12',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1083-5',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1083',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1084-12',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1084-3.3',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1084-5',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1084',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1085-12',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1085-3.3',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1085-3.6',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1085-5',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1085',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1086-12',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1086-2.85',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1086-3.3',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1086-3.6',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1086-5',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1086',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)]),
        Part(name='LT1086H',dest=TEMPLATE,tool=SKIDL,pyspice={'name': 'X', 'add': <function add_subcircuit_to_circuit at 0x0AB33AE0>},filename='C:\\xesscorp\\KiCad\\tools\\skidl\\tests\\lt1083.lib',ref_prefix='X',num_units=1,do_erc=True,pins=[
            Pin(num='1',name='1',do_erc=True),
            Pin(num='2',name='2',do_erc=True),
            Pin(num='3',name='3',do_erc=True)])])