from skidl import Pin, Part, SchLib, SKIDL, TEMPLATE

SKIDL_lib_version = '0.0.1'

stm32 = SchLib(tool=SKIDL).add_parts(*[
        Part(name='STM32F030C6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x0 Value Line',description='Core: ARM Cortex-M0 Package: LQFP48 Flash: 32KB Ram: 4KB Frequency: 48MHz Voltage: 2.4..3.6V IO-pins: 39',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/USART1_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/USART1_DE/USART1_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/USART1_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/USART1_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/SPI1_NSS/TIM14_CH1/USART1_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C1_SCL/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART1_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='SPI1_NSS/USART1_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='35',name='PF6/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='PF7/I2C1_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/SPI1_MISO/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TIM16_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/I2C1_SDA/IR_OUT/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C1_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/SPI1_NSS/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/SPI1_SCK/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/SPI1_MISO/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/RTC_REFIN/SPI1_MOSI/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F030C8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x0 Value Line',description='Core: ARM Cortex-M0 Package: LQFP48 Flash: 64KB Ram: 8KB Frequency: 48MHz Voltage: 2.4..3.6V IO-pins: 39',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/TIM15_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/TIM15_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/SPI1_NSS/TIM14_CH1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='TIM15_BKIN/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='SPI1_NSS/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='35',name='PF6/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='PF7/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/SPI1_MISO/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TIM16_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/I2C1_SDA/IR_OUT/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/SPI2_NSS/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/SPI2_SCK/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/SPI2_MISO/TIM15_CH1/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F030CCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x0 Value Line',description='Core: ARM Cortex-M0 Package: LQFP48 Flash: 256KB Ram: 32KB Frequency: 48MHz Voltage: 2.4..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/TIM15_CH1N/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/TIM15_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/TIM15_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/SPI1_NSS/TIM14_CH1/USART2_CK/USART6_TX/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/SPI1_SCK/USART6_RX/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C1_SCL/RCC_MCO/TIM15_BKIN/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='I2C2_SCL/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2C2_SDA/TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='SPI1_NSS/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='5',name='PF0/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/SPI1_SCK/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/SPI1_MISO/TIM17_BKIN/TIM3_CH1/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/SPI1_MOSI/TIM16_BKIN/TIM3_CH2/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TIM16_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/I2C1_SDA/IR_OUT/SPI2_NSS/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/SPI2_SCK/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C2_SDA/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C2_SCL/SPI2_SCK/TIM1_CH1N/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C2_SDA/SPI2_MISO/TIM15_CH1/TIM1_CH2N/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F030F4Px',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x0 Value Line',description='Core: ARM Cortex-M0 Package: TSSOP20 Flash: 16KB Ram: 4KB Frequency: 48MHz Voltage: 2.4..3.6V IO-pins: 15',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/USART1_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/USART1_DE/USART1_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/USART1_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/USART1_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/SPI1_NSS/TIM14_CH1/USART1_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='I2C1_SCL/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='SYS_SWCLK/USART1_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='1',name='BOOT0',do_erc=True),
            Pin(num='2',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='14',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='15',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F030K6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x0 Value Line',description='Core: ARM Cortex-M0 Package: LQFP32 Flash: 32KB Ram: 4KB Frequency: 48MHz Voltage: 2.4..3.6V IO-pins: 25',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/USART1_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/USART1_DE/USART1_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/USART1_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/USART1_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/SPI1_NSS/TIM14_CH1/USART1_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='I2C1_SCL/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='SYS_SWCLK/USART1_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='SPI1_NSS/USART1_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/SPI1_MISO/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/I2C1_SMBA/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/I2C1_SCL/TIM16_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/I2C1_SDA/TIM17_CH1N/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F030R8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x0 Value Line',description='Core: ARM Cortex-M0 Package: LQFP64 Flash: 64KB Ram: 8KB Frequency: 48MHz Voltage: 2.4..3.6V IO-pins: 55',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/TIM15_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/TIM15_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/SPI1_NSS/TIM14_CH1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='TIM15_BKIN/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='SPI1_NSS/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='SPI1_SCK/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='SPI1_MISO/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/SPI1_MOSI/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/TIM16_CH1/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='I2C1_SDA/IR_OUT/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C2_SDA/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SPI2_NSS/TIM1_BKIN/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SPI2_SCK/TIM1_CH1N/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='SPI2_MISO/TIM15_CH1/TIM1_CH2N/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='18',name='PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='PF6/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='PF7/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F030RCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x0 Value Line',description='Core: ARM Cortex-M0 Package: LQFP64 Flash: 256KB Ram: 32KB Frequency: 48MHz Voltage: 2.4..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/TIM15_CH1N/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/TIM15_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/TIM15_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/SPI1_NSS/TIM14_CH1/USART2_CK/USART6_TX/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/SPI1_SCK/USART6_RX/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='I2C1_SCL/RCC_MCO/TIM15_BKIN/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='I2C2_SCL/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='I2C2_SDA/TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='SPI1_NSS/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='SPI1_SCK/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='SPI1_MISO/TIM17_BKIN/TIM3_CH1/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/SPI1_MOSI/TIM16_BKIN/TIM3_CH2/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/TIM16_CH1/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='I2C1_SDA/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/SPI2_SCK/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C2_SDA/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SPI2_NSS/TIM15_BKIN/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2C2_SCL/SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2C2_SDA/SPI2_MISO/TIM15_CH1/TIM1_CH2N/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='5',name='PF0/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/USART3_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/USART3_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/USART3_CK/USART4_CK/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F031C4Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: LQFP48 Flash: 16KB Ram: 4KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 39',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F031C6Tx'],pins=[
            Pin(num='10',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART1_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/TIM2_CH2/USART1_DE/USART1_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/TIM2_CH3/USART1_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/TIM2_CH4/USART1_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/USART1_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C1_SCL/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART1_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART1_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='35',name='PF6/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='PF7/I2C1_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TIM16_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/I2C1_SDA/IR_OUT/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C1_SCL/TIM2_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C1_SDA/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/SPI1_NSS/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/SPI1_SCK/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/SPI1_MISO/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/RTC_REFIN/SPI1_MOSI/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F031F4Px',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: TSSOP20 Flash: 16KB Ram: 4KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 15',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F031F6Px'],pins=[
            Pin(num='6',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART1_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/TIM2_CH2/USART1_DE/USART1_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/TIM2_CH3/USART1_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/TIM2_CH4/USART1_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/USART1_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='I2C1_SCL/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='SYS_SWCLK/USART1_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='1',name='BOOT0',do_erc=True),
            Pin(num='2',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='14',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='15',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F031G4Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: UFQFPN28 Flash: 16KB Ram: 4KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 23',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F031G6Ux'],pins=[
            Pin(num='6',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART1_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/TIM2_CH2/USART1_DE/USART1_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/TIM2_CH3/USART1_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/TIM2_CH4/USART1_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/USART1_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='I2C1_SCL/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='SYS_SWCLK/USART1_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART1_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='1',name='BOOT0',do_erc=True),
            Pin(num='2',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB6/I2C1_SCL/TIM16_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB7/I2C1_SDA/TIM17_CH1N/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='29',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F031K4Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: UFQFPN32 Flash: 16KB Ram: 4KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 27',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F031K6Ux'],pins=[
            Pin(num='6',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART1_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/TIM2_CH2/USART1_DE/USART1_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/TIM2_CH3/USART1_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/TIM2_CH4/USART1_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/USART1_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='I2C1_SCL/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='SYS_SWCLK/USART1_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART1_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/I2C1_SCL/TIM16_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/I2C1_SDA/TIM17_CH1N/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PB8/I2C1_SCL/TIM16_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F031K6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: LQFP32 Flash: 32KB Ram: 4KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 25',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART1_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/TIM2_CH2/USART1_DE/USART1_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/TIM2_CH3/USART1_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/TIM2_CH4/USART1_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/USART1_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='I2C1_SCL/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='SYS_SWCLK/USART1_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART1_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/I2C1_SCL/TIM16_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/I2C1_SDA/TIM17_CH1N/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F038C6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x8',description='Core: ARM Cortex-M0 Package: LQFP48 Flash: 32KB Ram: 4KB Frequency: 48MHz Voltage: 1.65..1.95V IO-pins: 38',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART1_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/TIM2_CH2/USART1_DE/USART1_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/TIM2_CH3/USART1_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/TIM2_CH4/USART1_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/USART1_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C1_SCL/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART1_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART1_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='NPOR',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='35',name='PF6/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='PF7/I2C1_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TIM16_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/I2C1_SDA/IR_OUT/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C1_SCL/TIM2_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C1_SDA/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/SPI1_NSS/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/SPI1_SCK/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/SPI1_MISO/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/RTC_REFIN/SPI1_MOSI/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F038F6Px',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x8',description='Core: ARM Cortex-M0 Package: TSSOP20 Flash: 32KB Ram: 4KB Frequency: 48MHz Voltage: 1.65..1.95V IO-pins: 14',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART1_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/TIM2_CH2/USART1_DE/USART1_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/TIM2_CH3/USART1_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/TIM2_CH4/USART1_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/USART1_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='I2C1_SCL/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='SYS_SWCLK/USART1_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='1',name='BOOT0',do_erc=True),
            Pin(num='14',name='NPOR',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='16',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='15',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F038G6Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x8',description='Core: ARM Cortex-M0 Package: UFQFPN28 Flash: 32KB Ram: 4KB Frequency: 48MHz Voltage: 1.65..1.95V IO-pins: 22',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART1_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/TIM2_CH2/USART1_DE/USART1_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/TIM2_CH3/USART1_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/TIM2_CH4/USART1_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/USART1_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='I2C1_SCL/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='SYS_SWCLK/USART1_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART1_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='1',name='BOOT0',do_erc=True),
            Pin(num='15',name='NPOR',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB6/I2C1_SCL/TIM16_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB7/I2C1_SDA/TIM17_CH1N/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='29',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F038K6Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x8',description='Core: ARM Cortex-M0 Package: UFQFPN32 Flash: 32KB Ram: 4KB Frequency: 48MHz Voltage: 1.65..1.95V IO-pins: 26',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART1_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/TIM2_CH2/USART1_DE/USART1_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/TIM2_CH3/USART1_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/TIM2_CH4/USART1_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/USART1_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='I2C1_SCL/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='SYS_SWCLK/USART1_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART1_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='16',name='NPOR',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/I2C1_SCL/TIM16_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/I2C1_SDA/TIM17_CH1N/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PB8/I2C1_SCL/TIM16_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F042C4Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x2',description='Core: ARM Cortex-M0 Package: LQFP48 Flash: 16KB Ram: 6KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 38',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F042C6Tx'],pins=[
            Pin(num='10',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/SYS_WKUP4/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USB_OE/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/CEC/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C1_SCL/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='CAN_RX/I2C1_SCL/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN_TX/I2C1_SDA/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USB_OE/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='44',name='PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/CAN_TX/I2C1_SDA/IR_OUT/SPI2_NSS/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/CEC/I2C1_SCL/SPI2_SCK/TIM2_CH3/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C1_SDA/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/SPI2_NSS/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C1_SCL/SPI2_SCK/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C1_SDA/SPI2_MISO/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F042C6Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x2',description='Core: ARM Cortex-M0 Package: UFQFPN48 Flash: 32KB Ram: 6KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 38',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/SYS_WKUP4/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USB_OE/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/CEC/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C1_SCL/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='CAN_RX/I2C1_SCL/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN_TX/I2C1_SDA/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USB_OE/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='44',name='PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/CAN_TX/I2C1_SDA/IR_OUT/SPI2_NSS/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/CEC/I2C1_SCL/SPI2_SCK/TIM2_CH3/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C1_SDA/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/SPI2_NSS/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C1_SCL/SPI2_SCK/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C1_SDA/SPI2_MISO/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F042F4Px',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x2',description='Core: ARM Cortex-M0 Package: TSSOP20 Flash: 16KB Ram: 6KB Frequency: 48MHz Voltage: 2..--V IO-pins: 16',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/SYS_WKUP4/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USB_OE/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/CEC/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='I2C1_SCL/TIM1_CH2/TSC_G4_IO1/USART1_TX/CAN_RX/I2C1_SCL/TIM1_CH4/TSC_G4_IO3/USB_DM/PA11/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/CAN_TX/TIM1_ETR/TSC_G4_IO4/USB_DP/PA12/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='2',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='14',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PB8/CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='15',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F042F6Px',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x2',description='Core: ARM Cortex-M0 Package: TSSOP20 Flash: 32KB Ram: 6KB Voltage: 2..--V IO-pins: 16',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/SYS_WKUP4/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USB_OE/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/CEC/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='I2C1_SCL/TIM1_CH2/TSC_G4_IO1/USART1_TX/CAN_RX/I2C1_SCL/TIM1_CH4/TSC_G4_IO3/USB_DM/PA11/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/CAN_TX/TIM1_ETR/TSC_G4_IO4/USB_DP/PA12/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='2',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='14',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PB8/CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='15',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F042G4Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x2',description='Core: ARM Cortex-M0 Package: UFQFPN28 Flash: 16KB Ram: 6KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 23',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F042G6Ux'],pins=[
            Pin(num='6',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/SYS_WKUP4/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USB_OE/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/CEC/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='I2C1_SCL/TIM1_CH2/TSC_G4_IO1/USART1_TX/CAN_RX/I2C1_SCL/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/CAN_TX/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USB_OE/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='2',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB4/I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PB8/CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='29',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F042K4Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x2',description='Core: ARM Cortex-M0 Package: UFQFPN32 Flash: 16KB Ram: 6KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 28',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F042K6Ux'],pins=[
            Pin(num='6',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/SYS_WKUP4/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USB_OE/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/CEC/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='I2C1_SCL/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='CAN_RX/I2C1_SCL/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='CAN_TX/I2C1_SDA/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USB_OE/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='2',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='31',name='PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PB2/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PB8/CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F042K6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x2',description='Core: ARM Cortex-M0 Package: LQFP32 Flash: 32KB Ram: 6KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 26',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/SYS_WKUP4/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USB_OE/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/CEC/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='I2C1_SCL/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='CAN_RX/I2C1_SCL/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='CAN_TX/I2C1_SDA/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USB_OE/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='2',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='PB8/CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F042T6Yx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x2',description='Core: ARM Cortex-M0 Package: WLCSP36 Flash: 32KB Ram: 6KB Frequency: 48MHz Voltage: 2..--V IO-pins: 30',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='F6',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='ADC_IN1/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='ADC_IN2/SYS_WKUP4/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN3/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USB_OE/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='ADC_IN5/CEC/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='I2C1_SCL/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='CAN_RX/I2C1_SCL/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='CAN_TX/I2C1_SDA/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USB_OE/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='NRST',do_erc=True),
            Pin(num='B5',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='C5',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='A6',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PB2/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PB4/I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E6',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PB8/CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='E1',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F048C6Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x8',description='Core: ARM Cortex-M0 Package: UFQFPN48 Flash: 32KB Ram: 6KB Frequency: 48MHz Voltage: 1.65..1.95V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/SYS_WKUP4/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USB_OE/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/CEC/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C1_SCL/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='I2C1_SCL/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2C1_SDA/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USB_OE/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='NPOR',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='44',name='PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/I2C1_SDA/IR_OUT/SPI2_NSS/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/CEC/I2C1_SCL/SPI2_SCK/TIM2_CH3/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C1_SDA/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/SPI2_NSS/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C1_SCL/SPI2_SCK/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C1_SDA/SPI2_MISO/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F048G6Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x8',description='Core: ARM Cortex-M0 Package: UFQFPN28 Flash: 32KB Ram: 6KB Frequency: 48MHz Voltage: 1.65..1.95V IO-pins: 22',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/SYS_WKUP4/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USB_OE/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/CEC/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='I2C1_SCL/TIM1_CH2/TSC_G4_IO1/USART1_TX/I2C1_SCL/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USB_OE/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='15',name='NPOR',func=Pin.PWRIN,do_erc=True),
            Pin(num='2',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB4/I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PB8/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='29',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F048T6Yx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x8',description='Core: ARM Cortex-M0 Package: WLCSP36 Flash: 32KB Ram: 6KB Frequency: 48MHz Voltage: 1.65..1.95V IO-pins: 29',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='F6',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='ADC_IN1/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='ADC_IN2/SYS_WKUP4/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN3/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USB_OE/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='ADC_IN5/CEC/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='I2C1_SCL/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='I2C1_SCL/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='I2C1_SDA/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USB_OE/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='NRST',do_erc=True),
            Pin(num='D2',name='NPOR',func=Pin.PWRIN,do_erc=True),
            Pin(num='B5',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='C5',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='A6',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PB4/I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E6',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PB8/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='E1',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F050C4Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: LQFP48 Flash: 16KB Ram: 4KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 38',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F050C6Tx'],pins=[
            Pin(num='10',name='ADC_IN0/SYS_RTC_TAMP2/SYS_WKUP1/TIM2_CH1_ETR/USART1_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/TIM2_CH2/USART1_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/TIM2_CH3/USART1_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/TIM2_CH4/USART1_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/USART1_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/I2S1_CK/SPI1_SCK/TIM2_CH1_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='SYS_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C1_SCL/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='TIM1_ETR/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IRTIM_OUT/SYS_SWDAT/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART1_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1_ETR/USART1_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/SYS_OSC_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='PF1/SYS_OSC_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='PF6/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='PF7/I2C1_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/SYS_RTC_OUT/SYS_RTC_TAMP1/SYS_RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/SYS_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/SYS_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TIM16_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/I2C1_SDA/IRTIM_OUT/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C1_SCL/TIM2_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C1_SDA/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/SPI1_NSS/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/SPI1_SCK/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/SPI1_MISO/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/SPI1_MOSI/SYS_RTC_REFIN/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F050G4Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: UFQFPN28 Flash: 16KB Ram: 4KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 23',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F050G6Ux'],pins=[
            Pin(num='6',name='ADC_IN0/SYS_RTC_TAMP2/SYS_WKUP1/TIM2_CH1_ETR/USART1_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/TIM2_CH2/USART1_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/TIM2_CH3/USART1_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/TIM2_CH4/USART1_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/USART1_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/I2S1_CK/SPI1_SCK/TIM2_CH1_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='SYS_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='I2C1_SCL/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='IRTIM_OUT/SYS_SWDAT/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='SYS_SWCLK/USART1_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='I2S1_WS/SPI1_NSS/TIM2_CH1_ETR/USART1_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='1',name='BOOT0',do_erc=True),
            Pin(num='2',name='PF0/SYS_OSC_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PF1/SYS_OSC_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB6/I2C1_SCL/TIM16_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB7/I2C1_SDA/TIM17_CH1N/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='29',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F050K4Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: UFQFPN32 Flash: 16KB Ram: 4KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 26',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F050K6Ux'],pins=[
            Pin(num='6',name='ADC_IN0/SYS_RTC_TAMP2/SYS_WKUP1/TIM2_CH1_ETR/USART1_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/TIM2_CH2/USART1_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/TIM2_CH3/USART1_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/TIM2_CH4/USART1_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/I2S1_WS/SPI1_NSS/TIM14_CH1/USART1_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/I2S1_CK/SPI1_SCK/TIM2_CH1_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='SYS_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='I2C1_SCL/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='TIM1_ETR/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='IRTIM_OUT/SYS_SWDAT/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='SYS_SWCLK/USART1_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='I2S1_WS/SPI1_NSS/TIM2_CH1_ETR/USART1_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PF0/SYS_OSC_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PF1/SYS_OSC_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/I2C1_SCL/TIM16_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/I2C1_SDA/TIM17_CH1N/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PB8/I2C1_SCL/TIM16_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F051C4Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: LQFP48 Flash: 16KB Ram: 8KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 39',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM2_CH2/TSC_G1_IO2/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC1_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC1_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='35',name='PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='PF7',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC1_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/CEC/TIM2_CH3/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/TIM2_CH4/TSC_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/TIM1_BKIN/TSC_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/TIM1_CH1N/TSC_G6_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/RTC_REFIN/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F051C4Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: UFQFPN48 Flash: 16KB Ram: 8KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 39',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM2_CH2/TSC_G1_IO2/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC1_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC1_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='35',name='PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='PF7',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC1_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/CEC/TIM2_CH3/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/TIM2_CH4/TSC_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/TIM1_BKIN/TSC_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/TIM1_CH1N/TSC_G6_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/RTC_REFIN/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F051C6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: LQFP48 Flash: 32KB Ram: 8KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 39',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC1_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC1_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='35',name='PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='PF7',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC1_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/CEC/TIM2_CH3/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/TIM2_CH4/TSC_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/TIM1_BKIN/TSC_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/TIM1_CH1N/TSC_G6_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/RTC_REFIN/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F051C6Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: UFQFPN48 Flash: 32KB Ram: 8KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 39',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC1_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC1_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='35',name='PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='PF7',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC1_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/CEC/TIM2_CH3/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/TIM2_CH4/TSC_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/TIM1_BKIN/TSC_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/TIM1_CH1N/TSC_G6_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/RTC_REFIN/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F051C8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: LQFP48 Flash: 64KB Ram: 8KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 39',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC1_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC1_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='35',name='PF6/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='PF7/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC1_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/CEC/I2C2_SCL/TIM2_CH3/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C2_SDA/TIM2_CH4/TSC_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F051C8Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: UFQFPN48 Flash: 64KB Ram: 8KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 39',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC1_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC1_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='35',name='PF6/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='PF7/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC1_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/CEC/I2C2_SCL/TIM2_CH3/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C2_SDA/TIM2_CH4/TSC_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F051K4Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: LQFP32 Flash: 16KB Ram: 8KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 25',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/TIM2_CH2/TSC_G1_IO2/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC1_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='DAC1_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='SYS_SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F051K4Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: UFQFPN32 Flash: 16KB Ram: 8KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 27',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/TIM2_CH2/TSC_G1_IO2/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC1_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='DAC1_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='SYS_SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PB2/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PB8/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F051K6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: LQFP32 Flash: 32KB Ram: 8KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 25',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC1_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='DAC1_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F051K6Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: UFQFPN32 Flash: 32KB Ram: 8KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 27',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC1_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='DAC1_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PB2/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PB8/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F051K8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: LQFP32 Flash: 64KB Ram: 8KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 25',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC1_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='DAC1_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F051K8Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: UFQFPN32 Flash: 64KB Ram: 8KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 27',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC1_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='DAC1_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PB2/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PB8/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F051R4Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: LQFP64 Flash: 16KB Ram: 8KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 55',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/TIM2_CH2/TSC_G1_IO2/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC1_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC1_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2S1_MCK/SPI1_MISO/TIM3_CH1/TSC_G5_IO2/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC1_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CEC/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='TIM1_BKIN/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='TIM1_CH1N/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='RTC_REFIN/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='18',name='PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='PF7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/TSC_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC1_EXTI9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F051R6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: LQFP64 Flash: 32KB Ram: 8KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 55',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC1_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC1_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2S1_MCK/SPI1_MISO/TIM3_CH1/TSC_G5_IO2/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC1_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CEC/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='TIM1_BKIN/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='TIM1_CH1N/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='RTC_REFIN/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='18',name='PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='PF7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/TSC_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC1_EXTI9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F051R8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: LQFP64 Flash: 64KB Ram: 8KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 55',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC1_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC1_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2S1_MCK/SPI1_MISO/TIM3_CH1/TSC_G5_IO2/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC1_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CEC/I2C2_SCL/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='18',name='PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='PF6/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='PF7/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/TSC_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC1_EXTI9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F058C8Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x8',description='Core: ARM Cortex-M0 Package: UFQFPN48 Flash: 64KB Ram: 8KB Frequency: 48MHz Voltage: 1.65..1.95V IO-pins: 38',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC1_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC1_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='NPOR',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='35',name='PF6/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='PF7/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC1_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/CEC/I2C2_SCL/TIM2_CH3/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C2_SDA/TIM2_CH4/TSC_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F058R8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x8',description='Core: ARM Cortex-M0 Package: LQFP64 Flash: 64KB Ram: 8KB Frequency: 48MHz Voltage: 1.65..1.95V IO-pins: 54',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC1_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC1_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2S1_MCK/SPI1_MISO/TIM3_CH1/TSC_G5_IO2/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC1_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CEC/I2C2_SCL/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='NPOR',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='18',name='PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='PF6/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='PF7/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/TSC_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC1_EXTI9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F070C6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x0 Value Line',description='Core: ARM Cortex-M0 Package: LQFP48 Flash: 32KB Ram: 6KB Frequency: 48MHz Voltage: 2.4..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/SYS_WKUP4/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/SPI1_NSS/TIM14_CH1/USART2_CK/USB_OE/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C1_SCL/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='TIM1_ETR/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='SPI1_NSS/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='5',name='PF0/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/SPI1_MISO/TIM17_BKIN/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TIM16_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/I2C1_SDA/IR_OUT/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/RTC_REFIN/SYS_WKUP7/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F070CBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x0 Value Line',description='Core: ARM Cortex-M0 Package: LQFP48 Flash: 128KB Ram: 16KB Frequency: 48MHz Voltage: 2.4..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/TIM15_CH1N/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/SYS_WKUP4/TIM15_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/TIM15_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/SPI1_NSS/TIM14_CH1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='TIM15_BKIN/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='TIM1_ETR/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='SPI1_NSS/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/SPI1_MISO/TIM17_BKIN/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TIM16_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/I2C1_SDA/IR_OUT/SPI2_NSS/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/SPI2_SCK/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C2_SDA/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C2_SCL/SPI2_SCK/TIM1_CH1N/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C2_SDA/SPI2_MISO/TIM15_CH1/TIM1_CH2N/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F070F6Px',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x0 Value Line',description='Core: ARM Cortex-M0 Package: TSSOP20 Flash: 32KB Ram: 6KB Frequency: 48MHz Voltage: 2.4..3.6V IO-pins: 15',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/SYS_WKUP4/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/SPI1_NSS/TIM14_CH1/USART2_CK/USB_OE/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='I2C1_SCL/TIM1_CH2/USART1_TX/I2C1_SCL/TIM1_CH4/USART1_CTS/USB_DM/PA11/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/USART1_RX/TIM1_ETR/USART1_DE/USART1_RTS/USB_DP/PA12/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='1',name='BOOT0',do_erc=True),
            Pin(num='2',name='PF0/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='14',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='15',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F070RBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x0 Value Line',description='Core: ARM Cortex-M0 Package: LQFP64 Flash: 128KB Ram: 16KB Frequency: 48MHz Voltage: 2.4..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/RTC_TAMP2/SYS_WKUP1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/TIM15_CH1N/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/SYS_WKUP4/TIM15_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/TIM15_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/SPI1_NSS/TIM14_CH1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='TIM15_BKIN/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='TIM1_ETR/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='SPI1_NSS/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='SPI1_SCK/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='SPI1_MISO/TIM17_BKIN/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/TIM16_CH1/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='I2C1_SDA/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/SPI2_SCK/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C2_SDA/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SPI2_NSS/TIM15_BKIN/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2C2_SCL/SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2C2_SDA/SPI2_MISO/TIM15_CH1/TIM1_CH2N/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/SYS_WKUP5/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/USART3_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/USART3_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/USART3_CK/USART4_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F071CBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: LQFP48 Flash: 128KB Ram: 16KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F071CBUx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: UFQFPN48 Flash: 128KB Ram: 16KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F071CBYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: WLCSP49 Flash: 128KB Ram: 16KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='F6',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='NRST',do_erc=True),
            Pin(num='A5',name='BOOT0',do_erc=True),
            Pin(num='B6',name='NC',func=Pin.PWRIN,do_erc=True),
            Pin(num='B7',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='PF0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='D6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='D5',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PB2/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PB4/I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='PB8/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PB9/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PB10/CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PB11/I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PB12/I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PB13/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PB14/I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='PB15/I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='B2',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='A6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='B1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F071RBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: LQFP64 Flash: 128KB Ram: 16KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/I2S2_MCK/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/I2S2_SD/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/SYS_WKUP5/TSC_G3_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/USART3_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/USART3_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/USART3_CK/USART4_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F071V8Hx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: UFBGA100 Flash: 64KB Ram: 16KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 87',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F071VBHx'],pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/I2S2_MCK/SPI2_MISO/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/I2S2_SD/SPI2_MOSI/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/USART3_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/SYS_WKUP5/TSC_G3_IO1/USART3_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='USART3_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='USART3_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='USART3_CK/USART4_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='NC',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PF0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='J1',name='PF2/SYS_WKUP8',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PF9/DAC_EXTI9/TIM15_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PF10/TIM15_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/TIM16_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/TIM3_ETR/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/TIM3_CH1/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/TIM3_CH2/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/TIM3_CH3/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/DAC_EXTI9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/I2S1_WS/SPI1_NSS/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/I2S1_CK/SPI1_SCK/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/I2S1_MCK/SPI1_MISO/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/I2S1_SD/SPI1_MOSI/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0/I2S2_WS/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/I2S2_MCK/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9/DAC_EXTI9/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/TSC_G8_IO1/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/CRS_SYNC/TSC_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F071V8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: LQFP100 Flash: 64KB Ram: 16KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 87',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F071VBTx'],pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/I2S2_MCK/SPI2_MISO/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/I2S2_SD/SPI2_MOSI/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/USART3_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/SYS_WKUP5/TSC_G3_IO1/USART3_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='USART3_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='USART3_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='USART3_CK/USART4_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PF0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='19',name='PF2/SYS_WKUP8',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF9/DAC_EXTI9/TIM15_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF10/TIM15_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/TIM16_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/TIM3_ETR/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/TIM3_CH1/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/TIM3_CH2/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/TIM3_CH3/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/I2S1_WS/SPI1_NSS/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/I2S1_CK/SPI1_SCK/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/I2S1_MCK/SPI1_MISO/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/I2S1_SD/SPI1_MOSI/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/I2S2_WS/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/I2S2_MCK/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/TSC_G8_IO1/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/CRS_SYNC/TSC_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F072C8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x2',description='Core: ARM Cortex-M0 Package: LQFP48 Flash: 64KB Ram: 16KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F072CBTx'],pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='CAN_RX/COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN_TX/COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/CAN_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F072C8Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x2',description='Core: ARM Cortex-M0 Package: UFQFPN48 Flash: 64KB Ram: 16KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F072CBUx'],pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='CAN_RX/COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN_TX/COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/CAN_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F072CBYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x2',description='Core: ARM Cortex-M0 Package: WLCSP49 Flash: 128KB Ram: 16KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='F6',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='CAN_RX/COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='CAN_TX/COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='NRST',do_erc=True),
            Pin(num='A5',name='BOOT0',do_erc=True),
            Pin(num='B6',name='NC',func=Pin.PWRIN,do_erc=True),
            Pin(num='B7',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='PF0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='D6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='D5',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PB2/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PB4/I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='PB8/CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PB9/CAN_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PB10/CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PB11/I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PB12/I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PB13/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PB14/I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='PB15/I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='B2',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='A6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='B1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F072R8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x2',description='Core: ARM Cortex-M0 Package: LQFP64 Flash: 64KB Ram: 16KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F072RBTx'],pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='CAN_RX/COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN_TX/COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/I2S2_MCK/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/I2S2_SD/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/SYS_WKUP5/TSC_G3_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/USART3_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/USART3_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/USART3_CK/USART4_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F072RBHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x2',description='Core: ARM Cortex-M0 Package: UFBGA64 Flash: 128KB Ram: 16KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='G2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='CAN_RX/COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='CAN_TX/COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='CAN_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='B4',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='PF0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='B5',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC0/ADC_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC1/ADC_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC2/ADC_IN12/I2S2_MCK/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PC3/ADC_IN13/I2S2_SD/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC_IN14/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC5/ADC_IN15/SYS_WKUP5/TSC_G3_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC9/DAC_EXTI9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC10/USART3_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC11/USART3_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC12/USART3_CK/USART4_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F072RBIx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x2',description='Core: ARM Cortex-M0 Package: UFBGA64 Flash: 128KB Ram: 16KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='G2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='CAN_RX/COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='CAN_TX/COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='CAN_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='B4',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='PF0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='B5',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC0/ADC_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC1/ADC_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC2/ADC_IN12/I2S2_MCK/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PC3/ADC_IN13/I2S2_SD/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC_IN14/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC5/ADC_IN15/SYS_WKUP5/TSC_G3_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC9/DAC_EXTI9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC10/USART3_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC11/USART3_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC12/USART3_CK/USART4_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F072V8Hx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x2',description='Core: ARM Cortex-M0 Package: UFBGA100 Flash: 64KB Ram: 16KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 87',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F072VBHx'],pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN_RX/COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='CAN_TX/COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='CAN_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/I2S2_MCK/SPI2_MISO/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/I2S2_SD/SPI2_MOSI/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/USART3_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/SYS_WKUP5/TSC_G3_IO1/USART3_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='USART3_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='USART3_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='USART3_CK/USART4_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='NC',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PF0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='J1',name='PF2/SYS_WKUP8',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PF9/DAC_EXTI9/TIM15_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PF10/TIM15_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/TIM16_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/TIM3_ETR/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/TIM3_CH1/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/TIM3_CH2/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/TIM3_CH3/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/DAC_EXTI9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/I2S1_WS/SPI1_NSS/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/I2S1_CK/SPI1_SCK/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/I2S1_MCK/SPI1_MISO/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/I2S1_SD/SPI1_MOSI/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0/CAN_RX/I2S2_WS/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1/CAN_TX/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/I2S2_MCK/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9/DAC_EXTI9/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/TSC_G8_IO1/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/CRS_SYNC/TSC_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F072V8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x2',description='Core: ARM Cortex-M0 Package: LQFP100 Flash: 64KB Ram: 16KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 87',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F072VBTx'],pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='CAN_RX/COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN_TX/COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/I2S2_MCK/SPI2_MISO/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/I2S2_SD/SPI2_MOSI/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/USART3_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/SYS_WKUP5/TSC_G3_IO1/USART3_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='USART3_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='USART3_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='USART3_CK/USART4_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PF0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='19',name='PF2/SYS_WKUP8',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF9/DAC_EXTI9/TIM15_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF10/TIM15_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/TIM16_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/TIM3_ETR/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/TIM3_CH1/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/TIM3_CH2/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/TIM3_CH3/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/I2S1_WS/SPI1_NSS/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/I2S1_CK/SPI1_SCK/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/I2S1_MCK/SPI1_MISO/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/I2S1_SD/SPI1_MOSI/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN_RX/I2S2_WS/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN_TX/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/I2S2_MCK/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/TSC_G8_IO1/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/CRS_SYNC/TSC_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F078CBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x8',description='Core: ARM Cortex-M0 Package: LQFP48 Flash: 128KB Ram: 16KB Frequency: 48MHz Voltage: 1.65..1.95V IO-pins: 36',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='NPOR',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F078CBUx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x8',description='Core: ARM Cortex-M0 Package: UFQFPN48 Flash: 128KB Ram: 16KB Frequency: 48MHz Voltage: 1.65..1.95V IO-pins: 36',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='NPOR',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F078CBYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x8',description='Core: ARM Cortex-M0 Package: WLCSP49 Flash: 128KB Ram: 16KB Frequency: 48MHz Voltage: 1.65..1.95V IO-pins: 36',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='F6',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='NRST',do_erc=True),
            Pin(num='A5',name='BOOT0',do_erc=True),
            Pin(num='B6',name='NC',func=Pin.PWRIN,do_erc=True),
            Pin(num='B7',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='G3',name='NPOR',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='PF0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='D6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='D5',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PB4/I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='PB8/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PB9/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PB10/CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PB11/I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PB12/I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PB13/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PB14/I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='PB15/I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='B2',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='A6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='B1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F078RBHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x8',description='Core: ARM Cortex-M0 Package: UFBGA64 Flash: 128KB Ram: 16KB Frequency: 48MHz Voltage: 1.65..1.95V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='G2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='B4',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='NPOR',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='PF0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='B5',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC0/ADC_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC1/ADC_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC2/ADC_IN12/I2S2_MCK/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PC3/ADC_IN13/I2S2_SD/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC_IN14/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC5/ADC_IN15/SYS_WKUP5/TSC_G3_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC9/DAC_EXTI9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC10/USART3_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC11/USART3_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC12/USART3_CK/USART4_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F078RBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x8',description='Core: ARM Cortex-M0 Package: LQFP64 Flash: 128KB Ram: 16KB Frequency: 48MHz Voltage: 1.65..1.95V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='NPOR',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/I2S2_MCK/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/I2S2_SD/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/SYS_WKUP5/TSC_G3_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/USART3_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/USART3_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/USART3_CK/USART4_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F078VBHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x8',description='Core: ARM Cortex-M0 Package: UFBGA100 Flash: 128KB Ram: 16KB Frequency: 48MHz Voltage: 1.65..1.95V IO-pins: 86',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/I2S2_MCK/SPI2_MISO/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/I2S2_SD/SPI2_MOSI/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/USART3_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/SYS_WKUP5/TSC_G3_IO1/USART3_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='USART3_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='USART3_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='USART3_CK/USART4_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='NC',func=Pin.PWRIN,do_erc=True),
            Pin(num='L6',name='NPOR',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PF0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='J1',name='PF2/SYS_WKUP8',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PF9/DAC_EXTI9/TIM15_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PF10/TIM15_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/TIM16_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/TIM3_ETR/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/TIM3_CH1/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/TIM3_CH2/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/TIM3_CH3/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/DAC_EXTI9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/I2S1_WS/SPI1_NSS/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/I2S1_CK/SPI1_SCK/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/I2S1_MCK/SPI1_MISO/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/I2S1_SD/SPI1_MOSI/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0/I2S2_WS/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/I2S2_MCK/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9/DAC_EXTI9/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/TSC_G8_IO1/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/CRS_SYNC/TSC_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F078VBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x8',description='Core: ARM Cortex-M0 Package: LQFP100 Flash: 128KB Ram: 16KB Frequency: 48MHz Voltage: 1.65..1.95V IO-pins: 86',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='COMP1_OUT/TIM1_CH4/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='COMP2_OUT/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='IR_OUT/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/I2S2_MCK/SPI2_MISO/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/I2S2_SD/SPI2_MOSI/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/USART3_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/SYS_WKUP5/TSC_G3_IO1/USART3_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='USART3_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='USART3_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='USART3_CK/USART4_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='37',name='NPOR',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PF0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='19',name='PF2/SYS_WKUP8',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF9/DAC_EXTI9/TIM15_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF10/TIM15_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/TIM16_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/TIM3_ETR/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/TIM3_CH1/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/TIM3_CH2/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/TIM3_CH3/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/I2S1_WS/SPI1_NSS/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/I2S1_CK/SPI1_SCK/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/I2S1_MCK/SPI1_MISO/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/I2S1_SD/SPI1_MOSI/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/I2S2_WS/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/I2S2_MCK/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/TSC_G8_IO1/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/CRS_SYNC/TSC_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F091CBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: LQFP48 Flash: 128KB Ram: 32KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 38',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F091CCTx'],pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USART6_TX/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/USART6_RX/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/I2C1_SCL/RCC_MCO/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='CAN_RX/COMP1_OUT/I2C2_SCL/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN_TX/COMP2_OUT/I2C2_SDA/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='44',name='PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/CAN_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F091CBUx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: UFQFPN48 Flash: 128KB Ram: 32KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 38',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F091CCUx'],pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USART6_TX/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/USART6_RX/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/I2C1_SCL/RCC_MCO/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='CAN_RX/COMP1_OUT/I2C2_SCL/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN_TX/COMP2_OUT/I2C2_SDA/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='44',name='PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/CAN_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F091RBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: LQFP64 Flash: 128KB Ram: 32KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 52',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F091RCTx'],pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USART6_TX/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/USART6_RX/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/I2C1_SCL/RCC_MCO/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='CAN_RX/COMP1_OUT/I2C2_SCL/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN_TX/COMP2_OUT/I2C2_SDA/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='60',name='PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/USART6_TX/USART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/USART6_RX/USART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/I2S2_MCK/SPI2_MISO/USART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/I2S2_SD/SPI2_MOSI/USART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/SYS_WKUP5/TSC_G3_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1/USART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2/USART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3/USART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/TIM3_CH4/USART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/USART3_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/USART3_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/USART3_CK/USART4_CK/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F091RCHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: UFBGA64 Flash: 256KB Ram: 32KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 52',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='G2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USART6_TX/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/USART6_RX/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='DAC_EXTI9/I2C1_SCL/RCC_MCO/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='CAN_RX/COMP1_OUT/I2C2_SCL/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='CAN_TX/COMP2_OUT/I2C2_SDA/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='CAN_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='B2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='B4',name='PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC0/ADC_IN10/USART6_TX/USART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC1/ADC_IN11/USART6_RX/USART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC2/ADC_IN12/I2S2_MCK/SPI2_MISO/USART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PC3/ADC_IN13/I2S2_SD/SPI2_MOSI/USART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC_IN14/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC5/ADC_IN15/SYS_WKUP5/TSC_G3_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC6/TIM3_CH1/USART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC7/TIM3_CH2/USART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC8/TIM3_CH3/USART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC9/DAC_EXTI9/TIM3_CH4/USART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC10/USART3_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC11/USART3_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC12/USART3_CK/USART4_CK/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F091RCYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: WLCSP64 Flash: 256KB Ram: 32KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 52',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='F7',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USART6_TX/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/USART6_RX/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='DAC_EXTI9/I2C1_SCL/RCC_MCO/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='CAN_RX/COMP1_OUT/I2C2_SCL/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='CAN_TX/COMP2_OUT/I2C2_SDA/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='NRST',do_erc=True),
            Pin(num='B8',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='D8',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='E8',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='C6',name='PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC0/ADC_IN10/USART6_TX/USART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='PC1/ADC_IN11/USART6_RX/USART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PC2/ADC_IN12/I2S2_MCK/SPI2_MISO/USART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E6',name='PC3/ADC_IN13/I2S2_SD/SPI2_MOSI/USART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC_IN14/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='PC5/ADC_IN15/SYS_WKUP5/TSC_G3_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='PC6/TIM3_CH1/USART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='PC7/TIM3_CH2/USART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC8/TIM3_CH3/USART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC9/DAC_EXTI9/TIM3_CH4/USART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PC10/USART3_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PC11/USART3_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PC12/USART3_CK/USART4_CK/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='A1',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='A7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='B2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F091VBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: LQFP100 Flash: 128KB Ram: 32KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 88',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F091VCTx'],pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USART6_TX/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/USART6_RX/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/I2C1_SCL/RCC_MCO/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='CAN_RX/COMP1_OUT/I2C2_SCL/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN_TX/COMP2_OUT/I2C2_SDA/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/USART6_TX/USART7_TX/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/USART6_RX/USART7_RX/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/I2S2_MCK/SPI2_MISO/USART8_TX/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/I2S2_SD/SPI2_MOSI/USART8_RX/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/USART3_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/SYS_WKUP5/TSC_G3_IO1/USART3_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='TIM3_CH1/USART7_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='TIM3_CH2/USART7_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM3_CH3/USART8_TX/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/TIM3_CH4/USART8_RX/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='USART3_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='USART3_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='USART3_CK/USART4_CK/USART5_TX/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='19',name='PF2/SYS_WKUP8/USART7_CK/USART7_DE/USART7_RTS/USART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF3/USART6_CK/USART6_DE/USART6_RTS/USART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF9/DAC_EXTI9/TIM15_CH1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF10/TIM15_CH2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='94',name='PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/TIM16_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/TIM3_ETR/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/TIM3_CH1/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/TIM3_CH2/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/TIM3_CH3/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/TIM1_ETR/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/TIM1_CH1N/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/TIM1_CH1/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/TIM1_CH2N/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/TIM1_CH2/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/I2S1_WS/SPI1_NSS/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/I2S1_CK/SPI1_SCK/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/I2S1_MCK/SPI1_MISO/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/I2S1_SD/SPI1_MOSI/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN_RX/I2S2_WS/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN_TX/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/I2S2_MCK/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/TSC_G8_IO1/USART3_DE/USART3_RTS/USART8_CK/USART8_DE/USART8_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/TSC_G8_IO2/USART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/TSC_G8_IO3/USART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/CRS_SYNC/TSC_G8_IO4/USART7_CK/USART7_DE/USART7_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F091VCHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x1',description='Core: ARM Cortex-M0 Package: UFBGA100 Flash: 256KB Ram: 32KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 88',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USART6_TX/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/USART6_RX/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/I2C1_SCL/RCC_MCO/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN_RX/COMP1_OUT/I2C2_SCL/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='CAN_TX/COMP2_OUT/I2C2_SDA/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='CAN_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/USART6_TX/USART7_TX/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/USART6_RX/USART7_RX/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/I2S2_MCK/SPI2_MISO/USART8_TX/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/I2S2_SD/SPI2_MOSI/USART8_RX/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/USART3_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/SYS_WKUP5/TSC_G3_IO1/USART3_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='TIM3_CH1/USART7_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='TIM3_CH2/USART7_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='TIM3_CH3/USART8_TX/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/TIM3_CH4/USART8_RX/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='USART3_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='USART3_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='USART3_CK/USART4_CK/USART5_TX/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='NC',do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='E2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='J1',name='PF2/SYS_WKUP8/USART7_CK/USART7_DE/USART7_RTS/USART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PF3/USART6_CK/USART6_DE/USART6_RTS/USART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PF9/DAC_EXTI9/TIM15_CH1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PF10/TIM15_CH2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/TIM16_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/TIM3_ETR/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/TIM3_CH1/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/TIM3_CH2/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/TIM3_CH3/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/TIM1_ETR/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/TIM1_CH1N/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/DAC_EXTI9/TIM1_CH1/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/TIM1_CH2N/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/TIM1_CH2/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/I2S1_WS/SPI1_NSS/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/I2S1_CK/SPI1_SCK/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/I2S1_MCK/SPI1_MISO/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/I2S1_SD/SPI1_MOSI/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0/CAN_RX/I2S2_WS/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1/CAN_TX/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/I2S2_MCK/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9/DAC_EXTI9/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/TSC_G8_IO1/USART3_DE/USART3_RTS/USART8_CK/USART8_DE/USART8_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13/TSC_G8_IO2/USART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14/TSC_G8_IO3/USART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/CRS_SYNC/TSC_G8_IO4/USART7_CK/USART7_DE/USART7_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F098CCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x8',description='Core: ARM Cortex-M0 Package: LQFP48 Flash: 256KB Ram: 32KB Frequency: 48MHz Voltage: 1.65..1.95V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USART6_TX/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/USART6_RX/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/I2C1_SCL/RCC_MCO/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='CAN_RX/COMP1_OUT/I2C2_SCL/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN_TX/COMP2_OUT/I2C2_SDA/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='NPOR',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='44',name='PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/CAN_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F098CCUx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x8',description='Core: ARM Cortex-M0 Package: UFQFPN48 Flash: 256KB Ram: 32KB Frequency: 48MHz Voltage: 1.65..1.95V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USART6_TX/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/USART6_RX/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/I2C1_SCL/RCC_MCO/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='CAN_RX/COMP1_OUT/I2C2_SCL/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN_TX/COMP2_OUT/I2C2_SDA/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='NPOR',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='44',name='PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/CAN_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F098RCHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x8',description='Core: ARM Cortex-M0 Package: UFBGA64 Flash: 256KB Ram: 32KB Frequency: 48MHz Voltage: 1.65..1.95V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='G2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USART6_TX/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/USART6_RX/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='DAC_EXTI9/I2C1_SCL/RCC_MCO/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='CAN_RX/COMP1_OUT/I2C2_SCL/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='CAN_TX/COMP2_OUT/I2C2_SDA/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='CAN_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='B2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='NPOR',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='B4',name='PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC0/ADC_IN10/USART6_TX/USART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC1/ADC_IN11/USART6_RX/USART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC2/ADC_IN12/I2S2_MCK/SPI2_MISO/USART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PC3/ADC_IN13/I2S2_SD/SPI2_MOSI/USART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC_IN14/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC5/ADC_IN15/SYS_WKUP5/TSC_G3_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC6/TIM3_CH1/USART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC7/TIM3_CH2/USART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC8/TIM3_CH3/USART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC9/DAC_EXTI9/TIM3_CH4/USART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC10/USART3_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC11/USART3_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC12/USART3_CK/USART4_CK/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F098RCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x8',description='Core: ARM Cortex-M0 Package: LQFP64 Flash: 256KB Ram: 32KB Frequency: 48MHz Voltage: 1.65..1.95V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USART6_TX/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/USART6_RX/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/I2C1_SCL/RCC_MCO/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='CAN_RX/COMP1_OUT/I2C2_SCL/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN_TX/COMP2_OUT/I2C2_SDA/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='NPOR',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='60',name='PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/USART6_TX/USART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/USART6_RX/USART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/I2S2_MCK/SPI2_MISO/USART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/I2S2_SD/SPI2_MOSI/USART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/SYS_WKUP5/TSC_G3_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1/USART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2/USART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3/USART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/TIM3_CH4/USART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/USART3_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/USART3_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/USART3_CK/USART4_CK/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F098RCYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x8',description='Core: ARM Cortex-M0 Package: WLCSP64 Flash: 256KB Ram: 32KB Frequency: 48MHz Voltage: 1.65..1.95V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='F7',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USART6_TX/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/USART6_RX/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='DAC_EXTI9/I2C1_SCL/RCC_MCO/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='CAN_RX/COMP1_OUT/I2C2_SCL/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='CAN_TX/COMP2_OUT/I2C2_SDA/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='NRST',do_erc=True),
            Pin(num='B8',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='H4',name='NPOR',func=Pin.PWRIN,do_erc=True),
            Pin(num='D8',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='E8',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='C6',name='PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC0/ADC_IN10/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='PC1/ADC_IN11/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PC2/ADC_IN12/I2S2_MCK/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='E6',name='PC3/ADC_IN13/I2S2_SD/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC_IN14/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='PC5/ADC_IN15/SYS_WKUP5/TSC_G3_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC9/DAC_EXTI9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PC10/USART3_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PC11/USART3_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PC12/USART3_CK/USART4_CK/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='A1',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='A7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='B2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F098VCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0 STM32F0 STM32F0x8',description='Core: ARM Cortex-M0 Package: LQFP100 Flash: 256KB Ram: 32KB Frequency: 48MHz Voltage: 1.65..1.95V IO-pins: 87',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP2_INM/COMP2_OUT/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP2_INP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/I2S1_WS/SPI1_NSS/TIM14_CH1/TSC_G2_IO1/USART2_CK/USART6_TX/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/CEC/COMP1_INM/COMP2_INM/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/USART6_RX/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_OUT/I2S1_MCK/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='CRS_SYNC/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/I2C1_SCL/RCC_MCO/TIM15_BKIN/TIM1_CH2/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C1_SDA/TIM17_BKIN/TIM1_CH3/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='CAN_RX/COMP1_OUT/I2C2_SCL/TIM1_CH4/TSC_G4_IO3/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN_TX/COMP2_OUT/I2C2_SDA/TIM1_ETR/TSC_G4_IO4/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='IR_OUT/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='I2S1_WS/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S1_CK/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S1_MCK/SPI1_MISO/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/I2S1_SD/SPI1_MOSI/SYS_WKUP6/TIM16_BKIN/TIM3_CH2/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN_RX/CEC/I2C1_SCL/TIM16_CH1/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='CEC/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='I2C2_SDA/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2S2_WS/SPI2_NSS/TIM15_BKIN/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2C2_SDA/I2S2_MCK/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/SYS_WKUP7/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/USART6_TX/USART7_TX/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/USART6_RX/USART7_RX/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/I2S2_MCK/SPI2_MISO/USART8_TX/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/I2S2_SD/SPI2_MOSI/USART8_RX/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/USART3_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/SYS_WKUP5/TSC_G3_IO1/USART3_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='TIM3_CH1/USART7_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='TIM3_CH2/USART7_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM3_CH3/USART8_TX/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/TIM3_CH4/USART8_RX/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='USART3_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='USART3_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='USART3_CK/USART4_CK/USART5_TX/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='37',name='NPOR',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PF0/CRS_SYNC/I2C1_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PF1/I2C1_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='19',name='PF2/SYS_WKUP8/USART7_CK/USART7_DE/USART7_RTS/USART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF3/USART6_CK/USART6_DE/USART6_RTS/USART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF9/DAC_EXTI9/TIM15_CH1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF10/TIM15_CH2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='94',name='PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/TIM16_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/TIM3_ETR/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/TIM3_CH1/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/TIM3_CH2/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/TIM3_CH3/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/TIM1_ETR/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/TIM1_CH1N/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/TIM1_CH1/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/TIM1_CH2N/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/TIM1_CH2/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/I2S1_WS/SPI1_NSS/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/I2S1_CK/SPI1_SCK/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/I2S1_MCK/SPI1_MISO/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/I2S1_SD/SPI1_MOSI/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN_RX/I2S2_WS/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN_TX/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/TIM3_ETR/USART3_DE/USART3_RTS/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/I2S2_MCK/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/TSC_G8_IO1/USART3_DE/USART3_RTS/USART8_CK/USART8_DE/USART8_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/TSC_G8_IO2/USART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/TSC_G8_IO3/USART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/CRS_SYNC/TSC_G8_IO4/USART7_CK/USART7_DE/USART7_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F100C4Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F100 Value Line',description='Core: ARM Cortex-M3 Package: LQFP48 Flash: 16KB Ram: 4KB Frequency: 24MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F100C6Tx'],pins=[
            Pin(num='10',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN2/TIM15_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN3/TIM15_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN6/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN7/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='TIM1_ETR/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC1_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC1_IN9/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/SPI1_MISO/SYS_NJTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CEC/I2C1_SCL/TIM16_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/CEC/TIM2_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC1_EXTI11/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/TIM15_CH1/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC1_EXTI15/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F100C8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F100 Value Line',description='Core: ARM Cortex-M3 Package: LQFP48 Flash: 64KB Ram: 8KB Frequency: 24MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F100CBTx'],pins=[
            Pin(num='10',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN2/TIM15_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN3/TIM15_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN6/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN7/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='TIM1_ETR/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC1_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC1_IN9/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/SPI1_MISO/SYS_NJTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/SPI1_MOSI/TIM16_BKIN/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TIM4_CH1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TIM4_CH2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CEC/I2C1_SCL/TIM16_CH1/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/TIM17_CH1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/CEC/I2C2_SCL/TIM2_CH3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC1_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2C2_SMBA/SPI2_NSS/TIM1_BKIN/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/SPI2_SCK/TIM1_CH1N/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/SPI2_MISO/TIM15_CH1/TIM1_CH2N/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC1_EXTI15/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F100R4Hx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F100 Value Line',description='Core: ARM Cortex-M3 Package: TFBGA64 Flash: 16KB Ram: 4KB Frequency: 24MHz Voltage: 2..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F100R6Hx'],pins=[
            Pin(num='G2',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC1_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC1_IN2/TIM15_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC1_IN3/TIM15_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC1_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC1_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC1_IN6/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC1_IN7/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='ADC1_EXTI11/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='TIM1_ETR/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='ADC1_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC1_IN8/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC1_IN9/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='SPI1_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='I2C1_SMBA/SPI1_MOSI/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='I2C1_SCL/TIM16_CH1N/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='I2C1_SDA/TIM17_CH1N/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='CEC/I2C1_SCL/TIM16_CH1/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DAC_EXTI9/I2C1_SDA/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='CEC/TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC1_EXTI11/TIM2_CH4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='TIM1_BKIN/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='TIM1_CH1N/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='TIM15_CH1/TIM1_CH2N/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='ADC1_EXTI15/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='B4',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='B5',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC0/ADC1_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC1/ADC1_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC2/ADC1_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC1_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC5/ADC1_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC9/DAC_EXTI9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC11/ADC1_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F100R4Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F100 Value Line',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 16KB Ram: 4KB Frequency: 24MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F100R6Tx'],pins=[
            Pin(num='14',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/TIM15_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/TIM15_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='TIM1_ETR/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='SPI1_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/SPI1_MOSI/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CEC/I2C1_SCL/TIM16_CH1/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/TIM17_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CEC/TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/TIM2_CH4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='TIM1_BKIN/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='TIM1_CH1N/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='TIM15_CH1/TIM1_CH2N/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F100R8Hx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F100 Value Line',description='Core: ARM Cortex-M3 Package: TFBGA64 Flash: 64KB Ram: 8KB Frequency: 24MHz Voltage: 2..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F100RBHx'],pins=[
            Pin(num='G2',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC1_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC1_IN2/TIM15_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC1_IN3/TIM15_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC1_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC1_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC1_IN6/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC1_IN7/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='ADC1_EXTI11/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='TIM1_ETR/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='ADC1_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC1_IN8/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC1_IN9/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='SPI1_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='I2C1_SMBA/SPI1_MOSI/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='I2C1_SCL/TIM16_CH1N/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='I2C1_SDA/TIM17_CH1N/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='CEC/I2C1_SCL/TIM16_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DAC_EXTI9/I2C1_SDA/TIM17_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='CEC/I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC1_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='I2C2_SMBA/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='SPI2_MISO/TIM15_CH1/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='ADC1_EXTI15/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='B4',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='B5',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC0/ADC1_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC1/ADC1_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC2/ADC1_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC1_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC5/ADC1_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC9/DAC_EXTI9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC10/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC11/ADC1_EXTI11/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC12/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F100R8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F100 Value Line',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 64KB Ram: 8KB Frequency: 24MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F100RBTx'],pins=[
            Pin(num='14',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/TIM15_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/TIM15_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='TIM1_ETR/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='SPI1_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/SPI1_MOSI/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CEC/I2C1_SCL/TIM16_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/TIM17_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CEC/I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2C2_SMBA/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='SPI2_MISO/TIM15_CH1/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F100RCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F100 Value Line',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 256KB Ram: 24KB Frequency: 24MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F100RDTx', 'STM32F100RETx'],pins=[
            Pin(num='14',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/TIM15_CH1/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/TIM15_CH2/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='TIM1_ETR/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/TIM13_CH1/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CEC/I2C1_SCL/TIM16_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/TIM17_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CEC/I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2C2_SMBA/SPI2_NSS/TIM12_CH1/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SPI2_SCK/TIM12_CH2/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='SPI2_MISO/TIM15_CH1/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM13_CH1/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/TIM14_CH1/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F100V8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F100 Value Line',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 64KB Ram: 8KB Frequency: 24MHz Voltage: 2..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F100VBTx'],pins=[
            Pin(num='23',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/TIM15_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/TIM15_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='TIM1_ETR/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='SPI1_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/SPI1_MOSI/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM16_CH1N/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/TIM17_CH1N/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CEC/I2C1_SCL/TIM16_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/TIM17_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='CEC/I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2C2_SMBA/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='SPI2_MISO/TIM15_CH1/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT/RTC_TAMPER/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='97',name='PE0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/SYS_TRACED3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F100VCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F100 Value Line',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 256KB Ram: 24KB Frequency: 24MHz Voltage: 2..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F100VDTx', 'STM32F100VETx'],pins=[
            Pin(num='23',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/TIM15_CH1/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/TIM15_CH2/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='TIM1_ETR/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/TIM13_CH1/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM16_CH1N/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='FSMC_NL/I2C1_SDA/TIM17_CH1N/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CEC/I2C1_SCL/TIM16_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/TIM17_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='CEC/I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2C2_SMBA/SPI2_NSS/TIM12_CH1/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='SPI2_SCK/TIM12_CH2/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='SPI2_MISO/TIM15_CH1/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/TIM12_CH1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/TIM12_CH2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM13_CH1/TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/TIM14_CH1/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT/RTC_TAMPER/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='97',name='PE0/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FSMC_A22/SYS_TRACED3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/FSMC_D2/FSMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/FSMC_D3/FSMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/FSMC_CLK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FSMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FSMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/FSMC_NWAIT/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FSMC_NE1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FSMC_D13/FSMC_DA13/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FSMC_D15/FSMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/FSMC_A16/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FSMC_A17/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FSMC_A18/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FSMC_D0/FSMC_DA0/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F100ZCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F100 Value Line',description='Core: ARM Cortex-M3 Package: LQFP144 Flash: 256KB Ram: 24KB Frequency: 24MHz Voltage: 2..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F100ZDTx', 'STM32F100ZETx'],pins=[
            Pin(num='34',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN2/TIM15_CH1/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN3/TIM15_CH2/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN6/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN7/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/TIM15_BKIN/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='TIM17_BKIN/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='TIM1_ETR/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC1_EXTI15/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN8/TIM13_CH1/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN9/TIM14_CH1/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='I2C1_SMBA/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='I2C1_SCL/TIM16_CH1N/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='FSMC_NL/I2C1_SDA/TIM17_CH1N/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CEC/I2C1_SCL/TIM16_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='DAC_EXTI9/I2C1_SDA/TIM17_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='CEC/I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='I2C2_SMBA/SPI2_NSS/TIM12_CH1/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='SPI2_SCK/TIM12_CH2/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='SPI2_MISO/TIM15_CH1/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN12/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN13/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN14/TIM12_CH1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN15/TIM12_CH2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='TIM13_CH1/TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/TIM14_CH1/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT/RTC_TAMPER/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/FSMC_A16/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FSMC_A17/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC1_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='RCC_OSC_OUT',do_erc=True),
            Pin(num='106',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='56',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/FSMC_NE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FSMC_NE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/FSMC_A24',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/FSMC_A25',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC1_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FSMC_A0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FSMC_A1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FSMC_A2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC1_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FSMC_A22/SYS_TRACED3',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC1_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='143',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F101C8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F101',description='Core: ARM Cortex-M3 Package: LQFP48 Flash: 64KB Ram: 10KB Frequency: 36MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F101CBTx'],pins=[
            Pin(num='10',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN6/SPI1_MISO/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN7/SPI1_MOSI/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC1_IN8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC1_IN9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/SPI1_MISO/SYS_NJTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/SPI1_MOSI/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM4_CH1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM4_CH2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/I2C1_SDA/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/TIM2_CH3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC1_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2C2_SMBA/SPI2_NSS/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/SPI2_SCK/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/SPI2_MISO/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC1_EXTI15/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F101C6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F101',description='Core: ARM Cortex-M3 Package: LQFP48 Flash: 32KB Ram: 6KB Frequency: 36MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN6/SPI1_MISO/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN7/SPI1_MOSI/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC1_IN8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC1_IN9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/SPI1_MISO/SYS_NJTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/SPI1_MOSI/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/I2C1_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/TIM2_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC1_EXTI11/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC1_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F101CBUx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F101',description='Core: ARM Cortex-M3 Package: UFQFPN48 Flash: 128KB Ram: 16KB Frequency: 36MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN6/SPI1_MISO/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN7/SPI1_MOSI/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC1_IN8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC1_IN9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/SPI1_MISO/SYS_NJTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/SPI1_MOSI/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM4_CH1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM4_CH2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/I2C1_SDA/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/TIM2_CH3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC1_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2C2_SMBA/SPI2_NSS/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/SPI2_SCK/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/SPI2_MISO/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC1_EXTI15/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F101R4Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F101',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 16KB Ram: 4KB Frequency: 36MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F101R6Tx'],pins=[
            Pin(num='14',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/SPI1_MISO/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/SPI1_MOSI/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='SPI1_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/SPI1_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='I2C1_SDA/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/TIM2_CH4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F101R8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F101',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 64KB Ram: 10KB Frequency: 36MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F101RBTx'],pins=[
            Pin(num='14',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/SPI1_MISO/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/SPI1_MOSI/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='SPI1_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/SPI1_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='I2C1_SDA/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2C2_SMBA/SPI2_NSS/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SPI2_SCK/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='SPI2_MISO/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F101RCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F101',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 256KB Ram: 32KB Frequency: 36MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F101RDTx', 'STM32F101RETx'],pins=[
            Pin(num='14',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/SPI1_MISO/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/SPI1_MOSI/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2C2_SMBA/SPI2_NSS/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SPI2_SCK/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='SPI2_MISO/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F101RFTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F101',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 768KB Ram: 80KB Frequency: 36MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F101RGTx'],pins=[
            Pin(num='14',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/SPI1_MISO/TIM13_CH1/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/SPI1_MOSI/TIM14_CH1/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2C2_SMBA/SPI2_NSS/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SPI2_SCK/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='SPI2_MISO/TIM12_CH1/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/SPI2_MOSI/TIM12_CH2/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F101RBHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F101',description='Core: ARM Cortex-M3 Package: TFBGA64 Flash: 128KB Ram: 16KB Frequency: 36MHz Voltage: 2..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='G2',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC1_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC1_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC1_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC1_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC1_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC1_IN6/SPI1_MISO/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC1_IN7/SPI1_MOSI/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='ADC1_EXTI11/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='ADC1_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC1_IN8/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC1_IN9/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='SPI1_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='I2C1_SMBA/SPI1_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='I2C1_SCL/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SDA/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC1_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='I2C2_SMBA/SPI2_NSS/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='SPI2_SCK/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='SPI2_MISO/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='ADC1_EXTI15/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='B4',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='B5',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC0/ADC1_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC1/ADC1_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC2/ADC1_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC1_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC5/ADC1_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC10/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC11/ADC1_EXTI11/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC12/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F101T4Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F101',description='Core: ARM Cortex-M3 Package: VFQFPN36 Flash: 16KB Ram: 4KB Frequency: 36MHz Voltage: 2..3.6V IO-pins: 26',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F101T6Ux'],pins=[
            Pin(num='7',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC1_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC1_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN6/SPI1_MISO/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN7/SPI1_MOSI/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_EXTI11/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='35',name='BOOT0',do_erc=True),
            Pin(num='2',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='15',name='PB0/ADC1_IN8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PB1/ADC1_IN9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB3/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='PB4/SPI1_MISO/SYS_NJTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PB5/I2C1_SMBA/SPI1_MOSI/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='PB6/I2C1_SCL/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='PB7/I2C1_SDA/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='37',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F101T8Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F101',description='Core: ARM Cortex-M3 Package: VFQFPN36 Flash: 64KB Ram: 10KB Frequency: 36MHz Voltage: 2..3.6V IO-pins: 26',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F101TBUx'],pins=[
            Pin(num='7',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC1_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC1_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN6/SPI1_MISO/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN7/SPI1_MOSI/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_EXTI11/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='35',name='BOOT0',do_erc=True),
            Pin(num='2',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='15',name='PB0/ADC1_IN8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PB1/ADC1_IN9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB3/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='PB4/SPI1_MISO/SYS_NJTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PB5/I2C1_SMBA/SPI1_MOSI/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='PB6/I2C1_SCL/TIM4_CH1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='PB7/I2C1_SDA/TIM4_CH2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='37',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F101V8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F101',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 64KB Ram: 10KB Frequency: 36MHz Voltage: 2..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F101VBTx'],pins=[
            Pin(num='23',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/SPI1_MISO/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/SPI1_MOSI/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='SPI1_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/SPI1_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='I2C1_SDA/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2C2_SMBA/SPI2_NSS/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='SPI2_SCK/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='SPI2_MISO/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT/RTC_TAMPER/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='97',name='PE0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/SYS_TRACED3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F101VCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F101',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 256KB Ram: 32KB Frequency: 36MHz Voltage: 2..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F101VDTx', 'STM32F101VETx'],pins=[
            Pin(num='23',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/SPI1_MISO/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/SPI1_MOSI/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2C2_SMBA/SPI2_NSS/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='SPI2_SCK/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='SPI2_MISO/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT/RTC_TAMPER/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='97',name='PE0/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FSMC_A22/SYS_TRACED3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/FSMC_D4/FSMC_DA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/FSMC_D5/FSMC_DA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/FSMC_D7/FSMC_DA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/FSMC_D8/FSMC_DA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/FSMC_D9/FSMC_DA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/FSMC_D10/FSMC_DA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FSMC_D11/FSMC_DA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/FSMC_D12/FSMC_DA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/FSMC_D2/FSMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/FSMC_D3/FSMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/FSMC_CLK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FSMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FSMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/FSMC_NWAIT/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FSMC_NCE2/FSMC_NE1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FSMC_D13/FSMC_DA13/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FSMC_D15/FSMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FSMC_A18/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FSMC_D0/FSMC_DA0/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F101VFTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F101',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 768KB Ram: 80KB Frequency: 36MHz Voltage: 2..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F101VGTx'],pins=[
            Pin(num='23',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/SPI1_MISO/TIM13_CH1/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/SPI1_MOSI/TIM14_CH1/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2C2_SMBA/SPI2_NSS/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='SPI2_SCK/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='SPI2_MISO/TIM12_CH1/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/SPI2_MOSI/TIM12_CH2/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT/RTC_TAMPER/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='97',name='PE0/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FSMC_A22/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/FSMC_D4/FSMC_DA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/FSMC_D5/FSMC_DA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/FSMC_D7/FSMC_DA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/FSMC_D8/FSMC_DA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/FSMC_D9/FSMC_DA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/FSMC_D10/FSMC_DA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FSMC_D11/FSMC_DA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/FSMC_D12/FSMC_DA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/FSMC_D2/FSMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/FSMC_D3/FSMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/FSMC_CLK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FSMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FSMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/FSMC_NWAIT/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FSMC_NCE2/FSMC_NE1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FSMC_D13/FSMC_DA13/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FSMC_D15/FSMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FSMC_A18/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FSMC_D0/FSMC_DA0/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F101ZCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F101',description='Core: ARM Cortex-M3 Package: LQFP144 Flash: 256KB Ram: 32KB Frequency: 36MHz Voltage: 2..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F101ZDTx', 'STM32F101ZETx'],pins=[
            Pin(num='34',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN2/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN3/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN6/SPI1_MISO/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN7/SPI1_MOSI/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC1_EXTI15/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN8/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN9/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='I2C1_SMBA/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='I2C1_SCL/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='DAC_EXTI9/I2C1_SDA/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='I2C2_SMBA/SPI2_NSS/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='SPI2_SCK/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='SPI2_MISO/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN12/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN13/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT/RTC_TAMPER/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FSMC_NCE2/FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC1_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='RCC_OSC_OUT',do_erc=True),
            Pin(num='106',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='56',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/FSMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/FSMC_INT3',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/FSMC_NCE3/FSMC_NE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/FSMC_NCE4_1/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/FSMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FSMC_NE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/FSMC_A24',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/FSMC_A25',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC1_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FSMC_A0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FSMC_A1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FSMC_A2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/FSMC_NIORD',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/FSMC_NREG',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/FSMC_NIOWR',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/DAC_EXTI9/FSMC_CD',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/FSMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/FSMC_NIOS16',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC1_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FSMC_A22/SYS_TRACED3',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/FSMC_D4/FSMC_DA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/FSMC_D5/FSMC_DA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/FSMC_D7/FSMC_DA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/FSMC_D8/FSMC_DA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FSMC_D9/FSMC_DA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FSMC_D10/FSMC_DA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FSMC_D11/FSMC_DA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC1_EXTI15/FSMC_D12/FSMC_DA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='143',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F101ZFTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F101',description='Core: ARM Cortex-M3 Package: LQFP144 Flash: 768KB Ram: 80KB Frequency: 36MHz Voltage: 2..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F101ZGTx'],pins=[
            Pin(num='34',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN6/SPI1_MISO/TIM13_CH1/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN7/SPI1_MOSI/TIM14_CH1/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC1_EXTI15/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN8/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN9/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='I2C1_SMBA/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='I2C2_SMBA/SPI2_NSS/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='SPI2_SCK/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='SPI2_MISO/TIM12_CH1/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/SPI2_MOSI/TIM12_CH2/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN12/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN13/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT/RTC_TAMPER/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FSMC_NCE2/FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC1_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='RCC_OSC_OUT',do_erc=True),
            Pin(num='106',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='56',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/FSMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/FSMC_INT3',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/FSMC_NCE3/FSMC_NE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/FSMC_NCE4_1/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/FSMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FSMC_NE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/FSMC_A24',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/FSMC_A25',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC1_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FSMC_A0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FSMC_A1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FSMC_A2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/FSMC_NIORD/TIM10_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/FSMC_NREG/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/FSMC_NIOWR/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/DAC_EXTI9/FSMC_CD/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/FSMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/FSMC_NIOS16',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC1_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FSMC_A22/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/FSMC_D4/FSMC_DA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/FSMC_D5/FSMC_DA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/FSMC_D7/FSMC_DA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/FSMC_D8/FSMC_DA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FSMC_D9/FSMC_DA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FSMC_D10/FSMC_DA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FSMC_D11/FSMC_DA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC1_EXTI15/FSMC_D12/FSMC_DA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='143',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F102C4Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F102',description='Core: ARM Cortex-M3 Package: LQFP48 Flash: 16KB Ram: 4KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F102C6Tx'],pins=[
            Pin(num='10',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN6/SPI1_MISO/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN7/SPI1_MOSI/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC1_IN8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC1_IN9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/SPI1_MISO/SYS_NJTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/SPI1_MOSI/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/I2C1_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/TIM2_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC1_EXTI11/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC1_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F102C8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F102',description='Core: ARM Cortex-M3 Package: LQFP48 Flash: 64KB Ram: 10KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F102CBTx'],pins=[
            Pin(num='10',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN6/SPI1_MISO/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN7/SPI1_MOSI/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC1_IN8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC1_IN9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/SPI1_MISO/SYS_NJTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/SPI1_MOSI/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM4_CH1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM4_CH2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/I2C1_SDA/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/TIM2_CH3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC1_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2C2_SMBA/SPI2_NSS/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/SPI2_SCK/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/SPI2_MISO/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC1_EXTI15/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F102R4Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F102',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 16KB Ram: 4KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F102R6Tx'],pins=[
            Pin(num='14',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/SPI1_MISO/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/SPI1_MOSI/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='SPI1_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/SPI1_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='I2C1_SDA/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/TIM2_CH4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F102R8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F102',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 64KB Ram: 10KB Frequency: 48MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F102RBTx'],pins=[
            Pin(num='14',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/SPI1_MISO/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/SPI1_MOSI/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='SPI1_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/SPI1_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='I2C1_SDA/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2C2_SMBA/SPI2_NSS/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SPI2_SCK/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='SPI2_MISO/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103C4Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: LQFP48 Flash: 16KB Ram: 6KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F103C6Tx'],pins=[
            Pin(num='10',name='ADC1_IN0/ADC2_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN1/ADC2_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN2/ADC2_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN3/ADC2_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN4/ADC2_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN5/ADC2_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/ADC2_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/SPI1_MISO/SYS_NJTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/SPI1_MOSI/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CAN_RX/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/CAN_TX/I2C1_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/TIM2_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC1_EXTI11/ADC2_EXTI11/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC1_EXTI15/ADC2_EXTI15/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103C8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: LQFP48 Flash: 64KB Ram: 20KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F103CBTx'],pins=[
            Pin(num='10',name='ADC1_IN0/ADC2_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN1/ADC2_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN2/ADC2_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN3/ADC2_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN4/ADC2_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN5/ADC2_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/ADC2_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/SPI1_MISO/SYS_NJTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/SPI1_MOSI/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM4_CH1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM4_CH2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CAN_RX/I2C1_SCL/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/CAN_TX/I2C1_SDA/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/TIM2_CH3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC1_EXTI11/ADC2_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2C2_SMBA/SPI2_NSS/TIM1_BKIN/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/SPI2_SCK/TIM1_CH1N/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/SPI2_MISO/TIM1_CH2N/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC1_EXTI15/ADC2_EXTI15/SPI2_MOSI/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103C6Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: UFQFPN48 Flash: 32KB Ram: 10KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC1_IN0/ADC2_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN1/ADC2_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN2/ADC2_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN3/ADC2_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN4/ADC2_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN5/ADC2_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/ADC2_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/SPI1_MISO/SYS_NJTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/SPI1_MOSI/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CAN_RX/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/CAN_TX/I2C1_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/TIM2_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC1_EXTI11/ADC2_EXTI11/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC1_EXTI15/ADC2_EXTI15/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103CBUx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: UFQFPN48 Flash: 128KB Ram: 20KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC1_IN0/ADC2_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN1/ADC2_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN2/ADC2_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN3/ADC2_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN4/ADC2_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN5/ADC2_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/ADC2_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/SPI1_MISO/SYS_NJTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/SPI1_MOSI/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM4_CH1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM4_CH2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CAN_RX/I2C1_SCL/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/CAN_TX/I2C1_SDA/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/TIM2_CH3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC1_EXTI11/ADC2_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2C2_SMBA/SPI2_NSS/TIM1_BKIN/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/SPI2_SCK/TIM1_CH1N/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/SPI2_MISO/TIM1_CH2N/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC1_EXTI15/ADC2_EXTI15/SPI2_MOSI/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103R4Hx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: TFBGA64 Flash: 16KB Ram: 6KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F103R6Hx'],pins=[
            Pin(num='G2',name='ADC1_IN0/ADC2_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC1_IN1/ADC2_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC1_IN2/ADC2_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC1_IN3/ADC2_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC1_IN4/ADC2_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC1_IN5/ADC2_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='ADC1_EXTI15/ADC2_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='SPI1_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='I2C1_SMBA/SPI1_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='I2C1_SCL/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='I2C1_SDA/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='CAN_RX/I2C1_SCL/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='CAN_TX/I2C1_SDA/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC1_EXTI11/ADC2_EXTI11/TIM2_CH4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='TIM1_BKIN/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='TIM1_CH1N/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='TIM1_CH2N/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='ADC1_EXTI15/ADC2_EXTI15/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='B4',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='B5',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC0/ADC1_IN10/ADC2_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC1/ADC1_IN11/ADC2_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC2/ADC1_IN12/ADC2_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC1_IN14/ADC2_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC5/ADC1_IN15/ADC2_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC11/ADC1_EXTI11/ADC2_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PC15/ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103R4Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 16KB Ram: 6KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F103R6Tx'],pins=[
            Pin(num='14',name='ADC1_IN0/ADC2_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/ADC2_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/ADC2_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/ADC2_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/ADC2_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/ADC2_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/ADC2_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='SPI1_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/SPI1_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN_RX/I2C1_SCL/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN_TX/I2C1_SDA/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/ADC2_EXTI11/TIM2_CH4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='TIM1_BKIN/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='TIM1_CH1N/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='TIM1_CH2N/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/ADC2_EXTI15/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10/ADC2_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11/ADC2_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12/ADC2_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13/ADC2_IN13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14/ADC2_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15/ADC2_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/ADC2_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103R8Hx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: TFBGA64 Flash: 64KB Ram: 20KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F103RBHx'],pins=[
            Pin(num='G2',name='ADC1_IN0/ADC2_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC1_IN1/ADC2_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC1_IN2/ADC2_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC1_IN3/ADC2_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC1_IN4/ADC2_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC1_IN5/ADC2_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='ADC1_EXTI15/ADC2_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='SPI1_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='I2C1_SMBA/SPI1_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='CAN_RX/I2C1_SCL/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='CAN_TX/I2C1_SDA/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC1_EXTI11/ADC2_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='I2C2_SMBA/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='SPI2_MISO/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='ADC1_EXTI15/ADC2_EXTI15/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='B4',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='B5',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC0/ADC1_IN10/ADC2_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC1/ADC1_IN11/ADC2_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC2/ADC1_IN12/ADC2_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC1_IN14/ADC2_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC5/ADC1_IN15/ADC2_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC10/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC11/ADC1_EXTI11/ADC2_EXTI11/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC12/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PC15/ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103R8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 64KB Ram: 20KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F103RBTx'],pins=[
            Pin(num='14',name='ADC1_IN0/ADC2_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/ADC2_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/ADC2_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/ADC2_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/ADC2_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/ADC2_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/ADC2_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='SPI1_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/SPI1_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN_RX/I2C1_SCL/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN_TX/I2C1_SDA/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/ADC2_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2C2_SMBA/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='SPI2_MISO/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/ADC2_EXTI15/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10/ADC2_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11/ADC2_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12/ADC2_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13/ADC2_IN13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14/ADC2_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15/ADC2_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/ADC2_EXTI11/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103RCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 256KB Ram: 48KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F103RDTx', 'STM32F103RETx'],pins=[
            Pin(num='14',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/ADC2_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN_RX/I2C1_SCL/SDIO_D4/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN_TX/DAC_EXTI9/I2C1_SDA/SDIO_D5/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/ADC2_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='SPI2_MISO/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/ADC2_EXTI15/I2S2_SD/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10/ADC2_IN10/ADC3_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11/ADC2_IN11/ADC3_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12/ADC2_IN12/ADC3_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13/ADC2_IN13/ADC3_IN13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14/ADC2_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15/ADC2_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/SDIO_D0/TIM3_CH3/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/SDIO_D1/TIM3_CH4/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/SDIO_D2/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/ADC2_EXTI11/SDIO_D3/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/SDIO_CK/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103RDYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: WLCSP64 Flash: 384KB Ram: 64KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F103REYx'],pins=[
            Pin(num='F6',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='E6',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='DAC_EXTI9/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='ADC1_EXTI15/ADC2_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='CAN_RX/I2C1_SCL/SDIO_D4/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN_TX/DAC_EXTI9/I2C1_SDA/SDIO_D5/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC1_EXTI11/ADC2_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='SPI2_MISO/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_EXTI15/ADC2_EXTI15/I2S2_SD/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='NRST',do_erc=True),
            Pin(num='A6',name='BOOT0',do_erc=True),
            Pin(num='C6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='D8',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='D7',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='A3',name='PD2/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC0/ADC1_IN10/ADC2_IN10/ADC3_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='PC1/ADC1_IN11/ADC2_IN11/ADC3_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PC2/ADC1_IN12/ADC2_IN12/ADC3_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC4/ADC1_IN14/ADC2_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC5/ADC1_IN15/ADC2_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='PC6/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC7/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC8/SDIO_D0/TIM3_CH3/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='PC9/DAC_EXTI9/SDIO_D1/TIM3_CH4/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC10/SDIO_D2/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PC11/ADC1_EXTI11/ADC2_EXTI11/SDIO_D3/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PC12/SDIO_CK/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC15/ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='A8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='A7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='B1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E7',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103RFTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 768KB Ram: 96KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F103RGTx'],pins=[
            Pin(num='14',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/ADC2_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN_RX/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN_TX/DAC_EXTI9/I2C1_SDA/SDIO_D5/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/ADC2_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/ADC2_EXTI15/I2S2_SD/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10/ADC2_IN10/ADC3_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11/ADC2_IN11/ADC3_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12/ADC2_IN12/ADC3_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13/ADC2_IN13/ADC3_IN13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14/ADC2_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15/ADC2_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/SDIO_D0/TIM3_CH3/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/SDIO_D1/TIM3_CH4/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/SDIO_D2/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/ADC2_EXTI11/SDIO_D3/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/SDIO_CK/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103T4Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: VFQFPN36 Flash: 16KB Ram: 6KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 26',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F103T6Ux'],pins=[
            Pin(num='7',name='ADC1_IN0/ADC2_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC1_IN1/ADC2_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_IN2/ADC2_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC1_IN3/ADC2_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN4/ADC2_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN5/ADC2_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_EXTI15/ADC2_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='35',name='BOOT0',do_erc=True),
            Pin(num='2',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='15',name='PB0/ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PB1/ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB3/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='PB4/SPI1_MISO/SYS_NJTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PB5/I2C1_SMBA/SPI1_MOSI/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='PB6/I2C1_SCL/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='PB7/I2C1_SDA/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='37',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103T8Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: VFQFPN36 Flash: 64KB Ram: 20KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 26',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F103TBUx'],pins=[
            Pin(num='7',name='ADC1_IN0/ADC2_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC1_IN1/ADC2_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_IN2/ADC2_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC1_IN3/ADC2_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN4/ADC2_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN5/ADC2_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_EXTI15/ADC2_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='35',name='BOOT0',do_erc=True),
            Pin(num='2',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='3',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='15',name='PB0/ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PB1/ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB3/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='PB4/SPI1_MISO/SYS_NJTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PB5/I2C1_SMBA/SPI1_MOSI/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='PB6/I2C1_SCL/TIM4_CH1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='PB7/I2C1_SDA/TIM4_CH2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='37',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103V8Hx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: LFBGA100 Flash: 64KB Ram: 20KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F103VBHx'],pins=[
            Pin(num='G2',name='ADC1_IN0/ADC2_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC1_IN1/ADC2_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC1_IN2/ADC2_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_IN3/ADC2_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC1_IN4/ADC2_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC1_IN5/ADC2_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='ADC1_EXTI15/ADC2_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='SPI1_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='I2C1_SMBA/SPI1_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN_RX/I2C1_SCL/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='CAN_TX/I2C1_SDA/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='ADC1_EXTI11/ADC2_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='I2C2_SMBA/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='SPI2_MISO/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='ADC1_EXTI15/ADC2_EXTI15/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_IN10/ADC2_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='ADC1_IN11/ADC2_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='ADC1_IN12/ADC2_IN12/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC1_IN13/ADC2_IN13/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC1_IN14/ADC2_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC1_IN15/ADC2_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='ADC1_EXTI11/ADC2_EXTI11/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='RTC_OUT/RTC_TAMPER/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='D5',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='RCC_OSC_OUT',do_erc=True),
            Pin(num='F8',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='D4',name='PE0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PE2/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PE3/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE4/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PE5/SYS_TRACED2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PE6/SYS_TRACED3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PE7/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='PE8/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='PE9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='PE10/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PE11/ADC1_EXTI11/ADC2_EXTI11/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PE12/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='PE13/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='PE14/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='PE15/ADC1_EXTI15/ADC2_EXTI15/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PD0/CAN_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PD1/CAN_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PD3/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PD4/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='PD9/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='PD10/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='PD11/ADC1_EXTI11/ADC2_EXTI11/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='PD12/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD13/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD14/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G10',name='PD15/ADC1_EXTI15/ADC2_EXTI15/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103V8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 64KB Ram: 20KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F103VBTx'],pins=[
            Pin(num='23',name='ADC1_IN0/ADC2_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/ADC2_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/ADC2_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/ADC2_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/ADC2_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/ADC2_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='SPI1_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/SPI1_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN_RX/I2C1_SCL/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN_TX/I2C1_SDA/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2C2_SMBA/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='SPI2_MISO/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/ADC2_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/ADC2_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/ADC2_IN12/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/ADC2_IN13/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/ADC2_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/ADC2_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT/RTC_TAMPER/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='97',name='PE0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/SYS_TRACED3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103VCHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: LFBGA100 Flash: 256KB Ram: 48KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F103VDHx', 'STM32F103VEHx'],pins=[
            Pin(num='G2',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='DAC_EXTI9/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='ADC1_EXTI15/ADC2_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN_RX/I2C1_SCL/SDIO_D4/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='CAN_TX/DAC_EXTI9/I2C1_SDA/SDIO_D5/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='ADC1_EXTI11/ADC2_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='SPI2_MISO/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='ADC1_EXTI15/ADC2_EXTI15/I2S2_SD/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC1_IN14/ADC2_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC1_IN15/ADC2_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='SDIO_D0/TIM3_CH3/TIM8_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='DAC_EXTI9/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='SDIO_D2/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='ADC1_EXTI11/ADC2_EXTI11/SDIO_D3/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='SDIO_CK/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='RTC_OUT/RTC_TAMPER/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='D5',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='RCC_OSC_OUT',do_erc=True),
            Pin(num='F8',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='D4',name='PE0/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PE1/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PE2/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PE5/FSMC_A21/SYS_TRACED2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PE6/FSMC_A22/SYS_TRACED3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PE11/ADC1_EXTI11/ADC2_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='PE15/ADC1_EXTI15/ADC2_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PD0/CAN_RX/FSMC_D2/FSMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PD1/CAN_TX/FSMC_D3/FSMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD2/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PD3/FSMC_CLK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PD4/FSMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD5/FSMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PD6/FSMC_NWAIT/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PD7/FSMC_NCE2/FSMC_NE1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/FSMC_D13/FSMC_DA13/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='PD9/DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='PD10/FSMC_D15/FSMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='PD11/ADC1_EXTI11/ADC2_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='PD12/FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD13/FSMC_A18/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD14/FSMC_D0/FSMC_DA0/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G10',name='PD15/ADC1_EXTI15/ADC2_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103VCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 256KB Ram: 48KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F103VDTx', 'STM32F103VETx'],pins=[
            Pin(num='23',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN_RX/I2C1_SCL/SDIO_D4/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN_TX/DAC_EXTI9/I2C1_SDA/SDIO_D5/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='SPI2_MISO/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/I2S2_SD/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/ADC2_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/ADC2_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='SDIO_D0/TIM3_CH3/TIM8_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='SDIO_D2/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/SDIO_D3/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='SDIO_CK/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT/RTC_TAMPER/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='97',name='PE0/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FSMC_A22/SYS_TRACED3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN_RX/FSMC_D2/FSMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN_TX/FSMC_D3/FSMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/FSMC_CLK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FSMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FSMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/FSMC_NWAIT/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FSMC_NCE2/FSMC_NE1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FSMC_D13/FSMC_DA13/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FSMC_D15/FSMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FSMC_A18/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FSMC_D0/FSMC_DA0/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103VFTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 768KB Ram: 96KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F103VGTx'],pins=[
            Pin(num='23',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN_RX/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN_TX/DAC_EXTI9/I2C1_SDA/SDIO_D5/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/I2S2_SD/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/ADC2_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/ADC2_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='SDIO_D0/TIM3_CH3/TIM8_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='SDIO_D2/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/SDIO_D3/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='SDIO_CK/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT/RTC_TAMPER/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='97',name='PE0/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FSMC_A22/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN_RX/FSMC_D2/FSMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN_TX/FSMC_D3/FSMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/FSMC_CLK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FSMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FSMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/FSMC_NWAIT/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FSMC_NCE2/FSMC_NE1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FSMC_D13/FSMC_DA13/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FSMC_D15/FSMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FSMC_A18/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FSMC_D0/FSMC_DA0/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103VBIx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: UFBGA100 Flash: 128KB Ram: 20KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='L2',name='ADC1_IN0/ADC2_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN1/ADC2_IN1/TIM2_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC1_IN2/ADC2_IN2/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC1_IN3/ADC2_IN3/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN4/ADC2_IN4/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC1_IN5/ADC2_IN5/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ADC1_EXTI15/ADC2_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='SPI1_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='I2C1_SMBA/SPI1_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='CAN_RX/I2C1_SCL/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='CAN_TX/I2C1_SDA/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC1_EXTI11/ADC2_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='I2C2_SMBA/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='SPI2_MISO/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='ADC1_EXTI15/ADC2_EXTI15/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC1_IN10/ADC2_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC1_IN11/ADC2_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC1_IN12/ADC2_IN12/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_IN13/ADC2_IN13/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC1_IN14/ADC2_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC1_IN15/ADC2_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC1_EXTI11/ADC2_EXTI11/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT/RTC_TAMPER/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='RCC_OSC_OUT',do_erc=True),
            Pin(num='C11',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='C3',name='PE0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/SYS_TRACED2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/SYS_TRACED3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC1_EXTI11/ADC2_EXTI11/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/ADC1_EXTI15/ADC2_EXTI15/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0/CAN_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1/CAN_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/ADC1_EXTI11/ADC2_EXTI11/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/ADC1_EXTI15/ADC2_EXTI15/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103ZCHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: LFBGA144 Flash: 256KB Ram: 48KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F103ZDHx', 'STM32F103ZEHx'],pins=[
            Pin(num='J2',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='ADC1_EXTI15/ADC2_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='CAN_RX/I2C1_SCL/SDIO_D4/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='CAN_TX/DAC_EXTI9/I2C1_SDA/SDIO_D5/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='ADC1_EXTI11/ADC2_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='SPI2_MISO/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='ADC1_EXTI15/ADC2_EXTI15/I2S2_SD/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC1_IN14/ADC2_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC1_IN15/ADC2_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G12',name='I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F12',name='I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F11',name='SDIO_D0/TIM3_CH3/TIM8_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='DAC_EXTI9/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='SDIO_D2/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='ADC1_EXTI11/ADC2_EXTI11/SDIO_D3/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='SDIO_CK/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='RTC_OUT/RTC_TAMPER/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='CAN_RX/FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='CAN_TX/FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='FSMC_NCE2/FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='ADC1_EXTI11/ADC2_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='ADC1_EXTI15/ADC2_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='NRST',do_erc=True),
            Pin(num='D5',name='BOOT0',do_erc=True),
            Pin(num='C2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='D1',name='RCC_OSC_IN',do_erc=True),
            Pin(num='E1',name='RCC_OSC_OUT',do_erc=True),
            Pin(num='C11',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='K6',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PG6/FSMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PG7/FSMC_INT3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G11',name='PG8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PG9/DAC_EXTI9/FSMC_NCE3/FSMC_NE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PG10/FSMC_NCE4_1/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PG11/ADC1_EXTI11/ADC2_EXTI11/FSMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PG12/FSMC_NE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PG13/FSMC_A24',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG14/FSMC_A25',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG15/ADC1_EXTI15/ADC2_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PF0/FSMC_A0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PF1/FSMC_A1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PF2/FSMC_A2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PF3/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PF4/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PF5/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PF6/ADC3_IN4/FSMC_NIORD',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PF7/ADC3_IN5/FSMC_NREG',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PF8/ADC3_IN6/FSMC_NIOWR',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PF9/ADC3_IN7/DAC_EXTI9/FSMC_CD',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PF10/ADC3_IN8/FSMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='PF11/ADC1_EXTI11/ADC2_EXTI11/FSMC_NIOS16',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='PF15/ADC1_EXTI15/ADC2_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PE0/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PE1/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PE2/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PE5/FSMC_A21/SYS_TRACED2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PE6/FSMC_A22/SYS_TRACED3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='PE11/ADC1_EXTI11/ADC2_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE15/ADC1_EXTI15/ADC2_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103ZCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: LQFP144 Flash: 256KB Ram: 48KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F103ZDTx', 'STM32F103ZETx'],pins=[
            Pin(num='34',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC1_EXTI15/ADC2_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CAN_RX/I2C1_SCL/SDIO_D4/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='CAN_TX/DAC_EXTI9/I2C1_SDA/SDIO_D5/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='SPI2_MISO/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/I2S2_SD/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN14/ADC2_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN15/ADC2_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='SDIO_D0/TIM3_CH3/TIM8_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='SDIO_D2/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/ADC2_EXTI11/SDIO_D3/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='SDIO_CK/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT/RTC_TAMPER/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='CAN_RX/FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CAN_TX/FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FSMC_NCE2/FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC1_EXTI15/ADC2_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='RCC_OSC_OUT',do_erc=True),
            Pin(num='106',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='56',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/FSMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/FSMC_INT3',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/FSMC_NCE3/FSMC_NE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/FSMC_NCE4_1/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/ADC2_EXTI11/FSMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FSMC_NE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/FSMC_A24',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/FSMC_A25',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC1_EXTI15/ADC2_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FSMC_A0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FSMC_A1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FSMC_A2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC3_IN4/FSMC_NIORD',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC3_IN5/FSMC_NREG',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC3_IN6/FSMC_NIOWR',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC3_IN7/DAC_EXTI9/FSMC_CD',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC3_IN8/FSMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/ADC2_EXTI11/FSMC_NIOS16',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC1_EXTI15/ADC2_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FSMC_A22/SYS_TRACED3',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/ADC2_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC1_EXTI15/ADC2_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='143',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103ZFHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: LFBGA144 Flash: 768KB Ram: 96KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F103ZGHx'],pins=[
            Pin(num='J2',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='ADC1_EXTI15/ADC2_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='CAN_RX/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='CAN_TX/DAC_EXTI9/I2C1_SDA/SDIO_D5/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='ADC1_EXTI11/ADC2_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='ADC1_EXTI15/ADC2_EXTI15/I2S2_SD/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC1_IN14/ADC2_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC1_IN15/ADC2_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G12',name='I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F12',name='I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F11',name='SDIO_D0/TIM3_CH3/TIM8_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='DAC_EXTI9/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='SDIO_D2/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='ADC1_EXTI11/ADC2_EXTI11/SDIO_D3/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='SDIO_CK/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='RTC_OUT/RTC_TAMPER/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='CAN_RX/FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='CAN_TX/FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='FSMC_NCE2/FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='ADC1_EXTI11/ADC2_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='ADC1_EXTI15/ADC2_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='NRST',do_erc=True),
            Pin(num='D5',name='BOOT0',do_erc=True),
            Pin(num='C2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='D1',name='RCC_OSC_IN',do_erc=True),
            Pin(num='E1',name='RCC_OSC_OUT',do_erc=True),
            Pin(num='C11',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='K6',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PG6/FSMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PG7/FSMC_INT3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G11',name='PG8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PG9/DAC_EXTI9/FSMC_NCE3/FSMC_NE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PG10/FSMC_NCE4_1/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PG11/ADC1_EXTI11/ADC2_EXTI11/FSMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PG12/FSMC_NE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PG13/FSMC_A24',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG14/FSMC_A25',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG15/ADC1_EXTI15/ADC2_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PF0/FSMC_A0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PF1/FSMC_A1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PF2/FSMC_A2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PF3/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PF4/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PF5/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PF6/ADC3_IN4/FSMC_NIORD/TIM10_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PF7/ADC3_IN5/FSMC_NREG/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PF8/ADC3_IN6/FSMC_NIOWR/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PF9/ADC3_IN7/DAC_EXTI9/FSMC_CD/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PF10/ADC3_IN8/FSMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='PF11/ADC1_EXTI11/ADC2_EXTI11/FSMC_NIOS16',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='PF15/ADC1_EXTI15/ADC2_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PE0/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PE1/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PE2/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PE5/FSMC_A21/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PE6/FSMC_A22/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='PE11/ADC1_EXTI11/ADC2_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE15/ADC1_EXTI15/ADC2_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F103ZFTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F103',description='Core: ARM Cortex-M3 Package: LQFP144 Flash: 768KB Ram: 96KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F103ZGTx'],pins=[
            Pin(num='34',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN_TX/TIM1_ETR/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC1_EXTI15/ADC2_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CAN_RX/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='CAN_TX/DAC_EXTI9/I2C1_SDA/SDIO_D5/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/I2S2_SD/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN14/ADC2_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN15/ADC2_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='SDIO_D0/TIM3_CH3/TIM8_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='SDIO_D2/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/ADC2_EXTI11/SDIO_D3/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='SDIO_CK/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT/RTC_TAMPER/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='CAN_RX/FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CAN_TX/FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FSMC_NCE2/FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC1_EXTI15/ADC2_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='RCC_OSC_OUT',do_erc=True),
            Pin(num='106',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='56',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/FSMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/FSMC_INT3',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/FSMC_NCE3/FSMC_NE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/FSMC_NCE4_1/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/ADC2_EXTI11/FSMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FSMC_NE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/FSMC_A24',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/FSMC_A25',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC1_EXTI15/ADC2_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FSMC_A0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FSMC_A1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FSMC_A2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC3_IN4/FSMC_NIORD/TIM10_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC3_IN5/FSMC_NREG/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC3_IN6/FSMC_NIOWR/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC3_IN7/DAC_EXTI9/FSMC_CD/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC3_IN8/FSMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/ADC2_EXTI11/FSMC_NIOS16',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC1_EXTI15/ADC2_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FSMC_A22/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/ADC2_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC1_EXTI15/ADC2_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='143',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F105R8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F105/107',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 64KB Ram: 64KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F105RBTx', 'STM32F105RCTx'],pins=[
            Pin(num='14',name='ADC1_IN0/ADC2_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/ADC2_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/ADC2_IN2/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/ADC2_IN3/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/ADC2_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/ADC2_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO/SYS_TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='CAN2_RX/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='CAN2_TX/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN1_RX/I2C1_SCL/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN1_TX/DAC_EXTI9/I2C1_SDA/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/ADC2_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='CAN2_TX/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='SPI2_MISO/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/ADC2_EXTI15/I2S2_SD/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10/ADC2_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11/ADC2_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12/ADC2_IN12',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13/ADC2_IN13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14/ADC2_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15/ADC2_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/SPI3_SCK/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/ADC2_EXTI11/SPI3_MISO/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SPI3_MOSI/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F105V8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F105/107',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 64KB Ram: 64KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F105VBTx', 'STM32F105VCTx'],pins=[
            Pin(num='23',name='ADC1_IN0/ADC2_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/ADC2_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/ADC2_IN2/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/ADC2_IN3/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='RCC_MCO/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO/SYS_TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='CAN2_RX/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_TX/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN1_RX/I2C1_SCL/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN1_TX/DAC_EXTI9/I2C1_SDA/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='CAN2_TX/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='SPI2_MISO/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/I2S2_SD/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/ADC2_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/ADC2_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/ADC2_IN12/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/ADC2_IN13/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/ADC2_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/ADC2_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT/RTC_TAMPER/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='97',name='PE0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/SYS_TRACED3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F105VBHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F105/107',description='Core: ARM Cortex-M3 Package: LFBGA100 Flash: 128KB Ram: 64KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='G2',name='ADC1_IN0/ADC2_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC1_IN1/ADC2_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC1_IN2/ADC2_IN2/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_IN3/ADC2_IN3/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='RCC_MCO/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='DAC_EXTI9/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC1_EXTI11/ADC2_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='ADC1_EXTI15/ADC2_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO/SYS_TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='CAN2_RX/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='CAN2_TX/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN1_RX/I2C1_SCL/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='CAN1_TX/DAC_EXTI9/I2C1_SDA/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='ADC1_EXTI11/ADC2_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='CAN2_TX/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='SPI2_MISO/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='ADC1_EXTI15/ADC2_EXTI15/I2S2_SD/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_IN10/ADC2_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='ADC1_IN11/ADC2_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='ADC1_IN12/ADC2_IN12/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC1_IN13/ADC2_IN13/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC1_IN14/ADC2_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC1_IN15/ADC2_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='I2S2_MCK/TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='I2S3_MCK/TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='DAC_EXTI9/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='I2S3_CK/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='ADC1_EXTI11/ADC2_EXTI11/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='I2S3_SD/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='RTC_OUT/RTC_TAMPER/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='D5',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='RCC_OSC_OUT',do_erc=True),
            Pin(num='F8',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='D4',name='PE0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PE2/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PE3/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE4/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PE5/SYS_TRACED2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PE6/SYS_TRACED3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PE7/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='PE8/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='PE9/DAC_EXTI9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='PE10/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PE11/ADC1_EXTI11/ADC2_EXTI11/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PE12/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='PE13/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='PE14/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='PE15/ADC1_EXTI15/ADC2_EXTI15/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PD0/CAN1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PD1/CAN1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD2/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PD3/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PD4/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='PD9/DAC_EXTI9/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='PD10/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='PD11/ADC1_EXTI11/ADC2_EXTI11/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='PD12/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD13/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD14/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G10',name='PD15/ADC1_EXTI15/ADC2_EXTI15/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F107RBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F105/107',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 128KB Ram: 64KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F107RCTx'],pins=[
            Pin(num='14',name='ADC1_IN0/ADC2_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/ADC2_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/ADC2_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/ADC2_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/ADC2_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/ADC2_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO/SYS_TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='CAN2_RX/ETH_PPS_OUT/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='CAN2_TX/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN1_RX/ETH_TXD3/I2C1_SCL/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN1_TX/DAC_EXTI9/I2C1_SDA/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ETH_RX_ER/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/ADC2_EXTI11/ETH_TX_EN/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN2_RX/ETH_TXD0/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='SPI2_MISO/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/ADC2_EXTI15/I2S2_SD/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PD0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PD1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10/ADC2_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11/ADC2_IN11/ETH_MDC',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12/ADC2_IN12/ETH_TXD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13/ADC2_IN13/ETH_TX_CLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14/ADC2_IN14/ETH_RXD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15/ADC2_IN15/ETH_RXD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/SPI3_SCK/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/ADC2_EXTI11/SPI3_MISO/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SPI3_MOSI/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT/RTC_TAMPER',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F107VBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F105/107',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 128KB Ram: 64KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F107VCTx'],pins=[
            Pin(num='23',name='ADC1_IN0/ADC2_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/ADC2_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/ADC2_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/ADC2_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='RCC_MCO/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO/SYS_TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='CAN2_RX/ETH_PPS_OUT/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_TX/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN1_RX/ETH_TXD3/I2C1_SCL/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN1_TX/DAC_EXTI9/I2C1_SDA/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ETH_RX_ER/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/ETH_TX_EN/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='CAN2_RX/ETH_TXD0/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='SPI2_MISO/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/I2S2_SD/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/ADC2_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/ADC2_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/ADC2_IN12/ETH_TXD2/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/ADC2_IN13/ETH_TX_CLK/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT/RTC_TAMPER/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='97',name='PE0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/SYS_TRACED3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/ETH_CRS_DV/ETH_RX_DV/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/ETH_RXD0/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/ETH_RXD1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ETH_RXD2/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/ETH_RXD3/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F107VCHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F1 STM32F105/107',description='Core: ARM Cortex-M3 Package: LFBGA100 Flash: 256KB Ram: 64KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='G2',name='ADC1_IN0/ADC2_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC1_IN1/ADC2_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC1_IN2/ADC2_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_IN3/ADC2_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='RCC_MCO/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='DAC_EXTI9/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC1_EXTI11/ADC2_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='ADC1_EXTI15/ADC2_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO/SYS_TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='CAN2_RX/ETH_PPS_OUT/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='CAN2_TX/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN1_RX/ETH_TXD3/I2C1_SCL/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='CAN1_TX/DAC_EXTI9/I2C1_SDA/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='ETH_RX_ER/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='ADC1_EXTI11/ADC2_EXTI11/ETH_TX_EN/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='CAN2_RX/ETH_TXD0/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='SPI2_MISO/TIM1_CH2N/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='ADC1_EXTI15/ADC2_EXTI15/I2S2_SD/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_IN10/ADC2_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='ADC1_IN11/ADC2_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='ADC1_IN12/ADC2_IN12/ETH_TXD2/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC1_IN13/ADC2_IN13/ETH_TX_CLK/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='I2S2_MCK/TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='I2S3_MCK/TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='DAC_EXTI9/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='I2S3_CK/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='ADC1_EXTI11/ADC2_EXTI11/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='I2S3_SD/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='RTC_OUT/RTC_TAMPER/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='D5',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='RCC_OSC_OUT',do_erc=True),
            Pin(num='F8',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='D4',name='PE0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PE2/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PE3/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE4/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PE5/SYS_TRACED2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PE6/SYS_TRACED3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PE7/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='PE8/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='PE9/DAC_EXTI9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='PE10/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PE11/ADC1_EXTI11/ADC2_EXTI11/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PE12/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='PE13/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='PE14/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='PE15/ADC1_EXTI15/ADC2_EXTI15/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PD0/CAN1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PD1/CAN1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD2/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PD3/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PD4/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/ETH_CRS_DV/ETH_RX_DV/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='PD9/DAC_EXTI9/ETH_RXD0/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='PD10/ETH_RXD1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ETH_RXD2/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='PD12/ETH_RXD3/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD13/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD14/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G10',name='PD15/ADC1_EXTI15/ADC2_EXTI15/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F205RBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F2 STM32F2x5',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 128KB Ram: 64KB Frequency: 120MHz Voltage: 1.8..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F205RCTx', 'STM32F205RETx', 'STM32F205RFTx', 'STM32F205RGTx'],pins=[
            Pin(num='14',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S3_SCK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='CAN2_RX/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='CAN2_TX/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN1_RX/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN1_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/I2S2_SCK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='CAN2_TX/I2S2_SCK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11/ADC2_IN11/ADC3_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12/ADC2_IN12/ADC3_IN12/SPI2_MISO/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13/ADC2_IN13/ADC3_IN13/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14/ADC2_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15/ADC2_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_SCK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_AF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F205REYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F2 STM32F2x5',description='Core: ARM Cortex-M3 Package: WLCSP66 Flash: 512KB Ram: 128KB Frequency: 120MHz Voltage: 1.7..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F205RGYx'],pins=[
            Pin(num='E7',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='DAC_EXTI9/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='I2S3_SCK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='CAN2_RX/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='CAN2_TX/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='CAN1_RX/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='CAN1_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='I2C2_SCL/I2S2_SCK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J1',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='CAN2_TX/I2S2_SCK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='NRST',do_erc=True),
            Pin(num='B6',name='BOOT0',do_erc=True),
            Pin(num='A9',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='C8',name='IRROFF',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='REGOFF',func=Pin.PWRIN,do_erc=True),
            Pin(num='J3',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='E9',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='F9',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='C7',name='PD2/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='PC0/ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='PC1/ADC1_IN11/ADC2_IN11/ADC3_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PC2/ADC1_IN12/ADC2_IN12/ADC3_IN12/SPI2_MISO/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='PC3/ADC1_IN13/ADC2_IN13/ADC3_IN13/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PC4/ADC1_IN14/ADC2_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PC5/ADC1_IN15/ADC2_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PC6/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC7/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PC8/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='PC9/DAC_EXTI9/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PC10/I2S3_SCK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PC11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PC12/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PC13/RTC_AF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PC15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='B1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H9',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F205VBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F2 STM32F2x5',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 128KB Ram: 64KB Frequency: 120MHz Voltage: 1.8..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F205VCTx', 'STM32F205VETx', 'STM32F205VFTx', 'STM32F205VGTx'],pins=[
            Pin(num='23',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_SCK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='CAN2_RX/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_TX/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN1_RX/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN1_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/I2S2_SCK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='CAN2_TX/I2S2_SCK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/ADC2_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/ADC2_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_SCK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='RFU',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='97',name='PE0/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FSMC_A22/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN1_RX/FSMC_D2/FSMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN1_TX/FSMC_D3/FSMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/FSMC_CLK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FSMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FSMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/FSMC_NWAIT/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FSMC_NCE2/FSMC_NE1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FSMC_D13/FSMC_DA13/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FSMC_D15/FSMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FSMC_A18/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FSMC_D0/FSMC_DA0/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F205ZCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F2 STM32F2x5',description='Core: ARM Cortex-M3 Package: LQFP144 Flash: 256KB Ram: 96KB Frequency: 120MHz Voltage: 1.8..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F205ZETx', 'STM32F205ZFTx', 'STM32F205ZGTx'],pins=[
            Pin(num='34',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='I2S3_SCK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='CAN2_RX/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='CAN2_TX/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CAN1_RX/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='CAN1_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C2_SCL/I2S2_SCK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='CAN2_TX/I2S2_SCK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN14/ADC2_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN15/ADC2_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='I2S3_SCK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='CAN1_RX/FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CAN1_TX/FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FSMC_NCE2/FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='106',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='143',name='RFU',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='56',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/FSMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/FSMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/FSMC_NCE3/FSMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/FSMC_NCE4_1/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FSMC_NE4/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/FSMC_A24/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/FSMC_A25/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FSMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FSMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FSMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/ADC3_IN9/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/ADC3_IN14/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/ADC3_IN15/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC3_IN4/FSMC_NIORD/TIM10_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC3_IN5/FSMC_NREG/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC3_IN6/FSMC_NIOWR/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC3_IN7/DAC_EXTI9/FSMC_CD/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC3_IN8/FSMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FSMC_A22/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F207ICHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F2 STM32F2x7',description='Core: ARM Cortex-M3 Package: UFBGA176 Flash: 256KB Ram: 128KB Frequency: 120MHz Voltage: 1.8..3.6V IO-pins: 140',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F207IEHx', 'STM32F207IFHx', 'STM32F207IGHx'],pins=[
            Pin(num='N3',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='P2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='R2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P4',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='P3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R3',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F15',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E15',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D15',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C15',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B15',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A15',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A14',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='R5',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='R4',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='I2S3_SCK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN2_TX/DCMI_D5/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R12',name='ETH_RX_ER/I2C2_SCL/I2S2_SCK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='R13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='P12',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='P13',name='CAN2_TX/ETH_TXD1/I2S2_SCK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='R14',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R15',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P5',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H15',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G15',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G14',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F14',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B14',name='DCMI_D8/I2S3_SCK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN1_RX/FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='CAN1_TX/FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='FSMC_NCE2/FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P15',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P14',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='N15',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N14',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N13',name='FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M15',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='M14',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L14',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='DCMI_D2/FSMC_NBL0/TIM4_ETR/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DCMI_D3/FSMC_NBL1/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ETH_TXD3/FSMC_A23/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='FSMC_A19/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='DCMI_D4/FSMC_A20/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='DCMI_D6/FSMC_A21/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DCMI_D7/FSMC_A22/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R8',name='FSMC_D4/FSMC_DA4/TIM1_ETR/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P8',name='FSMC_D5/FSMC_DA5/TIM1_CH1N/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P9',name='DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R9',name='FSMC_D7/FSMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='R10',name='FSMC_D9/FSMC_DA9/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='FSMC_D10/FSMC_DA10/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P11',name='FSMC_D11/FSMC_DA11/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R11',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='J1',name='NRST',do_erc=True),
            Pin(num='D6',name='BOOT0',do_erc=True),
            Pin(num='C1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='C6',name='RFU',func=Pin.PWRIN,do_erc=True),
            Pin(num='F13',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='L4',name='REGOFF',func=Pin.PWRIN,do_erc=True),
            Pin(num='M10',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='N1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='P1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='E14',name='PI0/DCMI_D13/I2S2_WS/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D14',name='PI1/DCMI_D8/I2S2_SCK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C14',name='PI2/DCMI_D9/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PI3/DCMI_D10/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PI4/DCMI_D5/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PI5/DCMI_VSYNC/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PI6/DCMI_D6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PI7/DCMI_D7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PI8/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PI9/CAN1_RX/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI10/ETH_RX_ER',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='F4',name='PH2/ETH_CRS',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PH3/ETH_COL',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PH5/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PH6/ETH_RXD2/I2C2_SMBA/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='PH7/ETH_RXD3/I2C3_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PH8/DCMI_HSYNC/I2C3_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='PH9/DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='PH10/DCMI_D1/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='PH12/DCMI_D3/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='PH13/CAN1_TX/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='PH14/DCMI_D4/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L15',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K15',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K14',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='J15',name='PG6/FSMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J14',name='PG7/FSMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H14',name='PG8/ETH_PPS_OUT/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='PG9/DAC_EXTI9/FSMC_NCE3/FSMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PG10/FSMC_NCE4_1/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/FSMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PG12/FSMC_NE4/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='PG13/ETH_TXD0/FSMC_A24/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG14/ETH_TXD1/FSMC_A25/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PF0/FSMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PF1/FSMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='PF2/FSMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='PF3/ADC3_IN9/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='PF4/ADC3_IN14/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='PF5/ADC3_IN15/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='PF6/ADC3_IN4/FSMC_NIORD/TIM10_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='PF7/ADC3_IN5/FSMC_NREG/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PF8/ADC3_IN6/FSMC_NIOWR/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='PF9/ADC3_IN7/DAC_EXTI9/FSMC_CD/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PF10/ADC3_IN8/FSMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='R6',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12',func=Pin.BIDIR,do_erc=True),
            Pin(num='P6',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='R7',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P7',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='R1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F207ICTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F2 STM32F2x7',description='Core: ARM Cortex-M3 Package: LQFP176 Flash: 256KB Ram: 128KB Frequency: 120MHz Voltage: 1.8..3.6V IO-pins: 140',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F207IETx', 'STM32F207IFTx', 'STM32F207IGTx'],pins=[
            Pin(num='40',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='120',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='121',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='138',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='161',name='I2S3_SCK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='162',name='SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='163',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='164',name='CAN2_TX/DCMI_D5/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='165',name='DCMI_VSYNC/FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='167',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='168',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ETH_RX_ER/I2C2_SCL/I2S2_SCK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='CAN2_TX/ETH_TXD1/I2S2_SCK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='94',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='DCMI_D8/I2S3_SCK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='CAN1_RX/FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='143',name='CAN1_TX/FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='144',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='145',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='146',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='147',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='150',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='151',name='FSMC_NCE2/FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='169',name='DCMI_D2/FSMC_NBL0/TIM4_ETR/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='170',name='DCMI_D3/FSMC_NBL1/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='ETH_TXD3/FSMC_A23/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='FSMC_A19/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='DCMI_D4/FSMC_A20/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='DCMI_D6/FSMC_A21/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='DCMI_D7/FSMC_A22/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='FSMC_D4/FSMC_DA4/TIM1_ETR/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='FSMC_D5/FSMC_DA5/TIM1_CH1N/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='FSMC_D7/FSMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='FSMC_D9/FSMC_DA9/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='FSMC_D10/FSMC_DA10/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FSMC_D11/FSMC_DA11/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='NRST',do_erc=True),
            Pin(num='166',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='81',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='125',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='171',name='RFU',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='PI0/DCMI_D13/I2S2_WS/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PI1/DCMI_D8/I2S2_SCK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='PI2/DCMI_D9/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='PI3/DCMI_D10/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='173',name='PI4/DCMI_D5/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='174',name='PI5/DCMI_VSYNC/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='175',name='PI6/DCMI_D6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='176',name='PI7/DCMI_D7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='PI8/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PI9/CAN1_RX/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PI10/ETH_RX_ER',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='30',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='43',name='PH2/ETH_CRS',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PH3/ETH_COL',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PH5/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PH6/ETH_RXD2/I2C2_SMBA/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PH7/ETH_RXD3/I2C3_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PH8/DCMI_HSYNC/I2C3_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PH9/DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PH10/DCMI_D1/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PH12/DCMI_D3/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PH13/CAN1_TX/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PH14/DCMI_D4/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='130',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='106',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='107',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='108',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='PG6/FSMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='PG7/FSMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='PG8/ETH_PPS_OUT/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='152',name='PG9/DAC_EXTI9/FSMC_NCE3/FSMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='153',name='PG10/FSMC_NCE4_1/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='154',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/FSMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='155',name='PG12/FSMC_NE4/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='156',name='PG13/ETH_TXD0/FSMC_A24/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='157',name='PG14/ETH_TXD1/FSMC_A25/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='160',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PF0/FSMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='PF1/FSMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF2/FSMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF3/ADC3_IN9/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF4/ADC3_IN14/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF5/ADC3_IN15/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PF6/ADC3_IN4/FSMC_NIORD/TIM10_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PF7/ADC3_IN5/FSMC_NREG/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PF8/ADC3_IN6/FSMC_NIOWR/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PF9/ADC3_IN7/DAC_EXTI9/FSMC_CD/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PF10/ADC3_IN8/FSMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='82',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='91',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='103',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='114',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='127',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='136',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='149',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='159',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='172',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='90',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='102',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='113',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='126',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='135',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='148',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='158',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='37',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F207VCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F2 STM32F2x7',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 256KB Ram: 128KB Frequency: 120MHz Voltage: 1.8..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F207VETx', 'STM32F207VFTx', 'STM32F207VGTx'],pins=[
            Pin(num='23',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_SCK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_TX/DCMI_D5/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='DCMI_VSYNC/FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ETH_RX_ER/I2C2_SCL/I2S2_SCK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='CAN2_TX/ETH_TXD1/I2S2_SCK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DCMI_D8/I2S3_SCK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='RFU',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='97',name='PE0/DCMI_D2/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/DCMI_D3/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ETH_TXD3/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FSMC_A21/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FSMC_A22/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN1_RX/FSMC_D2/FSMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN1_TX/FSMC_D3/FSMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/FSMC_CLK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FSMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FSMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/FSMC_NWAIT/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FSMC_NCE2/FSMC_NE1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FSMC_D13/FSMC_DA13/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FSMC_D15/FSMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FSMC_A18/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FSMC_D0/FSMC_DA0/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F207ZCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F2 STM32F2x7',description='Core: ARM Cortex-M3 Package: LQFP144 Flash: 256KB Ram: 128KB Frequency: 120MHz Voltage: 1.8..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F207ZETx', 'STM32F207ZFTx', 'STM32F207ZGTx'],pins=[
            Pin(num='34',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='I2S3_SCK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='CAN2_TX/DCMI_D5/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='DCMI_VSYNC/FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='ETH_RX_ER/I2C2_SCL/I2S2_SCK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='CAN2_TX/ETH_TXD1/I2S2_SCK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='DCMI_D8/I2S3_SCK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='CAN1_RX/FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CAN1_TX/FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FSMC_NCE2/FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='106',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='143',name='RFU',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='56',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/FSMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/FSMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8/ETH_PPS_OUT/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/FSMC_NCE3/FSMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/FSMC_NCE4_1/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/FSMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FSMC_NE4/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/ETH_TXD0/FSMC_A24/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/ETH_TXD1/FSMC_A25/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FSMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FSMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FSMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/ADC3_IN9/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/ADC3_IN14/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/ADC3_IN15/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC3_IN4/FSMC_NIORD/TIM10_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC3_IN5/FSMC_NREG/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC3_IN6/FSMC_NIOWR/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC3_IN7/DAC_EXTI9/FSMC_CD/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC3_IN8/FSMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/DCMI_D2/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/DCMI_D3/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ETH_TXD3/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FSMC_A21/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FSMC_A22/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F215RETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F2 STM32F2x5',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 512KB Ram: 128KB Frequency: 120MHz Voltage: 1.8..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F215RGTx'],pins=[
            Pin(num='14',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S3_SCK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='CAN2_RX/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='CAN2_TX/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN1_RX/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN1_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/I2S2_SCK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='CAN2_TX/I2S2_SCK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11/ADC2_IN11/ADC3_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12/ADC2_IN12/ADC3_IN12/SPI2_MISO/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13/ADC2_IN13/ADC3_IN13/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14/ADC2_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15/ADC2_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_SCK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_AF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F215VETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F2 STM32F2x5',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 512KB Ram: 128KB Frequency: 120MHz Voltage: 1.8..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F215VGTx'],pins=[
            Pin(num='23',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_SCK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='CAN2_RX/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_TX/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN1_RX/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN1_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/I2S2_SCK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='CAN2_TX/I2S2_SCK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/ADC2_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/ADC2_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_SCK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='RFU',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='97',name='PE0/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FSMC_A22/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN1_RX/FSMC_D2/FSMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN1_TX/FSMC_D3/FSMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/FSMC_CLK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FSMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FSMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/FSMC_NWAIT/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FSMC_NCE2/FSMC_NE1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FSMC_D13/FSMC_DA13/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FSMC_D15/FSMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FSMC_A18/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FSMC_D0/FSMC_DA0/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F215ZETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F2 STM32F2x5',description='Core: ARM Cortex-M3 Package: LQFP144 Flash: 512KB Ram: 128KB Frequency: 120MHz Voltage: 1.8..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F215ZGTx'],pins=[
            Pin(num='34',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='I2S3_SCK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='CAN2_RX/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='CAN2_TX/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CAN1_RX/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='CAN1_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C2_SCL/I2S2_SCK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='CAN2_TX/I2S2_SCK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN14/ADC2_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN15/ADC2_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='I2S3_SCK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='CAN1_RX/FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CAN1_TX/FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FSMC_NCE2/FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='106',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='143',name='RFU',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='56',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/FSMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/FSMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/FSMC_NCE3/FSMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/FSMC_NCE4_1/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FSMC_NE4/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/FSMC_A24/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/FSMC_A25/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FSMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FSMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FSMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/ADC3_IN9/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/ADC3_IN14/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/ADC3_IN15/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC3_IN4/FSMC_NIORD/TIM10_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC3_IN5/FSMC_NREG/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC3_IN6/FSMC_NIOWR/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC3_IN7/DAC_EXTI9/FSMC_CD/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC3_IN8/FSMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FSMC_A22/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F217IEHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F2 STM32F2x7',description='Core: ARM Cortex-M3 Package: UFBGA176 Flash: 512KB Ram: 128KB Frequency: 120MHz Voltage: 1.8..3.6V IO-pins: 140',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F217IGHx'],pins=[
            Pin(num='N3',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='P2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='R2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P4',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='P3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R3',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F15',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E15',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D15',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C15',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B15',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A15',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A14',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='R5',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='R4',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='I2S3_SCK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN2_TX/DCMI_D5/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R12',name='ETH_RX_ER/I2C2_SCL/I2S2_SCK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='R13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='P12',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='P13',name='CAN2_TX/ETH_TXD1/I2S2_SCK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='R14',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R15',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P5',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H15',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G15',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G14',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F14',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B14',name='DCMI_D8/I2S3_SCK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN1_RX/FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='CAN1_TX/FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='FSMC_NCE2/FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P15',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P14',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='N15',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N14',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N13',name='FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M15',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='M14',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L14',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='DCMI_D2/FSMC_NBL0/TIM4_ETR/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DCMI_D3/FSMC_NBL1/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ETH_TXD3/FSMC_A23/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='FSMC_A19/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='DCMI_D4/FSMC_A20/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='DCMI_D6/FSMC_A21/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DCMI_D7/FSMC_A22/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R8',name='FSMC_D4/FSMC_DA4/TIM1_ETR/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P8',name='FSMC_D5/FSMC_DA5/TIM1_CH1N/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P9',name='DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R9',name='FSMC_D7/FSMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='R10',name='FSMC_D9/FSMC_DA9/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='FSMC_D10/FSMC_DA10/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P11',name='FSMC_D11/FSMC_DA11/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R11',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='J1',name='NRST',do_erc=True),
            Pin(num='D6',name='BOOT0',do_erc=True),
            Pin(num='C1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='C6',name='RFU',func=Pin.PWRIN,do_erc=True),
            Pin(num='F13',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='L4',name='REGOFF',func=Pin.PWRIN,do_erc=True),
            Pin(num='M10',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='N1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='P1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='E14',name='PI0/DCMI_D13/I2S2_WS/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D14',name='PI1/DCMI_D8/I2S2_SCK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C14',name='PI2/DCMI_D9/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PI3/DCMI_D10/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PI4/DCMI_D5/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PI5/DCMI_VSYNC/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PI6/DCMI_D6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PI7/DCMI_D7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PI8/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PI9/CAN1_RX/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI10/ETH_RX_ER',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='F4',name='PH2/ETH_CRS',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PH3/ETH_COL',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PH5/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PH6/ETH_RXD2/I2C2_SMBA/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='PH7/ETH_RXD3/I2C3_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PH8/DCMI_HSYNC/I2C3_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='PH9/DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='PH10/DCMI_D1/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='PH12/DCMI_D3/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='PH13/CAN1_TX/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='PH14/DCMI_D4/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L15',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K15',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K14',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='J15',name='PG6/FSMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J14',name='PG7/FSMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H14',name='PG8/ETH_PPS_OUT/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='PG9/DAC_EXTI9/FSMC_NCE3/FSMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PG10/FSMC_NCE4_1/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/FSMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PG12/FSMC_NE4/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='PG13/ETH_TXD0/FSMC_A24/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG14/ETH_TXD1/FSMC_A25/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PF0/FSMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PF1/FSMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='PF2/FSMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='PF3/ADC3_IN9/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='PF4/ADC3_IN14/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='PF5/ADC3_IN15/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='PF6/ADC3_IN4/FSMC_NIORD/TIM10_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='PF7/ADC3_IN5/FSMC_NREG/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PF8/ADC3_IN6/FSMC_NIOWR/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='PF9/ADC3_IN7/DAC_EXTI9/FSMC_CD/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PF10/ADC3_IN8/FSMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='R6',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12',func=Pin.BIDIR,do_erc=True),
            Pin(num='P6',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='R7',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P7',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='R1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F217IETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F2 STM32F2x7',description='Core: ARM Cortex-M3 Package: LQFP176 Flash: 512KB Ram: 128KB Frequency: 120MHz Voltage: 1.8..3.6V IO-pins: 140',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F217IGTx'],pins=[
            Pin(num='40',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='120',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='121',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='138',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='161',name='I2S3_SCK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='162',name='SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='163',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='164',name='CAN2_TX/DCMI_D5/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='165',name='DCMI_VSYNC/FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='167',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='168',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ETH_RX_ER/I2C2_SCL/I2S2_SCK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='CAN2_TX/ETH_TXD1/I2S2_SCK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='94',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='DCMI_D8/I2S3_SCK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='CAN1_RX/FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='143',name='CAN1_TX/FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='144',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='145',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='146',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='147',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='150',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='151',name='FSMC_NCE2/FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='169',name='DCMI_D2/FSMC_NBL0/TIM4_ETR/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='170',name='DCMI_D3/FSMC_NBL1/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='ETH_TXD3/FSMC_A23/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='FSMC_A19/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='DCMI_D4/FSMC_A20/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='DCMI_D6/FSMC_A21/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='DCMI_D7/FSMC_A22/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='FSMC_D4/FSMC_DA4/TIM1_ETR/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='FSMC_D5/FSMC_DA5/TIM1_CH1N/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='FSMC_D7/FSMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='FSMC_D9/FSMC_DA9/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='FSMC_D10/FSMC_DA10/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FSMC_D11/FSMC_DA11/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='NRST',do_erc=True),
            Pin(num='166',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='81',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='125',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='171',name='RFU',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='PI0/DCMI_D13/I2S2_WS/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PI1/DCMI_D8/I2S2_SCK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='PI2/DCMI_D9/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='PI3/DCMI_D10/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='173',name='PI4/DCMI_D5/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='174',name='PI5/DCMI_VSYNC/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='175',name='PI6/DCMI_D6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='176',name='PI7/DCMI_D7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='PI8/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PI9/CAN1_RX/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PI10/ETH_RX_ER',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='30',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='43',name='PH2/ETH_CRS',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PH3/ETH_COL',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PH5/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PH6/ETH_RXD2/I2C2_SMBA/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PH7/ETH_RXD3/I2C3_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PH8/DCMI_HSYNC/I2C3_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PH9/DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PH10/DCMI_D1/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PH12/DCMI_D3/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PH13/CAN1_TX/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PH14/DCMI_D4/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='130',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='106',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='107',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='108',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='PG6/FSMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='PG7/FSMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='PG8/ETH_PPS_OUT/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='152',name='PG9/DAC_EXTI9/FSMC_NCE3/FSMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='153',name='PG10/FSMC_NCE4_1/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='154',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/FSMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='155',name='PG12/FSMC_NE4/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='156',name='PG13/ETH_TXD0/FSMC_A24/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='157',name='PG14/ETH_TXD1/FSMC_A25/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='160',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PF0/FSMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='PF1/FSMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF2/FSMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF3/ADC3_IN9/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF4/ADC3_IN14/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF5/ADC3_IN15/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PF6/ADC3_IN4/FSMC_NIORD/TIM10_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PF7/ADC3_IN5/FSMC_NREG/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PF8/ADC3_IN6/FSMC_NIOWR/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PF9/ADC3_IN7/DAC_EXTI9/FSMC_CD/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PF10/ADC3_IN8/FSMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='82',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='91',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='103',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='114',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='127',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='136',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='149',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='159',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='172',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='90',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='102',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='113',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='126',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='135',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='148',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='158',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='37',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F217VETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F2 STM32F2x7',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 512KB Ram: 128KB Frequency: 120MHz Voltage: 1.8..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F217VGTx'],pins=[
            Pin(num='23',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_SCK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_TX/DCMI_D5/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='DCMI_VSYNC/FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ETH_RX_ER/I2C2_SCL/I2S2_SCK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='CAN2_TX/ETH_TXD1/I2S2_SCK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DCMI_D8/I2S3_SCK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='RFU',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='97',name='PE0/DCMI_D2/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/DCMI_D3/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ETH_TXD3/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FSMC_A21/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FSMC_A22/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN1_RX/FSMC_D2/FSMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN1_TX/FSMC_D3/FSMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/FSMC_CLK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FSMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FSMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/FSMC_NWAIT/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FSMC_NCE2/FSMC_NE1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FSMC_D13/FSMC_DA13/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FSMC_D15/FSMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FSMC_A18/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FSMC_D0/FSMC_DA0/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F217ZETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32F2 STM32F2x7',description='Core: ARM Cortex-M3 Package: LQFP144 Flash: 512KB Ram: 128KB Frequency: 120MHz Voltage: 1.8..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F217ZGTx'],pins=[
            Pin(num='34',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='I2S3_SCK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='CAN2_TX/DCMI_D5/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='DCMI_VSYNC/FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='ETH_RX_ER/I2C2_SCL/I2S2_SCK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='CAN2_TX/ETH_TXD1/I2S2_SCK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='DCMI_D8/I2S3_SCK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='CAN1_RX/FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CAN1_TX/FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FSMC_NCE2/FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='106',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='143',name='RFU',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='56',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/FSMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/FSMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8/ETH_PPS_OUT/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/FSMC_NCE3/FSMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/FSMC_NCE4_1/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/FSMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FSMC_NE4/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/ETH_TXD0/FSMC_A24/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/ETH_TXD1/FSMC_A25/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FSMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FSMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FSMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/ADC3_IN9/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/ADC3_IN14/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/ADC3_IN15/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC3_IN4/FSMC_NIORD/TIM10_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC3_IN5/FSMC_NREG/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC3_IN6/FSMC_NIOWR/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC3_IN7/DAC_EXTI9/FSMC_CD/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC3_IN8/FSMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/DCMI_D2/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/DCMI_D3/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ETH_TXD3/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FSMC_A21/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FSMC_A22/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F301C6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F301',description='Core: ARM Cortex-M4 Package: LQFP48 Flash: 32KB Ram: 16KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F301C8Tx'],pins=[
            Pin(num='10',name='ADC1_IN1/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN2/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN3/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN4/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN5/COMP2_INM/COMP4_INM/COMP6_INM/DAC_OUT1/I2S3_WS/SPI3_NSS/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='OPAMP2_VINM/OPAMP2_VINM_SEC/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN10/OPAMP2_VOUT/TIM16_CH1/TIM1_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN15/COMP2_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM17_CH1/TIM1_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SMBA/I2C3_SCL/I2S2_MCK/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/I2C2_SCL/I2C3_SMBA/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='COMP6_OUT/I2C2_SDA/I2S2_ext_SD/SPI2_MISO/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/I2S2_SD/SPI2_MOSI/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/I2S_CKIN/TIM16_CH1/TIM1_CH2N/TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/I2C1_SCL/I2S3_WS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/I2C2_SDA/I2S2_WS/RCC_OSC_IN/SPI2_NSS/TIM1_CH3N',do_erc=True),
            Pin(num='6',name='PF1/I2C2_SCL/I2S2_CK/RCC_OSC_OUT/SPI2_SCK',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC1_IN11/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC1_IN12/COMP4_OUT/TIM1_CH3N/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/COMP4_INM/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S3_CK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TSC_G5_IO1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S3_ext_SD/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TSC_G5_IO2/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2C3_SDA/I2S3_SD/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TSC_SYNC/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/COMP2_OUT/DAC_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC1_EXTI11/ADC1_IN14/COMP6_INP/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC1_IN13/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC1_EXTI15/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F301C8Yx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F301',description='Core: ARM Cortex-M4 Package: WLCSP49 Flash: 64KB Ram: 16KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='F6',name='ADC1_IN1/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='ADC1_IN2/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='ADC1_IN3/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='ADC1_IN4/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='ADC1_IN5/COMP2_INM/COMP4_INM/COMP6_INM/DAC_OUT1/I2S3_WS/SPI3_NSS/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='OPAMP2_VINM/OPAMP2_VINM_SEC/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC1_IN10/OPAMP2_VOUT/TIM16_CH1/TIM1_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC1_IN15/COMP2_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM17_CH1/TIM1_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='I2C2_SMBA/I2C3_SCL/I2S2_MCK/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='DAC_EXTI9/I2C2_SCL/I2C3_SMBA/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='COMP6_OUT/I2C2_SDA/I2S2_ext_SD/SPI2_MISO/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='ADC1_EXTI11/I2S2_SD/SPI2_MOSI/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='COMP2_OUT/I2S_CKIN/TIM16_CH1/TIM1_CH2N/TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ADC1_EXTI15/I2C1_SCL/I2S3_WS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='NC',do_erc=True),
            Pin(num='E7',name='NRST',do_erc=True),
            Pin(num='A5',name='BOOT0',do_erc=True),
            Pin(num='B6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='PF0/I2C2_SDA/I2S2_WS/RCC_OSC_IN/SPI2_NSS/TIM1_CH3N',do_erc=True),
            Pin(num='D6',name='PF1/I2C2_SCL/I2S2_CK/RCC_OSC_OUT/SPI2_SCK',do_erc=True),
            Pin(num='D5',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PB0/ADC1_IN11/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PB1/ADC1_IN12/COMP4_OUT/TIM1_CH3N/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PB2/COMP4_INM/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PB3/I2S3_CK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TSC_G5_IO1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PB4/I2S3_ext_SD/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TSC_G5_IO2/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PB5/I2C1_SMBA/I2C3_SDA/I2S3_SD/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='PB8/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TSC_SYNC/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PB9/COMP2_OUT/DAC_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PB10/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PB11/ADC1_EXTI11/ADC1_IN14/COMP6_INP/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PB12/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PB13/ADC1_IN13/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PB14/I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='PB15/ADC1_EXTI15/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='B7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='A6',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='B1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F301K6Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F301',description='Core: ARM Cortex-M4 Package: UFQFPN32 Flash: 32KB Ram: 16KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 24',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F301K8Ux'],pins=[
            Pin(num='7',name='ADC1_IN1/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC1_IN2/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_IN3/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC1_IN4/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN5/COMP2_INM/COMP4_INM/DAC_OUT1/I2S3_WS/SPI3_NSS/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='OPAMP2_VINM/OPAMP2_VINM_SEC/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN10/OPAMP2_VOUT/TIM16_CH1/TIM1_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN15/COMP2_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM17_CH1/TIM1_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='I2C2_SMBA/I2C3_SCL/I2S2_MCK/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='DAC_EXTI9/I2C2_SCL/I2C3_SMBA/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C2_SDA/I2S2_ext_SD/SPI2_MISO/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_EXTI11/I2S2_SD/SPI2_MOSI/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='COMP2_OUT/I2S_CKIN/TIM16_CH1/TIM1_CH2N/TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TSC_G4_IO3/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_EXTI15/I2C1_SCL/I2S3_WS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PF0/I2C2_SDA/I2S2_WS/RCC_OSC_IN/SPI2_NSS/TIM1_CH3N',do_erc=True),
            Pin(num='3',name='PF1/I2C2_SCL/I2S2_CK/RCC_OSC_OUT/SPI2_SCK',do_erc=True),
            Pin(num='15',name='PB0/ADC1_IN11/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/I2S3_CK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TSC_G5_IO1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/I2S3_ext_SD/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TSC_G5_IO2/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/I2C1_SMBA/I2C3_SDA/I2S3_SD/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F301R6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F301',description='Core: ARM Cortex-M4 Package: LQFP64 Flash: 32KB Ram: 16KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F301R8Tx'],pins=[
            Pin(num='14',name='ADC1_IN1/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN2/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN3/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN4/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN5/COMP2_INM/COMP4_INM/COMP6_INM/DAC_OUT1/I2S3_WS/SPI3_NSS/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='OPAMP2_VINM/OPAMP2_VINM_SEC/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN10/OPAMP2_VOUT/TIM16_CH1/TIM1_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN15/COMP2_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM17_CH1/TIM1_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='I2C2_SMBA/I2C3_SCL/I2S2_MCK/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/I2C2_SCL/I2C3_SMBA/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='COMP6_OUT/I2C2_SDA/I2S2_ext_SD/SPI2_MISO/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/I2S2_SD/SPI2_MOSI/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='COMP2_OUT/I2S_CKIN/TIM16_CH1/TIM1_CH2N/TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/I2C1_SCL/I2S3_WS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN11/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN12/COMP4_OUT/TIM1_CH3N/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='COMP4_INM/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S3_CK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2S3_ext_SD/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2C3_SDA/I2S3_SD/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/TIM16_CH1/TIM1_BKIN/TSC_SYNC/USART3_RX/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='COMP2_OUT/DAC_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/USART3_TX/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/ADC1_IN14/COMP6_INP/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN13/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/I2C2_SDA/I2S2_WS/RCC_OSC_IN/SPI2_NSS/TIM1_CH3N',do_erc=True),
            Pin(num='6',name='PF1/I2C2_SCL/I2S2_CK/RCC_OSC_OUT/SPI2_SCK',do_erc=True),
            Pin(num='54',name='PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN7/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN8/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN9/TIM1_BKIN2/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/TIM1_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/OPAMP2_VINM/OPAMP2_VINM_SEC/TIM15_BKIN/TSC_G3_IO1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/COMP6_OUT/I2S2_MCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/I2C3_SDA/I2S_CKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/SPI3_SCK/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/I2S3_ext_SD/SPI3_MISO/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SPI3_MOSI/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F302C6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F302',description='Core: ARM Cortex-M4 Package: LQFP48 Flash: 32KB Ram: 16KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F302C8Tx'],pins=[
            Pin(num='10',name='ADC1_IN1/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN2/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN3/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN4/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN5/COMP2_INM/COMP4_INM/COMP6_INM/DAC_OUT1/I2S3_WS/SPI3_NSS/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='OPAMP2_VINM/OPAMP2_VINM_SEC/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN10/OPAMP2_VOUT/TIM16_CH1/TIM1_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN15/COMP2_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM17_CH1/TIM1_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SMBA/I2C3_SCL/I2S2_MCK/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/I2C2_SCL/I2C3_SMBA/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='COMP6_OUT/I2C2_SDA/I2S2_ext_SD/SPI2_MISO/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/CAN_RX/I2S2_SD/SPI2_MOSI/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN_TX/COMP2_OUT/I2S_CKIN/TIM16_CH1/TIM1_CH2N/TIM1_ETR/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/I2C1_SCL/I2S3_WS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/I2C2_SDA/I2S2_WS/RCC_OSC_IN/SPI2_NSS/TIM1_CH3N',do_erc=True),
            Pin(num='6',name='PF1/I2C2_SCL/I2S2_CK/RCC_OSC_OUT/SPI2_SCK',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC1_IN11/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC1_IN12/COMP4_OUT/TIM1_CH3N/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/COMP4_INM/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S3_CK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TSC_G5_IO1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S3_ext_SD/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TSC_G5_IO2/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2C3_SDA/I2S3_SD/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CAN_RX/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TSC_SYNC/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/CAN_TX/COMP2_OUT/DAC_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC1_EXTI11/ADC1_IN14/COMP6_INP/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC1_IN13/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC1_EXTI15/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F302CBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F302',description='Core: ARM Cortex-M4 Package: LQFP48 Flash: 128KB Ram: 32KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F302CCTx'],pins=[
            Pin(num='10',name='ADC1_IN1/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN2/COMP1_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN3/COMP2_INM/COMP2_OUT/OPAMP1_VOUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN4/COMP2_INP/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP1_VINP/OPAMP1_VINP_SEC/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC2_IN1/COMP1_INM/COMP2_INM/COMP4_INM/COMP6_INM/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC2_IN2/COMP1_INM/COMP2_INM/COMP4_INM/COMP6_INM/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC2_IN3/COMP1_OUT/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC2_IN4/COMP2_INP/COMP2_OUT/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SMBA/I2S2_MCK/RCC_MCO/TIM1_CH1/TIM4_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/I2C2_SCL/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='COMP6_OUT/I2C2_SDA/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/COMP1_OUT/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/TIM4_CH1/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN_TX/COMP2_OUT/TIM16_CH1/TIM1_CH2N/TIM1_ETR/TIM4_CH2/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/ADC2_EXTI15/I2C1_SCL/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/I2C2_SDA/RCC_OSC_IN/TIM1_CH3N',do_erc=True),
            Pin(num='6',name='PF1/I2C2_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/COMP4_OUT/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/ADC2_IN12/COMP4_INM/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TIM4_ETR/TSC_G5_IO1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TIM4_CH1/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TIM3_CH4/TIM4_CH2/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CAN_RX/COMP1_OUT/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TIM4_CH3/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/CAN_TX/COMP2_OUT/DAC_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC1_EXTI11/ADC2_EXTI11/COMP6_INP/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC1_EXTI15/ADC2_EXTI15/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F302C8Yx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F302',description='Core: ARM Cortex-M4 Package: WLCSP49 Flash: 64KB Ram: 16KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='F6',name='ADC1_IN1/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='ADC1_IN2/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='ADC1_IN3/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='ADC1_IN4/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='ADC1_IN5/COMP2_INM/COMP4_INM/COMP6_INM/DAC_OUT1/I2S3_WS/SPI3_NSS/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='OPAMP2_VINM/OPAMP2_VINM_SEC/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC1_IN10/OPAMP2_VOUT/TIM16_CH1/TIM1_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC1_IN15/COMP2_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM17_CH1/TIM1_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='I2C2_SMBA/I2C3_SCL/I2S2_MCK/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='DAC_EXTI9/I2C2_SCL/I2C3_SMBA/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='COMP6_OUT/I2C2_SDA/I2S2_ext_SD/SPI2_MISO/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='ADC1_EXTI11/CAN_RX/I2S2_SD/SPI2_MOSI/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='CAN_TX/COMP2_OUT/I2S_CKIN/TIM16_CH1/TIM1_CH2N/TIM1_ETR/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ADC1_EXTI15/I2C1_SCL/I2S3_WS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='NC',do_erc=True),
            Pin(num='E7',name='NRST',do_erc=True),
            Pin(num='A5',name='BOOT0',do_erc=True),
            Pin(num='B6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='PF0/I2C2_SDA/I2S2_WS/RCC_OSC_IN/SPI2_NSS/TIM1_CH3N',do_erc=True),
            Pin(num='D6',name='PF1/I2C2_SCL/I2S2_CK/RCC_OSC_OUT/SPI2_SCK',do_erc=True),
            Pin(num='D5',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PB0/ADC1_IN11/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PB1/ADC1_IN12/COMP4_OUT/TIM1_CH3N/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PB2/COMP4_INM/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PB3/I2S3_CK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TSC_G5_IO1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PB4/I2S3_ext_SD/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TSC_G5_IO2/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PB5/I2C1_SMBA/I2C3_SDA/I2S3_SD/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='PB8/CAN_RX/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TSC_SYNC/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PB9/CAN_TX/COMP2_OUT/DAC_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PB10/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PB11/ADC1_EXTI11/ADC1_IN14/COMP6_INP/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PB12/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PB13/ADC1_IN13/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PB14/I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='PB15/ADC1_EXTI15/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='B7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='A6',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='B1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F302K6Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F302',description='Core: ARM Cortex-M4 Package: UFQFPN32 Flash: 32KB Ram: 16KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 24',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F302K8Ux'],pins=[
            Pin(num='7',name='ADC1_IN1/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC1_IN2/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_IN3/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC1_IN4/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN5/COMP2_INM/COMP4_INM/DAC_OUT1/I2S3_WS/SPI3_NSS/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='OPAMP2_VINM/OPAMP2_VINM_SEC/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN10/OPAMP2_VOUT/TIM16_CH1/TIM1_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN15/COMP2_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM17_CH1/TIM1_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='I2C2_SMBA/I2C3_SCL/I2S2_MCK/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='DAC_EXTI9/I2C2_SCL/I2C3_SMBA/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C2_SDA/I2S2_ext_SD/SPI2_MISO/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_EXTI11/CAN_RX/I2S2_SD/SPI2_MOSI/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='CAN_TX/COMP2_OUT/I2S_CKIN/TIM16_CH1/TIM1_CH2N/TIM1_ETR/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TSC_G4_IO3/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_EXTI15/I2C1_SCL/I2S3_WS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PF0/I2C2_SDA/I2S2_WS/RCC_OSC_IN/SPI2_NSS/TIM1_CH3N',do_erc=True),
            Pin(num='3',name='PF1/I2C2_SCL/I2S2_CK/RCC_OSC_OUT/SPI2_SCK',do_erc=True),
            Pin(num='15',name='PB0/ADC1_IN11/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/I2S3_CK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TSC_G5_IO1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/I2S3_ext_SD/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TSC_G5_IO2/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/I2C1_SMBA/I2C3_SDA/I2S3_SD/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F302R6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F302',description='Core: ARM Cortex-M4 Package: LQFP64 Flash: 32KB Ram: 16KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F302R8Tx'],pins=[
            Pin(num='14',name='ADC1_IN1/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN2/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN3/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN4/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN5/COMP2_INM/COMP4_INM/COMP6_INM/DAC_OUT1/I2S3_WS/SPI3_NSS/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='OPAMP2_VINM/OPAMP2_VINM_SEC/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN10/OPAMP2_VOUT/TIM16_CH1/TIM1_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN15/COMP2_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM17_CH1/TIM1_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='I2C2_SMBA/I2C3_SCL/I2S2_MCK/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/I2C2_SCL/I2C3_SMBA/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='COMP6_OUT/I2C2_SDA/I2S2_ext_SD/SPI2_MISO/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/CAN_RX/I2S2_SD/SPI2_MOSI/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN_TX/COMP2_OUT/I2S_CKIN/TIM16_CH1/TIM1_CH2N/TIM1_ETR/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/I2C1_SCL/I2S3_WS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN11/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN12/COMP4_OUT/TIM1_CH3N/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='COMP4_INM/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S3_CK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2S3_ext_SD/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2C3_SDA/I2S3_SD/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN_RX/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TSC_SYNC/USART3_RX/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN_TX/COMP2_OUT/DAC_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/USART3_TX/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/ADC1_IN14/COMP6_INP/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN13/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/I2C2_SDA/I2S2_WS/RCC_OSC_IN/SPI2_NSS/TIM1_CH3N',do_erc=True),
            Pin(num='6',name='PF1/I2C2_SCL/I2S2_CK/RCC_OSC_OUT/SPI2_SCK',do_erc=True),
            Pin(num='54',name='PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN7/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN8/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN9/TIM1_BKIN2/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/TIM1_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/OPAMP2_VINM/OPAMP2_VINM_SEC/TIM15_BKIN/TSC_G3_IO1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/COMP6_OUT/I2S2_MCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/I2C3_SDA/I2S_CKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/SPI3_SCK/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/I2S3_ext_SD/SPI3_MISO/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SPI3_MOSI/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F302RBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F302',description='Core: ARM Cortex-M4 Package: LQFP64 Flash: 128KB Ram: 32KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 52',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F302RCTx'],pins=[
            Pin(num='14',name='ADC1_IN1/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN2/COMP1_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN3/COMP2_INM/COMP2_OUT/OPAMP1_VOUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN4/COMP2_INP/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP1_VINP/OPAMP1_VINP_SEC/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC2_IN1/COMP1_INM/COMP2_INM/COMP4_INM/COMP6_INM/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC2_IN2/COMP1_INM/COMP2_INM/COMP4_INM/COMP6_INM/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC2_IN3/COMP1_OUT/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC2_IN4/COMP2_INP/COMP2_OUT/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='I2C2_SMBA/I2S2_MCK/RCC_MCO/TIM1_CH1/TIM4_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/I2C2_SCL/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='COMP6_OUT/I2C2_SDA/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/COMP1_OUT/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/TIM4_CH1/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN_TX/COMP2_OUT/TIM16_CH1/TIM1_CH2N/TIM1_ETR/TIM4_CH2/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/ADC2_EXTI15/I2C1_SCL/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='COMP4_OUT/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC2_IN12/COMP4_INM/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TIM4_ETR/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/TIM4_CH1/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/TIM3_CH4/TIM4_CH2/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN_RX/COMP1_OUT/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TIM4_CH3/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN_TX/COMP2_OUT/DAC_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/ADC2_EXTI11/COMP6_INP/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/ADC2_EXTI15/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/I2C2_SDA/RCC_OSC_IN/TIM1_CH3N',do_erc=True),
            Pin(num='6',name='PF1/I2C2_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='18',name='PF4/ADC1_IN5/COMP1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN6/ADC2_IN6',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN7/ADC2_IN7',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN8/ADC2_IN8',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN9/ADC2_IN9/TIM1_BKIN2',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC2_IN5/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC2_IN11/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/TSC_G3_IO1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/COMP6_OUT/I2S2_MCK/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/I2S_CKIN/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/SPI3_SCK/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/ADC2_EXTI11/I2S3_ext_SD/SPI3_MISO/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SPI3_MOSI/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F302RDTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F302',description='Core: ARM Cortex-M4 Package: LQFP64 Flash: 384KB Ram: 64KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F302RETx'],pins=[
            Pin(num='14',name='ADC1_IN1/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN2/COMP1_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN3/COMP2_INM/COMP2_OUT/OPAMP1_VOUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN4/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP1_VINP/OPAMP1_VINP_SEC/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC2_IN1/COMP1_INM/COMP2_INM/COMP4_INM/COMP6_INM/DAC1_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC2_IN2/COMP1_INM/COMP2_INM/COMP4_INM/COMP6_INM/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC2_IN3/COMP1_OUT/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC2_IN4/COMP2_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='I2C2_SMBA/I2C3_SCL/I2S2_MCK/RCC_MCO/TIM1_CH1/TIM4_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC1_EXTI9/I2C2_SCL/I2C3_SMBA/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='COMP6_OUT/I2C2_SDA/I2S2_ext_SD/SPI2_MISO/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/COMP1_OUT/I2S2_SD/SPI2_MOSI/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/TIM4_CH1/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN_TX/COMP2_OUT/I2S_CKIN/TIM16_CH1/TIM1_CH2N/TIM1_ETR/TIM4_CH2/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/ADC2_EXTI15/I2C1_SCL/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='COMP4_OUT/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC2_IN12/COMP4_INM/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TIM4_ETR/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2C3_SDA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/TIM4_CH1/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/TIM3_CH4/TIM4_CH2/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN_RX/COMP1_OUT/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TIM4_CH3/TSC_SYNC/USART3_RX/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN_TX/COMP2_OUT/DAC1_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/TIM4_CH4/USART3_TX/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/ADC1_IN14/ADC2_EXTI11/ADC2_IN14/COMP6_INP/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/ADC2_EXTI15/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/I2C2_SDA/I2S2_WS/RCC_OSC_IN/SPI2_NSS/TIM1_CH3N',do_erc=True),
            Pin(num='6',name='PF1/I2C2_SCL/I2S2_CK/RCC_OSC_OUT/SPI2_SCK',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN6/ADC2_IN6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN7/ADC2_IN7/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN8/ADC2_IN8/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN9/ADC2_IN9/TIM1_BKIN2/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC2_IN5/TIM1_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC2_IN11/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/TIM15_BKIN/TSC_G3_IO1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/COMP6_OUT/I2S2_MCK/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC1_EXTI9/I2C3_SDA/I2S_CKIN/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/SPI3_SCK/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/ADC2_EXTI11/I2S3_ext_SD/SPI3_MISO/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SPI3_MOSI/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F302VBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F302',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 128KB Ram: 32KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 87',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F302VCTx'],pins=[
            Pin(num='23',name='ADC1_IN1/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN2/COMP1_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN3/COMP2_INM/COMP2_OUT/OPAMP1_VOUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN4/COMP2_INP/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP1_VINP/OPAMP1_VINP_SEC/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC2_IN1/COMP1_INM/COMP2_INM/COMP4_INM/COMP6_INM/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC2_IN2/COMP1_INM/COMP2_INM/COMP4_INM/COMP6_INM/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC2_IN3/COMP1_OUT/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC2_IN4/COMP2_INP/COMP2_OUT/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C2_SMBA/I2S2_MCK/RCC_MCO/TIM1_CH1/TIM4_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/I2C2_SCL/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='COMP6_OUT/I2C2_SDA/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/COMP1_OUT/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/TIM4_CH1/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN_TX/COMP2_OUT/TIM16_CH1/TIM1_CH2N/TIM1_ETR/TIM4_CH2/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/I2C1_SCL/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='COMP4_OUT/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC2_IN12/COMP4_INM/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TIM4_ETR/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM16_CH1N/TIM4_CH1/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/TIM17_CH1N/TIM3_CH4/TIM4_CH2/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN_RX/COMP1_OUT/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TIM4_CH3/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN_TX/COMP2_OUT/DAC_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/COMP6_INP/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN6/ADC2_IN6/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN7/ADC2_IN7/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN8/ADC2_IN8/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN9/ADC2_IN9/TIM1_BKIN2/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC2_IN5/USART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC2_IN11/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/TSC_G3_IO1/USART1_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='COMP6_OUT/I2S2_MCK/TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/I2S_CKIN/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/I2S3_ext_SD/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PF0/I2C2_SDA/RCC_OSC_IN/TIM1_CH3N',do_erc=True),
            Pin(num='13',name='PF1/I2C2_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='19',name='PF2/ADC1_IN10/ADC2_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PF4/ADC1_IN5/COMP1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='PF6/I2C2_SCL/TIM4_CH4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF9/DAC_EXTI9/SPI2_SCK/TIM15_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF10/SPI2_SCK/TIM15_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/TIM16_CH1/TIM4_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/TIM17_CH1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/SYS_TRACECK/TIM3_CH1/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/SYS_TRACED0/TIM3_CH2/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH3/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM3_CH4/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/COMP4_INP/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/COMP4_INM/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/TIM1_BKIN2/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/TIM1_BKIN/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/TIM2_CH1/TIM2_ETR/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/TIM2_CH2/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/TIM2_CH4/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM2_CH3/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/COMP6_INM/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/COMP6_INP/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/TIM4_CH1/TSC_G8_IO1/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/TIM4_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM4_CH3/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/SPI2_NSS/TIM4_CH4/TSC_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F302VDTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F302',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 384KB Ram: 64KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 86',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F302VETx'],pins=[
            Pin(num='23',name='ADC1_IN1/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN2/COMP1_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN3/COMP2_INM/COMP2_OUT/OPAMP1_VOUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN4/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP1_VINP/OPAMP1_VINP_SEC/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC2_IN1/COMP1_INM/COMP2_INM/COMP4_INM/COMP6_INM/DAC1_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC2_IN2/COMP1_INM/COMP2_INM/COMP4_INM/COMP6_INM/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC2_IN3/COMP1_OUT/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC2_IN4/COMP2_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C2_SMBA/I2C3_SCL/I2S2_MCK/RCC_MCO/TIM1_CH1/TIM4_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC1_EXTI9/I2C2_SCL/I2C3_SMBA/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='COMP6_OUT/I2C2_SDA/I2S2_ext_SD/SPI2_MISO/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/COMP1_OUT/I2S2_SD/SPI2_MOSI/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/TIM4_CH1/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN_TX/COMP2_OUT/I2S_CKIN/TIM16_CH1/TIM1_CH2N/TIM1_ETR/TIM4_CH2/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/I2C1_SCL/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='COMP4_OUT/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC2_IN12/COMP4_INM/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TIM4_ETR/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/I2C3_SDA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM16_CH1N/TIM4_CH1/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='FMC_NL/I2C1_SDA/TIM17_CH1N/TIM3_CH4/TIM4_CH2/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN_RX/COMP1_OUT/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TIM4_CH3/TSC_SYNC/USART3_RX/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN_TX/COMP2_OUT/DAC1_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/TIM4_CH4/USART3_TX/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC1_IN14/ADC2_EXTI11/ADC2_IN14/COMP6_INP/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN6/ADC2_IN6/TIM1_CH1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN7/ADC2_IN7/TIM1_CH2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN8/ADC2_IN8/TIM1_CH3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN9/ADC2_IN9/TIM1_BKIN2/TIM1_CH4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC2_IN5/TIM1_ETR/USART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC2_IN11/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/TIM15_BKIN/TSC_G3_IO1/USART1_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='COMP6_OUT/I2S2_MCK/TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC1_EXTI9/I2C3_SDA/I2S_CKIN/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/I2S3_ext_SD/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PF0/I2C2_SDA/I2S2_WS/RCC_OSC_IN/SPI2_NSS/TIM1_CH3N',do_erc=True),
            Pin(num='13',name='PF1/I2C2_SCL/I2S2_CK/RCC_OSC_OUT/SPI2_SCK',do_erc=True),
            Pin(num='19',name='PF2/ADC1_IN10/ADC2_IN10/FMC_A2',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='PF6/FMC_NIORD/I2C2_SCL/TIM4_CH4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF9/DAC1_EXTI9/FMC_CD/SPI2_SCK/TIM15_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF10/FMC_INTR/SPI2_SCK/TIM15_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/FMC_NBL0/TIM16_CH1/TIM4_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/FMC_NBL1/TIM17_CH1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FMC_A23/SPI4_SCK/SYS_TRACECK/TIM3_CH1/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/SPI4_NSS/SYS_TRACED0/TIM3_CH2/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FMC_A20/SPI4_NSS/SYS_TRACED1/TIM3_CH3/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FMC_A21/SPI4_MISO/SYS_TRACED2/TIM3_CH4/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FMC_A22/RTC_TAMP3/SPI4_MOSI/SYS_TRACED3/SYS_WKUP3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/FMC_D4/FMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/COMP4_INM/FMC_D5/FMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC1_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/FMC_D7/FMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/FMC_D8/FMC_DA8/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/FMC_D9/FMC_DA9/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/FMC_D10/FMC_DA10/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FMC_D11/FMC_DA11/SPI4_MOSI/TIM1_BKIN2/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/FMC_D12/FMC_DA12/TIM1_BKIN/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN_RX/FMC_D2/FMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN_TX/FMC_D3/FMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/FMC_CLK/TIM2_CH1/TIM2_ETR/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FMC_NOE/TIM2_CH2/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/FMC_NWAIT/TIM2_CH4/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FMC_NCE2/FMC_NE1/TIM2_CH3/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FMC_D13/FMC_DA13/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC1_EXTI9/FMC_D14/FMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/COMP6_INM/FMC_D15/FMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/FMC_A16/FMC_CLE/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FMC_A17/FMC_ALE/TIM4_CH1/TSC_G8_IO1/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FMC_A18/TIM4_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FMC_D0/FMC_DA0/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM4_CH3/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/FMC_D1/FMC_DA1/SPI2_NSS/TIM4_CH4/TSC_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F302ZDTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F302',description='Core: ARM Cortex-M4 Package: LQFP144 Flash: 384KB Ram: 64KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 115',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F302ZETx'],pins=[
            Pin(num='34',name='ADC1_IN1/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN2/COMP1_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN3/COMP2_INM/COMP2_OUT/OPAMP1_VOUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN4/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP1_VINP/OPAMP1_VINP_SEC/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC2_IN1/COMP1_INM/COMP2_INM/COMP4_INM/COMP6_INM/DAC1_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC2_IN2/COMP1_INM/COMP2_INM/COMP4_INM/COMP6_INM/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC2_IN3/COMP1_OUT/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC2_IN4/COMP2_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='I2C2_SMBA/I2C3_SCL/I2S2_MCK/RCC_MCO/TIM1_CH1/TIM4_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC1_EXTI9/I2C2_SCL/I2C3_SMBA/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='COMP6_OUT/I2C2_SDA/I2S2_ext_SD/SPI2_MISO/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/COMP1_OUT/I2S2_SD/SPI2_MOSI/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/TIM4_CH1/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN_TX/COMP2_OUT/I2S_CKIN/TIM16_CH1/TIM1_CH2N/TIM1_ETR/TIM4_CH2/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC1_EXTI15/ADC2_EXTI15/I2C1_SCL/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='COMP4_OUT/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC2_IN12/COMP4_INM/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TIM4_ETR/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='I2C1_SMBA/I2C3_SDA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='I2C1_SCL/TIM16_CH1N/TIM4_CH1/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='FMC_NL/I2C1_SDA/TIM17_CH1N/TIM3_CH4/TIM4_CH2/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CAN_RX/COMP1_OUT/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TIM4_CH3/TSC_SYNC/USART3_RX/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='CAN_TX/COMP2_OUT/DAC1_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/TIM4_CH4/USART3_TX/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC1_IN14/ADC2_EXTI11/ADC2_IN14/COMP6_INP/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN6/ADC2_IN6/TIM1_CH1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN7/ADC2_IN7/TIM1_CH2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN8/ADC2_IN8/TIM1_CH3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN9/ADC2_IN9/TIM1_BKIN2/TIM1_CH4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC2_IN5/TIM1_ETR/USART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC2_IN11/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/TIM15_BKIN/TSC_G3_IO1/USART1_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='COMP6_OUT/I2S2_MCK/TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='I2S3_MCK/TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC1_EXTI9/I2C3_SDA/I2S_CKIN/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='I2S3_CK/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/ADC2_EXTI11/I2S3_ext_SD/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='I2S3_SD/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='CAN_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CAN_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='FMC_CLK/TIM2_CH1/TIM2_ETR/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FMC_NOE/TIM2_CH2/USART2_DE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='FMC_NWAIT/TIM2_CH4/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FMC_NCE2/FMC_NE1/TIM2_CH3/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC1_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='COMP6_INM/FMC_D15/FMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FMC_A17/FMC_ALE/TIM4_CH1/TSC_G8_IO1/USART3_DE/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FMC_A18/TIM4_CH2/TSC_G8_IO2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FMC_D0/FMC_DA0/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM4_CH3/TSC_G8_IO3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC1_EXTI15/ADC2_EXTI15/FMC_D1/FMC_DA1/SPI2_NSS/TIM4_CH4/TSC_G8_IO4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='PH0/FMC_A0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PH1/FMC_A1',func=Pin.BIDIR,do_erc=True),
            Pin(num='106',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/FMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/FMC_INT3',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC1_EXTI9/FMC_NCE3/FMC_NE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/FMC_NCE4_1/FMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/ADC2_EXTI11/FMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FMC_NE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/FMC_A24',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/FMC_A25',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC1_EXTI15/ADC2_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='PF0/I2C2_SDA/I2S2_WS/RCC_OSC_IN/SPI2_NSS/TIM1_CH3N',do_erc=True),
            Pin(num='24',name='PF1/I2C2_SCL/I2S2_CK/RCC_OSC_OUT/SPI2_SCK',do_erc=True),
            Pin(num='12',name='PF2/ADC1_IN10/ADC2_IN10/FMC_A2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/ADC1_IN5/COMP1_OUT/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/FMC_NIORD/I2C2_SCL/TIM4_CH4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/FMC_NREG',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/FMC_NIOWR',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/DAC1_EXTI9/FMC_CD/SPI2_SCK/TIM15_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/FMC_INTR/SPI2_SCK/TIM15_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/ADC2_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC1_EXTI15/ADC2_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/FMC_NBL0/TIM16_CH1/TIM4_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/FMC_NBL1/TIM17_CH1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FMC_A23/SPI4_SCK/SYS_TRACECK/TIM3_CH1/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/SPI4_NSS/SYS_TRACED0/TIM3_CH2/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FMC_A20/SPI4_NSS/SYS_TRACED1/TIM3_CH3/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FMC_A21/SPI4_MISO/SYS_TRACED2/TIM3_CH4/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FMC_A22/RTC_TAMP3/SPI4_MOSI/SYS_TRACED3/SYS_WKUP3',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/FMC_D4/FMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/COMP4_INM/FMC_D5/FMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC1_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/FMC_D7/FMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/ADC2_EXTI11/FMC_D8/FMC_DA8/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FMC_D9/FMC_DA9/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FMC_D10/FMC_DA10/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FMC_D11/FMC_DA11/SPI4_MOSI/TIM1_BKIN2/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC1_EXTI15/ADC2_EXTI15/FMC_D12/FMC_DA12/TIM1_BKIN/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='143',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F303C6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F303',description='Core: ARM Cortex-M4 Package: LQFP48 Flash: 32KB Ram: 12KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F303C8Tx'],pins=[
            Pin(num='10',name='ADC1_IN1/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN2/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN3/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN4/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC2_IN1/COMP2_INM/COMP4_INM/COMP6_INM/DAC1_OUT1/SPI1_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC2_IN2/DAC1_OUT2/OPAMP2_VINM/OPAMP2_VINM_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC2_IN3/DAC2_OUT1/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC2_IN4/COMP2_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC1_EXTI9/DAC2_EXTI9/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='COMP6_OUT/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='CAN_RX/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN_TX/COMP2_OUT/TIM16_CH1/TIM1_CH2N/TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2C1_SCL/SPI1_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN/TIM1_CH3N',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC1_IN11/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC1_IN12/COMP4_OUT/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/ADC2_IN12/COMP4_INM/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TSC_G5_IO1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/SPI1_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/SPI1_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TIM3_CH4/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CAN_RX/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TSC_SYNC/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/CAN_TX/COMP2_OUT/DAC1_EXTI9/DAC2_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/COMP6_INP/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/ADC2_IN13/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC1_IN13/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/ADC2_IN14/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC2_IN15/COMP6_INM/RTC_REFIN/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F303CBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F303',description='Core: ARM Cortex-M4 Package: LQFP48 Flash: 128KB Ram: 32KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F303CCTx'],pins=[
            Pin(num='10',name='ADC1_IN1/COMP1_INM/COMP1_OUT/COMP7_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM8_BKIN/TIM8_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN2/COMP1_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN3/ADC3_EXTI2/ADC4_EXTI2/COMP2_INM/COMP2_OUT/OPAMP1_VOUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN4/COMP2_INP/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP1_VINP/OPAMP1_VINP_SEC/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC2_IN1/COMP1_INM/COMP2_INM/COMP3_INM/COMP4_INM/COMP5_INM/COMP6_INM/COMP7_INM/DAC_OUT1/I2S3_WS/OPAMP4_VINP/OPAMP4_VINP_SEC/SPI1_NSS/SPI3_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC2_IN2/COMP1_INM/COMP2_INM/COMP3_INM/COMP4_INM/COMP5_INM/COMP6_INM/COMP7_INM/DAC_OUT2/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC2_IN3/COMP1_OUT/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC2_IN4/COMP2_INP/COMP2_OUT/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='COMP3_OUT/I2C2_SMBA/I2S2_MCK/RCC_MCO/TIM1_CH1/TIM4_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='COMP5_OUT/DAC_EXTI9/I2C2_SCL/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='COMP6_OUT/I2C2_SDA/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TIM8_BKIN/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/COMP1_OUT/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/TIM4_CH1/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN_TX/COMP2_OUT/TIM16_CH1/TIM1_CH2N/TIM1_ETR/TIM4_CH2/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TIM8_CH2/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/ADC2_EXTI15/I2C1_SCL/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TIM8_CH1/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/I2C2_SDA/RCC_OSC_IN/TIM1_CH3N',do_erc=True),
            Pin(num='6',name='PF1/I2C2_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC3_IN12/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC3_IN1/COMP4_OUT/OPAMP3_VOUT/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/ADC2_IN12/ADC3_EXTI2/ADC4_EXTI2/COMP4_INM/OPAMP3_VINM/OPAMP3_VINM_SEC/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TIM4_ETR/TIM8_CH1N/TSC_G5_IO1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TIM8_CH2N/TSC_G5_IO2/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/TIM8_CH3N/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_CH1/TIM8_ETR/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TIM3_CH4/TIM4_CH2/TIM8_BKIN/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CAN_RX/COMP1_OUT/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TIM4_CH3/TIM8_CH2/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/CAN_TX/COMP2_OUT/DAC_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/TIM4_CH4/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/COMP5_INM/OPAMP3_VINM/OPAMP3_VINM_SEC/OPAMP4_VINM/OPAMP4_VINM_SEC/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC1_EXTI11/ADC2_EXTI11/COMP6_INP/OPAMP4_VINP/OPAMP4_VINP_SEC/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/ADC4_IN3/COMP3_INM/I2C2_SMBA/I2S2_WS/OPAMP4_VOUT/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC3_IN5/COMP5_INP/I2S2_CK/OPAMP3_VINP/OPAMP3_VINP_SEC/OPAMP4_VINP/OPAMP4_VINP_SEC/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/ADC4_IN4/COMP3_INP/I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC1_EXTI15/ADC2_EXTI15/ADC4_IN5/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F303K6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F303',description='Core: ARM Cortex-M4 Package: LQFP32 Flash: 32KB Ram: 12KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 25',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F303K8Tx'],pins=[
            Pin(num='6',name='ADC1_IN1/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC1_IN2/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC1_IN3/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_IN4/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC2_IN1/COMP2_INM/COMP4_INM/DAC1_OUT1/SPI1_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC2_IN2/DAC1_OUT2/OPAMP2_VINM/OPAMP2_VINM_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC2_IN3/DAC2_OUT1/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC2_IN4/COMP2_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='DAC1_EXTI9/DAC2_EXTI9/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='CAN_RX/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='CAN_TX/COMP2_OUT/TIM16_CH1/TIM1_CH2N/TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TSC_G4_IO3/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='I2C1_SCL/SPI1_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PF0/RCC_OSC_IN/TIM1_CH3N',do_erc=True),
            Pin(num='3',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='14',name='PB0/ADC1_IN11/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC1_IN12/COMP4_OUT/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TSC_G5_IO1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/SPI1_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/I2C1_SMBA/SPI1_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/I2C1_SDA/TIM17_CH1N/TIM3_CH4/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F303R6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F303',description='Core: ARM Cortex-M4 Package: LQFP64 Flash: 32KB Ram: 12KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F303R8Tx'],pins=[
            Pin(num='14',name='ADC1_IN1/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN2/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN3/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN4/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC2_IN1/COMP2_INM/COMP4_INM/COMP6_INM/DAC1_OUT1/SPI1_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC2_IN2/DAC1_OUT2/OPAMP2_VINM/OPAMP2_VINM_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC2_IN3/DAC2_OUT1/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC2_IN4/COMP2_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC1_EXTI9/DAC2_EXTI9/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='COMP6_OUT/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='CAN_RX/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN_TX/COMP2_OUT/TIM16_CH1/TIM1_CH2N/TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='I2C1_SCL/SPI1_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN11/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN12/COMP4_OUT/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC2_IN12/COMP4_INM/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='SPI1_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/SPI1_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/TIM3_CH4/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN_RX/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TSC_SYNC/USART3_RX/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN_TX/COMP2_OUT/DAC1_EXTI9/DAC2_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/USART3_TX/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='COMP6_INP/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC2_IN13/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN13/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC2_IN14/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC2_IN15/COMP6_INM/RTC_REFIN/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN/TIM1_CH3N',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN6/ADC2_IN6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN7/ADC2_IN7/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN8/ADC2_IN8/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN9/ADC2_IN9/TIM1_BKIN2/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC2_IN5/TIM1_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC2_IN11/OPAMP2_VINM/OPAMP2_VINM_SEC/TIM15_BKIN/TSC_G3_IO1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/COMP6_OUT/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC1_EXTI9/DAC2_EXTI9/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F303RBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F303',description='Core: ARM Cortex-M4 Package: LQFP64 Flash: 128KB Ram: 32KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 52',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F303RCTx'],pins=[
            Pin(num='14',name='ADC1_IN1/COMP1_INM/COMP1_OUT/COMP7_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM8_BKIN/TIM8_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN2/COMP1_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN3/ADC3_EXTI2/ADC4_EXTI2/COMP2_INM/COMP2_OUT/OPAMP1_VOUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN4/COMP2_INP/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP1_VINP/OPAMP1_VINP_SEC/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC2_IN1/COMP1_INM/COMP2_INM/COMP3_INM/COMP4_INM/COMP5_INM/COMP6_INM/COMP7_INM/DAC_OUT1/I2S3_WS/OPAMP4_VINP/OPAMP4_VINP_SEC/SPI1_NSS/SPI3_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC2_IN2/COMP1_INM/COMP2_INM/COMP3_INM/COMP4_INM/COMP5_INM/COMP6_INM/COMP7_INM/DAC_OUT2/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC2_IN3/COMP1_OUT/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC2_IN4/COMP2_INP/COMP2_OUT/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='COMP3_OUT/I2C2_SMBA/I2S2_MCK/RCC_MCO/TIM1_CH1/TIM4_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='COMP5_OUT/DAC_EXTI9/I2C2_SCL/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='COMP6_OUT/I2C2_SDA/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TIM8_BKIN/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/COMP1_OUT/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/TIM4_CH1/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN_TX/COMP2_OUT/TIM16_CH1/TIM1_CH2N/TIM1_ETR/TIM4_CH2/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TIM8_CH2/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/ADC2_EXTI15/I2C1_SCL/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TIM8_CH1/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC3_IN12/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC3_IN1/COMP4_OUT/OPAMP3_VOUT/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC2_IN12/ADC3_EXTI2/ADC4_EXTI2/COMP4_INM/OPAMP3_VINM/OPAMP3_VINM_SEC/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TIM4_ETR/TIM8_CH1N/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TIM8_CH2N/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/TIM8_CH3N/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_CH1/TIM8_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/TIM3_CH4/TIM4_CH2/TIM8_BKIN/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN_RX/COMP1_OUT/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TIM4_CH3/TIM8_CH2/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN_TX/COMP2_OUT/DAC_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/TIM4_CH4/TIM8_CH3/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='COMP5_INM/OPAMP3_VINM/OPAMP3_VINM_SEC/OPAMP4_VINM/OPAMP4_VINM_SEC/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/ADC2_EXTI11/COMP6_INP/OPAMP4_VINP/OPAMP4_VINP_SEC/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC4_IN3/COMP3_INM/I2C2_SMBA/I2S2_WS/OPAMP4_VOUT/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC3_IN5/COMP5_INP/I2S2_CK/OPAMP3_VINP/OPAMP3_VINP_SEC/OPAMP4_VINP/OPAMP4_VINP_SEC/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC4_IN4/COMP3_INP/I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/ADC2_EXTI15/ADC4_IN5/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/I2C2_SDA/RCC_OSC_IN/TIM1_CH3N',do_erc=True),
            Pin(num='6',name='PF1/I2C2_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='18',name='PF4/ADC1_IN5/COMP1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PD2/ADC3_EXTI2/ADC4_EXTI2/TIM3_ETR/TIM8_BKIN/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN6/ADC2_IN6/COMP7_INM',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN7/ADC2_IN7/COMP7_INP',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN8/ADC2_IN8/ADC3_EXTI2/ADC4_EXTI2/COMP7_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN9/ADC2_IN9/TIM1_BKIN2',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC2_IN5/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC2_IN11/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/TSC_G3_IO1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/COMP6_OUT/I2S2_MCK/TIM3_CH1/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/COMP5_OUT/I2S3_MCK/TIM3_CH2/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/COMP3_OUT/TIM3_CH3/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/I2S_CKIN/TIM3_CH4/TIM8_BKIN2/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/SPI3_SCK/TIM8_CH1N/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/ADC2_EXTI11/I2S3_ext_SD/SPI3_MISO/TIM8_CH2N/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SPI3_MOSI/TIM8_CH3N/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F303RDTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F303',description='Core: ARM Cortex-M4 Package: LQFP64 Flash: 384KB Ram: 64KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F303RETx'],pins=[
            Pin(num='14',name='ADC1_IN1/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM8_BKIN/TIM8_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN2/COMP1_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN3/ADC3_EXTI2/ADC4_EXTI2/COMP2_INM/COMP2_OUT/OPAMP1_VOUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN4/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP1_VINP/OPAMP1_VINP_SEC/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC2_IN1/COMP1_INM/COMP2_INM/COMP3_INM/COMP4_INM/COMP5_INM/COMP6_INM/COMP7_INM/DAC1_OUT1/I2S3_WS/OPAMP4_VINP/OPAMP4_VINP_SEC/SPI1_NSS/SPI3_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC2_IN2/COMP1_INM/COMP2_INM/COMP3_INM/COMP4_INM/COMP5_INM/COMP6_INM/COMP7_INM/DAC1_OUT2/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC2_IN3/COMP1_OUT/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC2_IN4/COMP2_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='COMP3_OUT/I2C2_SMBA/I2C3_SCL/I2S2_MCK/RCC_MCO/TIM1_CH1/TIM4_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='COMP5_OUT/DAC1_EXTI9/I2C2_SCL/I2C3_SMBA/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='COMP6_OUT/I2C2_SDA/I2S2_ext_SD/SPI2_MISO/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TIM8_BKIN/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/COMP1_OUT/I2S2_SD/SPI2_MOSI/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/TIM4_CH1/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN_TX/COMP2_OUT/I2S_CKIN/TIM16_CH1/TIM1_CH2N/TIM1_ETR/TIM4_CH2/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TIM8_CH2/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/I2C1_SCL/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TIM8_CH1/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC3_IN12/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC3_IN1/COMP4_OUT/OPAMP3_VOUT/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC2_IN12/ADC3_EXTI2/ADC4_EXTI2/COMP4_INM/OPAMP3_VINM/OPAMP3_VINM_SEC/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TIM4_ETR/TIM8_CH1N/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TIM8_CH2N/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2C3_SDA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/TIM8_CH3N/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_CH1/TIM8_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/TIM3_CH4/TIM4_CH2/TIM8_BKIN/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN_RX/COMP1_OUT/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TIM4_CH3/TIM8_CH2/TSC_SYNC/USART3_RX/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN_TX/COMP2_OUT/DAC1_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/TIM4_CH4/TIM8_CH3/USART3_TX/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='COMP5_INM/OPAMP3_VINM/OPAMP3_VINM_SEC/OPAMP4_VINM/OPAMP4_VINM_SEC/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/ADC1_IN14/ADC2_EXTI11/ADC2_IN14/COMP6_INP/OPAMP4_VINP/OPAMP4_VINP_SEC/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC4_IN3/COMP3_INM/I2C2_SMBA/I2S2_WS/OPAMP4_VOUT/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC3_IN5/COMP5_INP/I2S2_CK/OPAMP3_VINP/OPAMP3_VINP_SEC/OPAMP4_VINP/OPAMP4_VINP_SEC/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC4_IN4/COMP3_INP/I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/ADC4_IN5/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/I2C2_SDA/I2S2_WS/RCC_OSC_IN/SPI2_NSS/TIM1_CH3N',do_erc=True),
            Pin(num='6',name='PF1/I2C2_SCL/I2S2_CK/RCC_OSC_OUT/SPI2_SCK',do_erc=True),
            Pin(num='54',name='PD2/ADC3_EXTI2/ADC4_EXTI2/TIM3_ETR/TIM8_BKIN/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN6/ADC2_IN6/COMP7_INM/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN7/ADC2_IN7/COMP7_INP/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN8/ADC2_IN8/ADC3_EXTI2/ADC4_EXTI2/COMP7_OUT/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN9/ADC2_IN9/TIM1_BKIN2/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC2_IN5/TIM1_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC2_IN11/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/TIM15_BKIN/TSC_G3_IO1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/COMP6_OUT/I2S2_MCK/TIM3_CH1/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/COMP5_OUT/I2S3_MCK/TIM3_CH2/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/COMP3_OUT/TIM3_CH3/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC1_EXTI9/I2C3_SDA/I2S_CKIN/TIM3_CH4/TIM8_BKIN2/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/SPI3_SCK/TIM8_CH1N/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/ADC2_EXTI11/I2S3_ext_SD/SPI3_MISO/TIM8_CH2N/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SPI3_MOSI/TIM8_CH3N/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F303VBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F303',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 128KB Ram: 32KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 87',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F303VCTx'],pins=[
            Pin(num='23',name='ADC1_IN1/COMP1_INM/COMP1_OUT/COMP7_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM8_BKIN/TIM8_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN2/COMP1_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN3/ADC3_EXTI2/ADC4_EXTI2/COMP2_INM/COMP2_OUT/OPAMP1_VOUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN4/COMP2_INP/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP1_VINP/OPAMP1_VINP_SEC/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC2_IN1/COMP1_INM/COMP2_INM/COMP3_INM/COMP4_INM/COMP5_INM/COMP6_INM/COMP7_INM/DAC_OUT1/I2S3_WS/OPAMP4_VINP/OPAMP4_VINP_SEC/SPI1_NSS/SPI3_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC2_IN2/COMP1_INM/COMP2_INM/COMP3_INM/COMP4_INM/COMP5_INM/COMP6_INM/COMP7_INM/DAC_OUT2/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC2_IN3/COMP1_OUT/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC2_IN4/COMP2_INP/COMP2_OUT/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='COMP3_OUT/I2C2_SMBA/I2S2_MCK/RCC_MCO/TIM1_CH1/TIM4_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='COMP5_OUT/DAC_EXTI9/I2C2_SCL/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='COMP6_OUT/I2C2_SDA/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TIM8_BKIN/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/COMP1_OUT/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/TIM4_CH1/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN_TX/COMP2_OUT/TIM16_CH1/TIM1_CH2N/TIM1_ETR/TIM4_CH2/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TIM8_CH2/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/I2C1_SCL/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TIM8_CH1/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC3_IN12/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC3_IN1/COMP4_OUT/OPAMP3_VOUT/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC2_IN12/ADC3_EXTI2/ADC4_EXTI2/COMP4_INM/OPAMP3_VINM/OPAMP3_VINM_SEC/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TIM4_ETR/TIM8_CH1N/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TIM8_CH2N/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/TIM8_CH3N/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_CH1/TIM8_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/TIM17_CH1N/TIM3_CH4/TIM4_CH2/TIM8_BKIN/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN_RX/COMP1_OUT/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TIM4_CH3/TIM8_CH2/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN_TX/COMP2_OUT/DAC_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/TIM4_CH4/TIM8_CH3/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='COMP5_INM/OPAMP3_VINM/OPAMP3_VINM_SEC/OPAMP4_VINM/OPAMP4_VINM_SEC/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/COMP6_INP/OPAMP4_VINP/OPAMP4_VINP_SEC/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC4_IN3/COMP3_INM/I2C2_SMBA/I2S2_WS/OPAMP4_VOUT/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC3_IN5/COMP5_INP/I2S2_CK/OPAMP3_VINP/OPAMP3_VINP_SEC/OPAMP4_VINP/OPAMP4_VINP_SEC/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC4_IN4/COMP3_INP/I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/ADC4_IN5/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN6/ADC2_IN6/COMP7_INM/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN7/ADC2_IN7/COMP7_INP/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN8/ADC2_IN8/ADC3_EXTI2/ADC4_EXTI2/COMP7_OUT/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN9/ADC2_IN9/TIM1_BKIN2/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC2_IN5/USART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC2_IN11/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/TSC_G3_IO1/USART1_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='COMP6_OUT/I2S2_MCK/TIM3_CH1/TIM8_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='COMP5_OUT/I2S3_MCK/TIM3_CH2/TIM8_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='COMP3_OUT/TIM3_CH3/TIM8_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/I2S_CKIN/TIM3_CH4/TIM8_BKIN2/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/SPI3_SCK/TIM8_CH1N/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/I2S3_ext_SD/SPI3_MISO/TIM8_CH2N/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/SPI3_MOSI/TIM8_CH3N/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PF0/I2C2_SDA/RCC_OSC_IN/TIM1_CH3N',do_erc=True),
            Pin(num='13',name='PF1/I2C2_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='19',name='PF2/ADC1_IN10/ADC2_IN10/ADC3_EXTI2/ADC4_EXTI2',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PF4/ADC1_IN5/COMP1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='PF6/I2C2_SCL/TIM4_CH4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF9/DAC_EXTI9/SPI2_SCK/TIM15_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF10/SPI2_SCK/TIM15_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/TIM16_CH1/TIM4_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/TIM17_CH1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ADC3_EXTI2/ADC4_EXTI2/SYS_TRACECK/TIM3_CH1/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/SYS_TRACED0/TIM3_CH2/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH3/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM3_CH4/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/ADC3_IN13/COMP4_INP/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/ADC3_IN6/ADC4_IN6/COMP4_INM/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/ADC3_IN2/DAC_EXTI9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/ADC3_IN14/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_IN15/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/ADC3_IN16/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/ADC3_IN3/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/ADC4_IN1/TIM1_BKIN2/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC4_IN2/TIM1_BKIN/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN_TX/TIM8_BKIN2/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/ADC3_EXTI2/ADC4_EXTI2/TIM3_ETR/TIM8_BKIN/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/TIM2_CH1/TIM2_ETR/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/TIM2_CH2/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/TIM2_CH4/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM2_CH3/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/ADC4_IN12/OPAMP4_VINM/OPAMP4_VINM_SEC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/ADC4_IN13/DAC_EXTI9/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/ADC3_IN7/ADC4_IN7/COMP6_INM/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_IN8/ADC4_IN8/COMP6_INP/OPAMP4_VINP/OPAMP4_VINP_SEC/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/ADC3_IN9/ADC4_IN9/COMP5_INP/TIM4_CH1/TSC_G8_IO1/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/ADC3_IN10/ADC4_IN10/COMP5_INM/TIM4_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/ADC3_IN11/ADC4_IN11/COMP3_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM4_CH3/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/COMP3_INM/SPI2_NSS/TIM4_CH4/TSC_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F303VDTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F303',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 384KB Ram: 64KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 86',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F303VETx'],pins=[
            Pin(num='23',name='ADC1_IN1/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM8_BKIN/TIM8_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN2/COMP1_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN3/ADC3_EXTI2/ADC4_EXTI2/COMP2_INM/COMP2_OUT/OPAMP1_VOUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN4/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP1_VINP/OPAMP1_VINP_SEC/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC2_IN1/COMP1_INM/COMP2_INM/COMP3_INM/COMP4_INM/COMP5_INM/COMP6_INM/COMP7_INM/DAC1_OUT1/I2S3_WS/OPAMP4_VINP/OPAMP4_VINP_SEC/SPI1_NSS/SPI3_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC2_IN2/COMP1_INM/COMP2_INM/COMP3_INM/COMP4_INM/COMP5_INM/COMP6_INM/COMP7_INM/DAC1_OUT2/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC2_IN3/COMP1_OUT/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC2_IN4/COMP2_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='COMP3_OUT/I2C2_SMBA/I2C3_SCL/I2S2_MCK/RCC_MCO/TIM1_CH1/TIM4_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='COMP5_OUT/DAC1_EXTI9/I2C2_SCL/I2C3_SMBA/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='COMP6_OUT/I2C2_SDA/I2S2_ext_SD/SPI2_MISO/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TIM8_BKIN/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/COMP1_OUT/I2S2_SD/SPI2_MOSI/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/TIM4_CH1/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN_TX/COMP2_OUT/I2S_CKIN/TIM16_CH1/TIM1_CH2N/TIM1_ETR/TIM4_CH2/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TIM8_CH2/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/I2C1_SCL/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TIM8_CH1/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC3_IN12/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC3_IN1/COMP4_OUT/OPAMP3_VOUT/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC2_IN12/ADC3_EXTI2/ADC4_EXTI2/COMP4_INM/OPAMP3_VINM/OPAMP3_VINM_SEC/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TIM4_ETR/TIM8_CH1N/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TIM8_CH2N/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/I2C3_SDA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/TIM8_CH3N/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_CH1/TIM8_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='FMC_NL/I2C1_SDA/TIM17_CH1N/TIM3_CH4/TIM4_CH2/TIM8_BKIN/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN_RX/COMP1_OUT/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TIM4_CH3/TIM8_CH2/TSC_SYNC/USART3_RX/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN_TX/COMP2_OUT/DAC1_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/TIM4_CH4/TIM8_CH3/USART3_TX/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='COMP5_INM/OPAMP3_VINM/OPAMP3_VINM_SEC/OPAMP4_VINM/OPAMP4_VINM_SEC/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC1_IN14/ADC2_EXTI11/ADC2_IN14/COMP6_INP/OPAMP4_VINP/OPAMP4_VINP_SEC/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC4_IN3/COMP3_INM/I2C2_SMBA/I2S2_WS/OPAMP4_VOUT/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC3_IN5/COMP5_INP/I2S2_CK/OPAMP3_VINP/OPAMP3_VINP_SEC/OPAMP4_VINP/OPAMP4_VINP_SEC/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC4_IN4/COMP3_INP/I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/ADC4_IN5/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN6/ADC2_IN6/COMP7_INM/TIM1_CH1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN7/ADC2_IN7/COMP7_INP/TIM1_CH2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN8/ADC2_IN8/ADC3_EXTI2/ADC4_EXTI2/COMP7_OUT/TIM1_CH3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN9/ADC2_IN9/TIM1_BKIN2/TIM1_CH4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC2_IN5/TIM1_ETR/USART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC2_IN11/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/TIM15_BKIN/TSC_G3_IO1/USART1_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='COMP6_OUT/I2S2_MCK/TIM3_CH1/TIM8_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='COMP5_OUT/I2S3_MCK/TIM3_CH2/TIM8_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='COMP3_OUT/TIM3_CH3/TIM8_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC1_EXTI9/I2C3_SDA/I2S_CKIN/TIM3_CH4/TIM8_BKIN2/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/SPI3_SCK/TIM8_CH1N/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/I2S3_ext_SD/SPI3_MISO/TIM8_CH2N/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/SPI3_MOSI/TIM8_CH3N/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PF0/I2C2_SDA/I2S2_WS/RCC_OSC_IN/SPI2_NSS/TIM1_CH3N',do_erc=True),
            Pin(num='13',name='PF1/I2C2_SCL/I2S2_CK/RCC_OSC_OUT/SPI2_SCK',do_erc=True),
            Pin(num='19',name='PF2/ADC1_IN10/ADC2_IN10/ADC3_EXTI2/ADC4_EXTI2/FMC_A2/TIM20_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='PF6/FMC_NIORD/I2C2_SCL/TIM4_CH4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF9/DAC1_EXTI9/FMC_CD/SPI2_SCK/TIM15_CH1/TIM20_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF10/FMC_INTR/SPI2_SCK/TIM15_CH2/TIM20_BKIN2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/FMC_NBL0/TIM16_CH1/TIM20_ETR/TIM4_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/FMC_NBL1/TIM17_CH1/TIM20_CH4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ADC3_EXTI2/ADC4_EXTI2/FMC_A23/SPI4_SCK/SYS_TRACECK/TIM20_CH1/TIM3_CH1/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/SPI4_NSS/SYS_TRACED0/TIM20_CH2/TIM3_CH2/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FMC_A20/SPI4_NSS/SYS_TRACED1/TIM20_CH1N/TIM3_CH3/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FMC_A21/SPI4_MISO/SYS_TRACED2/TIM20_CH2N/TIM3_CH4/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FMC_A22/RTC_TAMP3/SPI4_MOSI/SYS_TRACED3/SYS_WKUP3/TIM20_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/ADC3_IN13/FMC_D4/FMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/ADC3_IN6/ADC4_IN6/COMP4_INM/FMC_D5/FMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/ADC3_IN2/DAC1_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/ADC3_IN14/FMC_D7/FMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_IN15/FMC_D8/FMC_DA8/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/ADC3_IN16/FMC_D9/FMC_DA9/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/ADC3_IN3/FMC_D10/FMC_DA10/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/ADC4_IN1/FMC_D11/FMC_DA11/SPI4_MOSI/TIM1_BKIN2/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/ADC4_IN2/FMC_D12/FMC_DA12/TIM1_BKIN/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN_RX/FMC_D2/FMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN_TX/FMC_D3/FMC_DA3/TIM8_BKIN2/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/ADC3_EXTI2/ADC4_EXTI2/TIM3_ETR/TIM8_BKIN/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/FMC_CLK/TIM2_CH1/TIM2_ETR/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FMC_NOE/TIM2_CH2/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/FMC_NWAIT/TIM2_CH4/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FMC_NCE2/FMC_NE1/TIM2_CH3/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/ADC4_IN12/FMC_D13/FMC_DA13/OPAMP4_VINM/OPAMP4_VINM_SEC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/ADC4_IN13/DAC1_EXTI9/FMC_D14/FMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/ADC3_IN7/ADC4_IN7/COMP6_INM/FMC_D15/FMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_IN8/ADC4_IN8/FMC_A16/FMC_CLE/OPAMP4_VINP/OPAMP4_VINP_SEC/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/ADC3_IN9/ADC4_IN9/FMC_A17/FMC_ALE/TIM4_CH1/TSC_G8_IO1/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/ADC3_IN10/ADC4_IN10/COMP5_INM/FMC_A18/TIM4_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/ADC3_IN11/ADC4_IN11/FMC_D0/FMC_DA0/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM4_CH3/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/COMP3_INM/FMC_D1/FMC_DA1/SPI2_NSS/TIM4_CH4/TSC_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F303VEHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F303',description='Core: ARM Cortex-M4 Package: UFBGA100 Flash: 512KB Ram: 64KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 86',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='L2',name='ADC1_IN1/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM8_BKIN/TIM8_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN2/COMP1_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC1_IN3/ADC3_EXTI2/ADC4_EXTI2/COMP2_INM/COMP2_OUT/OPAMP1_VOUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC1_IN4/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP1_VINP/OPAMP1_VINP_SEC/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC2_IN1/COMP1_INM/COMP2_INM/COMP3_INM/COMP4_INM/COMP5_INM/COMP6_INM/COMP7_INM/DAC1_OUT1/I2S3_WS/OPAMP4_VINP/OPAMP4_VINP_SEC/SPI1_NSS/SPI3_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC2_IN2/COMP1_INM/COMP2_INM/COMP3_INM/COMP4_INM/COMP5_INM/COMP6_INM/COMP7_INM/DAC1_OUT2/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC2_IN3/COMP1_OUT/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC2_IN4/COMP2_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='COMP3_OUT/I2C2_SMBA/I2C3_SCL/I2S2_MCK/RCC_MCO/TIM1_CH1/TIM4_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='COMP5_OUT/DAC1_EXTI9/I2C2_SCL/I2C3_SMBA/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='COMP6_OUT/I2C2_SDA/I2S2_ext_SD/SPI2_MISO/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TIM8_BKIN/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/COMP1_OUT/I2S2_SD/SPI2_MOSI/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/TIM4_CH1/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='CAN_TX/COMP2_OUT/I2S_CKIN/TIM16_CH1/TIM1_CH2N/TIM1_ETR/TIM4_CH2/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TIM8_CH2/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/I2C1_SCL/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TIM8_CH1/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC3_IN12/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC3_IN1/COMP4_OUT/OPAMP3_VOUT/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='ADC2_IN12/ADC3_EXTI2/ADC4_EXTI2/COMP4_INM/OPAMP3_VINM/OPAMP3_VINM_SEC/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TIM4_ETR/TIM8_CH1N/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TIM8_CH2N/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='I2C1_SMBA/I2C3_SDA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/TIM8_CH3N/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2C1_SCL/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_CH1/TIM8_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='FMC_NL/I2C1_SDA/TIM17_CH1N/TIM3_CH4/TIM4_CH2/TIM8_BKIN/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='CAN_RX/COMP1_OUT/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TIM4_CH3/TIM8_CH2/TSC_SYNC/USART3_RX/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='CAN_TX/COMP2_OUT/DAC1_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/TIM4_CH4/TIM8_CH3/USART3_TX/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='COMP5_INM/OPAMP3_VINM/OPAMP3_VINM_SEC/OPAMP4_VINM/OPAMP4_VINM_SEC/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC1_EXTI11/ADC1_IN14/ADC2_EXTI11/ADC2_IN14/COMP6_INP/OPAMP4_VINP/OPAMP4_VINP_SEC/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='ADC4_IN3/COMP3_INM/I2C2_SMBA/I2S2_WS/OPAMP4_VOUT/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='ADC3_IN5/COMP5_INP/I2S2_CK/OPAMP3_VINP/OPAMP3_VINP_SEC/OPAMP4_VINP/OPAMP4_VINP_SEC/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='ADC4_IN4/COMP3_INP/I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/ADC4_IN5/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC1_IN6/ADC2_IN6/COMP7_INM/TIM1_CH1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC1_IN7/ADC2_IN7/COMP7_INP/TIM1_CH2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC1_IN8/ADC2_IN8/ADC3_EXTI2/ADC4_EXTI2/COMP7_OUT/TIM1_CH3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_IN9/ADC2_IN9/TIM1_BKIN2/TIM1_CH4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC2_IN5/TIM1_ETR/USART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC2_IN11/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/TIM15_BKIN/TSC_G3_IO1/USART1_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='COMP6_OUT/I2S2_MCK/TIM3_CH1/TIM8_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='COMP5_OUT/I2S3_MCK/TIM3_CH2/TIM8_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='COMP3_OUT/TIM3_CH3/TIM8_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC1_EXTI9/I2C3_SDA/I2S_CKIN/TIM3_CH4/TIM8_BKIN2/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='I2S3_CK/SPI3_SCK/TIM8_CH1N/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC1_EXTI11/ADC2_EXTI11/I2S3_ext_SD/SPI3_MISO/TIM8_CH2N/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='I2S3_SD/SPI3_MOSI/TIM8_CH3N/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PF0/I2C2_SDA/I2S2_WS/RCC_OSC_IN/SPI2_NSS/TIM1_CH3N',do_erc=True),
            Pin(num='G1',name='PF1/I2C2_SCL/I2S2_CK/RCC_OSC_OUT/SPI2_SCK',do_erc=True),
            Pin(num='J1',name='PF2/ADC1_IN10/ADC2_IN10/ADC3_EXTI2/ADC4_EXTI2/FMC_A2/TIM20_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='PF6/FMC_NIORD/I2C2_SCL/TIM4_CH4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PF9/DAC1_EXTI9/FMC_CD/SPI2_SCK/TIM15_CH1/TIM20_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PF10/FMC_INTR/SPI2_SCK/TIM15_CH2/TIM20_BKIN2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/FMC_NBL0/TIM16_CH1/TIM20_ETR/TIM4_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/FMC_NBL1/TIM17_CH1/TIM20_CH4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/ADC3_EXTI2/ADC4_EXTI2/FMC_A23/SPI4_SCK/SYS_TRACECK/TIM20_CH1/TIM3_CH1/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/FMC_A19/SPI4_NSS/SYS_TRACED0/TIM20_CH2/TIM3_CH2/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/FMC_A20/SPI4_NSS/SYS_TRACED1/TIM20_CH1N/TIM3_CH3/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/FMC_A21/SPI4_MISO/SYS_TRACED2/TIM20_CH2N/TIM3_CH4/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/FMC_A22/RTC_TAMP3/SPI4_MOSI/SYS_TRACED3/SYS_WKUP3/TIM20_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/ADC3_IN13/FMC_D4/FMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/ADC3_IN6/ADC4_IN6/COMP4_INM/FMC_D5/FMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/ADC3_IN2/DAC1_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/ADC3_IN14/FMC_D7/FMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_IN15/FMC_D8/FMC_DA8/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/ADC3_IN16/FMC_D9/FMC_DA9/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/ADC3_IN3/FMC_D10/FMC_DA10/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/ADC4_IN1/FMC_D11/FMC_DA11/SPI4_MOSI/TIM1_BKIN2/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/ADC4_IN2/FMC_D12/FMC_DA12/TIM1_BKIN/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0/CAN_RX/FMC_D2/FMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1/CAN_TX/FMC_D3/FMC_DA3/TIM8_BKIN2/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/ADC3_EXTI2/ADC4_EXTI2/TIM3_ETR/TIM8_BKIN/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/FMC_CLK/TIM2_CH1/TIM2_ETR/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/FMC_NOE/TIM2_CH2/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/FMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/FMC_NWAIT/TIM2_CH4/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/FMC_NCE2/FMC_NE1/TIM2_CH3/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/ADC4_IN12/FMC_D13/FMC_DA13/OPAMP4_VINM/OPAMP4_VINM_SEC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9/ADC4_IN13/DAC1_EXTI9/FMC_D14/FMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10/ADC3_IN7/ADC4_IN7/COMP6_INM/FMC_D15/FMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_IN8/ADC4_IN8/FMC_A16/FMC_CLE/OPAMP4_VINP/OPAMP4_VINP_SEC/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/ADC3_IN9/ADC4_IN9/FMC_A17/FMC_ALE/TIM4_CH1/TSC_G8_IO1/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13/ADC3_IN10/ADC4_IN10/COMP5_INM/FMC_A18/TIM4_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14/ADC3_IN11/ADC4_IN11/FMC_D0/FMC_DA0/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM4_CH3/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/COMP3_INM/FMC_D1/FMC_DA1/SPI2_NSS/TIM4_CH4/TSC_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F303ZDTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F303',description='Core: ARM Cortex-M4 Package: LQFP144 Flash: 384KB Ram: 64KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 115',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F303ZETx'],pins=[
            Pin(num='34',name='ADC1_IN1/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM8_BKIN/TIM8_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN2/COMP1_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN3/ADC3_EXTI2/ADC4_EXTI2/COMP2_INM/COMP2_OUT/OPAMP1_VOUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN4/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP1_VINP/OPAMP1_VINP_SEC/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC2_IN1/COMP1_INM/COMP2_INM/COMP3_INM/COMP4_INM/COMP5_INM/COMP6_INM/COMP7_INM/DAC1_OUT1/I2S3_WS/OPAMP4_VINP/OPAMP4_VINP_SEC/SPI1_NSS/SPI3_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC2_IN2/COMP1_INM/COMP2_INM/COMP3_INM/COMP4_INM/COMP5_INM/COMP6_INM/COMP7_INM/DAC1_OUT2/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC2_IN3/COMP1_OUT/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC2_IN4/COMP2_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='COMP3_OUT/I2C2_SMBA/I2C3_SCL/I2S2_MCK/RCC_MCO/TIM1_CH1/TIM4_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='COMP5_OUT/DAC1_EXTI9/I2C2_SCL/I2C3_SMBA/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='COMP6_OUT/I2C2_SDA/I2S2_ext_SD/SPI2_MISO/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TIM8_BKIN/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/COMP1_OUT/I2S2_SD/SPI2_MOSI/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/TIM4_CH1/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN_TX/COMP2_OUT/I2S_CKIN/TIM16_CH1/TIM1_CH2N/TIM1_ETR/TIM4_CH2/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TIM8_CH2/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/I2C1_SCL/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TIM8_CH1/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC3_IN12/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC3_IN1/COMP4_OUT/OPAMP3_VOUT/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC2_IN12/ADC3_EXTI2/ADC4_EXTI2/COMP4_INM/OPAMP3_VINM/OPAMP3_VINM_SEC/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TIM4_ETR/TIM8_CH1N/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TIM8_CH2N/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='I2C1_SMBA/I2C3_SDA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/TIM8_CH3N/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='I2C1_SCL/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_CH1/TIM8_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='FMC_NL/I2C1_SDA/TIM17_CH1N/TIM3_CH4/TIM4_CH2/TIM8_BKIN/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CAN_RX/COMP1_OUT/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TIM4_CH3/TIM8_CH2/TSC_SYNC/USART3_RX/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='CAN_TX/COMP2_OUT/DAC1_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/TIM4_CH4/TIM8_CH3/USART3_TX/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='COMP5_INM/OPAMP3_VINM/OPAMP3_VINM_SEC/OPAMP4_VINM/OPAMP4_VINM_SEC/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC1_IN14/ADC2_EXTI11/ADC2_IN14/COMP6_INP/OPAMP4_VINP/OPAMP4_VINP_SEC/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='ADC4_IN3/COMP3_INM/I2C2_SMBA/I2S2_WS/OPAMP4_VOUT/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='ADC3_IN5/COMP5_INP/I2S2_CK/OPAMP3_VINP/OPAMP3_VINP_SEC/OPAMP4_VINP/OPAMP4_VINP_SEC/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='ADC4_IN4/COMP3_INP/I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/ADC4_IN5/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN6/ADC2_IN6/COMP7_INM/TIM1_CH1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN7/ADC2_IN7/COMP7_INP/TIM1_CH2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN8/ADC2_IN8/ADC3_EXTI2/ADC4_EXTI2/COMP7_OUT/TIM1_CH3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN9/ADC2_IN9/TIM1_BKIN2/TIM1_CH4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC2_IN5/TIM1_ETR/USART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC2_IN11/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/TIM15_BKIN/TSC_G3_IO1/USART1_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='COMP6_OUT/I2S2_MCK/TIM3_CH1/TIM8_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='COMP5_OUT/I2S3_MCK/TIM3_CH2/TIM8_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='COMP3_OUT/TIM3_CH3/TIM8_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC1_EXTI9/I2C3_SDA/I2S_CKIN/TIM3_CH4/TIM8_BKIN2/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='I2S3_CK/SPI3_SCK/TIM8_CH1N/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/ADC2_EXTI11/I2S3_ext_SD/SPI3_MISO/TIM8_CH2N/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='I2S3_SD/SPI3_MOSI/TIM8_CH3N/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='CAN_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CAN_TX/FMC_D3/FMC_DA3/TIM8_BKIN2/TIM8_CH4/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='ADC3_EXTI2/ADC4_EXTI2/TIM3_ETR/TIM8_BKIN/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='FMC_CLK/TIM2_CH1/TIM2_ETR/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FMC_NOE/TIM2_CH2/USART2_DE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='FMC_NWAIT/TIM2_CH4/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FMC_NCE2/FMC_NE1/TIM2_CH3/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC4_IN12/FMC_D13/FMC_DA13/OPAMP4_VINM/OPAMP4_VINM_SEC/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='ADC4_IN13/DAC1_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC3_IN7/ADC4_IN7/COMP6_INM/FMC_D15/FMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_IN8/ADC4_IN8/FMC_A16/FMC_CLE/OPAMP4_VINP/OPAMP4_VINP_SEC/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='ADC3_IN9/ADC4_IN9/FMC_A17/FMC_ALE/TIM4_CH1/TSC_G8_IO1/USART3_DE/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='ADC3_IN10/ADC4_IN10/COMP5_INM/FMC_A18/TIM4_CH2/TSC_G8_IO2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='ADC3_IN11/ADC4_IN11/FMC_D0/FMC_DA0/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM4_CH3/TSC_G8_IO3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/COMP3_INM/FMC_D1/FMC_DA1/SPI2_NSS/TIM4_CH4/TSC_G8_IO4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='PH0/FMC_A0/TIM20_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PH1/FMC_A1/TIM20_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='106',name='PH2/ADC3_EXTI2/ADC4_EXTI2',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PG0/FMC_A10/TIM20_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FMC_A11/TIM20_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/ADC3_EXTI2/ADC4_EXTI2/FMC_A12/TIM20_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FMC_A13/TIM20_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FMC_A14/TIM20_BKIN2',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FMC_A15/TIM20_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/FMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/FMC_INT3',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC1_EXTI9/FMC_NCE3/FMC_NE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/FMC_NCE4_1/FMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/ADC2_EXTI11/FMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FMC_NE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/FMC_A24',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/FMC_A25',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='PF0/I2C2_SDA/I2S2_WS/RCC_OSC_IN/SPI2_NSS/TIM1_CH3N',do_erc=True),
            Pin(num='24',name='PF1/I2C2_SCL/I2S2_CK/RCC_OSC_OUT/SPI2_SCK',do_erc=True),
            Pin(num='12',name='PF2/ADC1_IN10/ADC2_IN10/ADC3_EXTI2/ADC4_EXTI2/FMC_A2/TIM20_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/FMC_A3/TIM20_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/ADC1_IN5/COMP1_OUT/FMC_A4/TIM20_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/FMC_A5/TIM20_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/FMC_NIORD/I2C2_SCL/TIM4_CH4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/FMC_NREG/TIM20_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/FMC_NIOWR/TIM20_BKIN2',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/DAC1_EXTI9/FMC_CD/SPI2_SCK/TIM15_CH1/TIM20_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/FMC_INTR/SPI2_SCK/TIM15_CH2/TIM20_BKIN2',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/ADC2_EXTI11/TIM20_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FMC_A6/TIM20_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FMC_A7/TIM20_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FMC_A8/TIM20_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/FMC_A9/TIM20_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/FMC_NBL0/TIM16_CH1/TIM20_ETR/TIM4_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/FMC_NBL1/TIM17_CH1/TIM20_CH4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ADC3_EXTI2/ADC4_EXTI2/FMC_A23/SPI4_SCK/SYS_TRACECK/TIM20_CH1/TIM3_CH1/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/SPI4_NSS/SYS_TRACED0/TIM20_CH2/TIM3_CH2/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FMC_A20/SPI4_NSS/SYS_TRACED1/TIM20_CH1N/TIM3_CH3/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FMC_A21/SPI4_MISO/SYS_TRACED2/TIM20_CH2N/TIM3_CH4/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FMC_A22/RTC_TAMP3/SPI4_MOSI/SYS_TRACED3/SYS_WKUP3/TIM20_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/ADC3_IN13/FMC_D4/FMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/ADC3_IN6/ADC4_IN6/COMP4_INM/FMC_D5/FMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/ADC3_IN2/DAC1_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/ADC3_IN14/FMC_D7/FMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_IN15/FMC_D8/FMC_DA8/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/ADC3_IN16/FMC_D9/FMC_DA9/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/ADC3_IN3/FMC_D10/FMC_DA10/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/ADC4_IN1/FMC_D11/FMC_DA11/SPI4_MOSI/TIM1_BKIN2/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/ADC4_IN2/FMC_D12/FMC_DA12/TIM1_BKIN/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='143',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F313CCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F303/313',description='Core: ARM Cortex-M4 Package: LQFP48 Flash: 256KB Ram: 48KB Frequency: 72MHz Voltage: 1.65..1.95V IO-pins: 36',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC1_IN1/COMP1_INM6/COMP1_OUT/COMP7_INP/SYS_RTC_TAMP2/SYS_WKUP1/TIM2_CH1_ETR/TIM8_BKIN/TIM8_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN2/COMP1_INP/OPAMP1_VINP/OPAMP3_VINP/SYS_RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN3/ADC3_EXTI2/ADC4_EXTI2/COMP2_INM6/COMP2_OUT/OPAMP1_VOUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN4/COMP2_INP/OPAMP1_VINM/OPAMP1_VINP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC2_IN1/COMP1_INM4/COMP2_INM4/COMP3_INM4/COMP4_INM4/COMP5_INM4/COMP6_INM4/COMP7_INM4/DAC_OUT1/I2S3_WS/OPAMP4_VINP/SPI1_NSS/SPI3_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC2_IN2/COMP1_INM5/COMP2_INM5/COMP3_INM5/COMP4_INM5/COMP5_INM5/COMP6_INM5/COMP7_INM5/DAC_OUT2/OPAMP1_VINP/OPAMP2_VINM/OPAMP3_VINP/SPI1_SCK/TIM2_CH1_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC2_IN3/COMP1_OUT/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC2_IN4/COMP2_INP/COMP2_OUT/OPAMP1_VINP/OPAMP2_VINP/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='COMP3_OUT/I2C2_SMBA/I2S2_MCK/SYS_MCO/TIM1_CH1/TIM4_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='COMP5_OUT/DAC_EXTI9/I2C2_SCL/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='COMP6_OUT/I2C2_SDA/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TIM8_BKIN/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/COMP1_OUT/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/TIM4_CH1/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN_TX/COMP2_OUT/TIM16_CH1/TIM1_CH2N/TIM1_ETR/TIM4_CH2/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IRTIM_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TIM8_CH2/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/ADC2_EXTI15/I2C1_SCL/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1_ETR/TIM8_CH1/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='20',name='NPOR',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/I2C2_SDA/SYS_OSC_IN/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='PF1/I2C2_SCL/SYS_OSC_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/SYS_RTC_OUT/SYS_RTC_TAMP1/SYS_RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/SYS_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/SYS_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC3_IN12/COMP4_INP/OPAMP2_VINP/OPAMP3_VINP/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC3_IN1/COMP4_OUT/OPAMP3_VOUT/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TIM4_ETR/TIM8_CH1N/TSC_G5_IO1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S3_EXT_SD/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TIM8_CH2N/TSC_G5_IO2/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/TIM8_CH3N/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_CH1/TIM8_ETR/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TIM3_CH4/TIM4_CH2/TIM8_BKIN/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CAN_RX/COMP1_OUT/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TIM4_CH3/TIM8_CH2/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/CAN_TX/COMP2_OUT/DAC_EXTI9/I2C1_SDA/IRTIM_OUT/TIM17_CH1/TIM4_CH4/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/COMP5_INM7/OPAMP3_VINM/OPAMP4_VINM/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC1_EXTI11/ADC2_EXTI11/COMP6_INP/OPAMP4_VINP/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/ADC4_IN3/COMP3_INM7/I2C2_SMBA/I2S2_WS/OPAMP4_VOUT/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC3_IN5/COMP5_INP/I2S2_CK/OPAMP3_VINP/OPAMP4_VINP/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/ADC4_IN4/COMP3_INP/I2S2_EXT_SD/OPAMP2_VINP/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC1_EXTI15/ADC2_EXTI15/ADC4_IN5/COMP6_INM7/I2S2_SD/SPI2_MOSI/SYS_RTC_REFIN/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='24',name='VDD_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD_3',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS_3',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F313RCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F303/313',description='Core: ARM Cortex-M4 Package: LQFP64 Flash: 256KB Ram: 48KB Frequency: 72MHz Voltage: 1.65..1.95V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC1_IN1/COMP1_INM6/COMP1_OUT/COMP7_INP/SYS_RTC_TAMP2/SYS_WKUP1/TIM2_CH1_ETR/TIM8_BKIN/TIM8_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN2/COMP1_INP/OPAMP1_VINP/OPAMP3_VINP/SYS_RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN3/ADC3_EXTI2/ADC4_EXTI2/COMP2_INM6/COMP2_OUT/OPAMP1_VOUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN4/COMP2_INP/OPAMP1_VINM/OPAMP1_VINP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC2_IN1/COMP1_INM4/COMP2_INM4/COMP3_INM4/COMP4_INM4/COMP5_INM4/COMP6_INM4/COMP7_INM4/DAC_OUT1/I2S3_WS/OPAMP4_VINP/SPI1_NSS/SPI3_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC2_IN2/COMP1_INM5/COMP2_INM5/COMP3_INM5/COMP4_INM5/COMP5_INM5/COMP6_INM5/COMP7_INM5/DAC_OUT2/OPAMP1_VINP/OPAMP2_VINM/OPAMP3_VINP/SPI1_SCK/TIM2_CH1_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC2_IN3/COMP1_OUT/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC2_IN4/COMP2_INP/COMP2_OUT/OPAMP1_VINP/OPAMP2_VINP/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='COMP3_OUT/I2C2_SMBA/I2S2_MCK/SYS_MCO/TIM1_CH1/TIM4_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='COMP5_OUT/DAC_EXTI9/I2C2_SCL/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='COMP6_OUT/I2C2_SDA/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TIM8_BKIN/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/COMP1_OUT/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/TIM4_CH1/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN_TX/COMP2_OUT/TIM16_CH1/TIM1_CH2N/TIM1_ETR/TIM4_CH2/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IRTIM_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TIM8_CH2/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/ADC2_EXTI15/I2C1_SCL/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1_ETR/TIM8_CH1/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC3_IN12/COMP4_INP/OPAMP2_VINP/OPAMP3_VINP/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC3_IN1/COMP4_OUT/OPAMP3_VOUT/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TIM4_ETR/TIM8_CH1N/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2S3_EXT_SD/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TIM8_CH2N/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/TIM8_CH3N/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_CH1/TIM8_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/TIM3_CH4/TIM4_CH2/TIM8_BKIN/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN_RX/COMP1_OUT/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TIM4_CH3/TIM8_CH2/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN_TX/COMP2_OUT/DAC_EXTI9/I2C1_SDA/IRTIM_OUT/TIM17_CH1/TIM4_CH4/TIM8_CH3/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='COMP5_INM7/OPAMP3_VINM/OPAMP4_VINM/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/ADC2_EXTI11/COMP6_INP/OPAMP4_VINP/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC4_IN3/COMP3_INM7/I2C2_SMBA/I2S2_WS/OPAMP4_VOUT/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC3_IN5/COMP5_INP/I2S2_CK/OPAMP3_VINP/OPAMP4_VINP/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC4_IN4/COMP3_INP/I2S2_EXT_SD/OPAMP2_VINP/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/ADC2_EXTI15/ADC4_IN5/COMP6_INM7/I2S2_SD/SPI2_MOSI/SYS_RTC_REFIN/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='28',name='NPOR',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/I2C2_SDA/SYS_OSC_IN/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='PF1/I2C2_SCL/SYS_OSC_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF4/ADC1_IN5/COMP1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PD2/ADC3_EXTI2/ADC4_EXTI2/TIM3_ETR/TIM8_BKIN/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN6/ADC2_IN6/COMP7_INM6',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN7/ADC2_IN7/COMP7_INP',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN8/ADC2_IN8/ADC3_EXTI2/ADC4_EXTI2/COMP7_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN9/ADC2_IN9/TIM1_BKIN2',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC2_IN5/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC2_IN11/OPAMP1_VINM/OPAMP2_VINM/TSC_G3_IO1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/COMP6_OUT/I2S2_MCK/TIM3_CH1/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/COMP5_OUT/I2S3_MCK/TIM3_CH2/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/COMP3_OUT/TIM3_CH3/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/I2S_CKIN/TIM3_CH4/TIM8_BKIN2/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/SPI3_SCK/TIM8_CH1N/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/ADC2_EXTI11/I2S3_EXT_SD/SPI3_MISO/TIM8_CH2N/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SPI3_MOSI/TIM8_CH3N/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/SYS_RTC_OUT/SYS_RTC_TAMP1/SYS_RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/SYS_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/SYS_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD_3',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD_4',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS_3',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F313VCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F303/313',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 256KB Ram: 48KB Frequency: 72MHz Voltage: 1.65..1.95V IO-pins: 86',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC1_IN1/COMP1_INM6/COMP1_OUT/COMP7_INP/SYS_RTC_TAMP2/SYS_WKUP1/TIM2_CH1_ETR/TIM8_BKIN/TIM8_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN2/COMP1_INP/OPAMP1_VINP/OPAMP3_VINP/SYS_RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN3/ADC3_EXTI2/ADC4_EXTI2/COMP2_INM6/COMP2_OUT/OPAMP1_VOUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN4/COMP2_INP/OPAMP1_VINM/OPAMP1_VINP/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC2_IN1/COMP1_INM4/COMP2_INM4/COMP3_INM4/COMP4_INM4/COMP5_INM4/COMP6_INM4/COMP7_INM4/DAC_OUT1/I2S3_WS/OPAMP4_VINP/SPI1_NSS/SPI3_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC2_IN2/COMP1_INM5/COMP2_INM5/COMP3_INM5/COMP4_INM5/COMP5_INM5/COMP6_INM5/COMP7_INM5/DAC_OUT2/OPAMP1_VINP/OPAMP2_VINM/OPAMP3_VINP/SPI1_SCK/TIM2_CH1_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC2_IN3/COMP1_OUT/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC2_IN4/COMP2_INP/COMP2_OUT/OPAMP1_VINP/OPAMP2_VINP/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='COMP3_OUT/I2C2_SMBA/I2S2_MCK/SYS_MCO/TIM1_CH1/TIM4_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='COMP5_OUT/DAC_EXTI9/I2C2_SCL/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='COMP6_OUT/I2C2_SDA/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TIM8_BKIN/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/COMP1_OUT/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/TIM4_CH1/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN_TX/COMP2_OUT/TIM16_CH1/TIM1_CH2N/TIM1_ETR/TIM4_CH2/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='IRTIM_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TIM8_CH2/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/I2C1_SCL/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1_ETR/TIM8_CH1/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC3_IN12/COMP4_INP/OPAMP2_VINP/OPAMP3_VINP/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC3_IN1/COMP4_OUT/OPAMP3_VOUT/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TIM4_ETR/TIM8_CH1N/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S3_EXT_SD/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TIM8_CH2N/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/TIM8_CH3N/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_CH1/TIM8_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/TIM17_CH1N/TIM3_CH4/TIM4_CH2/TIM8_BKIN/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN_RX/COMP1_OUT/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TIM4_CH3/TIM8_CH2/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN_TX/COMP2_OUT/DAC_EXTI9/I2C1_SDA/IRTIM_OUT/TIM17_CH1/TIM4_CH4/TIM8_CH3/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='COMP5_INM7/OPAMP3_VINM/OPAMP4_VINM/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/COMP6_INP/OPAMP4_VINP/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC4_IN3/COMP3_INM7/I2C2_SMBA/I2S2_WS/OPAMP4_VOUT/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC3_IN5/COMP5_INP/I2S2_CK/OPAMP3_VINP/OPAMP4_VINP/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC4_IN4/COMP3_INP/I2S2_EXT_SD/OPAMP2_VINP/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/ADC4_IN5/COMP6_INM7/I2S2_SD/SPI2_MOSI/SYS_RTC_REFIN/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN6/ADC2_IN6/COMP7_INM6/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN7/ADC2_IN7/COMP7_INP/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN8/ADC2_IN8/ADC3_EXTI2/ADC4_EXTI2/COMP7_OUT/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN9/ADC2_IN9/TIM1_BKIN2/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC2_IN5/USART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC2_IN11/OPAMP1_VINM/OPAMP2_VINM/TSC_G3_IO1/USART1_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='COMP6_OUT/I2S2_MCK/TIM3_CH1/TIM8_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='COMP5_OUT/I2S3_MCK/TIM3_CH2/TIM8_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='COMP3_OUT/TIM3_CH3/TIM8_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/I2S_CKIN/TIM3_CH4/TIM8_BKIN2/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/SPI3_SCK/TIM8_CH1N/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/I2S3_EXT_SD/SPI3_MISO/TIM8_CH2N/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/SPI3_MOSI/TIM8_CH3N/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='SYS_RTC_OUT/SYS_RTC_TAMP1/SYS_RTC_TS/SYS_WKUP2/TIM1_CH1N/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='SYS_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/SYS_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='37',name='NPOR',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PF0/I2C2_SDA/SYS_OSC_IN/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF1/I2C2_SCL/SYS_OSC_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF2/ADC1_IN10/ADC2_IN10/ADC3_EXTI2/ADC4_EXTI2',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PF4/ADC1_IN5/COMP1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='PF6/I2C2_SCL/TIM4_CH4/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF9/DAC_EXTI9/SPI2_SCK/TIM15_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF10/SPI2_SCK/TIM15_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/TIM16_CH1/TIM4_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/TIM17_CH1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ADC3_EXTI2/ADC4_EXTI2/SYS_TRACECK/TIM3_CH1/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/SYS_TRACED0/TIM3_CH2/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH3/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM3_CH4/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/SYS_RTC_TAMP3/SYS_TRACED3/SYS_WKUP3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/ADC3_IN13/COMP4_INP/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/ADC3_IN6/ADC4_IN6/COMP4_INM6/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/ADC3_IN2/DAC_EXTI9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/ADC3_IN14/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_IN15/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/ADC3_IN16/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/ADC3_IN3/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/ADC4_IN1/TIM1_BKIN2/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC4_IN2/TIM1_BKIN/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN_TX/TIM8_BKIN2/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/ADC3_EXTI2/ADC4_EXTI2/TIM3_ETR/TIM8_BKIN/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/TIM2_CH1_ETR/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/TIM2_CH2/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/TIM2_CH4/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM2_CH3/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/ADC4_IN12/OPAMP4_VINM/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/ADC4_IN13/DAC_EXTI9/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/ADC3_IN7/ADC4_IN7/COMP6_INM6/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_IN8/ADC4_IN8/COMP6_INP/OPAMP4_VINP/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/ADC3_IN9/ADC4_IN9/COMP5_INP/TIM4_CH1/TSC_G8_IO1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/ADC3_IN10/ADC4_IN10/COMP5_INM6/TIM4_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/ADC3_IN11/ADC4_IN11/COMP3_INP/OPAMP2_VINP/TIM4_CH3/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/COMP3_INM6/SPI2_NSS/TIM4_CH4/TSC_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD_3',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD_4',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS_3',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F318C8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F3x8',description='Core: ARM Cortex-M4 Package: LQFP48 Flash: 64KB Ram: 16KB Frequency: 72MHz Voltage: 1.65..1.95V IO-pins: 36',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC1_IN1/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN2/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN3/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN4/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN5/COMP2_INM/COMP4_INM/COMP6_INM/DAC_OUT1/I2S3_WS/SPI3_NSS/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='OPAMP2_VINM/OPAMP2_VINM_SEC/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN10/OPAMP2_VOUT/TIM16_CH1/TIM1_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN15/COMP2_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM17_CH1/TIM1_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SMBA/I2C3_SCL/I2S2_MCK/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/I2C2_SCL/I2C3_SMBA/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='COMP6_OUT/I2C2_SDA/I2S2_ext_SD/SPI2_MISO/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/I2S2_SD/SPI2_MOSI/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/I2S_CKIN/TIM16_CH1/TIM1_CH2N/TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/I2C1_SCL/I2S3_WS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='43',name='NPOR',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/I2C2_SDA/I2S2_WS/RCC_OSC_IN/SPI2_NSS/TIM1_CH3N',do_erc=True),
            Pin(num='6',name='PF1/I2C2_SCL/I2S2_CK/RCC_OSC_OUT/SPI2_SCK',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC1_IN11/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC1_IN12/COMP4_OUT/TIM1_CH3N/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/COMP4_INM/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S3_CK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TSC_G5_IO1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S3_ext_SD/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TSC_G5_IO2/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2C3_SDA/I2S3_SD/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TSC_SYNC/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/COMP2_OUT/DAC_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC1_EXTI11/ADC1_IN14/COMP6_INP/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC1_IN13/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC1_EXTI15/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F318C8Yx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F3x8',description='Core: ARM Cortex-M4 Package: WLCSP49 Flash: 64KB Ram: 16KB Frequency: 72MHz Voltage: 1.65..1.95V IO-pins: 36',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='F6',name='ADC1_IN1/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='ADC1_IN2/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='ADC1_IN3/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='ADC1_IN4/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='ADC1_IN5/COMP2_INM/COMP4_INM/COMP6_INM/DAC_OUT1/I2S3_WS/SPI3_NSS/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='OPAMP2_VINM/OPAMP2_VINM_SEC/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC1_IN10/OPAMP2_VOUT/TIM16_CH1/TIM1_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC1_IN15/COMP2_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM17_CH1/TIM1_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='I2C2_SMBA/I2C3_SCL/I2S2_MCK/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='DAC_EXTI9/I2C2_SCL/I2C3_SMBA/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='COMP6_OUT/I2C2_SDA/I2S2_ext_SD/SPI2_MISO/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='ADC1_EXTI11/I2S2_SD/SPI2_MOSI/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='COMP2_OUT/I2S_CKIN/TIM16_CH1/TIM1_CH2N/TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ADC1_EXTI15/I2C1_SCL/I2S3_WS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='NC',do_erc=True),
            Pin(num='E7',name='NRST',do_erc=True),
            Pin(num='G3',name='NPOR',do_erc=True),
            Pin(num='A5',name='BOOT0',do_erc=True),
            Pin(num='B6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='PF0/I2C2_SDA/I2S2_WS/RCC_OSC_IN/SPI2_NSS/TIM1_CH3N',do_erc=True),
            Pin(num='D6',name='PF1/I2C2_SCL/I2S2_CK/RCC_OSC_OUT/SPI2_SCK',do_erc=True),
            Pin(num='D5',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PB0/ADC1_IN11/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PB1/ADC1_IN12/COMP4_OUT/TIM1_CH3N/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PB3/I2S3_CK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TSC_G5_IO1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PB4/I2S3_ext_SD/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TSC_G5_IO2/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PB5/I2C1_SMBA/I2C3_SDA/I2S3_SD/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PB7/I2C1_SDA/TIM17_CH1N/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='PB8/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TSC_SYNC/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PB9/COMP2_OUT/DAC_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PB10/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PB11/ADC1_EXTI11/ADC1_IN14/COMP6_INP/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PB12/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PB13/ADC1_IN13/I2S2_CK/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PB14/I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='PB15/ADC1_EXTI15/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='B7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='A6',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='B1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F318K8Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F3x8',description='Core: ARM Cortex-M4 Package: UFQFPN32 Flash: 64KB Ram: 16KB Frequency: 72MHz Voltage: 1.65..1.95V IO-pins: 23',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='7',name='ADC1_IN1/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC1_IN2/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_IN3/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC1_IN4/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN5/COMP2_INM/COMP4_INM/DAC_OUT1/I2S3_WS/SPI3_NSS/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='OPAMP2_VINM/OPAMP2_VINM_SEC/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN10/OPAMP2_VOUT/TIM16_CH1/TIM1_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN15/COMP2_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM17_CH1/TIM1_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='I2C2_SMBA/I2C3_SCL/I2S2_MCK/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='DAC_EXTI9/I2C2_SCL/I2C3_SMBA/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C2_SDA/I2S2_ext_SD/SPI2_MISO/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_EXTI11/I2S2_SD/SPI2_MOSI/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='COMP2_OUT/I2S_CKIN/TIM16_CH1/TIM1_CH2N/TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TSC_G4_IO3/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_EXTI15/I2C1_SCL/I2S3_WS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='30',name='NPOR',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PF0/I2C2_SDA/I2S2_WS/RCC_OSC_IN/SPI2_NSS/TIM1_CH3N',do_erc=True),
            Pin(num='3',name='PF1/I2C2_SCL/I2S2_CK/RCC_OSC_OUT/SPI2_SCK',do_erc=True),
            Pin(num='15',name='PB0/ADC1_IN11/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/I2S3_CK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TSC_G5_IO1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/I2S3_ext_SD/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TSC_G5_IO2/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/I2C1_SMBA/I2C3_SDA/I2S3_SD/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='6',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F328C8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F3x8',description='Core: ARM Cortex-M4 Package: LQFP48 Flash: 64KB Ram: 12KB Frequency: 72MHz Voltage: 1.65..1.95V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC1_IN1/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN2/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN3/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN4/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC2_IN1/COMP2_INM/COMP4_INM/COMP6_INM/DAC1_OUT1/SPI1_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC2_IN2/DAC1_OUT2/OPAMP2_VINM/OPAMP2_VINM_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC2_IN3/DAC2_OUT1/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC2_IN4/COMP2_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC1_EXTI9/DAC2_EXTI9/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='COMP6_OUT/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='CAN_RX/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN_TX/COMP2_OUT/TIM16_CH1/TIM1_CH2N/TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='I2C1_SCL/SPI1_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='NPOR/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN/TIM1_CH3N',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC1_IN11/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC1_IN12/COMP4_OUT/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TSC_G5_IO1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/SPI1_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/SPI1_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TIM3_CH4/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CAN_RX/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TSC_SYNC/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/CAN_TX/COMP2_OUT/DAC1_EXTI9/DAC2_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/COMP6_INP/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/ADC2_IN13/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC1_IN13/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/ADC2_IN14/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC2_IN15/COMP6_INM/RTC_REFIN/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F334C4Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F334',description='Core: ARM Cortex-M4 Package: LQFP48 Flash: 16KB Ram: 8KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F334C6Tx', 'STM32F334C8Tx'],pins=[
            Pin(num='10',name='ADC1_IN1/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN2/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN3/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN4/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC2_IN1/COMP2_INM/COMP4_INM/COMP6_INM/DAC1_OUT1/SPI1_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC2_IN2/DAC1_OUT2/OPAMP2_VINM/OPAMP2_VINM_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC2_IN3/DAC2_OUT1/OPAMP2_DIG/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC2_IN4/COMP2_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='HRTIM1_CHA1/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC1_EXTI9/DAC2_EXTI9/HRTIM1_CHA2/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='COMP6_OUT/HRTIM1_CHB1/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='CAN_RX/HRTIM1_CHB2/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN_TX/COMP2_OUT/HRTIM1_FLT1/TIM16_CH1/TIM1_CH2N/TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='HRTIM1_FLT2/I2C1_SCL/SPI1_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN/TIM1_CH3N',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC1_IN11/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC1_IN12/COMP4_OUT/HRTIM1_SCOUT/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/ADC2_IN12/COMP4_INM/HRTIM1_SCIN/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/HRTIM1_EEV9/HRTIM1_SCOUT/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TSC_G5_IO1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/HRTIM1_EEV7/SPI1_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/HRTIM1_EEV6/I2C1_SMBA/SPI1_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/HRTIM1_EEV4/HRTIM1_SCIN/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/HRTIM1_EEV3/I2C1_SDA/TIM17_CH1N/TIM3_CH4/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CAN_RX/HRTIM1_EEV8/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TSC_SYNC/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/CAN_TX/COMP2_OUT/DAC1_EXTI9/DAC2_EXTI9/HRTIM1_EEV5/I2C1_SDA/IR_OUT/TIM17_CH1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/HRTIM1_FLT3/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/COMP6_INP/HRTIM1_FLT4/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/ADC2_IN13/HRTIM1_CHC1/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC1_IN13/HRTIM1_CHC2/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/ADC2_IN14/HRTIM1_CHD1/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC2_IN15/COMP6_INM/HRTIM1_CHD2/RTC_REFIN/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F334K4Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F334',description='Core: ARM Cortex-M4 Package: LQFP32 Flash: 16KB Ram: 8KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 25',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F334K6Tx', 'STM32F334K8Tx'],pins=[
            Pin(num='6',name='ADC1_IN1/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC1_IN2/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC1_IN3/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_IN4/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC2_IN1/COMP2_INM/COMP4_INM/DAC1_OUT1/SPI1_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC2_IN2/DAC1_OUT2/OPAMP2_VINM/OPAMP2_VINM_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC2_IN3/DAC2_OUT1/OPAMP2_DIG/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC2_IN4/COMP2_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='HRTIM1_CHA1/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='DAC1_EXTI9/DAC2_EXTI9/HRTIM1_CHA2/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='HRTIM1_CHB1/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='CAN_RX/HRTIM1_CHB2/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='CAN_TX/COMP2_OUT/HRTIM1_FLT1/TIM16_CH1/TIM1_CH2N/TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TSC_G4_IO3/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='HRTIM1_FLT2/I2C1_SCL/SPI1_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PF0/RCC_OSC_IN/TIM1_CH3N',do_erc=True),
            Pin(num='3',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='14',name='PB0/ADC1_IN11/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC1_IN12/COMP4_OUT/HRTIM1_SCOUT/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/HRTIM1_EEV9/HRTIM1_SCOUT/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TSC_G5_IO1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/HRTIM1_EEV7/SPI1_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/HRTIM1_EEV6/I2C1_SMBA/SPI1_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/HRTIM1_EEV4/HRTIM1_SCIN/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/HRTIM1_EEV3/I2C1_SDA/TIM17_CH1N/TIM3_CH4/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F334R6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F334',description='Core: ARM Cortex-M4 Package: LQFP64 Flash: 32KB Ram: 10KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F334R8Tx'],pins=[
            Pin(num='14',name='ADC1_IN1/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN2/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN3/COMP2_INM/COMP2_OUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN4/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC2_IN1/COMP2_INM/COMP4_INM/COMP6_INM/DAC1_OUT1/SPI1_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC2_IN2/DAC1_OUT2/OPAMP2_VINM/OPAMP2_VINM_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC2_IN3/DAC2_OUT1/OPAMP2_DIG/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC2_IN4/COMP2_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='HRTIM1_CHA1/RCC_MCO/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC1_EXTI9/DAC2_EXTI9/HRTIM1_CHA2/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='COMP6_OUT/HRTIM1_CHB1/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='CAN_RX/HRTIM1_CHB2/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN_TX/COMP2_OUT/HRTIM1_FLT1/TIM16_CH1/TIM1_CH2N/TIM1_ETR/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='HRTIM1_FLT2/I2C1_SCL/SPI1_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN11/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM1_CH2N/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN12/COMP4_OUT/HRTIM1_SCOUT/TIM1_CH3N/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC2_IN12/COMP4_INM/HRTIM1_SCIN/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='HRTIM1_EEV9/HRTIM1_SCOUT/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='HRTIM1_EEV7/SPI1_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='HRTIM1_EEV6/I2C1_SMBA/SPI1_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='HRTIM1_EEV4/HRTIM1_SCIN/I2C1_SCL/TIM16_CH1N/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='HRTIM1_EEV3/I2C1_SDA/TIM17_CH1N/TIM3_CH4/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN_RX/HRTIM1_EEV8/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TSC_SYNC/USART3_RX/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN_TX/COMP2_OUT/DAC1_EXTI9/DAC2_EXTI9/HRTIM1_EEV5/I2C1_SDA/IR_OUT/TIM17_CH1/USART3_TX/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='HRTIM1_FLT3/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='COMP6_INP/HRTIM1_FLT4/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC2_IN13/HRTIM1_CHC1/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN13/HRTIM1_CHC2/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC2_IN14/HRTIM1_CHD1/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC2_IN15/COMP6_INM/HRTIM1_CHD2/RTC_REFIN/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/RCC_OSC_IN/TIM1_CH3N',do_erc=True),
            Pin(num='6',name='PF1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN6/ADC2_IN6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN7/ADC2_IN7/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN8/ADC2_IN8/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN9/ADC2_IN9/TIM1_BKIN2/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC2_IN5/TIM1_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC2_IN11/OPAMP2_VINM/OPAMP2_VINM_SEC/TIM15_BKIN/TSC_G3_IO1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/COMP6_OUT/HRTIM1_EEV10/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/HRTIM1_FLT5/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/HRTIM1_CHE1/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC1_EXTI9/DAC2_EXTI9/HRTIM1_CHE2/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/HRTIM1_EEV2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/HRTIM1_EEV1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F358CCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F3x8',description='Core: ARM Cortex-M4 Package: LQFP48 Flash: 256KB Ram: 40KB Frequency: 72MHz Voltage: 1.65..1.95V IO-pins: 36',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC1_IN1/COMP1_INM/COMP1_OUT/COMP7_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM8_BKIN/TIM8_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN2/COMP1_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN3/ADC3_EXTI2/ADC4_EXTI2/COMP2_INM/COMP2_OUT/OPAMP1_VOUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN4/COMP2_INP/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP1_VINP/OPAMP1_VINP_SEC/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC2_IN1/COMP1_INM/COMP2_INM/COMP3_INM/COMP4_INM/COMP5_INM/COMP6_INM/COMP7_INM/DAC_OUT1/I2S3_WS/OPAMP4_VINP/OPAMP4_VINP_SEC/SPI1_NSS/SPI3_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC2_IN2/COMP1_INM/COMP2_INM/COMP3_INM/COMP4_INM/COMP5_INM/COMP6_INM/COMP7_INM/DAC_OUT2/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC2_IN3/COMP1_OUT/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC2_IN4/COMP2_INP/COMP2_OUT/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='COMP3_OUT/I2C2_SMBA/I2S2_MCK/RCC_MCO/TIM1_CH1/TIM4_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='COMP5_OUT/DAC_EXTI9/I2C2_SCL/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='COMP6_OUT/I2C2_SDA/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TIM8_BKIN/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/COMP1_OUT/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/TIM4_CH1/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN_TX/COMP2_OUT/TIM16_CH1/TIM1_CH2N/TIM1_ETR/TIM4_CH2/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TIM8_CH2/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/ADC2_EXTI15/I2C1_SCL/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TIM8_CH1/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='20',name='NPOR',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/I2C2_SDA/RCC_OSC_IN/TIM1_CH3N',do_erc=True),
            Pin(num='6',name='PF1/I2C2_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC3_IN12/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC3_IN1/COMP4_OUT/OPAMP3_VOUT/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TIM4_ETR/TIM8_CH1N/TSC_G5_IO1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TIM8_CH2N/TSC_G5_IO2/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/TIM8_CH3N/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_CH1/TIM8_ETR/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM17_CH1N/TIM3_CH4/TIM4_CH2/TIM8_BKIN/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/CAN_RX/COMP1_OUT/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TIM4_CH3/TIM8_CH2/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/CAN_TX/COMP2_OUT/DAC_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/TIM4_CH4/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/COMP5_INM/OPAMP3_VINM/OPAMP3_VINM_SEC/OPAMP4_VINM/OPAMP4_VINM_SEC/TIM2_CH3/TSC_SYNC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC1_EXTI11/ADC2_EXTI11/COMP6_INP/OPAMP4_VINP/OPAMP4_VINP_SEC/TIM2_CH4/TSC_G6_IO1/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/ADC4_IN3/COMP3_INM/I2C2_SMBA/I2S2_WS/OPAMP4_VOUT/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC3_IN5/COMP5_INP/I2S2_CK/OPAMP3_VINP/OPAMP3_VINP_SEC/OPAMP4_VINP/OPAMP4_VINP_SEC/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/ADC4_IN4/COMP3_INP/I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC1_EXTI15/ADC2_EXTI15/ADC4_IN5/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F358RCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F3x8',description='Core: ARM Cortex-M4 Package: LQFP64 Flash: 256KB Ram: 40KB Frequency: 72MHz Voltage: 1.65..1.95V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC1_IN1/COMP1_INM/COMP1_OUT/COMP7_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM8_BKIN/TIM8_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN2/COMP1_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN3/ADC3_EXTI2/ADC4_EXTI2/COMP2_INM/COMP2_OUT/OPAMP1_VOUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN4/COMP2_INP/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP1_VINP/OPAMP1_VINP_SEC/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC2_IN1/COMP1_INM/COMP2_INM/COMP3_INM/COMP4_INM/COMP5_INM/COMP6_INM/COMP7_INM/DAC_OUT1/I2S3_WS/OPAMP4_VINP/OPAMP4_VINP_SEC/SPI1_NSS/SPI3_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC2_IN2/COMP1_INM/COMP2_INM/COMP3_INM/COMP4_INM/COMP5_INM/COMP6_INM/COMP7_INM/DAC_OUT2/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC2_IN3/COMP1_OUT/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC2_IN4/COMP2_INP/COMP2_OUT/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='COMP3_OUT/I2C2_SMBA/I2S2_MCK/RCC_MCO/TIM1_CH1/TIM4_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='COMP5_OUT/DAC_EXTI9/I2C2_SCL/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='COMP6_OUT/I2C2_SDA/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TIM8_BKIN/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/COMP1_OUT/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/TIM4_CH1/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN_TX/COMP2_OUT/TIM16_CH1/TIM1_CH2N/TIM1_ETR/TIM4_CH2/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TIM8_CH2/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/ADC2_EXTI15/I2C1_SCL/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TIM8_CH1/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC3_IN12/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC3_IN1/COMP4_OUT/OPAMP3_VOUT/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TIM4_ETR/TIM8_CH1N/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TIM8_CH2N/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/TIM8_CH3N/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_CH1/TIM8_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM17_CH1N/TIM3_CH4/TIM4_CH2/TIM8_BKIN/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN_RX/COMP1_OUT/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TIM4_CH3/TIM8_CH2/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN_TX/COMP2_OUT/DAC_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/TIM4_CH4/TIM8_CH3/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='COMP5_INM/OPAMP3_VINM/OPAMP3_VINM_SEC/OPAMP4_VINM/OPAMP4_VINM_SEC/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/ADC2_EXTI11/COMP6_INP/OPAMP4_VINP/OPAMP4_VINP_SEC/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC4_IN3/COMP3_INM/I2C2_SMBA/I2S2_WS/OPAMP4_VOUT/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC3_IN5/COMP5_INP/I2S2_CK/OPAMP3_VINP/OPAMP3_VINP_SEC/OPAMP4_VINP/OPAMP4_VINP_SEC/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC4_IN4/COMP3_INP/I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/ADC2_EXTI15/ADC4_IN5/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='28',name='NPOR',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/I2C2_SDA/RCC_OSC_IN/TIM1_CH3N',do_erc=True),
            Pin(num='6',name='PF1/I2C2_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='18',name='PF4/ADC1_IN5/COMP1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PD2/ADC3_EXTI2/ADC4_EXTI2/TIM3_ETR/TIM8_BKIN/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN6/ADC2_IN6/COMP7_INM',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN7/ADC2_IN7/COMP7_INP',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN8/ADC2_IN8/ADC3_EXTI2/ADC4_EXTI2/COMP7_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN9/ADC2_IN9/TIM1_BKIN2',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC2_IN5/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC2_IN11/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/TSC_G3_IO1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/COMP6_OUT/I2S2_MCK/TIM3_CH1/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/COMP5_OUT/I2S3_MCK/TIM3_CH2/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/COMP3_OUT/TIM3_CH3/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/I2S_CKIN/TIM3_CH4/TIM8_BKIN2/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/SPI3_SCK/TIM8_CH1N/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/ADC2_EXTI11/I2S3_ext_SD/SPI3_MISO/TIM8_CH2N/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SPI3_MOSI/TIM8_CH3N/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F358VCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F3x8',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 256KB Ram: 40KB Frequency: 72MHz Voltage: 1.65..1.95V IO-pins: 86',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC1_IN1/COMP1_INM/COMP1_OUT/COMP7_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM8_BKIN/TIM8_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN2/COMP1_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN3/ADC3_EXTI2/ADC4_EXTI2/COMP2_INM/COMP2_OUT/OPAMP1_VOUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN4/COMP2_INP/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP1_VINP/OPAMP1_VINP_SEC/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC2_IN1/COMP1_INM/COMP2_INM/COMP3_INM/COMP4_INM/COMP5_INM/COMP6_INM/COMP7_INM/DAC_OUT1/I2S3_WS/OPAMP4_VINP/OPAMP4_VINP_SEC/SPI1_NSS/SPI3_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC2_IN2/COMP1_INM/COMP2_INM/COMP3_INM/COMP4_INM/COMP5_INM/COMP6_INM/COMP7_INM/DAC_OUT2/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC2_IN3/COMP1_OUT/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC2_IN4/COMP2_INP/COMP2_OUT/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='COMP3_OUT/I2C2_SMBA/I2S2_MCK/RCC_MCO/TIM1_CH1/TIM4_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='COMP5_OUT/DAC_EXTI9/I2C2_SCL/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='COMP6_OUT/I2C2_SDA/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TIM8_BKIN/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/COMP1_OUT/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/TIM4_CH1/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN_TX/COMP2_OUT/TIM16_CH1/TIM1_CH2N/TIM1_ETR/TIM4_CH2/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TIM8_CH2/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/I2C1_SCL/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TIM8_CH1/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC3_IN12/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC3_IN1/COMP4_OUT/OPAMP3_VOUT/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TIM4_ETR/TIM8_CH1N/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TIM8_CH2N/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/TIM8_CH3N/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_CH1/TIM8_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/TIM17_CH1N/TIM3_CH4/TIM4_CH2/TIM8_BKIN/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN_RX/COMP1_OUT/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TIM4_CH3/TIM8_CH2/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN_TX/COMP2_OUT/DAC_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/TIM4_CH4/TIM8_CH3/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='COMP5_INM/OPAMP3_VINM/OPAMP3_VINM_SEC/OPAMP4_VINM/OPAMP4_VINM_SEC/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/COMP6_INP/OPAMP4_VINP/OPAMP4_VINP_SEC/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC4_IN3/COMP3_INM/I2C2_SMBA/I2S2_WS/OPAMP4_VOUT/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC3_IN5/COMP5_INP/I2S2_CK/OPAMP3_VINP/OPAMP3_VINP_SEC/OPAMP4_VINP/OPAMP4_VINP_SEC/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC4_IN4/COMP3_INP/I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/ADC4_IN5/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN6/ADC2_IN6/COMP7_INM/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN7/ADC2_IN7/COMP7_INP/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN8/ADC2_IN8/ADC3_EXTI2/ADC4_EXTI2/COMP7_OUT/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN9/ADC2_IN9/TIM1_BKIN2/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC2_IN5/USART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC2_IN11/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/TSC_G3_IO1/USART1_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='COMP6_OUT/I2S2_MCK/TIM3_CH1/TIM8_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='COMP5_OUT/I2S3_MCK/TIM3_CH2/TIM8_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='COMP3_OUT/TIM3_CH3/TIM8_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/I2S_CKIN/TIM3_CH4/TIM8_BKIN2/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/SPI3_SCK/TIM8_CH1N/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/I2S3_ext_SD/SPI3_MISO/TIM8_CH2N/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/SPI3_MOSI/TIM8_CH3N/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='37',name='NPOR',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PF0/I2C2_SDA/RCC_OSC_IN/TIM1_CH3N',do_erc=True),
            Pin(num='13',name='PF1/I2C2_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='19',name='PF2/ADC1_IN10/ADC2_IN10/ADC3_EXTI2/ADC4_EXTI2',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PF4/ADC1_IN5/COMP1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='PF6/I2C2_SCL/TIM4_CH4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF9/DAC_EXTI9/SPI2_SCK/TIM15_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF10/SPI2_SCK/TIM15_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/TIM16_CH1/TIM4_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/TIM17_CH1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ADC3_EXTI2/ADC4_EXTI2/SYS_TRACECK/TIM3_CH1/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/SYS_TRACED0/TIM3_CH2/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH3/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM3_CH4/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/ADC3_IN13/COMP4_INP/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/ADC3_IN6/ADC4_IN6/COMP4_INM/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/ADC3_IN2/DAC_EXTI9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/ADC3_IN14/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_IN15/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/ADC3_IN16/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/ADC3_IN3/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/ADC4_IN1/TIM1_BKIN2/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC4_IN2/TIM1_BKIN/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN_TX/TIM8_BKIN2/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/ADC3_EXTI2/ADC4_EXTI2/TIM3_ETR/TIM8_BKIN/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/TIM2_CH1/TIM2_ETR/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/TIM2_CH2/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/TIM2_CH4/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM2_CH3/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/ADC4_IN12/OPAMP4_VINM/OPAMP4_VINM_SEC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/ADC4_IN13/DAC_EXTI9/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/ADC3_IN7/ADC4_IN7/COMP6_INM/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_IN8/ADC4_IN8/COMP6_INP/OPAMP4_VINP/OPAMP4_VINP_SEC/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/ADC3_IN9/ADC4_IN9/COMP5_INP/TIM4_CH1/TSC_G8_IO1/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/ADC3_IN10/ADC4_IN10/COMP5_INM/TIM4_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/ADC3_IN11/ADC4_IN11/COMP3_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM4_CH3/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/COMP3_INM/SPI2_NSS/TIM4_CH4/TSC_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F373C8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F373',description='Core: ARM Cortex-M4 Package: LQFP48 Flash: 64KB Ram: 16KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F373CBTx', 'STM32F373CCTx'],pins=[
            Pin(num='10',name='ADC1_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM19_CH1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM5_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN1/COMP1_INP/I2S3_CK/RTC_REFIN/SPI3_SCK/TIM15_CH1N/TIM19_CH2/TIM2_CH2/TIM5_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN2/COMP2_INM/COMP2_OUT/I2S3_MCK/SPI3_MISO/TIM15_CH1/TIM19_CH3/TIM2_CH3/TIM5_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN3/COMP2_INP/I2S3_SD/SPI3_MOSI/TIM15_CH2/TIM19_CH4/TIM2_CH4/TIM5_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN4/DAC1_OUT1/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/TIM12_CH1/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN5/CEC/DAC1_OUT2/I2S1_CK/SPI1_SCK/TIM12_CH2/TIM14_CH1/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN6/COMP1_OUT/DAC2_OUT1/I2S1_MCK/SPI1_MISO/TIM13_CH1/TIM16_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SMBA/I2S2_CK/RCC_MCO/SPI2_SCK/TIM4_ETR/TIM5_CH1/TIM5_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC1_EXTI9/DAC2_EXTI9/I2C2_SCL/I2S2_MCK/SPI2_MISO/TIM13_CH1/TIM15_BKIN/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2C2_SDA/I2S2_SD/SPI2_MOSI/TIM14_CH1/TIM17_BKIN/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/CAN_RX/COMP1_OUT/I2S1_WS/I2S2_WS/SDADC1_EXTI11/SDADC2_EXTI11/SDADC3_EXTI11/SPI1_NSS/SPI2_NSS/TIM4_CH1/TIM5_CH2/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN_TX/COMP2_OUT/I2S1_CK/SPI1_SCK/TIM16_CH1/TIM4_CH2/TIM5_CH3/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2S1_MCK/IR_OUT/SPI1_MISO/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TIM5_CH4/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM12_CH1/TSC_G4_IO4/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/I2C1_SCL/I2S1_WS/I2S3_WS/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_EXTI15/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM12_CH2/TIM2_CH1/TIM2_ETR/TSC_SYNC/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN8/I2S1_SD/SDADC1_AIN6P/SPI1_MOSI/TIM3_CH2/TIM3_CH3/TSC_G3_IO3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='ADC1_IN9/SDADC1_AIN5P/SDADC1_AIN6M/TIM3_CH4/TSC_G3_IO4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='SDADC1_AIN4P/SDADC2_AIN6P/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM13_CH1/TIM2_CH2/TIM3_ETR/TIM4_ETR/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='I2S1_MCK/I2S3_MCK/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM15_CH1N/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM19_ETR/TIM3_CH2/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='I2C1_SCL/TIM15_CH1/TIM16_CH1N/TIM19_CH1/TIM3_CH3/TIM4_CH1/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='I2C1_SDA/TIM15_CH2/TIM17_CH1N/TIM19_CH2/TIM3_CH4/TIM4_CH2/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN_RX/CEC/COMP1_OUT/I2C1_SCL/I2S2_CK/SPI2_SCK/TIM16_CH1/TIM19_CH3/TIM4_CH3/TSC_SYNC/USART3_TX/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='CAN_TX/COMP2_OUT/DAC1_EXTI9/DAC2_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/TIM19_CH4/TIM4_CH4/USART3_RX/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='I2S2_MCK/SDADC3_AIN8P/SPI2_MISO/TIM12_CH1/TIM15_CH1/TSC_G6_IO1/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_EXTI15/I2S2_SD/RTC_REFIN/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_AIN7P/SDADC3_AIN8M/SDADC3_EXTI15/SPI2_MOSI/TIM12_CH2/TIM15_CH1N/TIM15_CH2/TSC_G6_IO2/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='25',name='VREFSD+',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/I2C2_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/I2C2_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='35',name='PF6/I2C2_SCL/I2S1_SD/SPI1_MOSI/TIM4_CH4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='PF7/I2C2_SDA/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PE8/SDADC1_AIN8P/SDADC2_AIN8P',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PE9/DAC1_EXTI9/DAC2_EXTI9/SDADC1_AIN7P/SDADC1_AIN8M/SDADC2_AIN7P/SDADC2_AIN8M',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PD8/I2S2_CK/SDADC3_AIN6P/SPI2_SCK/TSC_G6_IO3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='24',name='VDDSD',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSSSD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F373R8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F373',description='Core: ARM Cortex-M4 Package: LQFP64 Flash: 64KB Ram: 16KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 52',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F373RBTx', 'STM32F373RCTx'],pins=[
            Pin(num='14',name='ADC1_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM19_CH1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM5_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/COMP1_INP/I2S3_CK/RTC_REFIN/SPI3_SCK/TIM15_CH1N/TIM19_CH2/TIM2_CH2/TIM5_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/COMP2_INM/COMP2_OUT/I2S3_MCK/SPI3_MISO/TIM15_CH1/TIM19_CH3/TIM2_CH3/TIM5_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN3/COMP2_INP/I2S3_SD/SPI3_MOSI/TIM15_CH2/TIM19_CH4/TIM2_CH4/TIM5_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/DAC1_OUT1/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/TIM12_CH1/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/CEC/DAC1_OUT2/I2S1_CK/SPI1_SCK/TIM12_CH2/TIM14_CH1/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/COMP1_OUT/DAC2_OUT1/I2S1_MCK/SPI1_MISO/TIM13_CH1/TIM16_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='I2C2_SMBA/I2S2_CK/RCC_MCO/SPI2_SCK/TIM4_ETR/TIM5_CH1/TIM5_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC1_EXTI9/DAC2_EXTI9/I2C2_SCL/I2S2_MCK/SPI2_MISO/TIM13_CH1/TIM15_BKIN/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='I2C2_SDA/I2S2_SD/SPI2_MOSI/TIM14_CH1/TIM17_BKIN/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/CAN_RX/COMP1_OUT/I2S1_WS/I2S2_WS/SDADC1_EXTI11/SDADC2_EXTI11/SDADC3_EXTI11/SPI1_NSS/SPI2_NSS/TIM4_CH1/TIM5_CH2/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN_TX/COMP2_OUT/I2S1_CK/SPI1_SCK/TIM16_CH1/TIM4_CH2/TIM5_CH3/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='I2S1_MCK/IR_OUT/SPI1_MISO/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TIM5_CH4/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM12_CH1/TSC_G4_IO4/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/I2C1_SCL/I2S1_WS/I2S3_WS/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_EXTI15/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM12_CH2/TIM2_CH1/TIM2_ETR/TSC_SYNC/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/I2S1_SD/SDADC1_AIN6P/SPI1_MOSI/TIM3_CH2/TIM3_CH3/TSC_G3_IO3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/SDADC1_AIN5P/SDADC1_AIN6M/TIM3_CH4/TSC_G3_IO4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='SDADC1_AIN4P/SDADC2_AIN6P/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM13_CH1/TIM2_CH2/TIM3_ETR/TIM4_ETR/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2S1_MCK/I2S3_MCK/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM15_CH1N/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM19_ETR/TIM3_CH2/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM15_CH1/TIM16_CH1N/TIM19_CH1/TIM3_CH3/TIM4_CH1/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM15_CH2/TIM17_CH1N/TIM19_CH2/TIM3_CH4/TIM4_CH2/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN_RX/CEC/COMP1_OUT/I2C1_SCL/I2S2_CK/SPI2_SCK/TIM16_CH1/TIM19_CH3/TIM4_CH3/TSC_SYNC/USART3_TX/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN_TX/COMP2_OUT/DAC1_EXTI9/DAC2_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/TIM19_CH4/TIM4_CH4/USART3_RX/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2S2_MCK/SDADC3_AIN8P/SPI2_MISO/TIM12_CH1/TIM15_CH1/TSC_G6_IO1/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_EXTI15/I2S2_SD/RTC_REFIN/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_AIN7P/SDADC3_AIN8M/SDADC3_EXTI15/SPI2_MOSI/TIM12_CH2/TIM15_CH1N/TIM15_CH2/TSC_G6_IO2/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VREFSD+',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/I2C2_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/I2C2_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='47',name='PF6/I2C2_SCL/I2S1_SD/SPI1_MOSI/TIM4_CH4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='PF7/I2C2_SDA/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PE8/SDADC1_AIN8P/SDADC2_AIN8P',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PE9/DAC1_EXTI9/DAC2_EXTI9/SDADC1_AIN7P/SDADC1_AIN8M/SDADC2_AIN7P/SDADC2_AIN8M',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='PD8/I2S2_CK/SDADC3_AIN6P/SPI2_SCK/TSC_G6_IO3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10/TIM5_CH1/TIM5_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12/I2S2_MCK/SPI2_MISO/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13/I2S2_SD/SPI2_MOSI/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14/TIM13_CH1/TSC_G3_IO1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15/TSC_G3_IO2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S1_WS/SPI1_NSS/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S1_CK/SPI1_SCK/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/I2S1_MCK/SPI1_MISO/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC1_EXTI9/DAC2_EXTI9/I2S1_SD/SPI1_MOSI/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/SPI3_SCK/TIM19_CH1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/I2S3_MCK/SDADC1_EXTI11/SDADC2_EXTI11/SDADC3_EXTI11/SPI3_MISO/TIM19_CH2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SPI3_MOSI/TIM19_CH3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDDSD',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSSSD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F373V8Hx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F373',description='Core: ARM Cortex-M4 Package: UFBGA100 Flash: 64KB Ram: 16KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 84',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F373VBHx', 'STM32F373VCHx'],pins=[
            Pin(num='L2',name='ADC1_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM19_CH1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM5_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN1/COMP1_INP/I2S3_CK/RTC_REFIN/SPI3_SCK/TIM15_CH1N/TIM19_CH2/TIM2_CH2/TIM5_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC1_IN2/COMP2_INM/COMP2_OUT/I2S3_MCK/SPI3_MISO/TIM15_CH1/TIM19_CH3/TIM2_CH3/TIM5_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC1_IN3/COMP2_INP/I2S3_SD/SPI3_MOSI/TIM15_CH2/TIM19_CH4/TIM2_CH4/TIM5_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN4/DAC1_OUT1/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/TIM12_CH1/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC1_IN5/CEC/DAC1_OUT2/I2S1_CK/SPI1_SCK/TIM12_CH2/TIM14_CH1/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC1_IN6/COMP1_OUT/DAC2_OUT1/I2S1_MCK/SPI1_MISO/TIM13_CH1/TIM16_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='I2C2_SMBA/I2S2_CK/RCC_MCO/SPI2_SCK/TIM4_ETR/TIM5_CH1/TIM5_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC1_EXTI9/DAC2_EXTI9/I2C2_SCL/I2S2_MCK/SPI2_MISO/TIM13_CH1/TIM15_BKIN/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='I2C2_SDA/I2S2_SD/SPI2_MOSI/TIM14_CH1/TIM17_BKIN/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC1_EXTI11/CAN_RX/COMP1_OUT/I2S1_WS/I2S2_WS/SDADC1_EXTI11/SDADC2_EXTI11/SDADC3_EXTI11/SPI1_NSS/SPI2_NSS/TIM4_CH1/TIM5_CH2/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='CAN_TX/COMP2_OUT/I2S1_CK/SPI1_SCK/TIM16_CH1/TIM4_CH2/TIM5_CH3/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='I2S1_MCK/IR_OUT/SPI1_MISO/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TIM5_CH4/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM12_CH1/TSC_G4_IO4/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ADC1_EXTI15/I2C1_SCL/I2S1_WS/I2S3_WS/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_EXTI15/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM12_CH2/TIM2_CH1/TIM2_ETR/TSC_SYNC/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC1_IN8/I2S1_SD/SDADC1_AIN6P/SPI1_MOSI/TIM3_CH2/TIM3_CH3/TSC_G3_IO3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC1_IN9/SDADC1_AIN5P/SDADC1_AIN6M/TIM3_CH4/TSC_G3_IO4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='SDADC1_AIN4P/SDADC2_AIN6P/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM13_CH1/TIM2_CH2/TIM3_ETR/TIM4_ETR/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='I2S1_MCK/I2S3_MCK/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM15_CH1N/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM19_ETR/TIM3_CH2/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2C1_SCL/TIM15_CH1/TIM16_CH1N/TIM19_CH1/TIM3_CH3/TIM4_CH1/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='I2C1_SDA/TIM15_CH2/TIM17_CH1N/TIM19_CH2/TIM3_CH4/TIM4_CH2/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='CAN_RX/CEC/COMP1_OUT/I2C1_SCL/I2S2_CK/SPI2_SCK/TIM16_CH1/TIM19_CH3/TIM4_CH3/TSC_SYNC/USART3_TX/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='CAN_TX/COMP2_OUT/DAC1_EXTI9/DAC2_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/TIM19_CH4/TIM4_CH4/USART3_RX/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='CEC/I2S2_CK/SDADC2_AIN0M/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='I2S2_MCK/SDADC3_AIN8P/SPI2_MISO/TIM12_CH1/TIM15_CH1/TSC_G6_IO1/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='ADC1_EXTI15/I2S2_SD/RTC_REFIN/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_AIN7P/SDADC3_AIN8M/SDADC3_EXTI15/SPI2_MOSI/TIM12_CH2/TIM15_CH1N/TIM15_CH2/TSC_G6_IO2/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC1_IN10/TIM5_CH1/TIM5_ETR/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC1_IN11/TIM5_CH2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC1_IN12/I2S2_MCK/SPI2_MISO/TIM5_CH3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_IN13/I2S2_SD/SPI2_MOSI/TIM5_CH4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC1_IN14/TIM13_CH1/TSC_G3_IO1/USART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC1_IN15/TSC_G3_IO2/USART1_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='I2S1_WS/SPI1_NSS/TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='I2S1_CK/SPI1_SCK/TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='I2S1_MCK/SPI1_MISO/TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC1_EXTI9/DAC2_EXTI9/I2S1_SD/SPI1_MOSI/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='I2S3_CK/SPI3_SCK/TIM19_CH1/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC1_EXTI11/I2S3_MCK/SDADC1_EXTI11/SDADC2_EXTI11/SDADC3_EXTI11/SPI3_MISO/TIM19_CH2/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='I2S3_SD/SPI3_MOSI/TIM19_CH3/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC1_EXTI15/RCC_OSC32_OUT/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_EXTI15/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='K12',name='VREFSD+',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='L11',name='VREFSD-',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PF0/I2C2_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PF1/I2C2_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='J1',name='PF2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='PF6/I2C2_SCL/I2S1_SD/SPI1_MOSI/TIM4_CH4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PF9/DAC1_EXTI9/DAC2_EXTI9/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PF10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/TIM4_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/SYS_TRACECK/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/SYS_TRACED0/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/SYS_TRACED1/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/SYS_TRACED2/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/SDADC1_AIN3P/SDADC1_AIN4M/SDADC2_AIN5P/SDADC2_AIN6M',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/SDADC1_AIN8P/SDADC2_AIN8P',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/DAC1_EXTI9/DAC2_EXTI9/SDADC1_AIN7P/SDADC1_AIN8M/SDADC2_AIN7P/SDADC2_AIN8M',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/SDADC1_AIN2P',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC1_EXTI11/SDADC1_AIN1P/SDADC1_AIN2M/SDADC1_EXTI11/SDADC2_AIN4P/SDADC2_EXTI11/SDADC3_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/SDADC1_AIN0P/SDADC2_AIN3P/SDADC2_AIN4M',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/SDADC1_AIN0M/SDADC2_AIN2P',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/SDADC2_AIN1P/SDADC2_AIN2M',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/ADC1_EXTI15/SDADC1_EXTI15/SDADC2_AIN0P/SDADC2_EXTI15/SDADC3_EXTI15/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0/CAN_RX/TIM19_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1/CAN_TX/TIM19_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/I2S2_MCK/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/I2S2_WS/SPI2_NSS/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/I2S2_CK/SPI2_SCK/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/I2S2_CK/SDADC3_AIN6P/SPI2_SCK/TSC_G6_IO3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9/DAC1_EXTI9/DAC2_EXTI9/SDADC3_AIN5P/SDADC3_AIN6M/TSC_G6_IO4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10/SDADC3_AIN4P/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/ADC1_EXTI11/SDADC1_EXTI11/SDADC2_EXTI11/SDADC3_AIN3P/SDADC3_AIN4M/SDADC3_EXTI11/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/SDADC3_AIN2P/TIM4_CH1/TSC_G8_IO1/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13/SDADC3_AIN1P/SDADC3_AIN2M/TIM4_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14/SDADC3_AIN0P/TIM4_CH3/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/ADC1_EXTI15/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_AIN0M/SDADC3_EXTI15/TIM4_CH4/TSC_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDDSD12',func=Pin.PWRIN,do_erc=True),
            Pin(num='L12',name='VDDSD3',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSSSD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F373V8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F373',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 64KB Ram: 16KB Frequency: 72MHz Voltage: 2..3.6V IO-pins: 84',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F373VBTx', 'STM32F373VCTx'],pins=[
            Pin(num='23',name='ADC1_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM19_CH1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM5_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/COMP1_INP/I2S3_CK/RTC_REFIN/SPI3_SCK/TIM15_CH1N/TIM19_CH2/TIM2_CH2/TIM5_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/COMP2_INM/COMP2_OUT/I2S3_MCK/SPI3_MISO/TIM15_CH1/TIM19_CH3/TIM2_CH3/TIM5_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/COMP2_INP/I2S3_SD/SPI3_MOSI/TIM15_CH2/TIM19_CH4/TIM2_CH4/TIM5_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/DAC1_OUT1/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/TIM12_CH1/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/CEC/DAC1_OUT2/I2S1_CK/SPI1_SCK/TIM12_CH2/TIM14_CH1/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/COMP1_OUT/DAC2_OUT1/I2S1_MCK/SPI1_MISO/TIM13_CH1/TIM16_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C2_SMBA/I2S2_CK/RCC_MCO/SPI2_SCK/TIM4_ETR/TIM5_CH1/TIM5_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC1_EXTI9/DAC2_EXTI9/I2C2_SCL/I2S2_MCK/SPI2_MISO/TIM13_CH1/TIM15_BKIN/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C2_SDA/I2S2_SD/SPI2_MOSI/TIM14_CH1/TIM17_BKIN/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/CAN_RX/COMP1_OUT/I2S1_WS/I2S2_WS/SDADC1_EXTI11/SDADC2_EXTI11/SDADC3_EXTI11/SPI1_NSS/SPI2_NSS/TIM4_CH1/TIM5_CH2/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN_TX/COMP2_OUT/I2S1_CK/SPI1_SCK/TIM16_CH1/TIM4_CH2/TIM5_CH3/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='I2S1_MCK/IR_OUT/SPI1_MISO/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TIM5_CH4/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM12_CH1/TSC_G4_IO4/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/I2C1_SCL/I2S1_WS/I2S3_WS/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_EXTI15/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM12_CH2/TIM2_CH1/TIM2_ETR/TSC_SYNC/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/I2S1_SD/SDADC1_AIN6P/SPI1_MOSI/TIM3_CH2/TIM3_CH3/TSC_G3_IO3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/SDADC1_AIN5P/SDADC1_AIN6M/TIM3_CH4/TSC_G3_IO4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SDADC1_AIN4P/SDADC2_AIN6P/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM13_CH1/TIM2_CH2/TIM3_ETR/TIM4_ETR/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S1_MCK/I2S3_MCK/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM15_CH1N/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM19_ETR/TIM3_CH2/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM15_CH1/TIM16_CH1N/TIM19_CH1/TIM3_CH3/TIM4_CH1/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/TIM15_CH2/TIM17_CH1N/TIM19_CH2/TIM3_CH4/TIM4_CH2/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN_RX/CEC/COMP1_OUT/I2C1_SCL/I2S2_CK/SPI2_SCK/TIM16_CH1/TIM19_CH3/TIM4_CH3/TSC_SYNC/USART3_TX/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN_TX/COMP2_OUT/DAC1_EXTI9/DAC2_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/TIM19_CH4/TIM4_CH4/USART3_RX/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='CEC/I2S2_CK/SDADC2_AIN0M/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2S2_MCK/SDADC3_AIN8P/SPI2_MISO/TIM12_CH1/TIM15_CH1/TSC_G6_IO1/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/I2S2_SD/RTC_REFIN/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_AIN7P/SDADC3_AIN8M/SDADC3_EXTI15/SPI2_MOSI/TIM12_CH2/TIM15_CH1N/TIM15_CH2/TSC_G6_IO2/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/TIM5_CH1/TIM5_ETR/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/TIM5_CH2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/I2S2_MCK/SPI2_MISO/TIM5_CH3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/I2S2_SD/SPI2_MOSI/TIM5_CH4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/TIM13_CH1/TSC_G3_IO1/USART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/TSC_G3_IO2/USART1_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S1_WS/SPI1_NSS/TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S1_CK/SPI1_SCK/TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='I2S1_MCK/SPI1_MISO/TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC1_EXTI9/DAC2_EXTI9/I2S1_SD/SPI1_MOSI/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/SPI3_SCK/TIM19_CH1/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/I2S3_MCK/SDADC1_EXTI11/SDADC2_EXTI11/SDADC3_EXTI11/SPI3_MISO/TIM19_CH2/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/SPI3_MOSI/TIM19_CH3/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/RCC_OSC32_OUT/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_EXTI15/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VREFSD-',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VREFSD+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PF0/I2C2_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PF1/I2C2_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='19',name='PF2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='PF6/I2C2_SCL/I2S1_SD/SPI1_MOSI/TIM4_CH4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF9/DAC1_EXTI9/DAC2_EXTI9/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF10',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/TIM4_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/SYS_TRACECK/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/SYS_TRACED0/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/SDADC1_AIN3P/SDADC1_AIN4M/SDADC2_AIN5P/SDADC2_AIN6M',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/SDADC1_AIN8P/SDADC2_AIN8P',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC1_EXTI9/DAC2_EXTI9/SDADC1_AIN7P/SDADC1_AIN8M/SDADC2_AIN7P/SDADC2_AIN8M',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/SDADC1_AIN2P',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/SDADC1_AIN1P/SDADC1_AIN2M/SDADC1_EXTI11/SDADC2_AIN4P/SDADC2_EXTI11/SDADC3_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/SDADC1_AIN0P/SDADC2_AIN3P/SDADC2_AIN4M',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SDADC1_AIN0M/SDADC2_AIN2P',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/SDADC2_AIN1P/SDADC2_AIN2M',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/SDADC1_EXTI15/SDADC2_AIN0P/SDADC2_EXTI15/SDADC3_EXTI15/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN_RX/TIM19_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN_TX/TIM19_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/I2S2_MCK/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/I2S2_WS/SPI2_NSS/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/I2S2_CK/SPI2_SCK/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/I2S2_CK/SDADC3_AIN6P/SPI2_SCK/TSC_G6_IO3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC1_EXTI9/DAC2_EXTI9/SDADC3_AIN5P/SDADC3_AIN6M/TSC_G6_IO4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/SDADC3_AIN4P/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/SDADC1_EXTI11/SDADC2_EXTI11/SDADC3_AIN3P/SDADC3_AIN4M/SDADC3_EXTI11/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/SDADC3_AIN2P/TIM4_CH1/TSC_G8_IO1/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/SDADC3_AIN1P/SDADC3_AIN2M/TIM4_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/SDADC3_AIN0P/TIM4_CH3/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_AIN0M/SDADC3_EXTI15/TIM4_CH4/TSC_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDDSD12',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VDDSD3',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSSSD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F378CCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F3x8',description='Core: ARM Cortex-M4 Package: LQFP48 Flash: 256KB Ram: 32KB Frequency: 72MHz Voltage: 1.65..1.95V IO-pins: 36',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC1_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM19_CH1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM5_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN1/COMP1_INP/I2S3_CK/RTC_REFIN/SPI3_SCK/TIM15_CH1N/TIM19_CH2/TIM2_CH2/TIM5_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN2/COMP2_INM/COMP2_OUT/I2S3_MCK/SPI3_MISO/TIM15_CH1/TIM19_CH3/TIM2_CH3/TIM5_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN3/COMP2_INP/I2S3_SD/SPI3_MOSI/TIM15_CH2/TIM19_CH4/TIM2_CH4/TIM5_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN4/DAC1_OUT1/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/TIM12_CH1/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN5/CEC/DAC1_OUT2/I2S1_CK/SPI1_SCK/TIM12_CH2/TIM14_CH1/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN6/COMP1_OUT/DAC2_OUT1/I2S1_MCK/SPI1_MISO/TIM13_CH1/TIM16_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SMBA/I2S2_CK/RCC_MCO/SPI2_SCK/TIM4_ETR/TIM5_CH1/TIM5_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC1_EXTI9/DAC2_EXTI9/I2C2_SCL/I2S2_MCK/SPI2_MISO/TIM13_CH1/TIM15_BKIN/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2C2_SDA/I2S2_SD/SPI2_MOSI/TIM14_CH1/TIM17_BKIN/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/CAN_RX/COMP1_OUT/I2S1_WS/I2S2_WS/SDADC1_EXTI11/SDADC2_EXTI11/SDADC3_EXTI11/SPI1_NSS/SPI2_NSS/TIM4_CH1/TIM5_CH2/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN_TX/COMP2_OUT/I2S1_CK/SPI1_SCK/TIM16_CH1/TIM4_CH2/TIM5_CH3/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2S1_MCK/IR_OUT/SPI1_MISO/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TIM5_CH4/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM12_CH1/TSC_G4_IO4/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/I2C1_SCL/I2S1_WS/I2S3_WS/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_EXTI15/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM12_CH2/TIM2_CH1/TIM2_ETR/TSC_SYNC/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN8/I2S1_SD/SDADC1_AIN6P/SPI1_MOSI/TIM3_CH2/TIM3_CH3/TSC_G3_IO3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='ADC1_IN9/SDADC1_AIN5P/SDADC1_AIN6M/TIM3_CH4/TSC_G3_IO4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM13_CH1/TIM2_CH2/TIM3_ETR/TIM4_ETR/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='I2S1_MCK/I2S3_MCK/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM15_CH1N/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM19_ETR/TIM3_CH2/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='I2C1_SCL/TIM15_CH1/TIM16_CH1N/TIM19_CH1/TIM3_CH3/TIM4_CH1/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='I2C1_SDA/TIM15_CH2/TIM17_CH1N/TIM19_CH2/TIM3_CH4/TIM4_CH2/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN_RX/CEC/COMP1_OUT/I2C1_SCL/I2S2_CK/SPI2_SCK/TIM16_CH1/TIM19_CH3/TIM4_CH3/TSC_SYNC/USART3_TX/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='CAN_TX/COMP2_OUT/DAC1_EXTI9/DAC2_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/TIM19_CH4/TIM4_CH4/USART3_RX/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='I2S2_MCK/SDADC3_AIN8P/SPI2_MISO/TIM12_CH1/TIM15_CH1/TSC_G6_IO1/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_EXTI15/I2S2_SD/RTC_REFIN/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_AIN7P/SDADC3_AIN8M/SDADC3_EXTI15/SPI2_MOSI/TIM12_CH2/TIM15_CH1N/TIM15_CH2/TSC_G6_IO2/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='20',name='NPOR',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='25',name='VREFSD+',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/I2C2_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/I2C2_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='35',name='PF6/I2C2_SCL/I2S1_SD/SPI1_MOSI/TIM4_CH4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='PF7/I2C2_SDA/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PE8/SDADC1_AIN8P/SDADC2_AIN8P',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PE9/DAC1_EXTI9/DAC2_EXTI9/SDADC1_AIN7P/SDADC1_AIN8M/SDADC2_AIN7P/SDADC2_AIN8M',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PD8/I2S2_CK/SDADC3_AIN6P/SPI2_SCK/TSC_G6_IO3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='24',name='VDDSD',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSSSD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F378RCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F3x8',description='Core: ARM Cortex-M4 Package: LQFP64 Flash: 256KB Ram: 32KB Frequency: 72MHz Voltage: 1.65..1.95V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC1_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM19_CH1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM5_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/COMP1_INP/I2S3_CK/RTC_REFIN/SPI3_SCK/TIM15_CH1N/TIM19_CH2/TIM2_CH2/TIM5_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/COMP2_INM/COMP2_OUT/I2S3_MCK/SPI3_MISO/TIM15_CH1/TIM19_CH3/TIM2_CH3/TIM5_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN3/COMP2_INP/I2S3_SD/SPI3_MOSI/TIM15_CH2/TIM19_CH4/TIM2_CH4/TIM5_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/DAC1_OUT1/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/TIM12_CH1/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/CEC/DAC1_OUT2/I2S1_CK/SPI1_SCK/TIM12_CH2/TIM14_CH1/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/COMP1_OUT/DAC2_OUT1/I2S1_MCK/SPI1_MISO/TIM13_CH1/TIM16_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='I2C2_SMBA/I2S2_CK/RCC_MCO/SPI2_SCK/TIM4_ETR/TIM5_CH1/TIM5_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC1_EXTI9/DAC2_EXTI9/I2C2_SCL/I2S2_MCK/SPI2_MISO/TIM13_CH1/TIM15_BKIN/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='I2C2_SDA/I2S2_SD/SPI2_MOSI/TIM14_CH1/TIM17_BKIN/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/CAN_RX/COMP1_OUT/I2S1_WS/I2S2_WS/SDADC1_EXTI11/SDADC2_EXTI11/SDADC3_EXTI11/SPI1_NSS/SPI2_NSS/TIM4_CH1/TIM5_CH2/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN_TX/COMP2_OUT/I2S1_CK/SPI1_SCK/TIM16_CH1/TIM4_CH2/TIM5_CH3/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='I2S1_MCK/IR_OUT/SPI1_MISO/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TIM5_CH4/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM12_CH1/TSC_G4_IO4/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/I2C1_SCL/I2S1_WS/I2S3_WS/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_EXTI15/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM12_CH2/TIM2_CH1/TIM2_ETR/TSC_SYNC/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/I2S1_SD/SDADC1_AIN6P/SPI1_MOSI/TIM3_CH2/TIM3_CH3/TSC_G3_IO3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/SDADC1_AIN5P/SDADC1_AIN6M/TIM3_CH4/TSC_G3_IO4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM13_CH1/TIM2_CH2/TIM3_ETR/TIM4_ETR/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2S1_MCK/I2S3_MCK/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM15_CH1N/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM19_ETR/TIM3_CH2/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM15_CH1/TIM16_CH1N/TIM19_CH1/TIM3_CH3/TIM4_CH1/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM15_CH2/TIM17_CH1N/TIM19_CH2/TIM3_CH4/TIM4_CH2/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN_RX/CEC/COMP1_OUT/I2C1_SCL/I2S2_CK/SPI2_SCK/TIM16_CH1/TIM19_CH3/TIM4_CH3/TSC_SYNC/USART3_TX/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN_TX/COMP2_OUT/DAC1_EXTI9/DAC2_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/TIM19_CH4/TIM4_CH4/USART3_RX/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2S2_MCK/SDADC3_AIN8P/SPI2_MISO/TIM12_CH1/TIM15_CH1/TSC_G6_IO1/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_EXTI15/I2S2_SD/RTC_REFIN/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_AIN7P/SDADC3_AIN8M/SDADC3_EXTI15/SPI2_MOSI/TIM12_CH2/TIM15_CH1N/TIM15_CH2/TSC_G6_IO2/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='28',name='NPOR',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VREFSD+',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PF0/I2C2_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PF1/I2C2_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='47',name='PF6/I2C2_SCL/I2S1_SD/SPI1_MOSI/TIM4_CH4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='PF7/I2C2_SDA/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PE8/SDADC1_AIN8P/SDADC2_AIN8P',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PE9/DAC1_EXTI9/DAC2_EXTI9/SDADC1_AIN7P/SDADC1_AIN8M/SDADC2_AIN7P/SDADC2_AIN8M',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='PD8/I2S2_CK/SDADC3_AIN6P/SPI2_SCK/TSC_G6_IO3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10/TIM5_CH1/TIM5_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12/I2S2_MCK/SPI2_MISO/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13/I2S2_SD/SPI2_MOSI/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14/TIM13_CH1/TSC_G3_IO1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15/TSC_G3_IO2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S1_WS/SPI1_NSS/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S1_CK/SPI1_SCK/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/I2S1_MCK/SPI1_MISO/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC1_EXTI9/DAC2_EXTI9/I2S1_SD/SPI1_MOSI/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/SPI3_SCK/TIM19_CH1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/I2S3_MCK/SDADC1_EXTI11/SDADC2_EXTI11/SDADC3_EXTI11/SPI3_MISO/TIM19_CH2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SPI3_MOSI/TIM19_CH3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDDSD',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSSSD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F378RCYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F3x8',description='Core: ARM Cortex-M4 Package: WLCSP66 Flash: 256KB Ram: 32KB Frequency: 72MHz Voltage: 1.65..1.95V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='H8',name='ADC1_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM19_CH1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM5_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC1_IN1/COMP1_INP/I2S3_CK/RTC_REFIN/SPI3_SCK/TIM15_CH1N/TIM19_CH2/TIM2_CH2/TIM5_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='ADC1_IN2/COMP2_INM/COMP2_OUT/I2S3_MCK/SPI3_MISO/TIM15_CH1/TIM19_CH3/TIM2_CH3/TIM5_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='ADC1_IN3/COMP2_INP/I2S3_SD/SPI3_MOSI/TIM15_CH2/TIM19_CH4/TIM2_CH4/TIM5_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='ADC1_IN4/DAC1_OUT1/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/TIM12_CH1/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='ADC1_IN5/CEC/DAC1_OUT2/I2S1_CK/SPI1_SCK/TIM12_CH2/TIM14_CH1/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='ADC1_IN6/COMP1_OUT/DAC2_OUT1/I2S1_MCK/SPI1_MISO/TIM13_CH1/TIM16_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC1_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='I2C2_SMBA/I2S2_CK/RCC_MCO/SPI2_SCK/TIM4_ETR/TIM5_CH1/TIM5_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='DAC1_EXTI9/DAC2_EXTI9/I2C2_SCL/I2S2_MCK/SPI2_MISO/TIM13_CH1/TIM15_BKIN/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='I2C2_SDA/I2S2_SD/SPI2_MOSI/TIM14_CH1/TIM17_BKIN/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='ADC1_EXTI11/CAN_RX/COMP1_OUT/I2S1_WS/I2S2_WS/SDADC1_EXTI11/SDADC2_EXTI11/SDADC3_EXTI11/SPI1_NSS/SPI2_NSS/TIM4_CH1/TIM5_CH2/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='CAN_TX/COMP2_OUT/I2S1_CK/SPI1_SCK/TIM16_CH1/TIM4_CH2/TIM5_CH3/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='I2S1_MCK/IR_OUT/SPI1_MISO/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TIM5_CH4/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM12_CH1/TSC_G4_IO4/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ADC1_EXTI15/I2C1_SCL/I2S1_WS/I2S3_WS/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_EXTI15/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM12_CH2/TIM2_CH1/TIM2_ETR/TSC_SYNC/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC1_IN8/I2S1_SD/SDADC1_AIN6P/SPI1_MOSI/TIM3_CH2/TIM3_CH3/TSC_G3_IO3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC1_IN9/SDADC1_AIN5P/SDADC1_AIN6M/TIM3_CH4/TSC_G3_IO4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM13_CH1/TIM2_CH2/TIM3_ETR/TIM4_ETR/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2S1_MCK/I2S3_MCK/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM15_CH1N/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM19_ETR/TIM3_CH2/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='I2C1_SCL/TIM15_CH1/TIM16_CH1N/TIM19_CH1/TIM3_CH3/TIM4_CH1/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='I2C1_SDA/TIM15_CH2/TIM17_CH1N/TIM19_CH2/TIM3_CH4/TIM4_CH2/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='CAN_RX/CEC/COMP1_OUT/I2C1_SCL/I2S2_CK/SPI2_SCK/TIM16_CH1/TIM19_CH3/TIM4_CH3/TSC_SYNC/USART3_TX/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='CAN_TX/COMP2_OUT/DAC1_EXTI9/DAC2_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/TIM19_CH4/TIM4_CH4/USART3_RX/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='I2S2_MCK/SDADC3_AIN8P/SPI2_MISO/TIM12_CH1/TIM15_CH1/TSC_G6_IO1/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_EXTI15/I2S2_SD/RTC_REFIN/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_AIN7P/SDADC3_AIN8M/SDADC3_EXTI15/SPI2_MOSI/TIM12_CH2/TIM15_CH1N/TIM15_CH2/TSC_G6_IO2/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='NRST',do_erc=True),
            Pin(num='G2',name='NPOR',do_erc=True),
            Pin(num='C7',name='BOOT0',do_erc=True),
            Pin(num='A8',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VREFSD+',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='PF0/I2C2_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='E8',name='PF1/I2C2_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='B2',name='PF6/I2C2_SCL/I2S1_SD/SPI1_MOSI/TIM4_CH4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PF7/I2C2_SDA/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='PE8/SDADC1_AIN8P/SDADC2_AIN8P',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='PE9/DAC1_EXTI9/DAC2_EXTI9/SDADC1_AIN7P/SDADC1_AIN8M/SDADC2_AIN7P/SDADC2_AIN8M',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PD8/I2S2_CK/SDADC3_AIN6P/SPI2_SCK/TSC_G6_IO3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E6',name='PC0/ADC1_IN10/TIM5_CH1/TIM5_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='PC1/ADC1_IN11/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='PC2/ADC1_IN12/I2S2_MCK/SPI2_MISO/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC3/ADC1_IN13/I2S2_SD/SPI2_MOSI/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PC4/ADC1_IN14/TIM13_CH1/TSC_G3_IO1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PC5/ADC1_IN15/TSC_G3_IO2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC6/I2S1_WS/SPI1_NSS/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='PC7/I2S1_CK/SPI1_SCK/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC8/I2S1_MCK/SPI1_MISO/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PC9/DAC1_EXTI9/DAC2_EXTI9/I2S1_SD/SPI1_MOSI/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PC10/I2S3_CK/SPI3_SCK/TIM19_CH1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PC11/ADC1_EXTI11/I2S3_MCK/SDADC1_EXTI11/SDADC2_EXTI11/SDADC3_EXTI11/SPI3_MISO/TIM19_CH2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PC12/I2S3_SD/SPI3_MOSI/TIM19_CH3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDSD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSSD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F378VCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F3x8',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 256KB Ram: 32KB Frequency: 72MHz Voltage: 1.65..1.95V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC1_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM19_CH1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM5_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/COMP1_INP/I2S3_CK/RTC_REFIN/SPI3_SCK/TIM15_CH1N/TIM19_CH2/TIM2_CH2/TIM5_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/COMP2_INM/COMP2_OUT/I2S3_MCK/SPI3_MISO/TIM15_CH1/TIM19_CH3/TIM2_CH3/TIM5_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/COMP2_INP/I2S3_SD/SPI3_MOSI/TIM15_CH2/TIM19_CH4/TIM2_CH4/TIM5_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/DAC1_OUT1/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/TIM12_CH1/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/CEC/DAC1_OUT2/I2S1_CK/SPI1_SCK/TIM12_CH2/TIM14_CH1/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/COMP1_OUT/DAC2_OUT1/I2S1_MCK/SPI1_MISO/TIM13_CH1/TIM16_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/COMP2_OUT/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM17_CH1/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C2_SMBA/I2S2_CK/RCC_MCO/SPI2_SCK/TIM4_ETR/TIM5_CH1/TIM5_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC1_EXTI9/DAC2_EXTI9/I2C2_SCL/I2S2_MCK/SPI2_MISO/TIM13_CH1/TIM15_BKIN/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C2_SDA/I2S2_SD/SPI2_MOSI/TIM14_CH1/TIM17_BKIN/TIM2_CH4/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/CAN_RX/COMP1_OUT/I2S1_WS/I2S2_WS/SDADC1_EXTI11/SDADC2_EXTI11/SDADC3_EXTI11/SPI1_NSS/SPI2_NSS/TIM4_CH1/TIM5_CH2/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN_TX/COMP2_OUT/I2S1_CK/SPI1_SCK/TIM16_CH1/TIM4_CH2/TIM5_CH3/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='I2S1_MCK/IR_OUT/SPI1_MISO/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TIM5_CH4/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM12_CH1/TSC_G4_IO4/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/I2C1_SCL/I2S1_WS/I2S3_WS/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_EXTI15/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM12_CH2/TIM2_CH1/TIM2_ETR/TSC_SYNC/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/I2S1_SD/SDADC1_AIN6P/SPI1_MOSI/TIM3_CH2/TIM3_CH3/TSC_G3_IO3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/SDADC1_AIN5P/SDADC1_AIN6M/TIM3_CH4/TSC_G3_IO4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM13_CH1/TIM2_CH2/TIM3_ETR/TIM4_ETR/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S1_MCK/I2S3_MCK/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM15_CH1N/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM19_ETR/TIM3_CH2/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM15_CH1/TIM16_CH1N/TIM19_CH1/TIM3_CH3/TIM4_CH1/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/TIM15_CH2/TIM17_CH1N/TIM19_CH2/TIM3_CH4/TIM4_CH2/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN_RX/CEC/COMP1_OUT/I2C1_SCL/I2S2_CK/SPI2_SCK/TIM16_CH1/TIM19_CH3/TIM4_CH3/TSC_SYNC/USART3_TX/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN_TX/COMP2_OUT/DAC1_EXTI9/DAC2_EXTI9/I2C1_SDA/I2S2_WS/IR_OUT/SPI2_NSS/TIM17_CH1/TIM19_CH4/TIM4_CH4/USART3_RX/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='CEC/I2S2_CK/SDADC2_AIN0M/SPI2_SCK/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2S2_MCK/SDADC3_AIN8P/SPI2_MISO/TIM12_CH1/TIM15_CH1/TSC_G6_IO1/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/I2S2_SD/RTC_REFIN/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_AIN7P/SDADC3_AIN8M/SDADC3_EXTI15/SPI2_MOSI/TIM12_CH2/TIM15_CH1N/TIM15_CH2/TSC_G6_IO2/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/TIM5_CH1/TIM5_ETR/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/TIM5_CH2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/I2S2_MCK/SPI2_MISO/TIM5_CH3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/I2S2_SD/SPI2_MOSI/TIM5_CH4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/TIM13_CH1/TSC_G3_IO1/USART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/TSC_G3_IO2/USART1_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S1_WS/SPI1_NSS/TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S1_CK/SPI1_SCK/TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='I2S1_MCK/SPI1_MISO/TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC1_EXTI9/DAC2_EXTI9/I2S1_SD/SPI1_MOSI/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/SPI3_SCK/TIM19_CH1/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/I2S3_MCK/SDADC1_EXTI11/SDADC2_EXTI11/SDADC3_EXTI11/SPI3_MISO/TIM19_CH2/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/SPI3_MOSI/TIM19_CH3/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/RCC_OSC32_OUT/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_EXTI15/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='37',name='NPOR',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VREFSD-',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VREFSD+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PF0/I2C2_SDA/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PF1/I2C2_SCL/RCC_OSC_OUT',do_erc=True),
            Pin(num='19',name='PF2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='PF6/I2C2_SCL/I2S1_SD/SPI1_MOSI/TIM4_CH4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF9/DAC1_EXTI9/DAC2_EXTI9/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF10',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/TIM4_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/SYS_TRACECK/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/SYS_TRACED0/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/SDADC1_AIN3P/SDADC1_AIN4M/SDADC2_AIN5P/SDADC2_AIN6M',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/SDADC1_AIN8P/SDADC2_AIN8P',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC1_EXTI9/DAC2_EXTI9/SDADC1_AIN7P/SDADC1_AIN8M/SDADC2_AIN7P/SDADC2_AIN8M',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/SDADC1_AIN2P',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/SDADC1_AIN1P/SDADC1_AIN2M/SDADC1_EXTI11/SDADC2_AIN4P/SDADC2_EXTI11/SDADC3_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/SDADC1_AIN0P/SDADC2_AIN3P/SDADC2_AIN4M',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SDADC1_AIN0M/SDADC2_AIN2P',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/SDADC2_AIN1P/SDADC2_AIN2M',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/SDADC1_EXTI15/SDADC2_AIN0P/SDADC2_EXTI15/SDADC3_EXTI15/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN_RX/TIM19_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN_TX/TIM19_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/I2S2_MCK/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/I2S2_WS/SPI2_NSS/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/I2S2_CK/SPI2_SCK/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/I2S2_CK/SDADC3_AIN6P/SPI2_SCK/TSC_G6_IO3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC1_EXTI9/DAC2_EXTI9/SDADC3_AIN5P/SDADC3_AIN6M/TSC_G6_IO4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/SDADC3_AIN4P/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/SDADC1_EXTI11/SDADC2_EXTI11/SDADC3_AIN3P/SDADC3_AIN4M/SDADC3_EXTI11/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/SDADC3_AIN2P/TIM4_CH1/TSC_G8_IO1/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/SDADC3_AIN1P/SDADC3_AIN2M/TIM4_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/SDADC3_AIN0P/TIM4_CH3/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/SDADC1_EXTI15/SDADC2_EXTI15/SDADC3_AIN0M/SDADC3_EXTI15/TIM4_CH4/TSC_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDDSD12',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VDDSD3',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSSSD',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F398VETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F3 STM32F3x8',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 512KB Ram: 64KB Frequency: 72MHz Voltage: 1.65..1.95V IO-pins: 85',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC1_IN1/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM8_BKIN/TIM8_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN2/COMP1_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/RTC_REFIN/TIM15_CH1N/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN3/ADC3_EXTI2/ADC4_EXTI2/COMP2_INM/COMP2_OUT/OPAMP1_VOUT/TIM15_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN4/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP1_VINP/OPAMP1_VINP_SEC/TIM15_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC2_IN1/COMP1_INM/COMP2_INM/COMP3_INM/COMP4_INM/COMP5_INM/COMP6_INM/COMP7_INM/DAC1_OUT1/I2S3_WS/OPAMP4_VINP/OPAMP4_VINP_SEC/SPI1_NSS/SPI3_NSS/TIM3_CH2/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC2_IN2/COMP1_INM/COMP2_INM/COMP3_INM/COMP4_INM/COMP5_INM/COMP6_INM/COMP7_INM/DAC1_OUT2/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC2_IN3/COMP1_OUT/OPAMP2_VOUT/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC2_IN4/COMP2_INP/OPAMP1_VINP/OPAMP1_VINP_SEC/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='COMP3_OUT/I2C2_SMBA/I2C3_SCL/I2S2_MCK/RCC_MCO/TIM1_CH1/TIM4_ETR/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='COMP5_OUT/DAC1_EXTI9/I2C2_SCL/I2C3_SMBA/I2S3_MCK/TIM15_BKIN/TIM1_CH2/TIM2_CH3/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='COMP6_OUT/I2C2_SDA/I2S2_ext_SD/SPI2_MISO/TIM17_BKIN/TIM1_CH3/TIM2_CH4/TIM8_BKIN/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/CAN_RX/COMP1_OUT/I2S2_SD/SPI2_MOSI/TIM1_BKIN2/TIM1_CH1N/TIM1_CH4/TIM4_CH1/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN_TX/COMP2_OUT/I2S_CKIN/TIM16_CH1/TIM1_CH2N/TIM1_ETR/TIM4_CH2/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='IR_OUT/SYS_JTMS-SWDIO/TIM16_CH1N/TIM4_CH3/TSC_G4_IO3/USART3_CTS/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='I2C1_SDA/SYS_JTCK-SWCLK/TIM1_BKIN/TIM8_CH2/TSC_G4_IO4/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/I2C1_SCL/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM1_BKIN/TIM2_CH1/TIM2_ETR/TIM8_CH1/TSC_SYNC/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC3_IN12/COMP4_INP/OPAMP2_VINP/OPAMP2_VINP_SEC/OPAMP3_VINP/OPAMP3_VINP_SEC/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC3_IN1/COMP4_OUT/OPAMP3_VOUT/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/TIM3_ETR/TIM4_ETR/TIM8_CH1N/TSC_G5_IO1/USART2_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_NJTRST/TIM16_CH1/TIM17_BKIN/TIM3_CH1/TIM8_CH2N/TSC_G5_IO2/USART2_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/I2C3_SDA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM17_CH1/TIM3_CH2/TIM8_CH3N/USART2_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_CH1/TIM8_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='FMC_NL/I2C1_SDA/TIM17_CH1N/TIM3_CH4/TIM4_CH2/TIM8_BKIN/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN_RX/COMP1_OUT/I2C1_SCL/TIM16_CH1/TIM1_BKIN/TIM4_CH3/TIM8_CH2/TSC_SYNC/USART3_RX/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN_TX/COMP2_OUT/DAC1_EXTI9/I2C1_SDA/IR_OUT/TIM17_CH1/TIM4_CH4/TIM8_CH3/USART3_TX/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='COMP5_INM/OPAMP3_VINM/OPAMP3_VINM_SEC/OPAMP4_VINM/OPAMP4_VINM_SEC/TIM2_CH3/TSC_SYNC/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC1_IN14/ADC2_EXTI11/ADC2_IN14/COMP6_INP/OPAMP4_VINP/OPAMP4_VINP_SEC/TIM2_CH4/TSC_G6_IO1/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC4_IN3/COMP3_INM/I2C2_SMBA/I2S2_WS/OPAMP4_VOUT/SPI2_NSS/TIM1_BKIN/TSC_G6_IO2/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC3_IN5/COMP5_INP/I2S2_CK/OPAMP3_VINP/OPAMP3_VINP_SEC/OPAMP4_VINP/OPAMP4_VINP_SEC/SPI2_SCK/TIM1_CH1N/TSC_G6_IO3/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC4_IN4/COMP3_INP/I2S2_ext_SD/OPAMP2_VINP/OPAMP2_VINP_SEC/SPI2_MISO/TIM15_CH1/TIM1_CH2N/TSC_G6_IO4/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/ADC4_IN5/COMP6_INM/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM15_CH1N/TIM15_CH2/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN6/ADC2_IN6/COMP7_INM/TIM1_CH1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN7/ADC2_IN7/COMP7_INP/TIM1_CH2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN8/ADC2_IN8/ADC3_EXTI2/ADC4_EXTI2/COMP7_OUT/TIM1_CH3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN9/ADC2_IN9/TIM1_BKIN2/TIM1_CH4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC2_IN5/TIM1_ETR/USART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC2_IN11/OPAMP1_VINM/OPAMP1_VINM_SEC/OPAMP2_VINM/OPAMP2_VINM_SEC/TIM15_BKIN/TSC_G3_IO1/USART1_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='COMP6_OUT/I2S2_MCK/TIM3_CH1/TIM8_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='COMP5_OUT/I2S3_MCK/TIM3_CH2/TIM8_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='COMP3_OUT/TIM3_CH3/TIM8_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC1_EXTI9/I2C3_SDA/I2S_CKIN/TIM3_CH4/TIM8_BKIN2/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/SPI3_SCK/TIM8_CH1N/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/I2S3_ext_SD/SPI3_MISO/TIM8_CH2N/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/SPI3_MOSI/TIM8_CH3N/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIM1_CH1N/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='37',name='NPOR',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PF0/I2C2_SDA/I2S2_WS/RCC_OSC_IN/SPI2_NSS/TIM1_CH3N',do_erc=True),
            Pin(num='13',name='PF1/I2C2_SCL/I2S2_CK/RCC_OSC_OUT/SPI2_SCK',do_erc=True),
            Pin(num='19',name='PF2/ADC1_IN10/ADC2_IN10/ADC3_EXTI2/ADC4_EXTI2/FMC_A2/TIM20_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='PF6/FMC_NIORD/I2C2_SCL/TIM4_CH4/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF9/DAC1_EXTI9/FMC_CD/SPI2_SCK/TIM15_CH1/TIM20_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF10/FMC_INTR/SPI2_SCK/TIM15_CH2/TIM20_BKIN2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/FMC_NBL0/TIM16_CH1/TIM20_ETR/TIM4_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/FMC_NBL1/TIM17_CH1/TIM20_CH4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ADC3_EXTI2/ADC4_EXTI2/FMC_A23/SPI4_SCK/SYS_TRACECK/TIM20_CH1/TIM3_CH1/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/SPI4_NSS/SYS_TRACED0/TIM20_CH2/TIM3_CH2/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FMC_A20/SPI4_NSS/SYS_TRACED1/TIM20_CH1N/TIM3_CH3/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FMC_A21/SPI4_MISO/SYS_TRACED2/TIM20_CH2N/TIM3_CH4/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FMC_A22/RTC_TAMP3/SPI4_MOSI/SYS_TRACED3/SYS_WKUP3/TIM20_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/ADC3_IN13/FMC_D4/FMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/ADC3_IN6/ADC4_IN6/COMP4_INM/FMC_D5/FMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/ADC3_IN2/DAC1_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/ADC3_IN14/FMC_D7/FMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_IN15/FMC_D8/FMC_DA8/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/ADC3_IN16/FMC_D9/FMC_DA9/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/ADC3_IN3/FMC_D10/FMC_DA10/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/ADC4_IN1/FMC_D11/FMC_DA11/SPI4_MOSI/TIM1_BKIN2/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/ADC4_IN2/FMC_D12/FMC_DA12/TIM1_BKIN/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN_RX/FMC_D2/FMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN_TX/FMC_D3/FMC_DA3/TIM8_BKIN2/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/ADC3_EXTI2/ADC4_EXTI2/TIM3_ETR/TIM8_BKIN/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/FMC_CLK/TIM2_CH1/TIM2_ETR/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FMC_NOE/TIM2_CH2/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/FMC_NWAIT/TIM2_CH4/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FMC_NCE2/FMC_NE1/TIM2_CH3/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/ADC4_IN12/FMC_D13/FMC_DA13/OPAMP4_VINM/OPAMP4_VINM_SEC/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/ADC4_IN13/DAC1_EXTI9/FMC_D14/FMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/ADC3_IN7/ADC4_IN7/COMP6_INM/FMC_D15/FMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_IN8/ADC4_IN8/FMC_A16/FMC_CLE/OPAMP4_VINP/OPAMP4_VINP_SEC/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/ADC3_IN9/ADC4_IN9/FMC_A17/FMC_ALE/TIM4_CH1/TSC_G8_IO1/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/ADC3_IN10/ADC4_IN10/COMP5_INM/FMC_A18/TIM4_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/ADC3_IN11/ADC4_IN11/FMC_D0/FMC_DA0/OPAMP2_VINP/OPAMP2_VINP_SEC/TIM4_CH3/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/ADC4_EXTI15/COMP3_INM/FMC_D1/FMC_DA1/SPI2_NSS/TIM4_CH4/TSC_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F401CBUx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F401',description='Core: ARM Cortex-M4 Package: UFQFPN48 Flash: 128KB Ram: 64KB Frequency: 84MHz Voltage: 1.7..3.6V IO-pins: 36',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F401CCUx'],pins=[
            Pin(num='10',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN4/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN5/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/TIM1_CH4/USART1_CTS/USART6_TX/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='TIM1_ETR/USART1_RTS/USART6_RX/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/ANTI_TAMP/RTC_AF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC1_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC1_IN9/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2C2_SDA/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2C3_SDA/I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM4_CH1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM4_CH2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TIM10_CH1/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/I2C1_SDA/I2S2_WS/SPI2_NSS/TIM11_CH1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2S2_CK/SPI2_SCK/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2S2_ext_SD/SPI2_MISO/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC1_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F401CBYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F401',description='Core: ARM Cortex-M4 Package: WLCSP49 Flash: 128KB Ram: 64KB Frequency: 84MHz Voltage: 1.7..3.6V IO-pins: 36',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F401CCYx'],pins=[
            Pin(num='F6',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='ADC1_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='ADC1_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='ADC1_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='ADC1_IN4/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC1_IN5/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC1_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC1_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='ADC1_EXTI11/TIM1_CH4/USART1_CTS/USART6_TX/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='TIM1_ETR/USART1_RTS/USART6_RX/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ADC1_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='NRST',do_erc=True),
            Pin(num='A5',name='BOOT0',do_erc=True),
            Pin(num='B6',name='PDR_ON',func=Pin.PWRIN,do_erc=True),
            Pin(num='B7',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='D6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='D5',name='PC13/ANTI_TAMP/RTC_AF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PB0/ADC1_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PB1/ADC1_IN9/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PB3/I2C2_SDA/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PB4/I2C3_SDA/I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PB5/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PB6/I2C1_SCL/TIM4_CH1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PB7/I2C1_SDA/TIM4_CH2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='PB8/I2C1_SCL/TIM10_CH1/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PB9/I2C1_SDA/I2S2_WS/SPI2_NSS/TIM11_CH1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PB10/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PB12/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PB13/I2S2_CK/SPI2_SCK/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PB14/I2S2_ext_SD/SPI2_MISO/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='PB15/ADC1_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='B2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='A6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='B1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F401CDUx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F401',description='Core: ARM Cortex-M4 Package: UFQFPN48 Flash: 384KB Ram: 96KB Frequency: 84MHz Voltage: 1.7..3.6V IO-pins: 36',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F401CEUx'],pins=[
            Pin(num='10',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN4/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN5/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/TIM1_CH4/USART1_CTS/USART6_TX/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='TIM1_ETR/USART1_RTS/USART6_RX/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/ANTI_TAMP/RTC_AF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC1_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC1_IN9/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2C2_SDA/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2C3_SDA/I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM4_CH1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/TIM4_CH2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TIM10_CH1/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/I2C1_SDA/I2S2_WS/SPI2_NSS/TIM11_CH1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2S2_CK/SPI2_SCK/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2S2_ext_SD/SPI2_MISO/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC1_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F401CDYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F401',description='Core: ARM Cortex-M4 Package: WLCSP49 Flash: 384KB Ram: 96KB Frequency: 84MHz Voltage: 1.7..3.6V IO-pins: 36',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F401CEYx'],pins=[
            Pin(num='F6',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='ADC1_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='ADC1_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='ADC1_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='ADC1_IN4/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC1_IN5/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC1_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC1_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='ADC1_EXTI11/TIM1_CH4/USART1_CTS/USART6_TX/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='TIM1_ETR/USART1_RTS/USART6_RX/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ADC1_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='NRST',do_erc=True),
            Pin(num='A5',name='BOOT0',do_erc=True),
            Pin(num='B6',name='PDR_ON',func=Pin.PWRIN,do_erc=True),
            Pin(num='B7',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='D6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='D5',name='PC13/ANTI_TAMP/RTC_AF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PB0/ADC1_IN8/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PB1/ADC1_IN9/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PB3/I2C2_SDA/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PB4/I2C3_SDA/I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PB5/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PB6/I2C1_SCL/TIM4_CH1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PB7/I2C1_SDA/TIM4_CH2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='PB8/I2C1_SCL/TIM10_CH1/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PB9/I2C1_SDA/I2S2_WS/SPI2_NSS/TIM11_CH1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PB10/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PB12/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PB13/I2S2_CK/SPI2_SCK/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PB14/I2S2_ext_SD/SPI2_MISO/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='PB15/ADC1_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='B2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='A6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='B1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F401RBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F401',description='Core: ARM Cortex-M4 Package: LQFP64 Flash: 128KB Ram: 64KB Frequency: 84MHz Voltage: 1.7..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F401RCTx'],pins=[
            Pin(num='14',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/TIM1_CH4/USART1_CTS/USART6_TX/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='TIM1_ETR/USART1_RTS/USART6_RX/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2C2_SDA/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2C3_SDA/I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2S2_CK/SPI2_SCK/TIM1_CH1N/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2S2_ext_SD/SPI2_MISO/TIM1_CH2N/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/SDIO_CMD/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12/I2S2_ext_SD/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13/I2S2_SD/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/SDIO_D6/TIM3_CH1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/SDIO_D7/TIM3_CH2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/SDIO_D0/TIM3_CH3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/SDIO_D2/SPI3_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/I2S3_ext_SD/SDIO_D3/SPI3_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SDIO_CK/SPI3_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/ANTI_TAMP/RTC_AF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F401RDTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F401',description='Core: ARM Cortex-M4 Package: LQFP64 Flash: 384KB Ram: 96KB Frequency: 84MHz Voltage: 1.7..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F401RETx'],pins=[
            Pin(num='14',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/TIM1_CH4/USART1_CTS/USART6_TX/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='TIM1_ETR/USART1_RTS/USART6_RX/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2C2_SDA/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2C3_SDA/I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2S2_CK/SPI2_SCK/TIM1_CH1N/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2S2_ext_SD/SPI2_MISO/TIM1_CH2N/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/SDIO_CMD/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12/I2S2_ext_SD/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13/I2S2_SD/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/SDIO_D6/TIM3_CH1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/SDIO_D7/TIM3_CH2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/SDIO_D0/TIM3_CH3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/SDIO_D2/SPI3_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/I2S3_ext_SD/SDIO_D3/SPI3_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SDIO_CK/SPI3_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/ANTI_TAMP/RTC_AF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F401VBHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F401',description='Core: ARM Cortex-M4 Package: UFBGA100 Flash: 128KB Ram: 64KB Frequency: 84MHz Voltage: 1.7..3.6V IO-pins: 81',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F401VCHx'],pins=[
            Pin(num='L2',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC1_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC1_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN4/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC1_IN5/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC1_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC1_EXTI11/TIM1_CH4/USART1_CTS/USART6_TX/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='TIM1_ETR/USART1_RTS/USART6_RX/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ADC1_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC1_IN8/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC1_IN9/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='I2C2_SDA/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='I2C3_SDA/I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='ADC1_EXTI11/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='I2S2_CK/SPI2_SCK/TIM1_CH1N/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='I2S2_ext_SD/SPI2_MISO/TIM1_CH2N/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='ADC1_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC1_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC1_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC1_IN12/I2S2_ext_SD/SPI2_MISO/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_IN13/I2S2_SD/SPI2_MOSI/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC1_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC1_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='I2S2_MCK/SDIO_D6/TIM3_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='I2S3_MCK/SDIO_D7/TIM3_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='SDIO_D0/TIM3_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='I2S3_CK/SDIO_D2/SPI3_SCK/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC1_EXTI11/I2S3_ext_SD/SDIO_D3/SPI3_MISO/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='I2S3_SD/SDIO_CK/SPI3_MOSI/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='ANTI_TAMP/RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC1_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E3',name='BYPASS_REG',do_erc=True),
            Pin(num='C11',name='VCAP2',func=Pin.PWRIN,do_erc=True),
            Pin(num='E2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='PDR_ON',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='L11',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='C3',name='PE0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/SPI4_MOSI/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC1_EXTI11/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/ADC1_EXTI15/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/SDIO_CMD/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/I2S2_CK/SPI2_SCK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/I2S3_SD/SPI3_MOSI/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/ADC1_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/TIM4_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/ADC1_EXTI15/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F401VBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F401',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 128KB Ram: 64KB Frequency: 84MHz Voltage: 1.7..3.6V IO-pins: 81',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F401VCTx'],pins=[
            Pin(num='23',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/TIM1_CH4/USART1_CTS/USART6_TX/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='TIM1_ETR/USART1_RTS/USART6_RX/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2C2_SDA/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2C3_SDA/I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='I2S2_CK/SPI2_SCK/TIM1_CH1N/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2S2_ext_SD/SPI2_MISO/TIM1_CH2N/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/I2S2_ext_SD/SPI2_MISO/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/I2S2_SD/SPI2_MOSI/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/SDIO_D6/TIM3_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/SDIO_D7/TIM3_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='SDIO_D0/TIM3_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/SDIO_D2/SPI3_SCK/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/I2S3_ext_SD/SDIO_D3/SPI3_MISO/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/SDIO_CK/SPI3_MOSI/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ANTI_TAMP/RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VCAP2',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='97',name='PE0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/SPI4_MOSI/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/SDIO_CMD/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/I2S2_CK/SPI2_SCK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/I2S3_SD/SPI3_MOSI/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/TIM4_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F401VDHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F401',description='Core: ARM Cortex-M4 Package: UFBGA100 Flash: 384KB Ram: 96KB Frequency: 84MHz Voltage: 1.7..3.6V IO-pins: 81',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F401VEHx'],pins=[
            Pin(num='L2',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC1_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC1_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN4/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC1_IN5/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC1_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC1_EXTI11/TIM1_CH4/USART1_CTS/USART6_TX/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='TIM1_ETR/USART1_RTS/USART6_RX/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ADC1_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC1_IN8/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC1_IN9/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='I2C2_SDA/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='I2C3_SDA/I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='ADC1_EXTI11/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='I2S2_CK/SPI2_SCK/TIM1_CH1N/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='I2S2_ext_SD/SPI2_MISO/TIM1_CH2N/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='ADC1_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC1_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC1_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC1_IN12/I2S2_ext_SD/SPI2_MISO/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_IN13/I2S2_SD/SPI2_MOSI/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC1_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC1_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='I2S2_MCK/SDIO_D6/TIM3_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='I2S3_MCK/SDIO_D7/TIM3_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='SDIO_D0/TIM3_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='I2S3_CK/SDIO_D2/SPI3_SCK/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC1_EXTI11/I2S3_ext_SD/SDIO_D3/SPI3_MISO/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='I2S3_SD/SDIO_CK/SPI3_MOSI/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='ANTI_TAMP/RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC1_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E3',name='BYPASS_REG',do_erc=True),
            Pin(num='C11',name='VCAP2',func=Pin.PWRIN,do_erc=True),
            Pin(num='E2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='PDR_ON',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='L11',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='C3',name='PE0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/SPI4_MOSI/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC1_EXTI11/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/ADC1_EXTI15/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/SDIO_CMD/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/I2S2_CK/SPI2_SCK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/I2S3_SD/SPI3_MOSI/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/ADC1_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/TIM4_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/ADC1_EXTI15/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F401VDTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F401',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 384KB Ram: 96KB Frequency: 84MHz Voltage: 1.7..3.6V IO-pins: 81',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F401VETx'],pins=[
            Pin(num='23',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/TIM1_CH4/USART1_CTS/USART6_TX/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='TIM1_ETR/USART1_RTS/USART6_RX/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2C2_SDA/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2C3_SDA/I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='I2S2_CK/SPI2_SCK/TIM1_CH1N/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2S2_ext_SD/SPI2_MISO/TIM1_CH2N/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/I2S2_ext_SD/SPI2_MISO/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/I2S2_SD/SPI2_MOSI/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/SDIO_D6/TIM3_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/SDIO_D7/TIM3_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='SDIO_D0/TIM3_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/SDIO_D2/SPI3_SCK/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/I2S3_ext_SD/SDIO_D3/SPI3_MISO/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/SDIO_CK/SPI3_MOSI/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ANTI_TAMP/RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VCAP2',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='97',name='PE0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/SPI4_MOSI/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/SDIO_CMD/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/I2S2_CK/SPI2_SCK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/I2S3_SD/SPI3_MOSI/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/TIM4_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F405OEYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F405/415',description='Core: ARM Cortex-M4 Package: WLCSP90 Flash: 512KB Ram: 128KB Frequency: 168MHz Voltage: 1.7..3.6V IO-pins: 72',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F405OGYx'],pins=[
            Pin(num='C10',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='DAC_EXTI9/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='CAN2_RX/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='CAN2_TX/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='CAN1_RX/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='CAN1_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='J1',name='CAN2_TX/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='DAC_EXTI9/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ANTI_TAMP/RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='PDR_ON',do_erc=True),
            Pin(num='D9',name='BYPASS_REG',do_erc=True),
            Pin(num='G10',name='NRST',do_erc=True),
            Pin(num='A7',name='BOOT0',do_erc=True),
            Pin(num='A10',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='B1',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='F4',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='C3',name='PI0/I2S2_WS/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PI1/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='F9',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='G6',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PD0/CAN1_RX/FSMC_D2/FSMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PD1/CAN1_TX/FSMC_D3/FSMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PD2/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PD4/FSMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PD5/FSMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='PD6/FSMC_NWAIT/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/FSMC_NCE2/FSMC_NE1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='PD8/FSMC_D13/FSMC_DA13/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PD9/DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PD10/FSMC_D15/FSMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PD12/FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PD14/FSMC_D0/FSMC_DA0/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PD15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='B8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='C9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F405RGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F405/415',description='Core: ARM Cortex-M4 Package: LQFP64 Flash: 1024KB Ram: 128KB Frequency: 168MHz Voltage: 1.8..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='CAN2_RX/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='CAN2_TX/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN1_RX/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN1_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='CAN2_TX/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11/ADC2_IN11/ADC3_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12/ADC2_IN12/ADC3_IN12/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13/ADC2_IN13/ADC3_IN13/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14/ADC2_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15/ADC2_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/ANTI_TAMP/RTC_AF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F405VGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F405/415',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 1024KB Ram: 128KB Frequency: 168MHz Voltage: 1.8..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='CAN2_RX/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_TX/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN1_RX/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN1_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='CAN2_TX/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/ADC2_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/ADC2_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ANTI_TAMP/RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='97',name='PE0/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FSMC_A22/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN1_RX/FSMC_D2/FSMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN1_TX/FSMC_D3/FSMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/FSMC_CLK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FSMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FSMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/FSMC_NWAIT/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FSMC_NCE2/FSMC_NE1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FSMC_D13/FSMC_DA13/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FSMC_D15/FSMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FSMC_A18/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FSMC_D0/FSMC_DA0/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F405ZGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F405/415',description='Core: ARM Cortex-M4 Package: LQFP144 Flash: 1024KB Ram: 128KB Frequency: 168MHz Voltage: 1.7..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='34',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='CAN2_RX/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='CAN2_TX/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CAN1_RX/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='CAN1_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='CAN2_TX/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN14/ADC2_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN15/ADC2_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ANTI_TAMP/RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='CAN1_RX/FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CAN1_TX/FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FSMC_NCE2/FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='143',name='PDR_ON',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='106',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='56',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/FSMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/FSMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/FSMC_NCE3/FSMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/FSMC_NCE4_1/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FSMC_NE4/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/FSMC_A24/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/FSMC_A25/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FSMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FSMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FSMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/ADC3_IN9/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/ADC3_IN14/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/ADC3_IN15/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC3_IN4/FSMC_NIORD/TIM10_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC3_IN5/FSMC_NREG/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC3_IN6/FSMC_NIOWR/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC3_IN7/DAC_EXTI9/FSMC_CD/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC3_IN8/FSMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FSMC_A22/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F407IEHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F407/417',description='Core: ARM Cortex-M4 Package: UFBGA176 Flash: 512KB Ram: 128KB Frequency: 168MHz Voltage: 1.7..3.6V IO-pins: 140',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F407IGHx'],pins=[
            Pin(num='N3',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='P2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='R2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P4',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='P3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R3',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F15',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E15',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D15',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C15',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B15',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A15',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A14',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='R5',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='R4',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN2_TX/DCMI_D5/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R12',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='R13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='P12',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='P13',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='R14',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R15',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P5',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H15',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G15',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G14',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F14',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B14',name='DCMI_D8/I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='ANTI_TAMP/RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN1_RX/FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='CAN1_TX/FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='FSMC_NCE2/FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P15',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P14',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='N15',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N14',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N13',name='FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M15',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='M14',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L14',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='DCMI_D2/FSMC_NBL0/TIM4_ETR/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DCMI_D3/FSMC_NBL1/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ETH_TXD3/FSMC_A23/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='FSMC_A19/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='DCMI_D4/FSMC_A20/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='DCMI_D6/FSMC_A21/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DCMI_D7/FSMC_A22/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R8',name='FSMC_D4/FSMC_DA4/TIM1_ETR/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P8',name='FSMC_D5/FSMC_DA5/TIM1_CH1N/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P9',name='DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R9',name='FSMC_D7/FSMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='R10',name='FSMC_D9/FSMC_DA9/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='FSMC_D10/FSMC_DA10/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P11',name='FSMC_D11/FSMC_DA11/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R11',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PDR_ON',do_erc=True),
            Pin(num='J1',name='NRST',do_erc=True),
            Pin(num='L4',name='BYPASS_REG',do_erc=True),
            Pin(num='D6',name='BOOT0',do_erc=True),
            Pin(num='C1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='F13',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='M10',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='N1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='P1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='E14',name='PI0/DCMI_D13/I2S2_WS/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D14',name='PI1/DCMI_D8/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C14',name='PI2/DCMI_D9/I2S2_ext_SD/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PI3/DCMI_D10/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PI4/DCMI_D5/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PI5/DCMI_VSYNC/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PI6/DCMI_D6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PI7/DCMI_D7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PI8/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PI9/CAN1_RX/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI10/ETH_RX_ER',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='F4',name='PH2/ETH_CRS',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PH3/ETH_COL',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PH5/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PH6/ETH_RXD2/I2C2_SMBA/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='PH7/ETH_RXD3/I2C3_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PH8/DCMI_HSYNC/I2C3_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='PH9/DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='PH10/DCMI_D1/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='PH12/DCMI_D3/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='PH13/CAN1_TX/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='PH14/DCMI_D4/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L15',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K15',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K14',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='J15',name='PG6/FSMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J14',name='PG7/FSMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H14',name='PG8/ETH_PPS_OUT/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='PG9/DAC_EXTI9/FSMC_NCE3/FSMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PG10/FSMC_NCE4_1/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/FSMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PG12/FSMC_NE4/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='PG13/ETH_TXD0/FSMC_A24/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG14/ETH_TXD1/FSMC_A25/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PF0/FSMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PF1/FSMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='PF2/FSMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='PF3/ADC3_IN9/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='PF4/ADC3_IN14/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='PF5/ADC3_IN15/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='PF6/ADC3_IN4/FSMC_NIORD/TIM10_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='PF7/ADC3_IN5/FSMC_NREG/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PF8/ADC3_IN6/FSMC_NIOWR/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='PF9/ADC3_IN7/DAC_EXTI9/FSMC_CD/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PF10/ADC3_IN8/FSMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='R6',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12',func=Pin.BIDIR,do_erc=True),
            Pin(num='P6',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='R7',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P7',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='R1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F407IETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F407/417',description='Core: ARM Cortex-M4 Package: LQFP176 Flash: 512KB Ram: 128KB Frequency: 168MHz Voltage: 1.7..3.6V IO-pins: 140',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F407IGTx'],pins=[
            Pin(num='40',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='120',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='121',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='138',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='161',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='162',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='163',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='164',name='CAN2_TX/DCMI_D5/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='165',name='DCMI_VSYNC/FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='167',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='168',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='94',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='DCMI_D8/I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ANTI_TAMP/RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='CAN1_RX/FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='143',name='CAN1_TX/FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='144',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='145',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='146',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='147',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='150',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='151',name='FSMC_NCE2/FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='169',name='DCMI_D2/FSMC_NBL0/TIM4_ETR/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='170',name='DCMI_D3/FSMC_NBL1/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='ETH_TXD3/FSMC_A23/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='FSMC_A19/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='DCMI_D4/FSMC_A20/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='DCMI_D6/FSMC_A21/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='DCMI_D7/FSMC_A22/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='FSMC_D4/FSMC_DA4/TIM1_ETR/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='FSMC_D5/FSMC_DA5/TIM1_CH1N/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='FSMC_D7/FSMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='FSMC_D9/FSMC_DA9/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='FSMC_D10/FSMC_DA10/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FSMC_D11/FSMC_DA11/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='NRST',do_erc=True),
            Pin(num='171',name='PDR_ON',do_erc=True),
            Pin(num='166',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='81',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='125',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='PI0/DCMI_D13/I2S2_WS/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PI1/DCMI_D8/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='PI2/DCMI_D9/I2S2_ext_SD/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='PI3/DCMI_D10/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='173',name='PI4/DCMI_D5/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='174',name='PI5/DCMI_VSYNC/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='175',name='PI6/DCMI_D6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='176',name='PI7/DCMI_D7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='PI8/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PI9/CAN1_RX/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PI10/ETH_RX_ER',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='30',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='43',name='PH2/ETH_CRS',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PH3/ETH_COL',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PH5/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PH6/ETH_RXD2/I2C2_SMBA/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PH7/ETH_RXD3/I2C3_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PH8/DCMI_HSYNC/I2C3_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PH9/DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PH10/DCMI_D1/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PH12/DCMI_D3/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PH13/CAN1_TX/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PH14/DCMI_D4/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='130',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='106',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='107',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='108',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='PG6/FSMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='PG7/FSMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='PG8/ETH_PPS_OUT/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='152',name='PG9/DAC_EXTI9/FSMC_NCE3/FSMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='153',name='PG10/FSMC_NCE4_1/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='154',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/FSMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='155',name='PG12/FSMC_NE4/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='156',name='PG13/ETH_TXD0/FSMC_A24/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='157',name='PG14/ETH_TXD1/FSMC_A25/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='160',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PF0/FSMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='PF1/FSMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF2/FSMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF3/ADC3_IN9/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF4/ADC3_IN14/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF5/ADC3_IN15/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PF6/ADC3_IN4/FSMC_NIORD/TIM10_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PF7/ADC3_IN5/FSMC_NREG/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PF8/ADC3_IN6/FSMC_NIOWR/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PF9/ADC3_IN7/DAC_EXTI9/FSMC_CD/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PF10/ADC3_IN8/FSMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='82',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='91',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='103',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='114',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='127',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='136',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='149',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='159',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='172',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='90',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='102',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='113',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='126',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='135',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='148',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='158',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='37',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F407VETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F407/417',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 512KB Ram: 128KB Frequency: 168MHz Voltage: 1.8..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F407VGTx'],pins=[
            Pin(num='23',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_TX/DCMI_D5/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='DCMI_VSYNC/FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DCMI_D8/I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ANTI_TAMP/RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='97',name='PE0/DCMI_D2/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/DCMI_D3/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ETH_TXD3/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FSMC_A21/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FSMC_A22/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN1_RX/FSMC_D2/FSMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN1_TX/FSMC_D3/FSMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/FSMC_CLK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FSMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FSMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/FSMC_NWAIT/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FSMC_NCE2/FSMC_NE1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FSMC_D13/FSMC_DA13/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FSMC_D15/FSMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FSMC_A18/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FSMC_D0/FSMC_DA0/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F407ZETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F407/417',description='Core: ARM Cortex-M4 Package: LQFP144 Flash: 512KB Ram: 128KB Frequency: 168MHz Voltage: 1.7..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F407ZGTx'],pins=[
            Pin(num='34',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='CAN2_TX/DCMI_D5/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='DCMI_VSYNC/FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='DCMI_D8/I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ANTI_TAMP/RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='CAN1_RX/FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CAN1_TX/FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FSMC_NCE2/FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='143',name='PDR_ON',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='106',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='56',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/FSMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/FSMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8/ETH_PPS_OUT/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/FSMC_NCE3/FSMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/FSMC_NCE4_1/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/FSMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FSMC_NE4/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/ETH_TXD0/FSMC_A24/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/ETH_TXD1/FSMC_A25/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FSMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FSMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FSMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/ADC3_IN9/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/ADC3_IN14/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/ADC3_IN15/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC3_IN4/FSMC_NIORD/TIM10_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC3_IN5/FSMC_NREG/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC3_IN6/FSMC_NIOWR/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC3_IN7/DAC_EXTI9/FSMC_CD/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC3_IN8/FSMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/DCMI_D2/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/DCMI_D3/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ETH_TXD3/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FSMC_A21/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FSMC_A22/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F410C8Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F410',description='Core: ARM Cortex-M4 Package: UFQFPN48 Flash: 64KB Ram: 32KB Voltage: 1.7..3.6V IO-pins: 36',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F410CBUx'],pins=[
            Pin(num='10',name='ADC1_IN0/SYS_WKUP1/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN1/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN2/I2S_CKIN/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN3/I2S2_MCK/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN4/I2S1_WS/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN5/DAC_OUT1/I2S1_CK/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN6/I2S2_MCK/SPI1_MISO/TIM1_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN7/I2S1_SD/SPI1_MOSI/TIM1_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='FMPI2C1_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2S5_SD/SPI5_MOSI/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/TIM1_CH4/USART1_CTS/USART6_TX/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SPI5_MISO/TIM1_ETR/USART1_RTS/USART6_RX/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/I2S1_WS/SPI1_NSS/SYS_JTDI/USART1_TX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/ANTI_TAMP/RTC_AF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC1_IN8/I2S5_CK/SPI5_SCK/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC1_IN9/I2S5_WS/SPI5_NSS/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1/LPTIM1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/FMPI2C1_SDA/I2C2_SDA/I2S1_CK/SPI1_SCK/SYS_JTDO-SWO/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/SPI1_MISO/SYS_JTRST',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/LPTIM1_IN1/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/LPTIM1_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/LPTIM1_IN2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/I2S5_SD/LPTIM1_OUT/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/I2C2_SDA/I2S2_WS/SPI2_NSS/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/FMPI2C1_SCL/I2C2_SCL/I2S1_MCK/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/FMPI2C1_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/FMPI2C1_SDA/SPI2_MISO/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC1_EXTI15/FMPI2C1_SCL/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F410R8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F410',description='Core: ARM Cortex-M4 Package: LQFP64 Flash: 64KB Ram: 32KB Voltage: 1.7..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F410RBTx'],pins=[
            Pin(num='14',name='ADC1_IN0/SYS_WKUP1/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/I2S_CKIN/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/I2S2_MCK/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/I2S1_WS/SPI1_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/DAC_OUT1/I2S1_CK/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/I2S2_MCK/SPI1_MISO/TIM1_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/I2S1_SD/SPI1_MOSI/TIM1_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='FMPI2C1_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/TIM1_CH2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='I2S5_SD/SPI5_MOSI/TIM1_CH3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/TIM1_CH4/USART1_CTS/USART6_TX/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='SPI5_MISO/TIM1_ETR/USART1_RTS/USART6_RX/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/I2S1_WS/SPI1_NSS/SYS_JTDI/USART1_TX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/I2S5_CK/SPI5_SCK/TIM1_CH2N/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/I2S5_WS/SPI5_NSS/TIM1_CH3N/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/LPTIM1_OUT/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='FMPI2C1_SDA/I2C2_SDA/I2S1_CK/SPI1_SCK/SYS_JTDO-SWO/USART1_RX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='SPI1_MISO/SYS_JTRST/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2S1_SD/LPTIM1_IN1/SPI1_MOSI/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/LPTIM1_ETR/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/LPTIM1_IN2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/I2S5_SD/LPTIM1_OUT/SPI5_MOSI/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/I2C2_SDA/I2S2_WS/SPI2_NSS/TIM11_CH1/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='FMPI2C1_SCL/I2C2_SCL/I2S1_MCK/I2S2_CK/SPI2_SCK/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI11/I2C2_SDA/I2S_CKIN/SYS_TRACED3/TIM5_CH4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/TIM5_CH1/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='FMPI2C1_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH1N/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='FMPI2C1_SDA/SPI2_MISO/TIM1_CH2N/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/FMPI2C1_SCL/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10/LPTIM1_IN1/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11/LPTIM1_OUT/SYS_WKUP3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12/LPTIM1_IN2/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13/I2S2_SD/LPTIM1_ETR/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15/FMPI2C1_SMBA/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/FMPI2C1_SCL/I2S2_MCK/SYS_TRACECLK/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/FMPI2C1_SDA/I2S1_MCK/I2S2_CK/SPI2_SCK/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/FMPI2C1_SDA/I2S_CKIN/RCC_MCO_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/SYS_TRACED0/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/SYS_TRACED1/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/SYS_TRACED2/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/ANTI_TAMP/RTC_AF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F410T8Yx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F410',description='Core: ARM Cortex-M4 Package: WLCSP36 Flash: 64KB Ram: 32KB Voltage: 1.7..3.6V IO-pins: 23',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F410TBYx'],pins=[
            Pin(num='E5',name='ADC1_IN0/SYS_WKUP1/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='ADC1_IN2/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC1_IN3/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC1_IN5/DAC_OUT1/I2S1_CK/SPI1_SCK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='FMPI2C1_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='TIM1_ETR/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ADC1_EXTI15/I2S1_WS/SPI1_NSS/SYS_JTDI/USART1_TX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='BOOT1/LPTIM1_OUT/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='FMPI2C1_SDA/I2C2_SDA/I2S1_CK/SPI1_SCK/SYS_JTDO-SWO/USART1_RX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='SPI1_MISO/SYS_JTRST/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SMBA/I2S1_SD/LPTIM1_IN1/SPI1_MOSI/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='I2C1_SCL/LPTIM1_ETR/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='I2C1_SDA/LPTIM1_IN2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='I2C1_SCL/LPTIM1_OUT/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='FMPI2C1_SCL/I2C2_SCL/I2S1_MCK/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='I2C2_SMBA/TIM1_BKIN/TIM5_CH1/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='NRST',do_erc=True),
            Pin(num='D4',name='BOOT0',do_erc=True),
            Pin(num='B4',name='PDR_ON',func=Pin.PWRIN,do_erc=True),
            Pin(num='B5',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='E2',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='C5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='D6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='C4',name='PC13/ANTI_TAMP/RTC_AF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='A6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='A5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='B1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F411CCYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F411',description='Core: ARM Cortex-M4 Package: WLCSP49 Flash: 256KB Ram: 128KB Frequency: 100MHz Voltage: 1.7..3.6V IO-pins: 36',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F411CEYx'],pins=[
            Pin(num='F6',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='ADC1_IN1/I2S4_SD/SPI4_MOSI/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='ADC1_IN2/I2S_CKIN/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='ADC1_IN3/I2S2_MCK/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='ADC1_IN4/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC1_IN5/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC1_IN6/I2S2_MCK/SDIO_CMD/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC1_IN7/I2S1_SD/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='I2C3_SCL/RCC_MCO_1/SDIO_D1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='I2C3_SMBA/SDIO_D2/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='I2S5_SD/SPI5_MOSI/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='ADC1_EXTI11/SPI4_MISO/TIM1_CH4/USART1_CTS/USART6_TX/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='SPI5_MISO/TIM1_ETR/USART1_RTS/USART6_RX/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ADC1_EXTI15/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/USART1_TX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='NRST',do_erc=True),
            Pin(num='A5',name='BOOT0',do_erc=True),
            Pin(num='B6',name='PDR_ON',func=Pin.PWRIN,do_erc=True),
            Pin(num='B7',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='D6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='D5',name='PC13/ANTI_TAMP/RTC_AF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PB0/ADC1_IN8/I2S5_CK/SPI5_SCK/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PB1/ADC1_IN9/I2S5_WS/SPI5_NSS/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PB3/I2C2_SDA/I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PB4/I2C3_SDA/I2S3_ext_SD/SDIO_D0/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PB5/I2C1_SMBA/I2S1_SD/I2S3_SD/SDIO_D3/SPI1_MOSI/SPI3_MOSI/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PB6/I2C1_SCL/TIM4_CH1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PB7/I2C1_SDA/SDIO_D0/TIM4_CH2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='PB8/I2C1_SCL/I2C3_SDA/I2S5_SD/SDIO_D4/SPI5_MOSI/TIM10_CH1/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PB9/I2C1_SDA/I2C2_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PB10/I2C2_SCL/I2S2_CK/I2S3_MCK/SDIO_D7/SPI2_SCK/TIM2_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PB12/I2C2_SMBA/I2S2_WS/I2S3_CK/I2S4_WS/SPI2_NSS/SPI3_SCK/SPI4_NSS/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PB13/I2S2_CK/I2S4_CK/SPI2_SCK/SPI4_SCK/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PB14/I2S2_ext_SD/SDIO_D6/SPI2_MISO/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='PB15/ADC1_EXTI15/I2S2_SD/RTC_REFIN/SDIO_CK/SPI2_MOSI/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='B2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='A6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='B1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F411CEUx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F411',description='Core: ARM Cortex-M4 Package: UFQFPN48 Flash: 512KB Ram: 128KB Frequency: 100MHz Voltage: 1.7..3.6V IO-pins: 36',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC1_IN1/I2S4_SD/SPI4_MOSI/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC1_IN2/I2S_CKIN/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC1_IN3/I2S2_MCK/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC1_IN4/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN5/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN6/I2S2_MCK/SDIO_CMD/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN7/I2S1_SD/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C3_SCL/RCC_MCO_1/SDIO_D1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C3_SMBA/SDIO_D2/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2S5_SD/SPI5_MOSI/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_EXTI11/SPI4_MISO/TIM1_CH4/USART1_CTS/USART6_TX/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SPI5_MISO/TIM1_ETR/USART1_RTS/USART6_RX/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_EXTI15/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/USART1_TX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/ANTI_TAMP/RTC_AF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC1_IN8/I2S5_CK/SPI5_SCK/TIM1_CH2N/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC1_IN9/I2S5_WS/SPI5_NSS/TIM1_CH3N/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/I2C2_SDA/I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/I2C3_SDA/I2S3_ext_SD/SDIO_D0/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/I2C1_SMBA/I2S1_SD/I2S3_SD/SDIO_D3/SPI1_MOSI/SPI3_MOSI/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM4_CH1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/SDIO_D0/TIM4_CH2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/I2C3_SDA/I2S5_SD/SDIO_D4/SPI5_MOSI/TIM10_CH1/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/I2C1_SDA/I2C2_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/I2S2_CK/I2S3_MCK/SDIO_D7/SPI2_SCK/TIM2_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2C2_SMBA/I2S2_WS/I2S3_CK/I2S4_WS/SPI2_NSS/SPI3_SCK/SPI4_NSS/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2S2_CK/I2S4_CK/SPI2_SCK/SPI4_SCK/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2S2_ext_SD/SDIO_D6/SPI2_MISO/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC1_EXTI15/I2S2_SD/RTC_REFIN/SDIO_CK/SPI2_MOSI/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F411RCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F411',description='Core: ARM Cortex-M4 Package: LQFP64 Flash: 256KB Ram: 128KB Frequency: 100MHz Voltage: 1.7..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F411RETx'],pins=[
            Pin(num='14',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/I2S4_SD/SPI4_MOSI/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/I2S_CKIN/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/I2S2_MCK/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/I2S2_MCK/SDIO_CMD/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/I2S1_SD/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='I2C3_SCL/RCC_MCO_1/SDIO_D1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='I2C3_SMBA/SDIO_D2/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='I2S5_SD/SPI5_MOSI/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/SPI4_MISO/TIM1_CH4/USART1_CTS/USART6_TX/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='SPI5_MISO/TIM1_ETR/USART1_RTS/USART6_RX/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/USART1_TX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/I2S5_CK/SPI5_SCK/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/I2S5_WS/SPI5_NSS/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2C2_SDA/I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/USART1_RX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2C3_SDA/I2S3_ext_SD/SDIO_D0/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='I2C1_SMBA/I2S1_SD/I2S3_SD/SDIO_D3/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/SDIO_D0/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/I2C3_SDA/I2S5_SD/SDIO_D4/SPI5_MOSI/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='I2C1_SDA/I2C2_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/I2S2_CK/I2S3_MCK/SDIO_D7/SPI2_SCK/TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2C2_SMBA/I2S2_WS/I2S3_CK/I2S4_WS/SPI2_NSS/SPI3_SCK/SPI4_NSS/TIM1_BKIN/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2S2_CK/I2S4_CK/SPI2_SCK/SPI4_SCK/TIM1_CH1N/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2S2_ext_SD/SDIO_D6/SPI2_MISO/TIM1_CH2N/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/I2S2_SD/RTC_REFIN/SDIO_CK/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/SDIO_CMD/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12/I2S2_ext_SD/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13/I2S2_SD/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/SDIO_D6/TIM3_CH1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S2_CK/I2S3_MCK/SDIO_D7/SPI2_SCK/TIM3_CH2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/SDIO_D0/TIM3_CH3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/SDIO_D2/SPI3_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/I2S3_ext_SD/SDIO_D3/SPI3_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SDIO_CK/SPI3_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/ANTI_TAMP/RTC_AF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F411VCHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F411',description='Core: ARM Cortex-M4 Package: UFBGA100 Flash: 256KB Ram: 128KB Frequency: 100MHz Voltage: 1.7..3.6V IO-pins: 81',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F411VEHx'],pins=[
            Pin(num='L2',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN1/I2S4_SD/SPI4_MOSI/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC1_IN2/I2S_CKIN/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC1_IN3/I2S2_MCK/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN4/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC1_IN5/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC1_IN6/I2S2_MCK/SDIO_CMD/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN7/I2S1_SD/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='I2C3_SCL/RCC_MCO_1/SDIO_D1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='I2C3_SMBA/SDIO_D2/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='I2S5_SD/SPI5_MOSI/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC1_EXTI11/SPI4_MISO/TIM1_CH4/USART1_CTS/USART6_TX/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='SPI5_MISO/TIM1_ETR/USART1_RTS/USART6_RX/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ADC1_EXTI15/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/USART1_TX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC1_IN8/I2S5_CK/SPI5_SCK/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC1_IN9/I2S5_WS/SPI5_NSS/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='I2C2_SDA/I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/USART1_RX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='I2C3_SDA/I2S3_ext_SD/SDIO_D0/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='I2C1_SMBA/I2S1_SD/I2S3_SD/SDIO_D3/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='I2C1_SDA/SDIO_D0/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/I2C3_SDA/I2S5_SD/SDIO_D4/SPI5_MOSI/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='I2C1_SDA/I2C2_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/I2S2_CK/I2S3_MCK/SDIO_D7/SPI2_SCK/TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='ADC1_EXTI11/I2C2_SDA/I2S_CKIN/TIM2_CH4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='I2C2_SMBA/I2S2_WS/I2S3_CK/I2S4_WS/SPI2_NSS/SPI3_SCK/SPI4_NSS/TIM1_BKIN/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='I2S2_CK/I2S4_CK/SPI2_SCK/SPI4_SCK/TIM1_CH1N/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='I2S2_ext_SD/SDIO_D6/SPI2_MISO/TIM1_CH2N/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='ADC1_EXTI15/I2S2_SD/RTC_REFIN/SDIO_CK/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC1_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC1_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC1_IN12/I2S2_ext_SD/SPI2_MISO/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_IN13/I2S2_SD/SPI2_MOSI/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC1_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC1_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='I2S2_MCK/SDIO_D6/TIM3_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='I2S2_CK/I2S3_MCK/SDIO_D7/SPI2_SCK/TIM3_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='SDIO_D0/TIM3_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='I2S3_CK/SDIO_D2/SPI3_SCK/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC1_EXTI11/I2S3_ext_SD/SDIO_D3/SPI3_MISO/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='I2S3_SD/SDIO_CK/SPI3_MOSI/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='ANTI_TAMP/RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC1_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E3',name='BYPASS_REG',do_erc=True),
            Pin(num='C11',name='VCAP2',func=Pin.PWRIN,do_erc=True),
            Pin(num='E2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='PDR_ON',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='L11',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='C3',name='PE0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/I2S4_CK/I2S5_CK/SPI4_SCK/SPI5_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/I2S4_WS/I2S5_WS/SPI4_NSS/SPI5_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/SPI4_MISO/SPI5_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/I2S4_SD/I2S5_SD/SPI4_MOSI/SPI5_MOSI/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC1_EXTI11/I2S4_WS/I2S5_WS/SPI4_NSS/SPI5_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/I2S4_CK/I2S5_CK/SPI4_SCK/SPI5_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/SPI4_MISO/SPI5_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/I2S4_SD/I2S5_SD/SPI4_MOSI/SPI5_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/ADC1_EXTI15/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/SDIO_CMD/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/I2S2_CK/SPI2_SCK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/I2S3_SD/SPI3_MOSI/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/ADC1_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/TIM4_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/ADC1_EXTI15/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F411VCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F411',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 256KB Ram: 128KB Frequency: 100MHz Voltage: 1.7..3.6V IO-pins: 81',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F411VETx'],pins=[
            Pin(num='23',name='ADC1_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/I2S4_SD/SPI4_MOSI/TIM2_CH2/TIM5_CH2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/I2S_CKIN/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/I2S2_MCK/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/I2S2_MCK/SDIO_CMD/SPI1_MISO/TIM1_BKIN/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/I2S1_SD/SPI1_MOSI/TIM1_CH1N/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C3_SCL/RCC_MCO_1/SDIO_D1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='I2C3_SMBA/SDIO_D2/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2S5_SD/SPI5_MOSI/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/SPI4_MISO/TIM1_CH4/USART1_CTS/USART6_TX/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='SPI5_MISO/TIM1_ETR/USART1_RTS/USART6_RX/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/USART1_TX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/I2S5_CK/SPI5_SCK/TIM1_CH2N/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/I2S5_WS/SPI5_NSS/TIM1_CH3N/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2C2_SDA/I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/USART1_RX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2C3_SDA/I2S3_ext_SD/SDIO_D0/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='I2C1_SMBA/I2S1_SD/I2S3_SD/SDIO_D3/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/SDIO_D0/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/I2C3_SDA/I2S5_SD/SDIO_D4/SPI5_MOSI/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='I2C1_SDA/I2C2_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/I2S2_CK/I2S3_MCK/SDIO_D7/SPI2_SCK/TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2C2_SMBA/I2S2_WS/I2S3_CK/I2S4_WS/SPI2_NSS/SPI3_SCK/SPI4_NSS/TIM1_BKIN/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='I2S2_CK/I2S4_CK/SPI2_SCK/SPI4_SCK/TIM1_CH1N/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2S2_ext_SD/SDIO_D6/SPI2_MISO/TIM1_CH2N/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/I2S2_SD/RTC_REFIN/SDIO_CK/SPI2_MOSI/TIM1_CH3N/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/I2S2_ext_SD/SPI2_MISO/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/I2S2_SD/SPI2_MOSI/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/SDIO_D6/TIM3_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S2_CK/I2S3_MCK/SDIO_D7/SPI2_SCK/TIM3_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='SDIO_D0/TIM3_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/SDIO_D2/SPI3_SCK/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/I2S3_ext_SD/SDIO_D3/SPI3_MISO/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/SDIO_CK/SPI3_MOSI/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ANTI_TAMP/RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VCAP2',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='97',name='PE0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/I2S4_CK/I2S5_CK/SPI4_SCK/SPI5_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/I2S4_WS/I2S5_WS/SPI4_NSS/SPI5_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SPI4_MISO/SPI5_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/I2S4_SD/I2S5_SD/SPI4_MOSI/SPI5_MOSI/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/I2S4_WS/I2S5_WS/SPI4_NSS/SPI5_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/I2S4_CK/I2S5_CK/SPI4_SCK/SPI5_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SPI4_MISO/SPI5_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/I2S4_SD/I2S5_SD/SPI4_MOSI/SPI5_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/SDIO_CMD/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/I2S2_CK/SPI2_SCK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/I2S3_SD/SPI3_MOSI/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/TIM4_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F415OGYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F405/415',description='Core: ARM Cortex-M4 Package: WLCSP90 Flash: 1024KB Ram: 128KB Frequency: 168MHz Voltage: 1.7..3.6V IO-pins: 72',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='C10',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='DAC_EXTI9/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='CAN2_RX/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='CAN2_TX/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='CAN1_RX/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='CAN1_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='J1',name='CAN2_TX/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='DAC_EXTI9/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ANTI_TAMP/RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='PDR_ON',do_erc=True),
            Pin(num='D9',name='BYPASS_REG',do_erc=True),
            Pin(num='G10',name='NRST',do_erc=True),
            Pin(num='A7',name='BOOT0',do_erc=True),
            Pin(num='A10',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='B1',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='F4',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='C3',name='PI0/I2S2_WS/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PI1/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='F9',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='G6',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PD0/CAN1_RX/FSMC_D2/FSMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PD1/CAN1_TX/FSMC_D3/FSMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PD2/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PD4/FSMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PD5/FSMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='PD6/FSMC_NWAIT/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/FSMC_NCE2/FSMC_NE1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='PD8/FSMC_D13/FSMC_DA13/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PD9/DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PD10/FSMC_D15/FSMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PD12/FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PD14/FSMC_D0/FSMC_DA0/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PD15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='B8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='C9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F415RGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F405/415',description='Core: ARM Cortex-M4 Package: LQFP64 Flash: 1024KB Ram: 128KB Frequency: 168MHz Voltage: 1.8..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='CAN2_RX/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='CAN2_TX/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN1_RX/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN1_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='CAN2_TX/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11/ADC2_IN11/ADC3_IN11',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12/ADC2_IN12/ADC3_IN12/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13/ADC2_IN13/ADC3_IN13/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14/ADC2_IN14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15/ADC2_IN15',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/ANTI_TAMP/RTC_AF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F415VGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F405/415',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 1024KB Ram: 128KB Frequency: 168MHz Voltage: 1.8..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='CAN2_RX/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_TX/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN1_RX/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN1_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='CAN2_TX/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/ADC2_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/ADC2_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ANTI_TAMP/RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='97',name='PE0/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FSMC_A22/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN1_RX/FSMC_D2/FSMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN1_TX/FSMC_D3/FSMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/FSMC_CLK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FSMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FSMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/FSMC_NWAIT/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FSMC_NCE2/FSMC_NE1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FSMC_D13/FSMC_DA13/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FSMC_D15/FSMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FSMC_A18/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FSMC_D0/FSMC_DA0/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F415ZGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F405/415',description='Core: ARM Cortex-M4 Package: LQFP144 Flash: 1024KB Ram: 128KB Frequency: 168MHz Voltage: 1.7..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='34',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN6/ADC2_IN6/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN7/ADC2_IN7/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN8/ADC2_IN8/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN9/ADC2_IN9/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='CAN2_RX/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='CAN2_TX/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CAN1_RX/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='CAN1_TX/DAC_EXTI9/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='CAN2_TX/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN14/ADC2_IN14/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN15/ADC2_IN15/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ANTI_TAMP/RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='CAN1_RX/FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CAN1_TX/FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FSMC_NCE2/FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='143',name='PDR_ON',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='106',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='56',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/FSMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/FSMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/FSMC_NCE3/FSMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/FSMC_NCE4_1/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FSMC_NE4/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/FSMC_A24/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/FSMC_A25/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FSMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FSMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FSMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/ADC3_IN9/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/ADC3_IN14/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/ADC3_IN15/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC3_IN4/FSMC_NIORD/TIM10_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC3_IN5/FSMC_NREG/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC3_IN6/FSMC_NIOWR/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC3_IN7/DAC_EXTI9/FSMC_CD/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC3_IN8/FSMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FSMC_A22/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F417IEHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F407/417',description='Core: ARM Cortex-M4 Package: UFBGA176 Flash: 512KB Ram: 128KB Frequency: 168MHz Voltage: 1.7..3.6V IO-pins: 140',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F417IGHx'],pins=[
            Pin(num='N3',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='P2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='R2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P4',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='P3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R3',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F15',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E15',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D15',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C15',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B15',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A15',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A14',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='R5',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='R4',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN2_TX/DCMI_D5/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R12',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='R13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='P12',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='P13',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='R14',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R15',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P5',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H15',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G15',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G14',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F14',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B14',name='DCMI_D8/I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='ANTI_TAMP/RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN1_RX/FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='CAN1_TX/FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='FSMC_NCE2/FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P15',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P14',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='N15',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N14',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N13',name='FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M15',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='M14',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L14',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='DCMI_D2/FSMC_NBL0/TIM4_ETR/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DCMI_D3/FSMC_NBL1/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ETH_TXD3/FSMC_A23/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='FSMC_A19/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='DCMI_D4/FSMC_A20/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='DCMI_D6/FSMC_A21/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DCMI_D7/FSMC_A22/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R8',name='FSMC_D4/FSMC_DA4/TIM1_ETR/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P8',name='FSMC_D5/FSMC_DA5/TIM1_CH1N/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P9',name='DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R9',name='FSMC_D7/FSMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='R10',name='FSMC_D9/FSMC_DA9/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='FSMC_D10/FSMC_DA10/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P11',name='FSMC_D11/FSMC_DA11/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R11',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PDR_ON',do_erc=True),
            Pin(num='J1',name='NRST',do_erc=True),
            Pin(num='L4',name='BYPASS_REG',do_erc=True),
            Pin(num='D6',name='BOOT0',do_erc=True),
            Pin(num='C1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='F13',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='M10',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='N1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='P1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='E14',name='PI0/DCMI_D13/I2S2_WS/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D14',name='PI1/DCMI_D8/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C14',name='PI2/DCMI_D9/I2S2_ext_SD/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PI3/DCMI_D10/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PI4/DCMI_D5/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PI5/DCMI_VSYNC/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PI6/DCMI_D6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PI7/DCMI_D7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PI8/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PI9/CAN1_RX/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI10/ETH_RX_ER',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='F4',name='PH2/ETH_CRS',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PH3/ETH_COL',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PH5/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PH6/ETH_RXD2/I2C2_SMBA/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='PH7/ETH_RXD3/I2C3_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PH8/DCMI_HSYNC/I2C3_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='PH9/DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='PH10/DCMI_D1/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='PH12/DCMI_D3/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='PH13/CAN1_TX/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='PH14/DCMI_D4/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L15',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K15',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K14',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='J15',name='PG6/FSMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J14',name='PG7/FSMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H14',name='PG8/ETH_PPS_OUT/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='PG9/DAC_EXTI9/FSMC_NCE3/FSMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PG10/FSMC_NCE4_1/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/FSMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PG12/FSMC_NE4/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='PG13/ETH_TXD0/FSMC_A24/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG14/ETH_TXD1/FSMC_A25/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PF0/FSMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PF1/FSMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='PF2/FSMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='PF3/ADC3_IN9/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='PF4/ADC3_IN14/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='PF5/ADC3_IN15/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='PF6/ADC3_IN4/FSMC_NIORD/TIM10_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='PF7/ADC3_IN5/FSMC_NREG/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PF8/ADC3_IN6/FSMC_NIOWR/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='PF9/ADC3_IN7/DAC_EXTI9/FSMC_CD/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PF10/ADC3_IN8/FSMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='R6',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12',func=Pin.BIDIR,do_erc=True),
            Pin(num='P6',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='R7',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P7',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='R1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F417IETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F407/417',description='Core: ARM Cortex-M4 Package: LQFP176 Flash: 512KB Ram: 128KB Frequency: 168MHz Voltage: 1.7..3.6V IO-pins: 140',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F417IGTx'],pins=[
            Pin(num='40',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='120',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='121',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='138',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='161',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='162',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='163',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='164',name='CAN2_TX/DCMI_D5/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='165',name='DCMI_VSYNC/FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='167',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='168',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='94',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='DCMI_D8/I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ANTI_TAMP/RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='CAN1_RX/FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='143',name='CAN1_TX/FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='144',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='145',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='146',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='147',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='150',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='151',name='FSMC_NCE2/FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='169',name='DCMI_D2/FSMC_NBL0/TIM4_ETR/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='170',name='DCMI_D3/FSMC_NBL1/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='ETH_TXD3/FSMC_A23/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='FSMC_A19/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='DCMI_D4/FSMC_A20/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='DCMI_D6/FSMC_A21/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='DCMI_D7/FSMC_A22/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='FSMC_D4/FSMC_DA4/TIM1_ETR/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='FSMC_D5/FSMC_DA5/TIM1_CH1N/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='FSMC_D7/FSMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='FSMC_D9/FSMC_DA9/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='FSMC_D10/FSMC_DA10/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FSMC_D11/FSMC_DA11/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='NRST',do_erc=True),
            Pin(num='171',name='PDR_ON',do_erc=True),
            Pin(num='166',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='81',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='125',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='PI0/DCMI_D13/I2S2_WS/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PI1/DCMI_D8/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='PI2/DCMI_D9/I2S2_ext_SD/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='PI3/DCMI_D10/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='173',name='PI4/DCMI_D5/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='174',name='PI5/DCMI_VSYNC/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='175',name='PI6/DCMI_D6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='176',name='PI7/DCMI_D7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='PI8/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PI9/CAN1_RX/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PI10/ETH_RX_ER',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='30',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='43',name='PH2/ETH_CRS',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PH3/ETH_COL',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PH5/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PH6/ETH_RXD2/I2C2_SMBA/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PH7/ETH_RXD3/I2C3_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PH8/DCMI_HSYNC/I2C3_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PH9/DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PH10/DCMI_D1/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PH12/DCMI_D3/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PH13/CAN1_TX/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PH14/DCMI_D4/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='130',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='106',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='107',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='108',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='PG6/FSMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='PG7/FSMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='PG8/ETH_PPS_OUT/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='152',name='PG9/DAC_EXTI9/FSMC_NCE3/FSMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='153',name='PG10/FSMC_NCE4_1/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='154',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/FSMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='155',name='PG12/FSMC_NE4/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='156',name='PG13/ETH_TXD0/FSMC_A24/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='157',name='PG14/ETH_TXD1/FSMC_A25/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='160',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PF0/FSMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='PF1/FSMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF2/FSMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF3/ADC3_IN9/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF4/ADC3_IN14/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF5/ADC3_IN15/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PF6/ADC3_IN4/FSMC_NIORD/TIM10_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PF7/ADC3_IN5/FSMC_NREG/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PF8/ADC3_IN6/FSMC_NIOWR/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PF9/ADC3_IN7/DAC_EXTI9/FSMC_CD/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PF10/ADC3_IN8/FSMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='82',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='91',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='103',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='114',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='127',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='136',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='149',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='159',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='172',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='90',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='102',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='113',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='126',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='135',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='148',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='158',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='37',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F417VETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F407/417',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 512KB Ram: 128KB Frequency: 168MHz Voltage: 1.8..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F417VGTx'],pins=[
            Pin(num='23',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_TX/DCMI_D5/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='DCMI_VSYNC/FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DCMI_D8/I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ANTI_TAMP/RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='97',name='PE0/DCMI_D2/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/DCMI_D3/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ETH_TXD3/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FSMC_A21/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FSMC_A22/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN1_RX/FSMC_D2/FSMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN1_TX/FSMC_D3/FSMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/FSMC_CLK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FSMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FSMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/FSMC_NWAIT/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FSMC_NCE2/FSMC_NE1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FSMC_D13/FSMC_DA13/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FSMC_D15/FSMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FSMC_A18/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FSMC_D0/FSMC_DA0/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F417ZETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F407/417',description='Core: ARM Cortex-M4 Package: LQFP144 Flash: 512KB Ram: 128KB Frequency: 168MHz Voltage: 1.7..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F417ZGTx'],pins=[
            Pin(num='34',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='CAN2_TX/DCMI_D5/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='DCMI_VSYNC/FSMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='DCMI_D8/I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ANTI_TAMP/RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='CAN1_RX/FSMC_D2/FSMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CAN1_TX/FSMC_D3/FSMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='FSMC_CLK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FSMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FSMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='FSMC_NWAIT/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FSMC_NCE2/FSMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FSMC_D13/FSMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FSMC_D15/FSMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_A16/FSMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FSMC_A17/FSMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FSMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FSMC_D0/FSMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='143',name='PDR_ON',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='106',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='56',name='PG0/FSMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FSMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FSMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FSMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FSMC_A14',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/FSMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/FSMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8/ETH_PPS_OUT/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/FSMC_NCE3/FSMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/FSMC_NCE4_1/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/FSMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FSMC_NE4/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/ETH_TXD0/FSMC_A24/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/ETH_TXD1/FSMC_A25/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FSMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FSMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FSMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/ADC3_IN9/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/ADC3_IN14/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/ADC3_IN15/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC3_IN4/FSMC_NIORD/TIM10_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC3_IN5/FSMC_NREG/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC3_IN6/FSMC_NIOWR/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC3_IN7/DAC_EXTI9/FSMC_CD/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC3_IN8/FSMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FSMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FSMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FSMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/DCMI_D2/FSMC_NBL0/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/DCMI_D3/FSMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ETH_TXD3/FSMC_A23/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FSMC_A20/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FSMC_A21/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FSMC_A22/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/FSMC_D4/FSMC_DA4/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/FSMC_D5/FSMC_DA5/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/FSMC_D7/FSMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FSMC_D8/FSMC_DA8/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FSMC_D9/FSMC_DA9/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FSMC_D10/FSMC_DA10/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FSMC_D11/FSMC_DA11/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FSMC_D12/FSMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F427AGHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F427/437',description='Core: ARM Cortex-M4 Package: UFBGA169 Flash: 1024KB Ram: 192KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 130',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F427AIHx'],pins=[
            Pin(num='J5',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='N3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F11',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F12',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='DCMI_D8/I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='DCMI_D5/FMC_CLK/I2S2_CK/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='DCMI_D10/FMC_NWAIT/I2S3_SD/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='FMC_NCE2/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='FMC_D15/FMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J13',name='FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='FMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='DCMI_D4/FMC_A20/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='DCMI_D6/FMC_A21/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='DCMI_D7/FMC_A22/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='FMC_D7/FMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N8',name='FMC_D9/FMC_DA9/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='FMC_D10/FMC_DA10/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='FMC_D11/FMC_DA11/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PDR_ON',do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='M1',name='BYPASS_REG',do_erc=True),
            Pin(num='A5',name='BOOT0',do_erc=True),
            Pin(num='D12',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='J2',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='J3',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='N9',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='A1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='A13',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='N1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='N13',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='B13',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PI4/DCMI_D5/FMC_NBL2/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PI5/DCMI_VSYNC/FMC_NBL3/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PI6/DCMI_D6/FMC_D28/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PI7/DCMI_D7/FMC_D29/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI10/ETH_RX_ER/FMC_D31',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='L2',name='PH2/ETH_CRS/FMC_SDCKE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PH3/ETH_COL/FMC_SDNE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='N10',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='PH10/DCMI_D1/FMC_D18/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='PH12/DCMI_D3/FMC_D20/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PH13/CAN1_TX/FMC_D21/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PH14/DCMI_D4/FMC_D22/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H13',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G13',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G11',name='PG6/DCMI_D12/FMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G12',name='PG7/DCMI_D13/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='F13',name='PG8/ETH_PPS_OUT/FMC_SDCLK/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG10/DCMI_D2/FMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG12/FMC_NE4/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='PF10/ADC3_IN8/DCMI_D11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J4',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F427IGHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F427/437',description='Core: ARM Cortex-M4 Package: UFBGA176 Flash: 1024KB Ram: 192KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 140',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F427IIHx'],pins=[
            Pin(num='N3',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='P2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='R2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P4',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='P3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R3',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F15',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E15',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D15',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C15',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B15',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A15',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A14',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='R5',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='R4',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R12',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='R13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='P12',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='P13',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='R14',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R15',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P5',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H15',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G15',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G14',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F14',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B14',name='DCMI_D8/I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='DCMI_D5/FMC_CLK/I2S2_CK/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='DCMI_D10/FMC_NWAIT/I2S3_SD/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='FMC_NCE2/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P15',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P14',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='N15',name='FMC_D15/FMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N14',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N13',name='FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M15',name='FMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='M14',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L14',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='DCMI_D4/FMC_A20/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='DCMI_D6/FMC_A21/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DCMI_D7/FMC_A22/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R8',name='FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P8',name='FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P9',name='DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R9',name='FMC_D7/FMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='R10',name='FMC_D9/FMC_DA9/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='FMC_D10/FMC_DA10/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P11',name='FMC_D11/FMC_DA11/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R11',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PDR_ON',do_erc=True),
            Pin(num='J1',name='NRST',do_erc=True),
            Pin(num='L4',name='BYPASS_REG',do_erc=True),
            Pin(num='D6',name='BOOT0',do_erc=True),
            Pin(num='C1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='F13',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='M10',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='N1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='P1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='E14',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D14',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C14',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PI4/DCMI_D5/FMC_NBL2/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PI5/DCMI_VSYNC/FMC_NBL3/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PI6/DCMI_D6/FMC_D28/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PI7/DCMI_D7/FMC_D29/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PI8/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI10/ETH_RX_ER/FMC_D31',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='F4',name='PH2/ETH_CRS/FMC_SDCKE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PH3/ETH_COL/FMC_SDNE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='PH10/DCMI_D1/FMC_D18/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='PH12/DCMI_D3/FMC_D20/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='PH13/CAN1_TX/FMC_D21/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='PH14/DCMI_D4/FMC_D22/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L15',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K15',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K14',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J15',name='PG6/DCMI_D12/FMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J14',name='PG7/DCMI_D13/FMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H14',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PG10/DCMI_D2/FMC_NCE4_1/FMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/FMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PG12/FMC_NE4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='PG13/ETH_TXD0/FMC_A24/SPI6_SCK/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG14/ETH_TXD1/FMC_A25/SPI6_MOSI/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='PF6/ADC3_IN4/FMC_NIORD/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='PF7/ADC3_IN5/FMC_NREG/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PF8/ADC3_IN6/FMC_NIOWR/SAI1_SCK_B/SPI5_MISO/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='PF9/ADC3_IN7/DAC_EXTI9/FMC_CD/SAI1_FS_B/SPI5_MOSI/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PF10/ADC3_IN8/DCMI_D11/FMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='R6',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='P6',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='R7',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P7',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='R1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F427IGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F427/437',description='Core: ARM Cortex-M4 Package: LQFP176 Flash: 1024KB Ram: 192KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 140',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F427IITx'],pins=[
            Pin(num='40',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='120',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='121',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='138',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='161',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='162',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='163',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='164',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='165',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='167',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='168',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='94',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='DCMI_D8/I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='143',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='144',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='145',name='DCMI_D5/FMC_CLK/I2S2_CK/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='146',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='147',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='150',name='DCMI_D10/FMC_NWAIT/I2S3_SD/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='151',name='FMC_NCE2/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='FMC_D15/FMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='FMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='169',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='170',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='DCMI_D4/FMC_A20/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='DCMI_D6/FMC_A21/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='DCMI_D7/FMC_A22/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='FMC_D7/FMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='FMC_D9/FMC_DA9/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='FMC_D10/FMC_DA10/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FMC_D11/FMC_DA11/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='NRST',do_erc=True),
            Pin(num='48',name='BYPASS_REG',do_erc=True),
            Pin(num='171',name='PDR_ON',do_erc=True),
            Pin(num='166',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='81',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='125',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='173',name='PI4/DCMI_D5/FMC_NBL2/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='174',name='PI5/DCMI_VSYNC/FMC_NBL3/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='175',name='PI6/DCMI_D6/FMC_D28/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='176',name='PI7/DCMI_D7/FMC_D29/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='PI8/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PI10/ETH_RX_ER/FMC_D31',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='30',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='43',name='PH2/ETH_CRS/FMC_SDCKE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PH3/ETH_COL/FMC_SDNE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PH10/DCMI_D1/FMC_D18/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PH12/DCMI_D3/FMC_D20/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PH13/CAN1_TX/FMC_D21/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PH14/DCMI_D4/FMC_D22/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='130',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='106',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='107',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='108',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='PG6/DCMI_D12/FMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='PG7/DCMI_D13/FMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='152',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='153',name='PG10/DCMI_D2/FMC_NCE4_1/FMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='154',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/FMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='155',name='PG12/FMC_NE4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='156',name='PG13/ETH_TXD0/FMC_A24/SPI6_SCK/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='157',name='PG14/ETH_TXD1/FMC_A25/SPI6_MOSI/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='160',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PF6/ADC3_IN4/FMC_NIORD/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PF7/ADC3_IN5/FMC_NREG/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PF8/ADC3_IN6/FMC_NIOWR/SAI1_SCK_B/SPI5_MISO/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PF9/ADC3_IN7/DAC_EXTI9/FMC_CD/SAI1_FS_B/SPI5_MOSI/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PF10/ADC3_IN8/DCMI_D11/FMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='82',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='91',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='103',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='114',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='127',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='136',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='149',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='159',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='172',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='90',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='102',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='113',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='126',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='135',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='148',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='158',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='37',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F427VGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F427/437',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 1024KB Ram: 192KB Frequency: 180MHz Voltage: 1.8..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F427VITx'],pins=[
            Pin(num='23',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DCMI_D8/I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='97',name='PE0/DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/DCMI_D3/FMC_NBL1/UART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/SAI1_SD_B/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FMC_A20/SAI1_FS_A/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FMC_A21/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FMC_A22/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/FMC_D7/FMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/FMC_D9/FMC_DA9/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/FMC_D10/FMC_DA10/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FMC_D11/FMC_DA11/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN1_RX/FMC_D2/FMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN1_TX/FMC_D3/FMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/DCMI_D5/FMC_CLK/I2S2_CK/SPI2_SCK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/DCMI_D10/FMC_NWAIT/I2S3_SD/SAI1_SD_A/SPI3_MOSI/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FMC_NCE2/FMC_NE1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FMC_D13/FMC_DA13/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FMC_D15/FMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FMC_A18/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FMC_D0/FMC_DA0/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F427ZGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F427/437',description='Core: ARM Cortex-M4 Package: LQFP144 Flash: 1024KB Ram: 192KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F427ZITx'],pins=[
            Pin(num='34',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='DCMI_D8/I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='DCMI_D5/FMC_CLK/I2S2_CK/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='DCMI_D10/FMC_NWAIT/I2S3_SD/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FMC_NCE2/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FMC_D15/FMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='143',name='PDR_ON',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='106',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='56',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/DCMI_D12/FMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/DCMI_D13/FMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/DCMI_D2/FMC_NCE4_1/FMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/FMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FMC_NE4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/ETH_TXD0/FMC_A24/SPI6_SCK/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/ETH_TXD1/FMC_A25/SPI6_MOSI/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC3_IN4/FMC_NIORD/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC3_IN5/FMC_NREG/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC3_IN6/FMC_NIOWR/SAI1_SCK_B/SPI5_MISO/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC3_IN7/DAC_EXTI9/FMC_CD/SAI1_FS_B/SPI5_MOSI/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC3_IN8/DCMI_D11/FMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/DCMI_D3/FMC_NBL1/UART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/SAI1_SD_B/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FMC_A20/SAI1_FS_A/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FMC_A21/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FMC_A22/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/FMC_D7/FMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FMC_D9/FMC_DA9/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FMC_D10/FMC_DA10/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FMC_D11/FMC_DA11/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F429AGHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F429/439',description='Core: ARM Cortex-M4 Package: UFBGA169 Flash: 1024KB Ram: 192KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 130',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F429AIHx'],pins=[
            Pin(num='J5',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='N3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F11',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F12',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='DCMI_D8/I2S3_CK/LTDC_R2/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='FMC_NCE2/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J13',name='FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='FMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='FMC_D7/FMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N8',name='FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PDR_ON',do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='M1',name='BYPASS_REG',do_erc=True),
            Pin(num='A5',name='BOOT0',do_erc=True),
            Pin(num='D12',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='J2',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='J3',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='N9',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='A1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='A13',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='N1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='N13',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='B13',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='L2',name='PH2/ETH_CRS/FMC_SDCKE0/LTDC_R0',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='N10',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='PH10/DCMI_D1/FMC_D18/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='PH12/DCMI_D3/FMC_D20/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H13',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G13',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G11',name='PG6/DCMI_D12/FMC_INT2/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G12',name='PG7/DCMI_D13/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='F13',name='PG8/ETH_PPS_OUT/FMC_SDCLK/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='PF10/ADC3_IN8/DCMI_D11/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J4',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F429BETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F429/439',description='Core: ARM Cortex-M4 Package: LQFP208 Flash: 512KB Ram: 192KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 168',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F429BGTx', 'STM32F429BITx'],pins=[
            Pin(num='43',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='143',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='144',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='145',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='146',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='147',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='159',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='160',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='192',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='193',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='194',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='195',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='196',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='198',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='199',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='106',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='107',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='138',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='161',name='DCMI_D8/I2S3_CK/LTDC_R2/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='162',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='163',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='164',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='165',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='166',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='167',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='168',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='169',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='172',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='173',name='FMC_NCE2/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='108',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='FMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='200',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='201',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='FMC_D7/FMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='FMC_A0/I2C2_SDA/PF0',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='FMC_A1/I2C2_SCL/PF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='FMC_A2/I2C2_SMBA/PF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC3_IN9/FMC_A3/PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC3_IN14/FMC_A4/PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC3_IN15/FMC_A5/PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC3_IN4/FMC_NIORD/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX/PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC3_IN5/FMC_NREG/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX/PF7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC3_IN6/FMC_NIOWR/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/PF8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC3_IN7/DAC_EXTI9/FMC_CD/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/PF9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC3_IN8/DCMI_D11/FMC_INTR/LTDC_DE/PF10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI/PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='FMC_A6/PF12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='FMC_A7/PF13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='FMC_A8/PF14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9/PF15',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='NRST',do_erc=True),
            Pin(num='203',name='PDR_ON',do_erc=True),
            Pin(num='197',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='41',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='92',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='148',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='126',name='PK0/LTDC_G5',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PK1/LTDC_G6',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PK2/LTDC_G7',func=Pin.BIDIR,do_erc=True),
            Pin(num='186',name='PK3/LTDC_B4',func=Pin.BIDIR,do_erc=True),
            Pin(num='187',name='PK4/LTDC_B5',func=Pin.BIDIR,do_erc=True),
            Pin(num='188',name='PK5/LTDC_B6',func=Pin.BIDIR,do_erc=True),
            Pin(num='189',name='PK6/LTDC_B7',func=Pin.BIDIR,do_erc=True),
            Pin(num='190',name='PK7/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PJ0/LTDC_R1',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PJ1/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PJ2/LTDC_R3',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PJ3/LTDC_R4',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='PJ4/LTDC_R5',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='PJ5/LTDC_R6',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='PJ6/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='PJ7/LTDC_G0',func=Pin.BIDIR,do_erc=True),
            Pin(num='120',name='PJ8/LTDC_G1',func=Pin.BIDIR,do_erc=True),
            Pin(num='121',name='PJ9/DAC_EXTI9/LTDC_G2',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='PJ10/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='PJ11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LTDC_G4',func=Pin.BIDIR,do_erc=True),
            Pin(num='174',name='PJ12/LTDC_B0',func=Pin.BIDIR,do_erc=True),
            Pin(num='175',name='PJ13/LTDC_B1',func=Pin.BIDIR,do_erc=True),
            Pin(num='176',name='PJ14/LTDC_B2',func=Pin.BIDIR,do_erc=True),
            Pin(num='177',name='PJ15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='154',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='155',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='156',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='157',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='205',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='206',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='207',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='208',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='PI8/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PI12/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PI13/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PI14/LTDC_CLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PI15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LTDC_R0',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='33',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='46',name='PH2/ETH_CRS/FMC_SDCKE0/LTDC_R0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='PH10/DCMI_D1/FMC_D18/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='PH12/DCMI_D3/FMC_D20/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='151',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='152',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='153',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='130',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='131',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='PG6/DCMI_D12/FMC_INT2/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='178',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='179',name='PG10/DCMI_D2/FMC_NCE4_1/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='180',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/FMC_NCE4_2/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='181',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='182',name='PG13/ETH_TXD0/FMC_A24/SPI6_SCK/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='183',name='PG14/ETH_TXD1/FMC_A25/SPI6_MOSI/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='191',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='59',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='103',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='115',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='124',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='137',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='150',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='158',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='171',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='185',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='204',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='42',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='25',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='60',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='82',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='93',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='114',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='125',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='136',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='149',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='170',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='184',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='202',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='40',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F429IEHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F429/439',description='Core: ARM Cortex-M4 Package: UFBGA176 Flash: 512KB Ram: 192KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 140',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F429IGHx', 'STM32F429IIHx'],pins=[
            Pin(num='N3',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='P2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='R2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P4',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='P3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R3',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F15',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E15',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D15',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C15',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B15',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A15',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A14',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='R5',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='R4',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R12',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='R13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='P12',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='P13',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='R14',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R15',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P5',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H15',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G15',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G14',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F14',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B14',name='DCMI_D8/I2S3_CK/LTDC_R2/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='FMC_NCE2/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P15',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P14',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='N15',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N14',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N13',name='FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M15',name='FMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='M14',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L14',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R8',name='FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P8',name='FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P9',name='DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R9',name='FMC_D7/FMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='R10',name='FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P11',name='FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R11',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PDR_ON',do_erc=True),
            Pin(num='J1',name='NRST',do_erc=True),
            Pin(num='L4',name='BYPASS_REG',do_erc=True),
            Pin(num='D6',name='BOOT0',do_erc=True),
            Pin(num='C1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='F13',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='M10',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='N1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='P1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='E14',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D14',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C14',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PI8/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='F4',name='PH2/ETH_CRS/FMC_SDCKE0/LTDC_R0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='PH10/DCMI_D1/FMC_D18/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='PH12/DCMI_D3/FMC_D20/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L15',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K15',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K14',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J15',name='PG6/DCMI_D12/FMC_INT2/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='J14',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H14',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PG10/DCMI_D2/FMC_NCE4_1/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/FMC_NCE4_2/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='PG13/ETH_TXD0/FMC_A24/SPI6_SCK/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG14/ETH_TXD1/FMC_A25/SPI6_MOSI/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='PF6/ADC3_IN4/FMC_NIORD/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='PF7/ADC3_IN5/FMC_NREG/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PF8/ADC3_IN6/FMC_NIOWR/SAI1_SCK_B/SPI5_MISO/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='PF9/ADC3_IN7/DAC_EXTI9/FMC_CD/SAI1_FS_B/SPI5_MOSI/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PF10/ADC3_IN8/DCMI_D11/FMC_INTR/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='R6',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='P6',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='R7',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P7',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='R1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F429IETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F429/439',description='Core: ARM Cortex-M4 Package: LQFP176 Flash: 512KB Ram: 192KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 140',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F429IGTx', 'STM32F429IITx'],pins=[
            Pin(num='40',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='120',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='121',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='138',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='161',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='162',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='163',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='164',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='165',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='167',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='168',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='94',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='DCMI_D8/I2S3_CK/LTDC_R2/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='143',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='144',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='145',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='146',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='147',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='150',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='151',name='FMC_NCE2/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='FMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='169',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='170',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='FMC_D7/FMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='NRST',do_erc=True),
            Pin(num='48',name='BYPASS_REG',do_erc=True),
            Pin(num='171',name='PDR_ON',do_erc=True),
            Pin(num='166',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='81',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='125',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='173',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='174',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='175',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='176',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='PI8/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='30',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='43',name='PH2/ETH_CRS/FMC_SDCKE0/LTDC_R0',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PH10/DCMI_D1/FMC_D18/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PH12/DCMI_D3/FMC_D20/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='130',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='106',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='107',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='108',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='PG6/DCMI_D12/FMC_INT2/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='152',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='153',name='PG10/DCMI_D2/FMC_NCE4_1/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='154',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/FMC_NCE4_2/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='155',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='156',name='PG13/ETH_TXD0/FMC_A24/SPI6_SCK/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='157',name='PG14/ETH_TXD1/FMC_A25/SPI6_MOSI/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='160',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PF6/ADC3_IN4/FMC_NIORD/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PF7/ADC3_IN5/FMC_NREG/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PF8/ADC3_IN6/FMC_NIOWR/SAI1_SCK_B/SPI5_MISO/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PF9/ADC3_IN7/DAC_EXTI9/FMC_CD/SAI1_FS_B/SPI5_MOSI/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PF10/ADC3_IN8/DCMI_D11/FMC_INTR/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='82',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='91',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='103',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='114',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='127',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='136',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='149',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='159',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='172',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='90',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='102',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='113',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='126',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='135',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='148',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='158',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='37',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F429NEHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F429/439',description='Core: ARM Cortex-M4 Package: TFBGA216 Flash: 512KB Ram: 192KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 168',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F429NGHx', 'STM32F429NIHx'],pins=[
            Pin(num='N3',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='P2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='R2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P4',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='P3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R3',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F15',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E15',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D15',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C15',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B15',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A15',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A14',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='R5',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='R4',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='P12',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='R13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K14',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='R14',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R15',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P5',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H15',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G15',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G14',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F14',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B14',name='DCMI_D8/I2S3_CK/LTDC_R2/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='FMC_NCE2/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L15',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='L14',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='K15',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='FMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R8',name='FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='N9',name='FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P9',name='DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R9',name='FMC_D7/FMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='R10',name='FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='R12',name='FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P11',name='FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R11',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='FMC_A0/I2C2_SDA/PF0',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='FMC_A1/I2C2_SCL/PF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='FMC_A2/I2C2_SMBA/PF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC3_IN9/FMC_A3/PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC3_IN14/FMC_A4/PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC3_IN15/FMC_A5/PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC3_IN4/FMC_NIORD/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX/PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='ADC3_IN5/FMC_NREG/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX/PF7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC3_IN6/FMC_NIOWR/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/PF8',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='ADC3_IN7/DAC_EXTI9/FMC_CD/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/PF9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='ADC3_IN8/DCMI_D11/FMC_INTR/LTDC_DE/PF10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P8',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI/PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='FMC_A6/PF12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='FMC_A7/PF13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P6',name='FMC_A8/PF14',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9/PF15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='PDR_ON',do_erc=True),
            Pin(num='J1',name='NRST',do_erc=True),
            Pin(num='L5',name='BYPASS_REG',do_erc=True),
            Pin(num='E6',name='BOOT0',do_erc=True),
            Pin(num='C1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='E11',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='L11',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='N1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='P1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='G13',name='PK0/LTDC_G5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F12',name='PK1/LTDC_G6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F13',name='PK2/LTDC_G7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PK3/LTDC_B4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PK4/LTDC_B5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PK5/LTDC_B6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PK6/LTDC_B7',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PK7/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='R6',name='PJ0/LTDC_R1',func=Pin.BIDIR,do_erc=True),
            Pin(num='R7',name='PJ1/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='P7',name='PJ2/LTDC_R3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N8',name='PJ3/LTDC_R4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PJ4/LTDC_R5',func=Pin.BIDIR,do_erc=True),
            Pin(num='M14',name='PJ5/LTDC_R6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='PJ6/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PJ7/LTDC_G0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PJ8/LTDC_G1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J13',name='PJ9/DAC_EXTI9/LTDC_G2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H13',name='PJ10/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G12',name='PJ11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LTDC_G4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PJ12/LTDC_B0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PJ13/LTDC_B1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PJ14/LTDC_B2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='PJ15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E14',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D14',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C14',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PI8/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI12/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PI13/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PI14/LTDC_CLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PI15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LTDC_R0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='K4',name='PH2/ETH_CRS/FMC_SDCKE0/LTDC_R0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='P13',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N13',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='P14',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='N14',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='P15',name='PH10/DCMI_D1/FMC_D18/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N15',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M15',name='PH12/DCMI_D3/FMC_D20/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J15',name='PG6/DCMI_D12/FMC_INT2/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='J14',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H14',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PG10/DCMI_D2/FMC_NCE4_1/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/FMC_NCE4_2/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PG13/ETH_TXD0/FMC_A24/SPI6_SCK/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PG14/ETH_TXD1/FMC_A25/SPI6_MOSI/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='R1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='L6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F429VETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F429/439',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 512KB Ram: 192KB Frequency: 180MHz Voltage: 1.8..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F429VGTx', 'STM32F429VITx'],pins=[
            Pin(num='23',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DCMI_D8/I2S3_CK/LTDC_R2/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='97',name='PE0/DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/DCMI_D3/FMC_NBL1/UART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/SAI1_SD_B/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/FMC_D7/FMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN1_RX/FMC_D2/FMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN1_TX/FMC_D3/FMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FMC_NCE2/FMC_NE1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FMC_D13/FMC_DA13/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FMC_D15/FMC_DA15/LTDC_B3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FMC_A18/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FMC_D0/FMC_DA0/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F429ZETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F429/439',description='Core: ARM Cortex-M4 Package: LQFP144 Flash: 512KB Ram: 192KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F429ZGTx', 'STM32F429ZITx'],pins=[
            Pin(num='34',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='DCMI_D8/I2S3_CK/LTDC_R2/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FMC_NCE2/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='143',name='PDR_ON',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='106',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='56',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/DCMI_D12/FMC_INT2/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/DCMI_D2/FMC_NCE4_1/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/FMC_NCE4_2/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/ETH_TXD0/FMC_A24/SPI6_SCK/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/ETH_TXD1/FMC_A25/SPI6_MOSI/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC3_IN4/FMC_NIORD/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC3_IN5/FMC_NREG/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC3_IN6/FMC_NIOWR/SAI1_SCK_B/SPI5_MISO/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC3_IN7/DAC_EXTI9/FMC_CD/SAI1_FS_B/SPI5_MOSI/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC3_IN8/DCMI_D11/FMC_INTR/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/DCMI_D3/FMC_NBL1/UART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/SAI1_SD_B/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/FMC_D7/FMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F429ZIYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F429/439',description='Core: ARM Cortex-M4 Package: WLCSP143 Flash: 2048KB Ram: 192KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='K9',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='N10',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='N8',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N3',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N1',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='N9',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='DCMI_D8/I2S3_CK/LTDC_R2/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='FMC_NCE2/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='M1',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='FMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='PDR_ON',do_erc=True),
            Pin(num='H9',name='NRST',do_erc=True),
            Pin(num='N11',name='BYPASS_REG',do_erc=True),
            Pin(num='C9',name='BOOT0',do_erc=True),
            Pin(num='C11',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='D1',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='L11',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='N2',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='J11',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H10',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='N6',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J1',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PG6/DCMI_D12/FMC_INT2/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PG10/DCMI_D2/FMC_NCE4_1/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/FMC_NCE4_2/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PG13/ETH_TXD0/FMC_A24/SPI6_SCK/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PG14/ETH_TXD1/FMC_A25/SPI6_MOSI/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F11',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='G11',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G10',name='PF6/ADC3_IN4/FMC_NIORD/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='PF7/ADC3_IN5/FMC_NREG/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PF8/ADC3_IN6/FMC_NIOWR/SAI1_SCK_B/SPI5_MISO/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='PF9/ADC3_IN7/DAC_EXTI9/FMC_CD/SAI1_FS_B/SPI5_MOSI/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='PF10/ADC3_IN8/DCMI_D11/FMC_INTR/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PE0/DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='PE1/DCMI_D3/FMC_NBL1/UART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PE2/ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='PE3/FMC_A19/SAI1_SD_B/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='PE4/DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PE5/DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PE6/DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='PE7/FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='PE8/FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='PE9/DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PE10/FMC_D7/FMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='PE12/FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='PE13/FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='PE14/FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L10',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F437AIHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F427/437',description='Core: ARM Cortex-M4 Package: UFBGA169 Flash: 2048KB Ram: 192KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 130',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='J5',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='N3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F11',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F12',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='DCMI_D8/I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='DCMI_D5/FMC_CLK/I2S2_CK/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='DCMI_D10/FMC_NWAIT/I2S3_SD/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='FMC_NCE2/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='FMC_D15/FMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J13',name='FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='FMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='DCMI_D4/FMC_A20/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='DCMI_D6/FMC_A21/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='DCMI_D7/FMC_A22/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='FMC_D7/FMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N8',name='FMC_D9/FMC_DA9/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='FMC_D10/FMC_DA10/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='FMC_D11/FMC_DA11/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PDR_ON',do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='M1',name='BYPASS_REG',do_erc=True),
            Pin(num='A5',name='BOOT0',do_erc=True),
            Pin(num='D12',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='J2',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='J3',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='N9',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='A1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='A13',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='N1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='N13',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='B13',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PI4/DCMI_D5/FMC_NBL2/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PI5/DCMI_VSYNC/FMC_NBL3/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PI6/DCMI_D6/FMC_D28/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PI7/DCMI_D7/FMC_D29/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI10/ETH_RX_ER/FMC_D31',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='L2',name='PH2/ETH_CRS/FMC_SDCKE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PH3/ETH_COL/FMC_SDNE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='N10',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='PH10/DCMI_D1/FMC_D18/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='PH12/DCMI_D3/FMC_D20/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PH13/CAN1_TX/FMC_D21/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PH14/DCMI_D4/FMC_D22/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H13',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G13',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G11',name='PG6/DCMI_D12/FMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G12',name='PG7/DCMI_D13/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='F13',name='PG8/ETH_PPS_OUT/FMC_SDCLK/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG10/DCMI_D2/FMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG12/FMC_NE4/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='PF10/ADC3_IN8/DCMI_D11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J4',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F437IGHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F427/437',description='Core: ARM Cortex-M4 Package: UFBGA176 Flash: 1024KB Ram: 192KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 140',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F437IIHx'],pins=[
            Pin(num='N3',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='P2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='R2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P4',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='P3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R3',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F15',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E15',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D15',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C15',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B15',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A15',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A14',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='R5',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='R4',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R12',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='R13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='P12',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='P13',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='R14',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R15',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P5',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H15',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G15',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G14',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F14',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B14',name='DCMI_D8/I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='DCMI_D5/FMC_CLK/I2S2_CK/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='DCMI_D10/FMC_NWAIT/I2S3_SD/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='FMC_NCE2/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P15',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P14',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='N15',name='FMC_D15/FMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N14',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N13',name='FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M15',name='FMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='M14',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L14',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='DCMI_D4/FMC_A20/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='DCMI_D6/FMC_A21/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DCMI_D7/FMC_A22/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R8',name='FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P8',name='FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P9',name='DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R9',name='FMC_D7/FMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='R10',name='FMC_D9/FMC_DA9/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='FMC_D10/FMC_DA10/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P11',name='FMC_D11/FMC_DA11/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R11',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PDR_ON',do_erc=True),
            Pin(num='J1',name='NRST',do_erc=True),
            Pin(num='L4',name='BYPASS_REG',do_erc=True),
            Pin(num='D6',name='BOOT0',do_erc=True),
            Pin(num='C1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='F13',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='M10',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='N1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='P1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='E14',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D14',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C14',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PI4/DCMI_D5/FMC_NBL2/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PI5/DCMI_VSYNC/FMC_NBL3/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PI6/DCMI_D6/FMC_D28/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PI7/DCMI_D7/FMC_D29/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PI8/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI10/ETH_RX_ER/FMC_D31',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='F4',name='PH2/ETH_CRS/FMC_SDCKE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PH3/ETH_COL/FMC_SDNE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='PH10/DCMI_D1/FMC_D18/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='PH12/DCMI_D3/FMC_D20/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='PH13/CAN1_TX/FMC_D21/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='PH14/DCMI_D4/FMC_D22/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L15',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K15',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K14',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J15',name='PG6/DCMI_D12/FMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J14',name='PG7/DCMI_D13/FMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H14',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PG10/DCMI_D2/FMC_NCE4_1/FMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/FMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PG12/FMC_NE4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='PG13/ETH_TXD0/FMC_A24/SPI6_SCK/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG14/ETH_TXD1/FMC_A25/SPI6_MOSI/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='PF6/ADC3_IN4/FMC_NIORD/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='PF7/ADC3_IN5/FMC_NREG/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PF8/ADC3_IN6/FMC_NIOWR/SAI1_SCK_B/SPI5_MISO/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='PF9/ADC3_IN7/DAC_EXTI9/FMC_CD/SAI1_FS_B/SPI5_MOSI/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PF10/ADC3_IN8/DCMI_D11/FMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='R6',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='P6',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='R7',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P7',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='R1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F437IGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F427/437',description='Core: ARM Cortex-M4 Package: LQFP176 Flash: 1024KB Ram: 192KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 140',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F437IITx'],pins=[
            Pin(num='40',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='120',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='121',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='138',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='161',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='162',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='163',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='164',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='165',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='167',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='168',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='94',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='DCMI_D8/I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='143',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='144',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='145',name='DCMI_D5/FMC_CLK/I2S2_CK/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='146',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='147',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='150',name='DCMI_D10/FMC_NWAIT/I2S3_SD/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='151',name='FMC_NCE2/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='FMC_D15/FMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='FMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='169',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='170',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='DCMI_D4/FMC_A20/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='DCMI_D6/FMC_A21/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='DCMI_D7/FMC_A22/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='FMC_D7/FMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='FMC_D9/FMC_DA9/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='FMC_D10/FMC_DA10/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FMC_D11/FMC_DA11/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='NRST',do_erc=True),
            Pin(num='48',name='BYPASS_REG',do_erc=True),
            Pin(num='171',name='PDR_ON',do_erc=True),
            Pin(num='166',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='81',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='125',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='173',name='PI4/DCMI_D5/FMC_NBL2/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='174',name='PI5/DCMI_VSYNC/FMC_NBL3/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='175',name='PI6/DCMI_D6/FMC_D28/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='176',name='PI7/DCMI_D7/FMC_D29/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='PI8/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PI10/ETH_RX_ER/FMC_D31',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='30',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='43',name='PH2/ETH_CRS/FMC_SDCKE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PH3/ETH_COL/FMC_SDNE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PH10/DCMI_D1/FMC_D18/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PH12/DCMI_D3/FMC_D20/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PH13/CAN1_TX/FMC_D21/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PH14/DCMI_D4/FMC_D22/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='130',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='106',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='107',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='108',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='PG6/DCMI_D12/FMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='PG7/DCMI_D13/FMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='152',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='153',name='PG10/DCMI_D2/FMC_NCE4_1/FMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='154',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/FMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='155',name='PG12/FMC_NE4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='156',name='PG13/ETH_TXD0/FMC_A24/SPI6_SCK/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='157',name='PG14/ETH_TXD1/FMC_A25/SPI6_MOSI/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='160',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PF6/ADC3_IN4/FMC_NIORD/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PF7/ADC3_IN5/FMC_NREG/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PF8/ADC3_IN6/FMC_NIOWR/SAI1_SCK_B/SPI5_MISO/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PF9/ADC3_IN7/DAC_EXTI9/FMC_CD/SAI1_FS_B/SPI5_MOSI/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PF10/ADC3_IN8/DCMI_D11/FMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='82',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='91',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='103',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='114',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='127',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='136',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='149',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='159',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='172',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='90',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='102',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='113',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='126',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='135',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='148',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='158',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='37',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F437VGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F427/437',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 1024KB Ram: 192KB Frequency: 180MHz Voltage: 1.8..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F437VITx'],pins=[
            Pin(num='23',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DCMI_D8/I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='97',name='PE0/DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/DCMI_D3/FMC_NBL1/UART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/SAI1_SD_B/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FMC_A20/SAI1_FS_A/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FMC_A21/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FMC_A22/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/FMC_D7/FMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/FMC_D9/FMC_DA9/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/FMC_D10/FMC_DA10/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FMC_D11/FMC_DA11/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN1_RX/FMC_D2/FMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN1_TX/FMC_D3/FMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/DCMI_D5/FMC_CLK/I2S2_CK/SPI2_SCK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/DCMI_D10/FMC_NWAIT/I2S3_SD/SAI1_SD_A/SPI3_MOSI/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FMC_NCE2/FMC_NE1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FMC_D13/FMC_DA13/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FMC_D15/FMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FMC_A18/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FMC_D0/FMC_DA0/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F437ZGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F427/437',description='Core: ARM Cortex-M4 Package: LQFP144 Flash: 1024KB Ram: 192KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F437ZITx'],pins=[
            Pin(num='34',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DCMI_D0/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DCMI_D1/I2S3_MCK/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='DCMI_D8/I2S3_CK/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='DCMI_D5/FMC_CLK/I2S2_CK/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='DCMI_D10/FMC_NWAIT/I2S3_SD/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FMC_NCE2/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FMC_D15/FMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='143',name='PDR_ON',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='106',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='56',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/DCMI_D12/FMC_INT2',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/DCMI_D13/FMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/DCMI_D2/FMC_NCE4_1/FMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/FMC_NCE4_2',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FMC_NE4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/ETH_TXD0/FMC_A24/SPI6_SCK/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/ETH_TXD1/FMC_A25/SPI6_MOSI/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC3_IN4/FMC_NIORD/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC3_IN5/FMC_NREG/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC3_IN6/FMC_NIOWR/SAI1_SCK_B/SPI5_MISO/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC3_IN7/DAC_EXTI9/FMC_CD/SAI1_FS_B/SPI5_MOSI/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC3_IN8/DCMI_D11/FMC_INTR',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/DCMI_D3/FMC_NBL1/UART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/SAI1_SD_B/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FMC_A20/SAI1_FS_A/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FMC_A21/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FMC_A22/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/FMC_D7/FMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FMC_D9/FMC_DA9/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FMC_D10/FMC_DA10/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FMC_D11/FMC_DA11/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F439AIHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F429/439',description='Core: ARM Cortex-M4 Package: UFBGA169 Flash: 2048KB Ram: 192KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 130',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='J5',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='N3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F11',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F12',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='DCMI_D8/I2S3_CK/LTDC_R2/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='FMC_NCE2/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J13',name='FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='FMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='FMC_D7/FMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N8',name='FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PDR_ON',do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='M1',name='BYPASS_REG',do_erc=True),
            Pin(num='A5',name='BOOT0',do_erc=True),
            Pin(num='D12',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='J2',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='J3',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='N9',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='A1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='A13',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='N1',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='N13',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='B13',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='L2',name='PH2/ETH_CRS/FMC_SDCKE0/LTDC_R0',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='N10',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='PH10/DCMI_D1/FMC_D18/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='PH12/DCMI_D3/FMC_D20/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H13',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G13',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G11',name='PG6/DCMI_D12/FMC_INT2/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G12',name='PG7/DCMI_D13/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='F13',name='PG8/ETH_PPS_OUT/FMC_SDCLK/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='PF10/ADC3_IN8/DCMI_D11/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J4',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F439BGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F429/439',description='Core: ARM Cortex-M4 Package: LQFP208 Flash: 1024KB Ram: 192KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 168',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F439BITx'],pins=[
            Pin(num='43',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='143',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='144',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='145',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='146',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='147',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='159',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='160',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='192',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='193',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='194',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='195',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='196',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='198',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='199',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='106',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='107',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='138',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='161',name='DCMI_D8/I2S3_CK/LTDC_R2/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='162',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='163',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='164',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='165',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='166',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='167',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='168',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='169',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='172',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='173',name='FMC_NCE2/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='108',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='FMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='200',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='201',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='FMC_D7/FMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='FMC_A0/I2C2_SDA/PF0',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='FMC_A1/I2C2_SCL/PF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='FMC_A2/I2C2_SMBA/PF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC3_IN9/FMC_A3/PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC3_IN14/FMC_A4/PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC3_IN15/FMC_A5/PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC3_IN4/FMC_NIORD/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX/PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC3_IN5/FMC_NREG/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX/PF7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC3_IN6/FMC_NIOWR/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/PF8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC3_IN7/DAC_EXTI9/FMC_CD/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/PF9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC3_IN8/DCMI_D11/FMC_INTR/LTDC_DE/PF10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI/PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='FMC_A6/PF12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='FMC_A7/PF13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='FMC_A8/PF14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9/PF15',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='NRST',do_erc=True),
            Pin(num='203',name='PDR_ON',do_erc=True),
            Pin(num='197',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='41',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='92',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='148',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='126',name='PK0/LTDC_G5',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PK1/LTDC_G6',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PK2/LTDC_G7',func=Pin.BIDIR,do_erc=True),
            Pin(num='186',name='PK3/LTDC_B4',func=Pin.BIDIR,do_erc=True),
            Pin(num='187',name='PK4/LTDC_B5',func=Pin.BIDIR,do_erc=True),
            Pin(num='188',name='PK5/LTDC_B6',func=Pin.BIDIR,do_erc=True),
            Pin(num='189',name='PK6/LTDC_B7',func=Pin.BIDIR,do_erc=True),
            Pin(num='190',name='PK7/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PJ0/LTDC_R1',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PJ1/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PJ2/LTDC_R3',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PJ3/LTDC_R4',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='PJ4/LTDC_R5',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='PJ5/LTDC_R6',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='PJ6/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='PJ7/LTDC_G0',func=Pin.BIDIR,do_erc=True),
            Pin(num='120',name='PJ8/LTDC_G1',func=Pin.BIDIR,do_erc=True),
            Pin(num='121',name='PJ9/DAC_EXTI9/LTDC_G2',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='PJ10/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='PJ11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LTDC_G4',func=Pin.BIDIR,do_erc=True),
            Pin(num='174',name='PJ12/LTDC_B0',func=Pin.BIDIR,do_erc=True),
            Pin(num='175',name='PJ13/LTDC_B1',func=Pin.BIDIR,do_erc=True),
            Pin(num='176',name='PJ14/LTDC_B2',func=Pin.BIDIR,do_erc=True),
            Pin(num='177',name='PJ15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='154',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='155',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='156',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='157',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='205',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='206',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='207',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='208',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='PI8/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PI12/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PI13/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PI14/LTDC_CLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PI15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LTDC_R0',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='33',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='46',name='PH2/ETH_CRS/FMC_SDCKE0/LTDC_R0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='PH10/DCMI_D1/FMC_D18/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='PH12/DCMI_D3/FMC_D20/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='151',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='152',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='153',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='130',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='131',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='PG6/DCMI_D12/FMC_INT2/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='178',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='179',name='PG10/DCMI_D2/FMC_NCE4_1/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='180',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/FMC_NCE4_2/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='181',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='182',name='PG13/ETH_TXD0/FMC_A24/SPI6_SCK/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='183',name='PG14/ETH_TXD1/FMC_A25/SPI6_MOSI/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='191',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='59',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='103',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='115',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='124',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='137',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='150',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='158',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='171',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='185',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='204',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='42',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='25',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='60',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='82',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='93',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='114',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='125',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='136',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='149',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='170',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='184',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='202',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='40',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F439IGHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F429/439',description='Core: ARM Cortex-M4 Package: UFBGA176 Flash: 1024KB Ram: 192KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 140',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F439IIHx'],pins=[
            Pin(num='N3',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='P2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='R2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P4',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='P3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R3',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F15',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E15',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D15',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C15',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B15',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A15',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A14',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='R5',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='R4',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R12',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='R13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='P12',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='P13',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='R14',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R15',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P5',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H15',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G15',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G14',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F14',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B14',name='DCMI_D8/I2S3_CK/LTDC_R2/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='FMC_NCE2/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P15',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P14',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='N15',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N14',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N13',name='FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M15',name='FMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='M14',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L14',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R8',name='FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P8',name='FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P9',name='DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R9',name='FMC_D7/FMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='R10',name='FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P11',name='FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R11',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PDR_ON',do_erc=True),
            Pin(num='J1',name='NRST',do_erc=True),
            Pin(num='L4',name='BYPASS_REG',do_erc=True),
            Pin(num='D6',name='BOOT0',do_erc=True),
            Pin(num='C1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='F13',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='M10',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='N1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='P1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='E14',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D14',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C14',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PI8/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='F4',name='PH2/ETH_CRS/FMC_SDCKE0/LTDC_R0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='PH10/DCMI_D1/FMC_D18/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='PH12/DCMI_D3/FMC_D20/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L15',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K15',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K14',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J15',name='PG6/DCMI_D12/FMC_INT2/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='J14',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H14',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PG10/DCMI_D2/FMC_NCE4_1/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/FMC_NCE4_2/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='PG13/ETH_TXD0/FMC_A24/SPI6_SCK/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG14/ETH_TXD1/FMC_A25/SPI6_MOSI/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='PF6/ADC3_IN4/FMC_NIORD/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='PF7/ADC3_IN5/FMC_NREG/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PF8/ADC3_IN6/FMC_NIOWR/SAI1_SCK_B/SPI5_MISO/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='PF9/ADC3_IN7/DAC_EXTI9/FMC_CD/SAI1_FS_B/SPI5_MOSI/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PF10/ADC3_IN8/DCMI_D11/FMC_INTR/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='R6',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='P6',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='R7',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P7',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='R1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F439IGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F429/439',description='Core: ARM Cortex-M4 Package: LQFP176 Flash: 1024KB Ram: 192KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 140',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F439IITx'],pins=[
            Pin(num='40',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='120',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='121',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='138',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='161',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='162',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='163',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='164',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='165',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='167',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='168',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='94',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='DCMI_D8/I2S3_CK/LTDC_R2/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='143',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='144',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='145',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='146',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='147',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='150',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='151',name='FMC_NCE2/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='FMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='169',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='170',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='FMC_D7/FMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='NRST',do_erc=True),
            Pin(num='48',name='BYPASS_REG',do_erc=True),
            Pin(num='171',name='PDR_ON',do_erc=True),
            Pin(num='166',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='81',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='125',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='173',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='174',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='175',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='176',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='PI8/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='30',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='43',name='PH2/ETH_CRS/FMC_SDCKE0/LTDC_R0',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PH10/DCMI_D1/FMC_D18/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PH12/DCMI_D3/FMC_D20/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='130',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='106',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='107',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='108',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='PG6/DCMI_D12/FMC_INT2/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='152',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='153',name='PG10/DCMI_D2/FMC_NCE4_1/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='154',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/FMC_NCE4_2/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='155',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='156',name='PG13/ETH_TXD0/FMC_A24/SPI6_SCK/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='157',name='PG14/ETH_TXD1/FMC_A25/SPI6_MOSI/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='160',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PF6/ADC3_IN4/FMC_NIORD/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PF7/ADC3_IN5/FMC_NREG/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PF8/ADC3_IN6/FMC_NIOWR/SAI1_SCK_B/SPI5_MISO/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PF9/ADC3_IN7/DAC_EXTI9/FMC_CD/SAI1_FS_B/SPI5_MOSI/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PF10/ADC3_IN8/DCMI_D11/FMC_INTR/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='82',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='91',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='103',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='114',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='127',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='136',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='149',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='159',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='172',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='90',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='102',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='113',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='126',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='135',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='148',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='158',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='37',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F439NGHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F429/439',description='Core: ARM Cortex-M4 Package: TFBGA216 Flash: 1024KB Ram: 192KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 168',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F439NIHx'],pins=[
            Pin(num='N3',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='P2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='R2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P4',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='P3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R3',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F15',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E15',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D15',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C15',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B15',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A15',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A14',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='R5',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='R4',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='P12',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='R13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K14',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='R14',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R15',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P5',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H15',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G15',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G14',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F14',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B14',name='DCMI_D8/I2S3_CK/LTDC_R2/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='FMC_NCE2/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L15',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='L14',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='K15',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='FMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R8',name='FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='N9',name='FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P9',name='DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R9',name='FMC_D7/FMC_DA7/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='R10',name='FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='R12',name='FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P11',name='FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R11',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='FMC_A0/I2C2_SDA/PF0',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='FMC_A1/I2C2_SCL/PF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='FMC_A2/I2C2_SMBA/PF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC3_IN9/FMC_A3/PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC3_IN14/FMC_A4/PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC3_IN15/FMC_A5/PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC3_IN4/FMC_NIORD/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX/PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='ADC3_IN5/FMC_NREG/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX/PF7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC3_IN6/FMC_NIOWR/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/PF8',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='ADC3_IN7/DAC_EXTI9/FMC_CD/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/PF9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='ADC3_IN8/DCMI_D11/FMC_INTR/LTDC_DE/PF10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P8',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI/PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='FMC_A6/PF12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='FMC_A7/PF13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P6',name='FMC_A8/PF14',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9/PF15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='PDR_ON',do_erc=True),
            Pin(num='J1',name='NRST',do_erc=True),
            Pin(num='L5',name='BYPASS_REG',do_erc=True),
            Pin(num='E6',name='BOOT0',do_erc=True),
            Pin(num='C1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='E11',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='L11',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='N1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='P1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='G13',name='PK0/LTDC_G5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F12',name='PK1/LTDC_G6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F13',name='PK2/LTDC_G7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PK3/LTDC_B4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PK4/LTDC_B5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PK5/LTDC_B6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PK6/LTDC_B7',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PK7/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='R6',name='PJ0/LTDC_R1',func=Pin.BIDIR,do_erc=True),
            Pin(num='R7',name='PJ1/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='P7',name='PJ2/LTDC_R3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N8',name='PJ3/LTDC_R4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PJ4/LTDC_R5',func=Pin.BIDIR,do_erc=True),
            Pin(num='M14',name='PJ5/LTDC_R6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='PJ6/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PJ7/LTDC_G0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PJ8/LTDC_G1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J13',name='PJ9/DAC_EXTI9/LTDC_G2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H13',name='PJ10/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G12',name='PJ11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LTDC_G4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PJ12/LTDC_B0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PJ13/LTDC_B1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PJ14/LTDC_B2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='PJ15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E14',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D14',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C14',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PI8/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI12/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PI13/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PI14/LTDC_CLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PI15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LTDC_R0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='K4',name='PH2/ETH_CRS/FMC_SDCKE0/LTDC_R0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='P13',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N13',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='P14',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='N14',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='P15',name='PH10/DCMI_D1/FMC_D18/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N15',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M15',name='PH12/DCMI_D3/FMC_D20/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J15',name='PG6/DCMI_D12/FMC_INT2/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='J14',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H14',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PG10/DCMI_D2/FMC_NCE4_1/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/FMC_NCE4_2/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PG13/ETH_TXD0/FMC_A24/SPI6_SCK/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PG14/ETH_TXD1/FMC_A25/SPI6_MOSI/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='R1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='L6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F439VGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F429/439',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 1024KB Ram: 192KB Frequency: 180MHz Voltage: 1.8..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F439VITx'],pins=[
            Pin(num='23',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_TX/DCMI_D5/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DCMI_D8/I2S3_CK/LTDC_R2/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='97',name='PE0/DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/DCMI_D3/FMC_NBL1/UART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/SAI1_SD_B/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/FMC_D7/FMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN1_RX/FMC_D2/FMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN1_TX/FMC_D3/FMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FMC_NCE2/FMC_NE1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FMC_D13/FMC_DA13/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FMC_D15/FMC_DA15/LTDC_B3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FMC_A18/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FMC_D0/FMC_DA0/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F439ZGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F429/439',description='Core: ARM Cortex-M4 Package: LQFP144 Flash: 1024KB Ram: 192KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F439ZITx'],pins=[
            Pin(num='34',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='DCMI_D8/I2S3_CK/LTDC_R2/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FMC_NCE2/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='143',name='PDR_ON',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='106',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='56',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/DCMI_D12/FMC_INT2/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/DCMI_D2/FMC_NCE4_1/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/FMC_NCE4_2/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/ETH_TXD0/FMC_A24/SPI6_SCK/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/ETH_TXD1/FMC_A25/SPI6_MOSI/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC3_IN4/FMC_NIORD/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC3_IN5/FMC_NREG/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC3_IN6/FMC_NIOWR/SAI1_SCK_B/SPI5_MISO/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC3_IN7/DAC_EXTI9/FMC_CD/SAI1_FS_B/SPI5_MOSI/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC3_IN8/DCMI_D11/FMC_INTR/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/DCMI_D3/FMC_NBL1/UART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/SAI1_SD_B/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/FMC_D7/FMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F439ZIYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F429/439',description='Core: ARM Cortex-M4 Package: WLCSP143 Flash: 2048KB Ram: 192KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='K9',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='N10',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='N8',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N3',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N1',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='N9',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='DCMI_D2/SDIO_D0/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='DCMI_D8/I2S3_CK/LTDC_R2/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='FMC_NCE2/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='M1',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='FMC_A17/FMC_ALE/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='FMC_A18/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='PDR_ON',do_erc=True),
            Pin(num='H9',name='NRST',do_erc=True),
            Pin(num='N11',name='BYPASS_REG',do_erc=True),
            Pin(num='C9',name='BOOT0',do_erc=True),
            Pin(num='C11',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='D1',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='L11',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='N2',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='J11',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H10',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='N6',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J1',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PG6/DCMI_D12/FMC_INT2/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PG10/DCMI_D2/FMC_NCE4_1/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/FMC_NCE4_2/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PG13/ETH_TXD0/FMC_A24/SPI6_SCK/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PG14/ETH_TXD1/FMC_A25/SPI6_MOSI/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F11',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='G11',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G10',name='PF6/ADC3_IN4/FMC_NIORD/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='PF7/ADC3_IN5/FMC_NREG/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PF8/ADC3_IN6/FMC_NIOWR/SAI1_SCK_B/SPI5_MISO/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='PF9/ADC3_IN7/DAC_EXTI9/FMC_CD/SAI1_FS_B/SPI5_MOSI/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='PF10/ADC3_IN8/DCMI_D11/FMC_INTR/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PE0/DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='PE1/DCMI_D3/FMC_NBL1/UART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PE2/ETH_TXD3/FMC_A23/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='PE3/FMC_A19/SAI1_SD_B/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='PE4/DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PE5/DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PE6/DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='PE7/FMC_D4/FMC_DA4/TIM1_ETR/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='PE8/FMC_D5/FMC_DA5/TIM1_CH1N/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='PE9/DAC_EXTI9/FMC_D6/FMC_DA6/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PE10/FMC_D7/FMC_DA7/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='PE12/FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='PE13/FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='PE14/FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L10',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F446MCYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F446',description='Core: ARM Cortex-M4 Package: WLCSP81 Flash: 256KB Ram: 128KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 63',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F446MEYx'],pins=[
            Pin(num='J9',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/RTC_AF2/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/QUADSPI_BK1_IO3/SAI2_MCLK_B/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/SAI2_SCK_B/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E6',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/SAI1_FS_A/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/I2S2_MCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='ADC1_IN7/ADC2_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SAI1_SD_B/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='CAN1_TX/SAI2_FS_B/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC1_IN8/ADC2_IN8/I2S3_SD/SDIO_D1/SPI3_MOSI/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='ADC1_IN9/ADC2_IN9/SDIO_D2/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='BOOT1/I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SDIO_CK/SPI3_MOSI/TIM2_CH4/USB_OTG_HS_ULPI_D4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='I2C2_SDA/I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2C3_SDA/I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='CAN2_RX/DCMI_D10/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='CAN2_TX/CEC/DCMI_D5/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='DCMI_VSYNC/I2C1_SDA/SPDIFRX_IN0/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='CAN1_RX/DCMI_D6/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM2_CH1/TIM2_ETR/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SAI1_FS_B/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM2_CH2/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='I2C2_SCL/I2S2_CK/SAI1_SCK_A/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SAI1_SCK_B/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='CAN2_TX/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='J1',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PDR_ON',do_erc=True),
            Pin(num='D8',name='NRST',do_erc=True),
            Pin(num='J8',name='BYPASS_REG',do_erc=True),
            Pin(num='A7',name='BOOT0',do_erc=True),
            Pin(num='B9',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='J3',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='E9',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='F9',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='D7',name='PE2/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PE3/SAI1_SD_B/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='PE4/DCMI_D4/SAI1_FS_A/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='PE7/QUADSPI_BK2_IO0/TIM1_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PE8/QUADSPI_BK2_IO1/TIM1_CH1N/UART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PE9/DAC_EXTI9/QUADSPI_BK2_IO2/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PE10/QUADSPI_BK2_IO3/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PD0/CAN1_RX/I2S3_SD/SPI3_MOSI/SPI4_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PD1/CAN1_TX/I2S2_WS/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='PD2/DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PD4/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PD6/DCMI_D10/I2S3_SD/SAI1_SD_A/SPI3_MOSI/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PD7/SPDIFRX_IN0/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMPI2C1_SMBA/QUADSPI_BK1_IO0/SAI2_SD_A/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PD12/FMPI2C1_SCL/QUADSPI_BK1_IO1/SAI2_FS_A/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PD13/FMPI2C1_SDA/QUADSPI_BK1_IO3/SAI2_SCK_A/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='PC0/ADC1_IN10/ADC2_IN10/ADC3_IN10/SAI1_MCLK_B/USB_OTG_HS_ULPI_STP',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC2/ADC1_IN12/ADC2_IN12/ADC3_IN12/SPI2_MISO/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='PC3/ADC1_IN13/ADC2_IN13/ADC3_IN13/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='PC4/ADC1_IN14/ADC2_IN14/I2S1_MCK/SPDIFRX_IN2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PC6/DCMI_D0/FMPI2C1_SCL/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC7/DCMI_D1/FMPI2C1_SDA/I2S2_CK/I2S3_MCK/SDIO_D7/SPDIFRX_IN1/SPI2_SCK/TIM3_CH2/TIM8_CH2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PC8/DCMI_D2/SDIO_D0/SYS_TRACED0/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='PC9/DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/UART5_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PC10/DCMI_D8/I2S3_CK/QUADSPI_BK1_IO1/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PC11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC12/DCMI_D9/I2C2_SDA/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PC13/RTC_AF1/SYS_WKUP1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PC15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='A8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E1',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='B1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='B7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F446RCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F446',description='Core: ARM Cortex-M4 Package: LQFP64 Flash: 256KB Ram: 128KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F446RETx'],pins=[
            Pin(num='14',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/RTC_AF2/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/QUADSPI_BK1_IO3/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/SAI1_FS_A/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/I2S2_MCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN7/ADC2_IN7/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SAI1_SD_B/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN1_TX/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/ADC2_IN8/I2S3_SD/SDIO_D1/SPI3_MOSI/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN9/ADC2_IN9/SDIO_D2/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SDIO_CK/SPI3_MOSI/TIM2_CH4/USB_OTG_HS_ULPI_D4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='I2C2_SDA/I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='I2C3_SDA/I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='CAN2_RX/DCMI_D10/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='CAN2_TX/CEC/DCMI_D5/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='DCMI_VSYNC/I2C1_SDA/SPDIFRX_IN0/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN1_RX/DCMI_D6/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM2_CH1/TIM2_ETR/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SAI1_FS_B/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM2_CH2/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/I2S2_CK/SAI1_SCK_A/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SAI1_SCK_B/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='CAN2_TX/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN10/ADC2_IN10/ADC3_IN10/SAI1_MCLK_B/USB_OTG_HS_ULPI_STP',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN11/ADC2_IN11/ADC3_IN11/I2S2_SD/I2S3_SD/SAI1_SD_A/SPI2_MOSI/SPI3_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN12/ADC2_IN12/ADC3_IN12/SPI2_MISO/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN13/ADC2_IN13/ADC3_IN13/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN14/ADC2_IN14/I2S1_MCK/SPDIFRX_IN2',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN15/ADC2_IN15/SPDIFRX_IN3/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/DCMI_D0/FMPI2C1_SCL/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/DCMI_D1/FMPI2C1_SDA/I2S2_CK/I2S3_MCK/SDIO_D7/SPDIFRX_IN1/SPI2_SCK/TIM3_CH2/TIM8_CH2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/DCMI_D2/SDIO_D0/SYS_TRACED0/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/UART5_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/DCMI_D8/I2S3_CK/QUADSPI_BK1_IO1/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/DCMI_D9/I2C2_SDA/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_AF1/SYS_WKUP1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F446VCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F446',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 256KB Ram: 128KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 81',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F446VETx'],pins=[
            Pin(num='23',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/RTC_AF2/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/QUADSPI_BK1_IO3/SAI2_MCLK_B/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/SAI2_SCK_B/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/SAI1_FS_A/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/I2S2_MCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN7/ADC2_IN7/FMC_SDNWE/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SAI1_SD_B/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN1_TX/SAI2_FS_B/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN8/ADC2_IN8/I2S3_SD/SDIO_D1/SPI3_MOSI/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN9/ADC2_IN9/SDIO_D2/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SDIO_CK/SPI3_MOSI/TIM2_CH4/USB_OTG_HS_ULPI_D4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2C2_SDA/I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2C3_SDA/I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='CAN2_RX/DCMI_D10/FMC_SDCKE1/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_TX/CEC/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/SPDIFRX_IN0/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN1_RX/DCMI_D6/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM2_CH1/TIM2_ETR/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SAI1_FS_B/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM2_CH2/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/I2S2_CK/SAI1_SCK_A/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SAI1_SCK_B/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='CAN2_TX/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/SAI1_MCLK_B/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/I2S2_SD/I2S3_SD/SAI1_SD_A/SPI2_MOSI/SPI3_MOSI/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/FMC_SDNE0/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN14/ADC2_IN14/FMC_SDNE0/I2S1_MCK/SPDIFRX_IN2/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN15/ADC2_IN15/FMC_SDCKE0/SPDIFRX_IN3/USART3_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='DCMI_D0/FMPI2C1_SCL/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='DCMI_D1/FMPI2C1_SDA/I2S2_CK/I2S3_MCK/SDIO_D7/SPDIFRX_IN1/SPI2_SCK/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='DCMI_D2/SDIO_D0/SYS_TRACED0/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/UART5_CTS/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DCMI_D8/I2S3_CK/QUADSPI_BK1_IO1/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='DCMI_D9/I2C2_SDA/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_AF1/SYS_WKUP1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='97',name='PE0/DCMI_D2/FMC_NBL0/SAI2_MCLK_A/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/DCMI_D3/FMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/SAI1_SD_B/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FMC_A20/SAI1_FS_A/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FMC_A21/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FMC_A22/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/SAI2_SD_B/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/FMC_D9/FMC_DA9/SAI2_SCK_B/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/FMC_D10/FMC_DA10/SAI2_FS_B/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FMC_D11/FMC_DA11/SAI2_MCLK_B/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN1_RX/FMC_D2/FMC_DA2/I2S3_SD/SPI3_MOSI/SPI4_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN1_TX/FMC_D3/FMC_DA3/I2S2_WS/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/DCMI_D5/FMC_CLK/I2S2_CK/QUADSPI_CLK/SPI2_SCK/SYS_TRACED1/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/DCMI_D10/FMC_NWAIT/I2S3_SD/SAI1_SD_A/SPI3_MOSI/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FMC_NE1/SPDIFRX_IN0/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FMC_D13/FMC_DA13/SPDIFRX_IN1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FMC_D15/FMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMPI2C1_SMBA/QUADSPI_BK1_IO0/SAI2_SD_A/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FMC_A17/FMPI2C1_SCL/QUADSPI_BK1_IO1/SAI2_FS_A/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FMC_A18/FMPI2C1_SDA/QUADSPI_BK1_IO3/SAI2_SCK_A/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FMC_D0/FMC_DA0/FMPI2C1_SCL/SAI2_SCK_A/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/FMPI2C1_SDA/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F446ZCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F446',description='Core: ARM Cortex-M4 Package: LQFP144 Flash: 256KB Ram: 128KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F446ZETx'],pins=[
            Pin(num='34',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/RTC_AF2/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/QUADSPI_BK1_IO3/SAI2_MCLK_B/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/SAI2_SCK_B/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/SAI1_FS_A/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/I2S2_MCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN7/ADC2_IN7/FMC_SDNWE/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SAI1_SD_B/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN1_TX/SAI2_FS_B/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN8/ADC2_IN8/I2S3_SD/SDIO_D1/SPI3_MOSI/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN9/ADC2_IN9/SDIO_D2/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SDIO_CK/SPI3_MOSI/TIM2_CH4/USB_OTG_HS_ULPI_D4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='I2C2_SDA/I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='I2C3_SDA/I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='CAN2_RX/DCMI_D10/FMC_SDCKE1/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='CAN2_TX/CEC/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/SPDIFRX_IN0/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CAN1_RX/DCMI_D6/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM2_CH1/TIM2_ETR/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SAI1_FS_B/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM2_CH2/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C2_SCL/I2S2_CK/SAI1_SCK_A/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2C2_SDA/SAI2_SD_A/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SAI1_SCK_B/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='CAN2_TX/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/SAI1_MCLK_B/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/I2S2_SD/I2S3_SD/SAI1_SD_A/SPI2_MOSI/SPI3_MOSI/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/FMC_SDNE0/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN14/ADC2_IN14/FMC_SDNE0/I2S1_MCK/SPDIFRX_IN2/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN15/ADC2_IN15/FMC_SDCKE0/SPDIFRX_IN3/USART3_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DCMI_D0/FMPI2C1_SCL/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DCMI_D1/FMPI2C1_SDA/I2S2_CK/I2S3_MCK/SDIO_D7/SPDIFRX_IN1/SPI2_SCK/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='DCMI_D2/SDIO_D0/SYS_TRACED0/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/UART5_CTS/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='DCMI_D8/I2S3_CK/QUADSPI_BK1_IO1/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='DCMI_D9/I2C2_SDA/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_AF1/SYS_WKUP1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='CAN1_RX/FMC_D2/FMC_DA2/I2S3_SD/SPI3_MOSI/SPI4_MISO/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CAN1_TX/FMC_D3/FMC_DA3/I2S2_WS/SPI2_NSS/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='DCMI_D5/FMC_CLK/I2S2_CK/QUADSPI_CLK/SPI2_SCK/SYS_TRACED1/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='DCMI_D10/FMC_NWAIT/I2S3_SD/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FMC_NE1/SPDIFRX_IN0/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FMC_D13/FMC_DA13/SPDIFRX_IN1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FMC_D15/FMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/FMPI2C1_SMBA/QUADSPI_BK1_IO0/SAI2_SD_A/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FMC_A17/FMC_ALE/FMPI2C1_SCL/QUADSPI_BK1_IO1/SAI2_FS_A/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FMC_A18/FMPI2C1_SDA/QUADSPI_BK1_IO3/SAI2_SCK_A/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FMC_D0/FMC_DA0/FMPI2C1_SCL/SAI2_SCK_A/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/FMPI2C1_SDA/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='143',name='PDR_ON',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='106',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='56',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/DCMI_D12/QUADSPI_BK1_NCS',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/DCMI_D13/FMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8/FMC_SDCLK/SPDIFRX_IN2/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/SAI2_FS_B/SPDIFRX_IN3/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/DCMI_D2/FMC_NE3/SAI2_SD_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/SPDIFRX_IN0/SPI4_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FMC_NE4/SPDIFRX_IN1/SPI4_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/FMC_A24/SPI4_MOSI/SYS_TRACED2/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/FMC_A25/QUADSPI_BK2_IO3/SPI4_NSS/SYS_TRACED3/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/TIM10_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC3_IN8/DCMI_D11',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SAI2_SD_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FMC_A7/FMPI2C1_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FMC_A8/FMPI2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9/FMPI2C1_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/DCMI_D2/FMC_NBL0/SAI2_MCLK_A/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/DCMI_D3/FMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/SAI1_SD_B/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FMC_A20/SAI1_FS_A/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FMC_A21/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FMC_A22/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/SAI2_SD_B/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FMC_D9/FMC_DA9/SAI2_SCK_B/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FMC_D10/FMC_DA10/SAI2_FS_B/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FMC_D11/FMC_DA11/SAI2_MCLK_B/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F446ZEHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F446',description='Core: ARM Cortex-M4 Package: UFBGA144 Flash: 512KB Ram: 128KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='J2',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/RTC_AF2/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/QUADSPI_BK1_IO3/SAI2_MCLK_B/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/SAI2_SCK_B/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/SAI1_FS_A/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/I2S2_MCK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN7/ADC2_IN7/FMC_SDNWE/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SAI1_SD_B/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN1_TX/SAI2_FS_B/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC1_IN8/ADC2_IN8/I2S3_SD/SDIO_D1/SPI3_MOSI/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN9/ADC2_IN9/SDIO_D2/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='BOOT1/I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SDIO_CK/SPI3_MOSI/TIM2_CH4/USB_OTG_HS_ULPI_D4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='I2C2_SDA/I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='I2C3_SDA/I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN2_RX/DCMI_D10/FMC_SDCKE1/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='CAN2_TX/CEC/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/SPDIFRX_IN0/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='CAN1_RX/DCMI_D6/I2C1_SCL/SDIO_D4/TIM10_CH1/TIM2_CH1/TIM2_ETR/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SAI1_FS_B/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM2_CH2/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='I2C2_SCL/I2S2_CK/SAI1_SCK_A/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/I2C2_SDA/SAI2_SD_A/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SAI1_SCK_B/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='CAN2_TX/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/SAI1_MCLK_B/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/I2S2_SD/I2S3_SD/SAI1_SD_A/SPI2_MOSI/SPI3_MOSI/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/FMC_SDNE0/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC1_IN14/ADC2_IN14/FMC_SDNE0/I2S1_MCK/SPDIFRX_IN2/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC1_IN15/ADC2_IN15/FMC_SDCKE0/SPDIFRX_IN3/USART3_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G12',name='DCMI_D0/FMPI2C1_SCL/I2S2_MCK/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F12',name='DCMI_D1/FMPI2C1_SDA/I2S2_CK/I2S3_MCK/SDIO_D7/SPDIFRX_IN1/SPI2_SCK/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F11',name='DCMI_D2/SDIO_D0/SYS_TRACED0/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/UART5_CTS/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='DCMI_D8/I2S3_CK/QUADSPI_BK1_IO1/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='DCMI_D9/I2C2_SDA/I2S3_SD/SDIO_CK/SPI3_MOSI/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='RTC_AF1/SYS_WKUP1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='CAN1_RX/FMC_D2/FMC_DA2/I2S3_SD/SPI3_MOSI/SPI4_MISO/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='CAN1_TX/FMC_D3/FMC_DA3/I2S2_WS/SPI2_NSS/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='DCMI_D11/SDIO_CMD/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='DCMI_D5/FMC_CLK/I2S2_CK/QUADSPI_CLK/SPI2_SCK/SYS_TRACED1/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='DCMI_D10/FMC_NWAIT/I2S3_SD/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='FMC_NE1/SPDIFRX_IN0/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='FMC_D13/FMC_DA13/SPDIFRX_IN1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='FMC_D15/FMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/FMPI2C1_SMBA/QUADSPI_BK1_IO0/SAI2_SD_A/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='FMC_A17/FMC_ALE/FMPI2C1_SCL/QUADSPI_BK1_IO1/SAI2_FS_A/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='FMC_A18/FMPI2C1_SDA/QUADSPI_BK1_IO3/SAI2_SCK_A/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='FMC_D0/FMC_DA0/FMPI2C1_SCL/SAI2_SCK_A/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/FMPI2C1_SDA/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='PDR_ON',do_erc=True),
            Pin(num='F1',name='NRST',do_erc=True),
            Pin(num='H5',name='BYPASS_REG',do_erc=True),
            Pin(num='D5',name='BOOT0',do_erc=True),
            Pin(num='C2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='D1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='E1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='K6',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PG6/DCMI_D12/QUADSPI_BK1_NCS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PG7/DCMI_D13/FMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G11',name='PG8/FMC_SDCLK/SPDIFRX_IN2/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/SAI2_FS_B/SPDIFRX_IN3/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PG10/DCMI_D2/FMC_NE3/SAI2_SD_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/SPDIFRX_IN0/SPI4_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PG12/FMC_NE4/SPDIFRX_IN1/SPI4_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PG13/FMC_A24/SPI4_MOSI/SYS_TRACED2/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG14/FMC_A25/QUADSPI_BK2_IO3/SPI4_NSS/SYS_TRACED3/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PF6/ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/TIM10_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PF7/ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PF8/ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PF9/ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PF10/ADC3_IN8/DCMI_D11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SAI2_SD_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='PF13/FMC_A7/FMPI2C1_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='PF14/FMC_A8/FMPI2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9/FMPI2C1_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PE0/DCMI_D2/FMC_NBL0/SAI2_MCLK_A/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PE1/DCMI_D3/FMC_NBL1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PE2/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE3/FMC_A19/SAI1_SD_B/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE4/DCMI_D4/FMC_A20/SAI1_FS_A/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PE5/DCMI_D6/FMC_A21/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PE6/DCMI_D7/FMC_A22/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='PE9/DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='PE10/FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/SAI2_SD_B/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='PE12/FMC_D9/FMC_DA9/SAI2_SCK_B/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PE13/FMC_D10/FMC_DA10/SAI2_FS_B/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE14/FMC_D11/FMC_DA11/SAI2_MCLK_B/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='C11',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='D2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F469AEHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F469/479',description='Core: ARM Cortex-M4 Package: UFBGA169 Flash: 512KB Ram: 320KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 128',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F469AGHx', 'STM32F469AIHx'],pins=[
            Pin(num='J5',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/LTDC_R2/QUADSPI_BK1_IO3/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/LTDC_R1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/LTDC_B2/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='N3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC1_IN7/ADC2_IN7/FMC_SDNWE/QUADSPI_CLK/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='A13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN8/ADC2_IN8/LTDC_G1/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC1_IN9/ADC2_IN9/LTDC_G0/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='CAN2_RX/DCMI_D10/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/LTDC_G7/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='CAN1_RX/DCMI_D6/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='I2C2_SCL/I2S2_CK/LTDC_G4/QUADSPI_BK1_NCS/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N8',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DSIHOST_TE/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N10',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='CAN2_TX/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='N13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M1',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N1',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/I2S2_SD/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='DCMI_D2/SDIO_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='G10',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/QUADSPI_BK2_NCS/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='DCMI_D11/SDIO_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/QUADSPI_BK1_IO0/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='FMC_A17/FMC_ALE/QUADSPI_BK1_IO1/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='FMC_A18/QUADSPI_BK1_IO3/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PDR_ON',do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A5',name='BOOT0',do_erc=True),
            Pin(num='D12',name='VCAP2',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='K12',name='VCAPDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='N9',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='DSIHOST_D1P/DSIHOST_D1P',func=Pin.BIDIR,do_erc=True),
            Pin(num='G13',name='DSIHOST_D1N/DSIHOST_D1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='DSIHOST_CKP/DSIHOST_CKP',func=Pin.BIDIR,do_erc=True),
            Pin(num='H13',name='DSIHOST_CKN/DSIHOST_CKN',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='DSIHOST_D0P/DSIHOST_D0P',func=Pin.BIDIR,do_erc=True),
            Pin(num='J13',name='DSIHOST_D0N/DSIHOST_D0N',func=Pin.BIDIR,do_erc=True),
            Pin(num='B13',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PI10/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LTDC_G6/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='L2',name='PH2/FMC_SDCKE0/LTDC_R0/QUADSPI_BK2_IO0',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PH3/FMC_SDNE0/LTDC_R1/QUADSPI_BK2_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='PH4/I2C2_SCL/LTDC_G4/LTDC_G5/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PH5/FMC_SDNWE/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='PH10/DCMI_D1/FMC_D18/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PH12/DCMI_D3/FMC_D20/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='F13',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='F12',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F11',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/SAI1_MCLK_A/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PG8/FMC_SDCLK/LTDC_G7/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E6',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PG13/FMC_A24/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='PF10/ADC3_IN8/DCMI_D11/LTDC_DE/QUADSPI_CLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J11',name='VDD12DSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='J3',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='K13',name='VDDDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='D11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J2',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='H11',name='VSSDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='K11',name='VSSDSI',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F469AEYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F469/479',description='Core: ARM Cortex-M4 Package: WLCSP168 Flash: 512KB Ram: 320KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 128',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F469AGYx', 'STM32F469AIYx'],pins=[
            Pin(num='L10',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/LTDC_R2/QUADSPI_BK1_IO3/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/LTDC_R1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='N10',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/LTDC_B2/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='P11',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='ADC1_IN7/ADC2_IN7/FMC_SDNWE/QUADSPI_CLK/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='P10',name='ADC1_IN8/ADC2_IN8/LTDC_G1/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N9',name='ADC1_IN9/ADC2_IN9/LTDC_G0/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='P9',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='CAN2_RX/DCMI_D10/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/LTDC_G7/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='CAN1_RX/DCMI_D6/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='I2C2_SCL/I2S2_CK/LTDC_G4/QUADSPI_BK1_NCS/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DSIHOST_TE/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='CAN2_TX/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P1',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/I2S2_SD/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='DCMI_D2/SDIO_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/QUADSPI_BK2_NCS/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E6',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='DCMI_D11/SDIO_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='N1',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/QUADSPI_BK1_IO0/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='FMC_A17/FMC_ALE/QUADSPI_BK1_IO1/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='FMC_A18/QUADSPI_BK1_IO3/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='P6',name='FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='P5',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PDR_ON',do_erc=True),
            Pin(num='H9',name='NRST',do_erc=True),
            Pin(num='F8',name='BOOT0',do_erc=True),
            Pin(num='C12',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='D2',name='VCAP2',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VCAPDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='N4',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='H2',name='DSIHOST_D1N/DSIHOST_D1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='DSIHOST_D1P/DSIHOST_D1P',func=Pin.BIDIR,do_erc=True),
            Pin(num='J1',name='DSIHOST_CKP/DSIHOST_CKP',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='DSIHOST_CKN/DSIHOST_CKN',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='DSIHOST_D0N/DSIHOST_D0N',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='DSIHOST_D0P/DSIHOST_D0P',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='PI10/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='F11',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LTDC_G6/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='K12',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='M11',name='PH2/FMC_SDCKE0/LTDC_R0/QUADSPI_BK2_IO0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='PH3/FMC_SDNE0/LTDC_R1/QUADSPI_BK2_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PH4/I2C2_SCL/LTDC_G4/LTDC_G5/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PH5/FMC_SDNWE/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='PH10/DCMI_D1/FMC_D18/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N3',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='P2',name='PH12/DCMI_D3/FMC_D20/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/SAI1_MCLK_A/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='PG8/FMC_SDCLK/LTDC_G7/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PG13/FMC_A24/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='G10',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='G12',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='PF10/ADC3_IN8/DCMI_D11/LTDC_DE/QUADSPI_CLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='A11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='B5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='P3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='P8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='P12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K2',name='VDD12DSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='M12',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VDDDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='A4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='B7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='B10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='N8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='N11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='P4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='L11',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VSSDSI',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F469BETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F469/479',description='Core: ARM Cortex-M4 Package: LQFP208 Flash: 512KB Ram: 320KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 159',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F469BGTx', 'STM32F469BITx'],pins=[
            Pin(num='43',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/LTDC_R2/QUADSPI_BK1_IO3/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/LTDC_R1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B2/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/QUADSPI_CLK/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='143',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='144',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='145',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='146',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='147',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='159',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='160',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_G1/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_G0/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='192',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='193',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='194',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/LTDC_G7/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='195',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='196',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='198',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='199',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/QUADSPI_BK1_NCS/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DSIHOST_TE/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='106',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='107',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='138',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='DCMI_D2/SDIO_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='161',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='162',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/QUADSPI_BK2_NCS/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='163',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='164',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='165',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='166',name='DCMI_D11/SDIO_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='167',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='168',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='169',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='172',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='173',name='FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='108',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/QUADSPI_BK1_IO0/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='FMC_A17/FMC_ALE/QUADSPI_BK1_IO1/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='FMC_A18/QUADSPI_BK1_IO3/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='200',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='201',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='FMC_A0/I2C2_SDA/PF0',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='FMC_A1/I2C2_SCL/PF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='FMC_A2/I2C2_SMBA/PF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC3_IN9/FMC_A3/PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC3_IN14/FMC_A4/PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC3_IN15/FMC_A5/PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX/PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX/PF7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/PF8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/PF9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC3_IN8/DCMI_D11/LTDC_DE/QUADSPI_CLK/PF10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI/PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='FMC_A6/PF12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='FMC_A7/PF13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='FMC_A8/PF14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9/PF15',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='NRST',do_erc=True),
            Pin(num='203',name='PDR_ON',do_erc=True),
            Pin(num='197',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='41',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='92',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='119',name='VCAPDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='148',name='VCAP2',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='DSIHOST_D0P/DSIHOST_D0P',func=Pin.BIDIR,do_erc=True),
            Pin(num='121',name='DSIHOST_D0N/DSIHOST_D0N',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='DSIHOST_CKP/DSIHOST_CKP',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='DSIHOST_CKN/DSIHOST_CKN',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='DSIHOST_D1P/DSIHOST_D1P',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='DSIHOST_D1N/DSIHOST_D1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='186',name='PK3/LTDC_B4',func=Pin.BIDIR,do_erc=True),
            Pin(num='187',name='PK4/LTDC_B5',func=Pin.BIDIR,do_erc=True),
            Pin(num='188',name='PK5/LTDC_B6',func=Pin.BIDIR,do_erc=True),
            Pin(num='189',name='PK6/LTDC_B7',func=Pin.BIDIR,do_erc=True),
            Pin(num='190',name='PK7/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PJ0/LTDC_R1/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PJ1/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PJ2/DSIHOST_TE/LTDC_R3',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PJ3/LTDC_R4',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='PJ4/LTDC_R5',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='PJ5/LTDC_R6',func=Pin.BIDIR,do_erc=True),
            Pin(num='174',name='PJ12/LTDC_B0/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='175',name='PJ13/LTDC_B1/LTDC_G4',func=Pin.BIDIR,do_erc=True),
            Pin(num='176',name='PJ14/LTDC_B2',func=Pin.BIDIR,do_erc=True),
            Pin(num='177',name='PJ15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='154',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='155',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='156',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='157',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='205',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='206',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='207',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='208',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='PI8/RTC_AF1/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LTDC_G6/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PI12/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PI13/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PI14/LTDC_CLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PI15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LTDC_G2/LTDC_R0',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='33',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='46',name='PH2/ETH_CRS/FMC_SDCKE0/LTDC_R0/QUADSPI_BK2_IO0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1/QUADSPI_BK2_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='PH4/I2C2_SCL/LTDC_G4/LTDC_G5/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='PH10/DCMI_D1/FMC_D18/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='PH12/DCMI_D3/FMC_D20/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='151',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='152',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='153',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='130',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='131',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/SAI1_MCLK_A/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='PG8/ETH_PPS_OUT/FMC_SDCLK/LTDC_G7/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='178',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='179',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='180',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='181',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='182',name='PG13/ETH_TXD0/FMC_A24/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='183',name='PG14/ETH_TXD1/FMC_A25/LTDC_B0/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='191',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='59',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='103',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='115',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='150',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='158',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='171',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='185',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='204',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='125',name='VDD12DSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='42',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='118',name='VDDDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='137',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='25',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='60',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='82',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='93',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='114',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='136',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='149',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='170',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='184',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='202',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='40',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='122',name='VSSDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='128',name='VSSDSI',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F469IETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F469/479',description='Core: ARM Cortex-M4 Package: LQFP176 Flash: 512KB Ram: 320KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 131',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F469IGTx', 'STM32F469IITx'],pins=[
            Pin(num='40',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/LTDC_R2/QUADSPI_BK1_IO3/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/LTDC_R1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B2/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/QUADSPI_CLK/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='138',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_G1/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_G0/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='161',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='162',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='163',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/LTDC_G7/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='164',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='165',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='167',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='168',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/QUADSPI_BK1_NCS/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DSIHOST_TE/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='120',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='121',name='DCMI_D2/SDIO_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/QUADSPI_BK2_NCS/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='143',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='144',name='DCMI_D11/SDIO_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='145',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='146',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='147',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='150',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='151',name='FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/QUADSPI_BK1_IO0/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='FMC_A17/FMC_ALE/QUADSPI_BK1_IO1/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='94',name='FMC_A18/QUADSPI_BK1_IO3/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='169',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='170',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='NRST',do_erc=True),
            Pin(num='48',name='BYPASS_REG',do_erc=True),
            Pin(num='171',name='PDR_ON',do_erc=True),
            Pin(num='166',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='81',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VCAPDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='129',name='VCAP2',func=Pin.PWRIN,do_erc=True),
            Pin(num='101',name='DSIHOST_D0P/DSIHOST_D0P',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='DSIHOST_D0N/DSIHOST_D0N',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='DSIHOST_CKP/DSIHOST_CKP',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='DSIHOST_CKN/DSIHOST_CKN',func=Pin.BIDIR,do_erc=True),
            Pin(num='107',name='DSIHOST_D1P/DSIHOST_D1P',func=Pin.BIDIR,do_erc=True),
            Pin(num='108',name='DSIHOST_D1N/DSIHOST_D1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='173',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='174',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='175',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='176',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='PI8/RTC_AF1/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LTDC_G6/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='30',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='43',name='PH2/ETH_CRS/FMC_SDCKE0/LTDC_R0/QUADSPI_BK2_IO0',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1/QUADSPI_BK2_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PH4/I2C2_SCL/LTDC_G4/LTDC_G5/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/SAI1_MCLK_A/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='PG8/ETH_PPS_OUT/FMC_SDCLK/LTDC_G7/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='152',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='153',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='154',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='155',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='156',name='PG13/ETH_TXD0/FMC_A24/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='157',name='PG14/ETH_TXD1/FMC_A25/LTDC_B0/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='160',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PF6/ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PF7/ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PF8/ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PF9/ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PF10/ADC3_IN8/DCMI_D11/LTDC_DE/QUADSPI_CLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='82',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='96',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='136',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='149',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='159',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='172',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='106',name='VDD12DSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VDDDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='118',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='117',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='135',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='148',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='158',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='37',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='103',name='VSSDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='109',name='VSSDSI',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F469IGHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F469/479',description='Core: ARM Cortex-M4 Package: UFBGA176 Flash: 1024KB Ram: 320KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 131',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F469IIHx'],pins=[
            Pin(num='N3',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/LTDC_R2/QUADSPI_BK1_IO3/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='P2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/LTDC_R1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='R2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B2/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P4',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='P3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R3',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/QUADSPI_CLK/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F15',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E15',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D15',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C15',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B15',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A15',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A14',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='R5',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_G1/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='R4',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_G0/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/LTDC_G7/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R12',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/QUADSPI_BK1_NCS/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='R13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DSIHOST_TE/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='P12',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='P13',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='R14',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R15',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P5',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H15',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G15',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G14',name='DCMI_D2/SDIO_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F14',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B14',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/QUADSPI_BK2_NCS/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DCMI_D11/SDIO_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P15',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P14',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='N15',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N14',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/QUADSPI_BK1_IO0/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N13',name='FMC_A17/FMC_ALE/QUADSPI_BK1_IO1/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M15',name='FMC_A18/QUADSPI_BK1_IO3/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='M14',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L14',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R8',name='FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P8',name='FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P9',name='DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R9',name='FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='R10',name='FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P11',name='FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R11',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PDR_ON',do_erc=True),
            Pin(num='J1',name='NRST',do_erc=True),
            Pin(num='L4',name='BYPASS_REG',do_erc=True),
            Pin(num='D6',name='BOOT0',do_erc=True),
            Pin(num='C1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='F13',name='VCAP2',func=Pin.PWRIN,do_erc=True),
            Pin(num='K12',name='VCAPDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='M10',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='N1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='P1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C14',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='E12',name='DSIHOST_D1P/DSIHOST_D1P',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='DSIHOST_D1N/DSIHOST_D1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='DSIHOST_CKP/DSIHOST_CKP',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='DSIHOST_CKN/DSIHOST_CKN',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='DSIHOST_D0P/DSIHOST_D0P',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='DSIHOST_D0N/DSIHOST_D0N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E14',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D14',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PI8/RTC_AF1/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LTDC_G6/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='F4',name='PH2/ETH_CRS/FMC_SDCKE0/LTDC_R0/QUADSPI_BK2_IO0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1/QUADSPI_BK2_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PH4/I2C2_SCL/LTDC_G4/LTDC_G5/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L15',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K15',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K14',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J15',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='J14',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/SAI1_MCLK_A/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H14',name='PG8/ETH_PPS_OUT/FMC_SDCLK/LTDC_G7/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='PG13/ETH_TXD0/FMC_A24/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG14/ETH_TXD1/FMC_A25/LTDC_B0/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='PF6/ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='PF7/ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PF8/ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='PF9/ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PF10/ADC3_IN8/DCMI_D11/LTDC_DE/QUADSPI_CLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='R6',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='P6',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='R7',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P7',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D13',name='VDD12DSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='R1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='J12',name='VDDDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='H13',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='H12',name='VSSDSI',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F469NEHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F469/479',description='Core: ARM Cortex-M4 Package: TFBGA216 Flash: 512KB Ram: 320KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 159',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F469NGHx', 'STM32F469NIHx'],pins=[
            Pin(num='N3',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/LTDC_R2/QUADSPI_BK1_IO3/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='P2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/LTDC_R1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='R2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B2/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P4',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='P3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R3',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/QUADSPI_CLK/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F15',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E15',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D15',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C15',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B15',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A15',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A14',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='R5',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_G1/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='R4',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_G0/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/LTDC_G7/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='P12',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/QUADSPI_BK1_NCS/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='R13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DSIHOST_TE/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K14',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='R14',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R15',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P5',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H15',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G15',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G14',name='DCMI_D2/SDIO_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F14',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B14',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/QUADSPI_BK2_NCS/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DCMI_D11/SDIO_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L15',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='L14',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='K15',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/QUADSPI_BK1_IO0/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='FMC_A17/FMC_ALE/QUADSPI_BK1_IO1/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='FMC_A18/QUADSPI_BK1_IO3/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R8',name='FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='N9',name='FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P9',name='DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R9',name='FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='R10',name='FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='R12',name='FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P11',name='FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R11',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='FMC_A0/I2C2_SDA/PF0',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='FMC_A1/I2C2_SCL/PF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='FMC_A2/I2C2_SMBA/PF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC3_IN9/FMC_A3/PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC3_IN14/FMC_A4/PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC3_IN15/FMC_A5/PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX/PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX/PF7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/PF8',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/PF9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='ADC3_IN8/DCMI_D11/LTDC_DE/QUADSPI_CLK/PF10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P8',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI/PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='FMC_A6/PF12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='FMC_A7/PF13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P6',name='FMC_A8/PF14',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9/PF15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='PDR_ON',do_erc=True),
            Pin(num='J1',name='NRST',do_erc=True),
            Pin(num='L5',name='BYPASS_REG',do_erc=True),
            Pin(num='E6',name='BOOT0',do_erc=True),
            Pin(num='C1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='E11',name='VCAP2',func=Pin.PWRIN,do_erc=True),
            Pin(num='K12',name='VCAPDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='L11',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='N1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='P1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='DSIHOST_D1P/DSIHOST_D1P',func=Pin.BIDIR,do_erc=True),
            Pin(num='F13',name='DSIHOST_D1N/DSIHOST_D1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='DSIHOST_CKP/DSIHOST_CKP',func=Pin.BIDIR,do_erc=True),
            Pin(num='H13',name='DSIHOST_CKN/DSIHOST_CKN',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='DSIHOST_D0P/DSIHOST_D0P',func=Pin.BIDIR,do_erc=True),
            Pin(num='J13',name='DSIHOST_D0N/DSIHOST_D0N',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PK3/LTDC_B4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PK4/LTDC_B5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PK5/LTDC_B6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PK6/LTDC_B7',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PK7/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='R6',name='PJ0/LTDC_R1/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='R7',name='PJ1/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='P7',name='PJ2/DSIHOST_TE/LTDC_R3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N8',name='PJ3/LTDC_R4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PJ4/LTDC_R5',func=Pin.BIDIR,do_erc=True),
            Pin(num='M14',name='PJ5/LTDC_R6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PJ12/LTDC_B0/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PJ13/LTDC_B1/LTDC_G4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PJ14/LTDC_B2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='PJ15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E14',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D14',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C14',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PI8/RTC_AF1/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LTDC_G6/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI12/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PI13/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PI14/LTDC_CLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PI15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LTDC_G2/LTDC_R0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='K4',name='PH2/ETH_CRS/FMC_SDCKE0/LTDC_R0/QUADSPI_BK2_IO0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1/QUADSPI_BK2_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PH4/I2C2_SCL/LTDC_G4/LTDC_G5/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='P13',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N13',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='P14',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='N14',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='P15',name='PH10/DCMI_D1/FMC_D18/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N15',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M15',name='PH12/DCMI_D3/FMC_D20/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J15',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='J14',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/SAI1_MCLK_A/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H14',name='PG8/ETH_PPS_OUT/FMC_SDCLK/LTDC_G7/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PG13/ETH_TXD0/FMC_A24/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PG14/ETH_TXD1/FMC_A25/LTDC_B0/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G13',name='VDD12DSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='R1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='H11',name='VDDDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='L6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VSSDSI',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F479AGHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F469/479',description='Core: ARM Cortex-M4 Package: UFBGA169 Flash: 1024KB Ram: 320KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 128',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F479AIHx'],pins=[
            Pin(num='J5',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/LTDC_R2/QUADSPI_BK1_IO3/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/LTDC_R1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/LTDC_B2/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='N3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC1_IN7/ADC2_IN7/FMC_SDNWE/QUADSPI_CLK/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='A13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN8/ADC2_IN8/LTDC_G1/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC1_IN9/ADC2_IN9/LTDC_G0/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='CAN2_RX/DCMI_D10/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/LTDC_G7/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='CAN1_RX/DCMI_D6/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='I2C2_SCL/I2S2_CK/LTDC_G4/QUADSPI_BK1_NCS/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N8',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DSIHOST_TE/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N10',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='CAN2_TX/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='N13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M1',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N1',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/I2S2_SD/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='DCMI_D2/SDIO_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='G10',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/QUADSPI_BK2_NCS/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='DCMI_D11/SDIO_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/QUADSPI_BK1_IO0/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='FMC_A17/FMC_ALE/QUADSPI_BK1_IO1/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='FMC_A18/QUADSPI_BK1_IO3/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PDR_ON',do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A5',name='BOOT0',do_erc=True),
            Pin(num='D12',name='VCAP2',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='K12',name='VCAPDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='N9',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='DSIHOST_D1P/DSIHOST_D1P',func=Pin.BIDIR,do_erc=True),
            Pin(num='G13',name='DSIHOST_D1N/DSIHOST_D1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='DSIHOST_CKP/DSIHOST_CKP',func=Pin.BIDIR,do_erc=True),
            Pin(num='H13',name='DSIHOST_CKN/DSIHOST_CKN',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='DSIHOST_D0P/DSIHOST_D0P',func=Pin.BIDIR,do_erc=True),
            Pin(num='J13',name='DSIHOST_D0N/DSIHOST_D0N',func=Pin.BIDIR,do_erc=True),
            Pin(num='B13',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PI10/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LTDC_G6/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='L2',name='PH2/FMC_SDCKE0/LTDC_R0/QUADSPI_BK2_IO0',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PH3/FMC_SDNE0/LTDC_R1/QUADSPI_BK2_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='PH4/I2C2_SCL/LTDC_G4/LTDC_G5/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PH5/FMC_SDNWE/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='PH10/DCMI_D1/FMC_D18/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PH12/DCMI_D3/FMC_D20/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='F13',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='F12',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F11',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/SAI1_MCLK_A/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PG8/FMC_SDCLK/LTDC_G7/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E6',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PG13/FMC_A24/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='PF10/ADC3_IN8/DCMI_D11/LTDC_DE/QUADSPI_CLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J11',name='VDD12DSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='J3',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='K13',name='VDDDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='D11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J2',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='H11',name='VSSDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='K11',name='VSSDSI',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F479AGYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F469/479',description='Core: ARM Cortex-M4 Package: WLCSP168 Flash: 1024KB Ram: 320KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 128',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F479AIYx'],pins=[
            Pin(num='L10',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/LTDC_R2/QUADSPI_BK1_IO3/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/LTDC_R1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='N10',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/LTDC_B2/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='P11',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='ADC1_IN7/ADC2_IN7/FMC_SDNWE/QUADSPI_CLK/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='P10',name='ADC1_IN8/ADC2_IN8/LTDC_G1/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N9',name='ADC1_IN9/ADC2_IN9/LTDC_G0/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='P9',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='CAN2_RX/DCMI_D10/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/LTDC_G7/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='CAN1_RX/DCMI_D6/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='I2C2_SCL/I2S2_CK/LTDC_G4/QUADSPI_BK1_NCS/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DSIHOST_TE/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='CAN2_RX/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='CAN2_TX/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P1',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/I2S2_SD/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='DCMI_D2/SDIO_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/QUADSPI_BK2_NCS/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E6',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='DCMI_D11/SDIO_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='N1',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/QUADSPI_BK1_IO0/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='FMC_A17/FMC_ALE/QUADSPI_BK1_IO1/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='FMC_A18/QUADSPI_BK1_IO3/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='P6',name='FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='P5',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PDR_ON',do_erc=True),
            Pin(num='H9',name='NRST',do_erc=True),
            Pin(num='F8',name='BOOT0',do_erc=True),
            Pin(num='C12',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='D2',name='VCAP2',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VCAPDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='N4',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='H2',name='DSIHOST_D1N/DSIHOST_D1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='DSIHOST_D1P/DSIHOST_D1P',func=Pin.BIDIR,do_erc=True),
            Pin(num='J1',name='DSIHOST_CKP/DSIHOST_CKP',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='DSIHOST_CKN/DSIHOST_CKN',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='DSIHOST_D0N/DSIHOST_D0N',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='DSIHOST_D0P/DSIHOST_D0P',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='PI10/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='F11',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LTDC_G6/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='K12',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='M11',name='PH2/FMC_SDCKE0/LTDC_R0/QUADSPI_BK2_IO0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='PH3/FMC_SDNE0/LTDC_R1/QUADSPI_BK2_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PH4/I2C2_SCL/LTDC_G4/LTDC_G5/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PH5/FMC_SDNWE/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='PH10/DCMI_D1/FMC_D18/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N3',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='P2',name='PH12/DCMI_D3/FMC_D20/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/SAI1_MCLK_A/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='PG8/FMC_SDCLK/LTDC_G7/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PG13/FMC_A24/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='G10',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='G12',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='PF10/ADC3_IN8/DCMI_D11/LTDC_DE/QUADSPI_CLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='A11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='B5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='P3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='P8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='P12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K2',name='VDD12DSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='M12',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VDDDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='A4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='B7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='B10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='N8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='N11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='P4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='L11',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VSSDSI',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F479BGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F469/479',description='Core: ARM Cortex-M4 Package: LQFP208 Flash: 1024KB Ram: 320KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 159',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F479BITx'],pins=[
            Pin(num='43',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/LTDC_R2/QUADSPI_BK1_IO3/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/LTDC_R1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B2/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/QUADSPI_CLK/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='143',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='144',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='145',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='146',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='147',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='159',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='160',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_G1/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_G0/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='192',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='193',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='194',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/LTDC_G7/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='195',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='196',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='198',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='199',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/QUADSPI_BK1_NCS/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DSIHOST_TE/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='106',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='107',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='138',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='DCMI_D2/SDIO_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='161',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='162',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/QUADSPI_BK2_NCS/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='163',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='164',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='165',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='166',name='DCMI_D11/SDIO_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='167',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='168',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='169',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='172',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='173',name='FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='108',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/QUADSPI_BK1_IO0/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='FMC_A17/FMC_ALE/QUADSPI_BK1_IO1/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='FMC_A18/QUADSPI_BK1_IO3/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='200',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='201',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='FMC_A0/I2C2_SDA/PF0',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='FMC_A1/I2C2_SCL/PF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='FMC_A2/I2C2_SMBA/PF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC3_IN9/FMC_A3/PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC3_IN14/FMC_A4/PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC3_IN15/FMC_A5/PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX/PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX/PF7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/PF8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/PF9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC3_IN8/DCMI_D11/LTDC_DE/QUADSPI_CLK/PF10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI/PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='FMC_A6/PF12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='FMC_A7/PF13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='FMC_A8/PF14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9/PF15',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='NRST',do_erc=True),
            Pin(num='203',name='PDR_ON',do_erc=True),
            Pin(num='197',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='41',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='92',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='119',name='VCAPDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='148',name='VCAP2',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='DSIHOST_D0P/DSIHOST_D0P',func=Pin.BIDIR,do_erc=True),
            Pin(num='121',name='DSIHOST_D0N/DSIHOST_D0N',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='DSIHOST_CKP/DSIHOST_CKP',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='DSIHOST_CKN/DSIHOST_CKN',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='DSIHOST_D1P/DSIHOST_D1P',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='DSIHOST_D1N/DSIHOST_D1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='186',name='PK3/LTDC_B4',func=Pin.BIDIR,do_erc=True),
            Pin(num='187',name='PK4/LTDC_B5',func=Pin.BIDIR,do_erc=True),
            Pin(num='188',name='PK5/LTDC_B6',func=Pin.BIDIR,do_erc=True),
            Pin(num='189',name='PK6/LTDC_B7',func=Pin.BIDIR,do_erc=True),
            Pin(num='190',name='PK7/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PJ0/LTDC_R1/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PJ1/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PJ2/DSIHOST_TE/LTDC_R3',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PJ3/LTDC_R4',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='PJ4/LTDC_R5',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='PJ5/LTDC_R6',func=Pin.BIDIR,do_erc=True),
            Pin(num='174',name='PJ12/LTDC_B0/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='175',name='PJ13/LTDC_B1/LTDC_G4',func=Pin.BIDIR,do_erc=True),
            Pin(num='176',name='PJ14/LTDC_B2',func=Pin.BIDIR,do_erc=True),
            Pin(num='177',name='PJ15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='154',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='155',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='156',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='157',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='205',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='206',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='207',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='208',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='PI8/RTC_AF1/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LTDC_G6/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PI12/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PI13/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PI14/LTDC_CLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PI15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LTDC_G2/LTDC_R0',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='33',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='46',name='PH2/ETH_CRS/FMC_SDCKE0/LTDC_R0/QUADSPI_BK2_IO0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1/QUADSPI_BK2_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='PH4/I2C2_SCL/LTDC_G4/LTDC_G5/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='PH10/DCMI_D1/FMC_D18/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='PH12/DCMI_D3/FMC_D20/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='151',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='152',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='153',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='130',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='131',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/SAI1_MCLK_A/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='PG8/ETH_PPS_OUT/FMC_SDCLK/LTDC_G7/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='178',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='179',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='180',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='181',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='182',name='PG13/ETH_TXD0/FMC_A24/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='183',name='PG14/ETH_TXD1/FMC_A25/LTDC_B0/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='191',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='59',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='103',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='115',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='150',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='158',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='171',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='185',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='204',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='125',name='VDD12DSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='42',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='118',name='VDDDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='137',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='25',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='60',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='82',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='93',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='114',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='136',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='149',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='170',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='184',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='202',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='40',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='122',name='VSSDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='128',name='VSSDSI',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F479IGHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F469/479',description='Core: ARM Cortex-M4 Package: UFBGA176 Flash: 1024KB Ram: 320KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 131',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F479IIHx'],pins=[
            Pin(num='N3',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/LTDC_R2/QUADSPI_BK1_IO3/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='P2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/LTDC_R1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='R2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B2/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P4',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='P3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R3',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/QUADSPI_CLK/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F15',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E15',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D15',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C15',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B15',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A15',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A14',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='R5',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_G1/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='R4',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_G0/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/LTDC_G7/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R12',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/QUADSPI_BK1_NCS/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='R13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DSIHOST_TE/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='P12',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='P13',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='R14',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R15',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P5',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H15',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G15',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G14',name='DCMI_D2/SDIO_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F14',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B14',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/QUADSPI_BK2_NCS/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DCMI_D11/SDIO_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P15',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P14',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='N15',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N14',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/QUADSPI_BK1_IO0/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N13',name='FMC_A17/FMC_ALE/QUADSPI_BK1_IO1/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M15',name='FMC_A18/QUADSPI_BK1_IO3/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='M14',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L14',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R8',name='FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P8',name='FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P9',name='DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R9',name='FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='R10',name='FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P11',name='FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R11',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PDR_ON',do_erc=True),
            Pin(num='J1',name='NRST',do_erc=True),
            Pin(num='L4',name='BYPASS_REG',do_erc=True),
            Pin(num='D6',name='BOOT0',do_erc=True),
            Pin(num='C1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='F13',name='VCAP2',func=Pin.PWRIN,do_erc=True),
            Pin(num='K12',name='VCAPDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='M10',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='N1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='P1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C14',name='NC',func=Pin.NOCONNECT,do_erc=True),
            Pin(num='E12',name='DSIHOST_D1P/DSIHOST_D1P',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='DSIHOST_D1N/DSIHOST_D1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='DSIHOST_CKP/DSIHOST_CKP',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='DSIHOST_CKN/DSIHOST_CKN',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='DSIHOST_D0P/DSIHOST_D0P',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='DSIHOST_D0N/DSIHOST_D0N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E14',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D14',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PI8/RTC_AF1/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LTDC_G6/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='F4',name='PH2/ETH_CRS/FMC_SDCKE0/LTDC_R0/QUADSPI_BK2_IO0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1/QUADSPI_BK2_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PH4/I2C2_SCL/LTDC_G4/LTDC_G5/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L15',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K15',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K14',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J15',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='J14',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/SAI1_MCLK_A/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H14',name='PG8/ETH_PPS_OUT/FMC_SDCLK/LTDC_G7/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='PG13/ETH_TXD0/FMC_A24/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG14/ETH_TXD1/FMC_A25/LTDC_B0/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='PF6/ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='PF7/ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PF8/ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='PF9/ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PF10/ADC3_IN8/DCMI_D11/LTDC_DE/QUADSPI_CLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='R6',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='P6',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='R7',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P7',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D13',name='VDD12DSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='R1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='J12',name='VDDDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='H13',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='H12',name='VSSDSI',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F479IGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F469/479',description='Core: ARM Cortex-M4 Package: LQFP176 Flash: 1024KB Ram: 320KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 131',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F479IITx'],pins=[
            Pin(num='40',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/LTDC_R2/QUADSPI_BK1_IO3/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/LTDC_R1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B2/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/QUADSPI_CLK/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='138',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_G1/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_G0/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='161',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='162',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='163',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/LTDC_G7/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='164',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='165',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='167',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='168',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/QUADSPI_BK1_NCS/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DSIHOST_TE/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='120',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='121',name='DCMI_D2/SDIO_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/QUADSPI_BK2_NCS/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='143',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='144',name='DCMI_D11/SDIO_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='145',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='146',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='147',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='150',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='151',name='FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/QUADSPI_BK1_IO0/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='FMC_A17/FMC_ALE/QUADSPI_BK1_IO1/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='94',name='FMC_A18/QUADSPI_BK1_IO3/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='169',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='170',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='NRST',do_erc=True),
            Pin(num='48',name='BYPASS_REG',do_erc=True),
            Pin(num='171',name='PDR_ON',do_erc=True),
            Pin(num='166',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='81',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VCAPDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='129',name='VCAP2',func=Pin.PWRIN,do_erc=True),
            Pin(num='101',name='DSIHOST_D0P/DSIHOST_D0P',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='DSIHOST_D0N/DSIHOST_D0N',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='DSIHOST_CKP/DSIHOST_CKP',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='DSIHOST_CKN/DSIHOST_CKN',func=Pin.BIDIR,do_erc=True),
            Pin(num='107',name='DSIHOST_D1P/DSIHOST_D1P',func=Pin.BIDIR,do_erc=True),
            Pin(num='108',name='DSIHOST_D1N/DSIHOST_D1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='173',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='174',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='175',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='176',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='PI8/RTC_AF1/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LTDC_G6/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='30',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='43',name='PH2/ETH_CRS/FMC_SDCKE0/LTDC_R0/QUADSPI_BK2_IO0',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1/QUADSPI_BK2_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PH4/I2C2_SCL/LTDC_G4/LTDC_G5/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/SAI1_MCLK_A/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='PG8/ETH_PPS_OUT/FMC_SDCLK/LTDC_G7/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='152',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='153',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='154',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='155',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='156',name='PG13/ETH_TXD0/FMC_A24/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='157',name='PG14/ETH_TXD1/FMC_A25/LTDC_B0/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='160',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PF6/ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PF7/ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PF8/ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PF9/ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PF10/ADC3_IN8/DCMI_D11/LTDC_DE/QUADSPI_CLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PF13/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PF14/FMC_A8',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='82',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='96',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='136',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='149',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='159',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='172',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='106',name='VDD12DSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VDDDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='118',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='117',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='135',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='148',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='158',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='37',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='103',name='VSSDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='109',name='VSSDSI',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F479NGHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32F4 STM32F469/479',description='Core: ARM Cortex-M4 Package: TFBGA216 Flash: 1024KB Ram: 320KB Frequency: 180MHz Voltage: 1.7..3.6V IO-pins: 159',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F479NIHx'],pins=[
            Pin(num='N3',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SYS_WKUP/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/LTDC_R2/QUADSPI_BK1_IO3/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='P2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/LTDC_R1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='R2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B2/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P4',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='P3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R3',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/QUADSPI_CLK/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F15',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E15',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D15',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C15',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B15',name='CAN1_TX/LTDC_R5/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A15',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A14',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='R5',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_G1/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='R4',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_G0/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='I2S3_ext_SD/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S3_SD/LTDC_G7/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN2_TX/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDIO_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='P12',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/QUADSPI_BK1_NCS/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='R13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DSIHOST_TE/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K14',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='R14',name='I2S2_ext_SD/SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R15',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/I2S2_ext_SD/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P5',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H15',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDIO_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G15',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDIO_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G14',name='DCMI_D2/SDIO_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F14',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDIO_D1/TIM3_CH4/TIM8_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B14',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDIO_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/I2S3_ext_SD/QUADSPI_BK2_NCS/SDIO_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='DCMI_D9/I2S3_SD/SDIO_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RTC_AF1/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DCMI_D11/SDIO_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L15',name='FMC_D13/FMC_DA13/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='L14',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='K15',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/QUADSPI_BK1_IO0/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='FMC_A17/FMC_ALE/QUADSPI_BK1_IO1/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='FMC_A18/QUADSPI_BK1_IO3/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='FMC_D0/FMC_DA0/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='DCMI_D2/FMC_NBL0/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='DCMI_D3/FMC_NBL1/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SPI4_MOSI/SYS_TRACED3/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R8',name='FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='N9',name='FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P9',name='DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R9',name='FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='R10',name='FMC_D9/FMC_DA9/LTDC_B4/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='R12',name='FMC_D10/FMC_DA10/LTDC_DE/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P11',name='FMC_D11/FMC_DA11/LTDC_CLK/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R11',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='FMC_A0/I2C2_SDA/PF0',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='FMC_A1/I2C2_SCL/PF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='FMC_A2/I2C2_SMBA/PF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC3_IN9/FMC_A3/PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC3_IN14/FMC_A4/PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC3_IN15/FMC_A5/PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX/PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX/PF7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/PF8',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/PF9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='ADC3_IN8/DCMI_D11/LTDC_DE/QUADSPI_CLK/PF10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P8',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SPI5_MOSI/PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='FMC_A6/PF12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='FMC_A7/PF13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P6',name='FMC_A8/PF14',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9/PF15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='PDR_ON',do_erc=True),
            Pin(num='J1',name='NRST',do_erc=True),
            Pin(num='L5',name='BYPASS_REG',do_erc=True),
            Pin(num='E6',name='BOOT0',do_erc=True),
            Pin(num='C1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='E11',name='VCAP2',func=Pin.PWRIN,do_erc=True),
            Pin(num='K12',name='VCAPDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='L11',name='VCAP1',func=Pin.PWRIN,do_erc=True),
            Pin(num='N1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='P1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='DSIHOST_D1P/DSIHOST_D1P',func=Pin.BIDIR,do_erc=True),
            Pin(num='F13',name='DSIHOST_D1N/DSIHOST_D1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='DSIHOST_CKP/DSIHOST_CKP',func=Pin.BIDIR,do_erc=True),
            Pin(num='H13',name='DSIHOST_CKN/DSIHOST_CKN',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='DSIHOST_D0P/DSIHOST_D0P',func=Pin.BIDIR,do_erc=True),
            Pin(num='J13',name='DSIHOST_D0N/DSIHOST_D0N',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PK3/LTDC_B4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PK4/LTDC_B5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PK5/LTDC_B6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PK6/LTDC_B7',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PK7/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='R6',name='PJ0/LTDC_R1/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='R7',name='PJ1/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='P7',name='PJ2/DSIHOST_TE/LTDC_R3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N8',name='PJ3/LTDC_R4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PJ4/LTDC_R5',func=Pin.BIDIR,do_erc=True),
            Pin(num='M14',name='PJ5/LTDC_R6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PJ12/LTDC_B0/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PJ13/LTDC_B1/LTDC_G4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PJ14/LTDC_B2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='PJ15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E14',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D14',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C14',name='PI2/DCMI_D9/FMC_D26/I2S2_ext_SD/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PI8/RTC_AF1/RTC_AF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LTDC_G6/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI12/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PI13/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PI14/LTDC_CLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PI15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LTDC_G2/LTDC_R0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='K4',name='PH2/ETH_CRS/FMC_SDCKE0/LTDC_R0/QUADSPI_BK2_IO0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1/QUADSPI_BK2_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PH4/I2C2_SCL/LTDC_G4/LTDC_G5/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='P13',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N13',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='P14',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='N14',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='P15',name='PH10/DCMI_D1/FMC_D18/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N15',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M15',name='PH12/DCMI_D3/FMC_D20/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PH15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J15',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='J14',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/SAI1_MCLK_A/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H14',name='PG8/ETH_PPS_OUT/FMC_SDCLK/LTDC_G7/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG12/FMC_NE4/LTDC_B1/LTDC_B4/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PG13/ETH_TXD0/FMC_A24/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PG14/ETH_TXD1/FMC_A25/LTDC_B0/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G13',name='VDD12DSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='R1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='H11',name='VDDDSI',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='L6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSSA',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VSSDSI',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F745IEKx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M7 STM32F7 STM32F7x5',description='Core: ARM Cortex-M7 Package: UFBGA176 Flash: 512KB Ram: 320KB Frequency: 216MHz Voltage: 1.7..3.6V IO-pins: 140',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F745IGKx'],pins=[
            Pin(num='N3',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SAI2_SD_B/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/QUADSPI_BK1_IO3/SAI2_MCLK_B/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='P2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/SAI2_SCK_B/SYS_WKUP1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='R2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P4',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='P3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R3',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F15',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/TIM8_BKIN2/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E15',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D15',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C15',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B15',name='CAN1_TX/SAI2_FS_B/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A15',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A14',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A13',name='CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='R5',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='R4',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SPI3_MOSI/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN2_TX/CEC/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDMMC1_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDMMC1_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R12',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='R13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='P12',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='P13',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='R14',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R15',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/SAI2_FS_B/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/RTC_TAMP3/RTC_TS/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/SYS_WKUP5/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/I2S1_MCK/SPDIFRX_IN2/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P5',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/SPDIFRX_IN3/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H15',name='DCMI_D0/I2S2_MCK/SDMMC1_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G15',name='DCMI_D1/I2S3_MCK/SDMMC1_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G14',name='DCMI_D2/SDMMC1_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F14',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDMMC1_D1/TIM3_CH4/TIM8_CH4/UART5_CTS/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B14',name='DCMI_D8/I2S3_CK/QUADSPI_BK1_IO1/SDMMC1_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDMMC1_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='DCMI_D9/I2S3_SD/SDMMC1_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DCMI_D11/SDMMC1_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='DCMI_D5/FMC_CLK/I2S2_CK/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='DCMI_D10/FMC_NWAIT/I2S3_SD/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='FMC_NE1/SPDIFRX_IN0/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P15',name='FMC_D13/FMC_DA13/SPDIFRX_IN1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P14',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='N15',name='FMC_D15/FMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N14',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/I2C4_SMBA/QUADSPI_BK1_IO0/SAI2_SD_A/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N13',name='FMC_A17/FMC_ALE/I2C4_SCL/LPTIM1_IN1/QUADSPI_BK1_IO1/SAI2_FS_A/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M15',name='FMC_A18/I2C4_SDA/LPTIM1_OUT/QUADSPI_BK1_IO3/SAI2_SCK_A/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='M14',name='FMC_D0/FMC_DA0/TIM4_CH3/UART8_CTS/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L14',name='FMC_D1/FMC_DA1/TIM4_CH4/UART8_RTS/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='DCMI_D2/FMC_NBL0/LPTIM1_ETR/SAI2_MCLK_A/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DCMI_D3/FMC_NBL1/LPTIM1_IN2/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='DCMI_D4/FMC_A20/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='DCMI_D6/FMC_A21/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DCMI_D7/FMC_A22/SAI1_SD_A/SAI2_MCLK_B/SPI4_MOSI/SYS_TRACED3/TIM1_BKIN2/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R8',name='FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P8',name='FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P9',name='DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/UART7_RTS/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R9',name='FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/UART7_CTS/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/SAI2_SD_B/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='R10',name='FMC_D9/FMC_DA9/SAI2_SCK_B/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='FMC_D10/FMC_DA10/SAI2_FS_B/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P11',name='FMC_D11/FMC_DA11/SAI2_MCLK_B/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R11',name='FMC_D12/FMC_DA12/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PDR_ON',do_erc=True),
            Pin(num='J1',name='NRST',do_erc=True),
            Pin(num='L4',name='BYPASS_REG',do_erc=True),
            Pin(num='D6',name='BOOT0',do_erc=True),
            Pin(num='C1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='F13',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='M10',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='N1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='P1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='E14',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D14',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/SPI2_SCK/TIM8_BKIN2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C14',name='PI2/DCMI_D9/FMC_D26/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PI4/DCMI_D5/FMC_NBL2/SAI2_MCLK_A/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PI5/DCMI_VSYNC/FMC_NBL3/SAI2_SCK_A/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PI6/DCMI_D6/FMC_D28/SAI2_SD_A/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PI7/DCMI_D7/FMC_D29/SAI2_FS_A/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PI8/RTC_TAMP2/RTC_TS/SYS_WKUP3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI10/ETH_RX_ER/FMC_D31',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/SYS_WKUP4/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='F4',name='PH2/ETH_CRS/FMC_SDCKE0/LPTIM1_IN2/QUADSPI_BK2_IO0/SAI2_SCK_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PH3/ETH_COL/FMC_SDNE0/QUADSPI_BK2_IO1/SAI2_MCLK_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='PH10/DCMI_D1/FMC_D18/I2C4_SMBA/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/I2C4_SCL/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='PH12/DCMI_D3/FMC_D20/I2C4_SDA/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='PH13/CAN1_TX/FMC_D21/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='PH14/DCMI_D4/FMC_D22/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PH15/DCMI_D11/FMC_D23/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L15',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K15',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K14',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J15',name='PG6/DCMI_D12',func=Pin.BIDIR,do_erc=True),
            Pin(num='J14',name='PG7/DCMI_D13/FMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H14',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPDIFRX_IN2/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/SAI2_FS_B/SPDIFRX_IN3/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PG10/DCMI_D2/FMC_NE3/SAI2_SD_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/SPDIFRX_IN0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PG12/FMC_NE4/LPTIM1_IN1/SPDIFRX_IN1/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='PG13/ETH_TXD0/FMC_A24/LPTIM1_OUT/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG14/ETH_TXD1/FMC_A25/LPTIM1_ETR/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='PF6/ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='PF7/ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PF8/ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/UART7_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='PF9/ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/UART7_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PF10/ADC3_IN8/DCMI_D11',func=Pin.BIDIR,do_erc=True),
            Pin(num='R6',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SAI2_SD_B/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='P6',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='PF13/FMC_A7/I2C4_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='R7',name='PF14/FMC_A8/I2C4_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='P7',name='PF15/FMC_A9/I2C4_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='R1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='H13',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F745IETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M7 STM32F7 STM32F7x5',description='Core: ARM Cortex-M7 Package: LQFP176 Flash: 512KB Ram: 320KB Frequency: 216MHz Voltage: 1.7..3.6V IO-pins: 140',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F745IGTx'],pins=[
            Pin(num='40',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SAI2_SD_B/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/QUADSPI_BK1_IO3/SAI2_MCLK_B/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/SAI2_SCK_B/SYS_WKUP1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/TIM8_BKIN2/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='120',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='121',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='CAN1_TX/SAI2_FS_B/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='138',name='CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SPI3_MOSI/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='161',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='162',name='I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='163',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='164',name='CAN2_TX/CEC/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='165',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='167',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDMMC1_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='168',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDMMC1_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='94',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/SAI2_FS_B/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/RTC_TAMP3/RTC_TS/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/SYS_WKUP5/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/I2S1_MCK/SPDIFRX_IN2/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/SPDIFRX_IN3/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='DCMI_D0/I2S2_MCK/SDMMC1_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D1/I2S3_MCK/SDMMC1_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='DCMI_D2/SDMMC1_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDMMC1_D1/TIM3_CH4/TIM8_CH4/UART5_CTS/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='DCMI_D8/I2S3_CK/QUADSPI_BK1_IO1/SDMMC1_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDMMC1_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='DCMI_D9/I2S3_SD/SDMMC1_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='143',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='144',name='DCMI_D11/SDMMC1_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='145',name='DCMI_D5/FMC_CLK/I2S2_CK/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='146',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='147',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='150',name='DCMI_D10/FMC_NWAIT/I2S3_SD/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='151',name='FMC_NE1/SPDIFRX_IN0/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='FMC_D13/FMC_DA13/SPDIFRX_IN1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='FMC_D15/FMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/I2C4_SMBA/QUADSPI_BK1_IO0/SAI2_SD_A/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='FMC_A17/FMC_ALE/I2C4_SCL/LPTIM1_IN1/QUADSPI_BK1_IO1/SAI2_FS_A/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='FMC_A18/I2C4_SDA/LPTIM1_OUT/QUADSPI_BK1_IO3/SAI2_SCK_A/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='FMC_D0/FMC_DA0/TIM4_CH3/UART8_CTS/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='FMC_D1/FMC_DA1/TIM4_CH4/UART8_RTS/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='169',name='DCMI_D2/FMC_NBL0/LPTIM1_ETR/SAI2_MCLK_A/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='170',name='DCMI_D3/FMC_NBL1/LPTIM1_IN2/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='DCMI_D4/FMC_A20/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='DCMI_D6/FMC_A21/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='DCMI_D7/FMC_A22/SAI1_SD_A/SAI2_MCLK_B/SPI4_MOSI/SYS_TRACED3/TIM1_BKIN2/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/UART7_RTS/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/UART7_CTS/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/SAI2_SD_B/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='FMC_D9/FMC_DA9/SAI2_SCK_B/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='FMC_D10/FMC_DA10/SAI2_FS_B/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FMC_D11/FMC_DA11/SAI2_MCLK_B/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='FMC_D12/FMC_DA12/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='NRST',do_erc=True),
            Pin(num='48',name='BYPASS_REG',do_erc=True),
            Pin(num='171',name='PDR_ON',do_erc=True),
            Pin(num='166',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='81',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='125',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/SPI2_SCK/TIM8_BKIN2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='PI2/DCMI_D9/FMC_D26/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='173',name='PI4/DCMI_D5/FMC_NBL2/SAI2_MCLK_A/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='174',name='PI5/DCMI_VSYNC/FMC_NBL3/SAI2_SCK_A/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='175',name='PI6/DCMI_D6/FMC_D28/SAI2_SD_A/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='176',name='PI7/DCMI_D7/FMC_D29/SAI2_FS_A/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='PI8/RTC_TAMP2/RTC_TS/SYS_WKUP3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PI10/ETH_RX_ER/FMC_D31',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/SYS_WKUP4/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='30',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='43',name='PH2/ETH_CRS/FMC_SDCKE0/LPTIM1_IN2/QUADSPI_BK2_IO0/SAI2_SCK_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PH3/ETH_COL/FMC_SDNE0/QUADSPI_BK2_IO1/SAI2_MCLK_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PH10/DCMI_D1/FMC_D18/I2C4_SMBA/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/I2C4_SCL/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PH12/DCMI_D3/FMC_D20/I2C4_SDA/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PH13/CAN1_TX/FMC_D21/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PH14/DCMI_D4/FMC_D22/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='130',name='PH15/DCMI_D11/FMC_D23/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='106',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='107',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='108',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='PG6/DCMI_D12',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='PG7/DCMI_D13/FMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPDIFRX_IN2/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='152',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/SAI2_FS_B/SPDIFRX_IN3/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='153',name='PG10/DCMI_D2/FMC_NE3/SAI2_SD_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='154',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/SPDIFRX_IN0',func=Pin.BIDIR,do_erc=True),
            Pin(num='155',name='PG12/FMC_NE4/LPTIM1_IN1/SPDIFRX_IN1/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='156',name='PG13/ETH_TXD0/FMC_A24/LPTIM1_OUT/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='157',name='PG14/ETH_TXD1/FMC_A25/LPTIM1_ETR/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='160',name='PG15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PF6/ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PF7/ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PF8/ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/UART7_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PF9/ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/UART7_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PF10/ADC3_IN8/DCMI_D11',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SAI2_SD_B/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PF13/FMC_A7/I2C4_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PF14/FMC_A8/I2C4_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PF15/FMC_A9/I2C4_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='82',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='91',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='103',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='127',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='136',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='149',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='159',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='172',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='114',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='90',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='102',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='113',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='126',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='135',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='148',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='158',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='37',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F745VETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M7 STM32F7 STM32F7x5',description='Core: ARM Cortex-M7 Package: LQFP100 Flash: 512KB Ram: 320KB Frequency: 216MHz Voltage: 1.7..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F745VGTx'],pins=[
            Pin(num='22',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SAI2_SD_B/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/QUADSPI_BK1_IO3/SAI2_MCLK_B/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/SAI2_SCK_B/SYS_WKUP1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/TIM8_BKIN2/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN1_TX/SAI2_FS_B/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SPI3_MOSI/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_TX/CEC/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDMMC1_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDMMC1_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/SAI2_FS_B/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/RTC_TAMP3/RTC_TS/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/SYS_WKUP5/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/I2S1_MCK/SPDIFRX_IN2/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/SPDIFRX_IN3/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='DCMI_D0/I2S2_MCK/SDMMC1_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='DCMI_D1/I2S3_MCK/SDMMC1_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='DCMI_D2/SDMMC1_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDMMC1_D1/TIM3_CH4/TIM8_CH4/UART5_CTS/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DCMI_D8/I2S3_CK/QUADSPI_BK1_IO1/SDMMC1_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDMMC1_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='DCMI_D9/I2S3_SD/SDMMC1_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='97',name='PE0/DCMI_D2/FMC_NBL0/LPTIM1_ETR/SAI2_MCLK_A/TIM4_ETR/UART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/DCMI_D3/FMC_NBL1/LPTIM1_IN2/UART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/SAI1_SD_B/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FMC_A20/SAI1_FS_A/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FMC_A21/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FMC_A22/SAI1_SD_A/SAI2_MCLK_B/SPI4_MOSI/SYS_TRACED3/TIM1_BKIN2/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PE7/FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE8/FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE9/DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/UART7_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE10/FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/UART7_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/SAI2_SD_B/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE12/FMC_D9/FMC_DA9/SAI2_SCK_B/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE13/FMC_D10/FMC_DA10/SAI2_FS_B/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE14/FMC_D11/FMC_DA11/SAI2_MCLK_B/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE15/FMC_D12/FMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN1_RX/FMC_D2/FMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN1_TX/FMC_D3/FMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/DCMI_D11/SDMMC1_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/DCMI_D5/FMC_CLK/I2S2_CK/SPI2_SCK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/DCMI_D10/FMC_NWAIT/I2S3_SD/SAI1_SD_A/SPI3_MOSI/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FMC_NE1/SPDIFRX_IN0/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FMC_D13/FMC_DA13/SPDIFRX_IN1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FMC_D15/FMC_DA15/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/I2C4_SMBA/QUADSPI_BK1_IO0/SAI2_SD_A/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FMC_A17/FMC_ALE/I2C4_SCL/LPTIM1_IN1/QUADSPI_BK1_IO1/SAI2_FS_A/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FMC_A18/I2C4_SDA/LPTIM1_OUT/QUADSPI_BK1_IO3/SAI2_SCK_A/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FMC_D0/FMC_DA0/TIM4_CH3/UART8_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/FMC_D1/FMC_DA1/TIM4_CH4/UART8_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F745ZETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M7 STM32F7 STM32F7x5',description='Core: ARM Cortex-M7 Package: LQFP144 Flash: 512KB Ram: 320KB Frequency: 216MHz Voltage: 1.7..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F745ZGTx'],pins=[
            Pin(num='34',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SAI2_SD_B/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/QUADSPI_BK1_IO3/SAI2_MCLK_B/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/SAI2_SCK_B/SYS_WKUP1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='I2C3_SCL/RCC_MCO_1/TIM1_CH1/TIM8_BKIN2/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN1_TX/SAI2_FS_B/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SPI3_MOSI/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='CAN2_TX/CEC/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/SDMMC1_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/SDMMC1_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/SAI2_FS_B/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/RTC_TAMP3/RTC_TS/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/SYS_WKUP5/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/I2S1_MCK/SPDIFRX_IN2/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/SPDIFRX_IN3/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DCMI_D0/I2S2_MCK/SDMMC1_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DCMI_D1/I2S3_MCK/SDMMC1_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='DCMI_D2/SDMMC1_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDMMC1_D1/TIM3_CH4/TIM8_CH4/UART5_CTS/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='DCMI_D8/I2S3_CK/QUADSPI_BK1_IO1/SDMMC1_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDMMC1_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='DCMI_D9/I2S3_SD/SDMMC1_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D11/SDMMC1_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='DCMI_D5/FMC_CLK/I2S2_CK/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='DCMI_D10/FMC_NWAIT/I2S3_SD/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FMC_NE1/SPDIFRX_IN0/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FMC_D13/FMC_DA13/SPDIFRX_IN1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FMC_D15/FMC_DA15/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/I2C4_SMBA/QUADSPI_BK1_IO0/SAI2_SD_A/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FMC_A17/FMC_ALE/I2C4_SCL/LPTIM1_IN1/QUADSPI_BK1_IO1/SAI2_FS_A/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FMC_A18/I2C4_SDA/LPTIM1_OUT/QUADSPI_BK1_IO3/SAI2_SCK_A/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FMC_D0/FMC_DA0/TIM4_CH3/UART8_CTS/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='FMC_D1/FMC_DA1/TIM4_CH4/UART8_RTS/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='143',name='PDR_ON',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='106',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='56',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/DCMI_D12',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/DCMI_D13/FMC_INT3/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPDIFRX_IN2/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/SAI2_FS_B/SPDIFRX_IN3/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/DCMI_D2/FMC_NE3/SAI2_SD_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/SPDIFRX_IN0',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FMC_NE4/LPTIM1_IN1/SPDIFRX_IN1/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/ETH_TXD0/FMC_A24/LPTIM1_OUT/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/ETH_TXD1/FMC_A25/LPTIM1_ETR/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/UART7_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/UART7_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC3_IN8/DCMI_D11',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SAI2_SD_B/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FMC_A7/I2C4_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FMC_A8/I2C4_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/FMC_A9/I2C4_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/DCMI_D2/FMC_NBL0/LPTIM1_ETR/SAI2_MCLK_A/TIM4_ETR/UART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/DCMI_D3/FMC_NBL1/LPTIM1_IN2/UART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/SAI1_SD_B/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FMC_A20/SAI1_FS_A/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FMC_A21/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FMC_A22/SAI1_SD_A/SAI2_MCLK_B/SPI4_MOSI/SYS_TRACED3/TIM1_BKIN2/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/UART7_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/UART7_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/SAI2_SD_B/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FMC_D9/FMC_DA9/SAI2_SCK_B/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FMC_D10/FMC_DA10/SAI2_FS_B/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FMC_D11/FMC_DA11/SAI2_MCLK_B/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/FMC_D12/FMC_DA12/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F746BETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M7 STM32F7 STM32F7x6',description='Core: ARM Cortex-M7 Package: LQFP208 Flash: 512KB Ram: 320KB Frequency: 216MHz Voltage: 1.7..3.6V IO-pins: 168',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F746BGTx'],pins=[
            Pin(num='43',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SAI2_SD_B/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/LTDC_R2/QUADSPI_BK1_IO3/SAI2_MCLK_B/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/LTDC_R1/SAI2_SCK_B/SYS_WKUP1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/TIM8_BKIN2/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='143',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='144',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='145',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='146',name='CAN1_TX/LTDC_R5/SAI2_FS_B/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='147',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='159',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='160',name='CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SPI3_MOSI/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='192',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='193',name='I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='194',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='195',name='CAN2_TX/CEC/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='196',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='198',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDMMC1_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='199',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDMMC1_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='106',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='107',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/SAI2_FS_B/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/RTC_TAMP3/RTC_TS/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/SYS_WKUP5/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/I2S1_MCK/SPDIFRX_IN2/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/SPDIFRX_IN3/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='138',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDMMC1_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDMMC1_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='DCMI_D2/SDMMC1_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDMMC1_D1/TIM3_CH4/TIM8_CH4/UART5_CTS/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='161',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDMMC1_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='162',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDMMC1_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='163',name='DCMI_D9/I2S3_SD/SDMMC1_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='164',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='165',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='166',name='DCMI_D11/SDMMC1_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='167',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='168',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='169',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='172',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='173',name='FMC_NE1/SPDIFRX_IN0/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='108',name='FMC_D13/FMC_DA13/SPDIFRX_IN1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/I2C4_SMBA/QUADSPI_BK1_IO0/SAI2_SD_A/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='FMC_A17/FMC_ALE/I2C4_SCL/LPTIM1_IN1/QUADSPI_BK1_IO1/SAI2_FS_A/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='FMC_A18/I2C4_SDA/LPTIM1_OUT/QUADSPI_BK1_IO3/SAI2_SCK_A/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='FMC_D0/FMC_DA0/TIM4_CH3/UART8_CTS/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='FMC_D1/FMC_DA1/TIM4_CH4/UART8_RTS/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='200',name='DCMI_D2/FMC_NBL0/LPTIM1_ETR/SAI2_MCLK_A/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='201',name='DCMI_D3/FMC_NBL1/LPTIM1_IN2/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SAI2_MCLK_B/SPI4_MOSI/SYS_TRACED3/TIM1_BKIN2/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/UART7_RTS/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/UART7_CTS/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SAI2_SD_B/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='FMC_D9/FMC_DA9/LTDC_B4/SAI2_SCK_B/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='FMC_D10/FMC_DA10/LTDC_DE/SAI2_FS_B/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='FMC_D11/FMC_DA11/LTDC_CLK/SAI2_MCLK_B/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='FMC_A0/I2C2_SDA/PF0',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='FMC_A1/I2C2_SCL/PF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='FMC_A2/I2C2_SMBA/PF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC3_IN9/FMC_A3/PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC3_IN14/FMC_A4/PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC3_IN15/FMC_A5/PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX/PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX/PF7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/UART7_RTS/PF8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/UART7_CTS/PF9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC3_IN8/DCMI_D11/LTDC_DE/PF10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SAI2_SD_B/SPI5_MOSI/PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='FMC_A6/PF12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='FMC_A7/I2C4_SMBA/PF13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='FMC_A8/I2C4_SCL/PF14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='FMC_A9/I2C4_SDA/PF15',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='NRST',do_erc=True),
            Pin(num='203',name='PDR_ON',do_erc=True),
            Pin(num='197',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='41',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='92',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='148',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='126',name='PK0/LTDC_G5',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PK1/LTDC_G6',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PK2/LTDC_G7',func=Pin.BIDIR,do_erc=True),
            Pin(num='186',name='PK3/LTDC_B4',func=Pin.BIDIR,do_erc=True),
            Pin(num='187',name='PK4/LTDC_B5',func=Pin.BIDIR,do_erc=True),
            Pin(num='188',name='PK5/LTDC_B6',func=Pin.BIDIR,do_erc=True),
            Pin(num='189',name='PK6/LTDC_B7',func=Pin.BIDIR,do_erc=True),
            Pin(num='190',name='PK7/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PJ0/LTDC_R1',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PJ1/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PJ2/LTDC_R3',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PJ3/LTDC_R4',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='PJ4/LTDC_R5',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='PJ5/LTDC_R6',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='PJ6/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='PJ7/LTDC_G0',func=Pin.BIDIR,do_erc=True),
            Pin(num='120',name='PJ8/LTDC_G1',func=Pin.BIDIR,do_erc=True),
            Pin(num='121',name='PJ9/DAC_EXTI9/LTDC_G2',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='PJ10/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='PJ11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LTDC_G4',func=Pin.BIDIR,do_erc=True),
            Pin(num='174',name='PJ12/LTDC_B0',func=Pin.BIDIR,do_erc=True),
            Pin(num='175',name='PJ13/LTDC_B1',func=Pin.BIDIR,do_erc=True),
            Pin(num='176',name='PJ14/LTDC_B2',func=Pin.BIDIR,do_erc=True),
            Pin(num='177',name='PJ15/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='154',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='155',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK/TIM8_BKIN2',func=Pin.BIDIR,do_erc=True),
            Pin(num='156',name='PI2/DCMI_D9/FMC_D26/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='157',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='205',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/SAI2_MCLK_A/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='206',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/SAI2_SCK_A/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='207',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/SAI2_SD_A/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='208',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/SAI2_FS_A/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='PI8/RTC_TAMP2/RTC_TS/SYS_WKUP3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/SYS_WKUP4/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PI12/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PI13/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PI14/LTDC_CLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PI15/LTDC_R0',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='33',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='46',name='PH2/ETH_CRS/FMC_SDCKE0/LPTIM1_IN2/LTDC_R0/QUADSPI_BK2_IO0/SAI2_SCK_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1/QUADSPI_BK2_IO1/SAI2_MCLK_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='PH10/DCMI_D1/FMC_D18/I2C4_SMBA/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/I2C4_SCL/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='PH12/DCMI_D3/FMC_D20/I2C4_SDA/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='151',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='152',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='153',name='PH15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='130',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='131',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPDIFRX_IN2/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='178',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/SAI2_FS_B/SPDIFRX_IN3/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='179',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3/SAI2_SD_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='180',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/LTDC_B3/SPDIFRX_IN0',func=Pin.BIDIR,do_erc=True),
            Pin(num='181',name='PG12/FMC_NE4/LPTIM1_IN1/LTDC_B1/LTDC_B4/SPDIFRX_IN1/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='182',name='PG13/ETH_TXD0/FMC_A24/LPTIM1_OUT/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='183',name='PG14/ETH_TXD1/FMC_A25/LPTIM1_ETR/LTDC_B0/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='191',name='PG15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='59',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='103',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='115',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='124',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='150',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='158',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='171',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='185',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='204',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='42',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='137',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='25',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='60',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='82',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='93',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='114',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='125',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='136',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='149',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='170',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='184',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='202',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='40',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F746IEKx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M7 STM32F7 STM32F7x6',description='Core: ARM Cortex-M7 Package: UFBGA176 Flash: 512KB Ram: 320KB Frequency: 216MHz Voltage: 1.7..3.6V IO-pins: 140',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F746IGKx'],pins=[
            Pin(num='N3',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SAI2_SD_B/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/LTDC_R2/QUADSPI_BK1_IO3/SAI2_MCLK_B/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='P2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/LTDC_R1/SAI2_SCK_B/SYS_WKUP1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='R2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P4',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='P3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R3',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F15',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/TIM8_BKIN2/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E15',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D15',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C15',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B15',name='CAN1_TX/LTDC_R5/SAI2_FS_B/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A15',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A14',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A13',name='CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='R5',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='R4',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SPI3_MOSI/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN2_TX/CEC/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDMMC1_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDMMC1_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R12',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='R13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='P12',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='P13',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='R14',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R15',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/SAI2_FS_B/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/RTC_TAMP3/RTC_TS/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/SYS_WKUP5/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/I2S1_MCK/SPDIFRX_IN2/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P5',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/SPDIFRX_IN3/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H15',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDMMC1_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G15',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDMMC1_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G14',name='DCMI_D2/SDMMC1_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F14',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDMMC1_D1/TIM3_CH4/TIM8_CH4/UART5_CTS/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B14',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDMMC1_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDMMC1_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='DCMI_D9/I2S3_SD/SDMMC1_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DCMI_D11/SDMMC1_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='FMC_NE1/SPDIFRX_IN0/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P15',name='FMC_D13/FMC_DA13/SPDIFRX_IN1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P14',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='N15',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N14',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/I2C4_SMBA/QUADSPI_BK1_IO0/SAI2_SD_A/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N13',name='FMC_A17/FMC_ALE/I2C4_SCL/LPTIM1_IN1/QUADSPI_BK1_IO1/SAI2_FS_A/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M15',name='FMC_A18/I2C4_SDA/LPTIM1_OUT/QUADSPI_BK1_IO3/SAI2_SCK_A/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='M14',name='FMC_D0/FMC_DA0/TIM4_CH3/UART8_CTS/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L14',name='FMC_D1/FMC_DA1/TIM4_CH4/UART8_RTS/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='DCMI_D2/FMC_NBL0/LPTIM1_ETR/SAI2_MCLK_A/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DCMI_D3/FMC_NBL1/LPTIM1_IN2/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SAI2_MCLK_B/SPI4_MOSI/SYS_TRACED3/TIM1_BKIN2/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R8',name='FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P8',name='FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P9',name='DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/UART7_RTS/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R9',name='FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/UART7_CTS/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SAI2_SD_B/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='R10',name='FMC_D9/FMC_DA9/LTDC_B4/SAI2_SCK_B/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='FMC_D10/FMC_DA10/LTDC_DE/SAI2_FS_B/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P11',name='FMC_D11/FMC_DA11/LTDC_CLK/SAI2_MCLK_B/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R11',name='FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PDR_ON',do_erc=True),
            Pin(num='J1',name='NRST',do_erc=True),
            Pin(num='L4',name='BYPASS_REG',do_erc=True),
            Pin(num='D6',name='BOOT0',do_erc=True),
            Pin(num='C1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='F13',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='M10',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='N1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='P1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='E14',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D14',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK/TIM8_BKIN2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C14',name='PI2/DCMI_D9/FMC_D26/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/SAI2_MCLK_A/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/SAI2_SCK_A/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/SAI2_SD_A/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/SAI2_FS_A/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PI8/RTC_TAMP2/RTC_TS/SYS_WKUP3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/SYS_WKUP4/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='F4',name='PH2/ETH_CRS/FMC_SDCKE0/LPTIM1_IN2/LTDC_R0/QUADSPI_BK2_IO0/SAI2_SCK_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1/QUADSPI_BK2_IO1/SAI2_MCLK_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='PH10/DCMI_D1/FMC_D18/I2C4_SMBA/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/I2C4_SCL/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='PH12/DCMI_D3/FMC_D20/I2C4_SDA/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PH15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L15',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K15',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K14',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J15',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='J14',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H14',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPDIFRX_IN2/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/SAI2_FS_B/SPDIFRX_IN3/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3/SAI2_SD_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/LTDC_B3/SPDIFRX_IN0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PG12/FMC_NE4/LPTIM1_IN1/LTDC_B1/LTDC_B4/SPDIFRX_IN1/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='PG13/ETH_TXD0/FMC_A24/LPTIM1_OUT/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG14/ETH_TXD1/FMC_A25/LPTIM1_ETR/LTDC_B0/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='PF6/ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='PF7/ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PF8/ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/UART7_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='PF9/ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/UART7_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PF10/ADC3_IN8/DCMI_D11/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='R6',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SAI2_SD_B/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='P6',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='PF13/FMC_A7/I2C4_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='R7',name='PF14/FMC_A8/I2C4_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='P7',name='PF15/FMC_A9/I2C4_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='R1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='H13',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F746IETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M7 STM32F7 STM32F7x6',description='Core: ARM Cortex-M7 Package: LQFP176 Flash: 512KB Ram: 320KB Frequency: 216MHz Voltage: 1.7..3.6V IO-pins: 140',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F746IGTx'],pins=[
            Pin(num='40',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SAI2_SD_B/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/LTDC_R2/QUADSPI_BK1_IO3/SAI2_MCLK_B/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/LTDC_R1/SAI2_SCK_B/SYS_WKUP1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/TIM8_BKIN2/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='120',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='121',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='CAN1_TX/LTDC_R5/SAI2_FS_B/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='138',name='CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SPI3_MOSI/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='161',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='162',name='I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='163',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='164',name='CAN2_TX/CEC/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='165',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='167',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDMMC1_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='168',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDMMC1_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='94',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/SAI2_FS_B/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/RTC_TAMP3/RTC_TS/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/SYS_WKUP5/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/I2S1_MCK/SPDIFRX_IN2/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/SPDIFRX_IN3/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDMMC1_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDMMC1_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='DCMI_D2/SDMMC1_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDMMC1_D1/TIM3_CH4/TIM8_CH4/UART5_CTS/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDMMC1_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDMMC1_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='DCMI_D9/I2S3_SD/SDMMC1_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='143',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='144',name='DCMI_D11/SDMMC1_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='145',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='146',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='147',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='150',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='151',name='FMC_NE1/SPDIFRX_IN0/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='FMC_D13/FMC_DA13/SPDIFRX_IN1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/I2C4_SMBA/QUADSPI_BK1_IO0/SAI2_SD_A/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='FMC_A17/FMC_ALE/I2C4_SCL/LPTIM1_IN1/QUADSPI_BK1_IO1/SAI2_FS_A/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='FMC_A18/I2C4_SDA/LPTIM1_OUT/QUADSPI_BK1_IO3/SAI2_SCK_A/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='FMC_D0/FMC_DA0/TIM4_CH3/UART8_CTS/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='FMC_D1/FMC_DA1/TIM4_CH4/UART8_RTS/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='169',name='DCMI_D2/FMC_NBL0/LPTIM1_ETR/SAI2_MCLK_A/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='170',name='DCMI_D3/FMC_NBL1/LPTIM1_IN2/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SAI2_MCLK_B/SPI4_MOSI/SYS_TRACED3/TIM1_BKIN2/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/UART7_RTS/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/UART7_CTS/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SAI2_SD_B/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='FMC_D9/FMC_DA9/LTDC_B4/SAI2_SCK_B/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='FMC_D10/FMC_DA10/LTDC_DE/SAI2_FS_B/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FMC_D11/FMC_DA11/LTDC_CLK/SAI2_MCLK_B/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='NRST',do_erc=True),
            Pin(num='48',name='BYPASS_REG',do_erc=True),
            Pin(num='171',name='PDR_ON',do_erc=True),
            Pin(num='166',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='81',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='125',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK/TIM8_BKIN2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='PI2/DCMI_D9/FMC_D26/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='173',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/SAI2_MCLK_A/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='174',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/SAI2_SCK_A/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='175',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/SAI2_SD_A/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='176',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/SAI2_FS_A/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='PI8/RTC_TAMP2/RTC_TS/SYS_WKUP3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/SYS_WKUP4/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='30',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='43',name='PH2/ETH_CRS/FMC_SDCKE0/LPTIM1_IN2/LTDC_R0/QUADSPI_BK2_IO0/SAI2_SCK_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1/QUADSPI_BK2_IO1/SAI2_MCLK_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PH10/DCMI_D1/FMC_D18/I2C4_SMBA/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/I2C4_SCL/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PH12/DCMI_D3/FMC_D20/I2C4_SDA/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='130',name='PH15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='106',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='107',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='108',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPDIFRX_IN2/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='152',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/SAI2_FS_B/SPDIFRX_IN3/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='153',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3/SAI2_SD_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='154',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/LTDC_B3/SPDIFRX_IN0',func=Pin.BIDIR,do_erc=True),
            Pin(num='155',name='PG12/FMC_NE4/LPTIM1_IN1/LTDC_B1/LTDC_B4/SPDIFRX_IN1/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='156',name='PG13/ETH_TXD0/FMC_A24/LPTIM1_OUT/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='157',name='PG14/ETH_TXD1/FMC_A25/LPTIM1_ETR/LTDC_B0/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='160',name='PG15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PF6/ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PF7/ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PF8/ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/UART7_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PF9/ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/UART7_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PF10/ADC3_IN8/DCMI_D11/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SAI2_SD_B/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PF13/FMC_A7/I2C4_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PF14/FMC_A8/I2C4_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PF15/FMC_A9/I2C4_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='82',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='91',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='103',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='127',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='136',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='149',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='159',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='172',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='114',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='90',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='102',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='113',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='126',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='135',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='148',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='158',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='37',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F746NEHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M7 STM32F7 STM32F7x6',description='Core: ARM Cortex-M7 Package: TFBGA216 Flash: 512KB Ram: 320KB Frequency: 216MHz Voltage: 1.7..3.6V IO-pins: 168',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F746NGHx'],pins=[
            Pin(num='N3',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SAI2_SD_B/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/LTDC_R2/QUADSPI_BK1_IO3/SAI2_MCLK_B/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='P2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/LTDC_R1/SAI2_SCK_B/SYS_WKUP1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='R2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P4',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='P3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R3',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F15',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/TIM8_BKIN2/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E15',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D15',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C15',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B15',name='CAN1_TX/LTDC_R5/SAI2_FS_B/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A15',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A14',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A13',name='CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='R5',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='R4',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SPI3_MOSI/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN2_TX/CEC/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDMMC1_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDMMC1_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='P12',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='R13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K14',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='R14',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R15',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/SAI2_FS_B/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/RTC_TAMP3/RTC_TS/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/SYS_WKUP5/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/I2S1_MCK/SPDIFRX_IN2/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P5',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/SPDIFRX_IN3/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H15',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDMMC1_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G15',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDMMC1_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G14',name='DCMI_D2/SDMMC1_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F14',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDMMC1_D1/TIM3_CH4/TIM8_CH4/UART5_CTS/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B14',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDMMC1_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDMMC1_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='DCMI_D9/I2S3_SD/SDMMC1_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DCMI_D11/SDMMC1_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='FMC_NE1/SPDIFRX_IN0/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L15',name='FMC_D13/FMC_DA13/SPDIFRX_IN1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='L14',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='K15',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/I2C4_SMBA/QUADSPI_BK1_IO0/SAI2_SD_A/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='FMC_A17/FMC_ALE/I2C4_SCL/LPTIM1_IN1/QUADSPI_BK1_IO1/SAI2_FS_A/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='FMC_A18/I2C4_SDA/LPTIM1_OUT/QUADSPI_BK1_IO3/SAI2_SCK_A/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='FMC_D0/FMC_DA0/TIM4_CH3/UART8_CTS/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='FMC_D1/FMC_DA1/TIM4_CH4/UART8_RTS/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='DCMI_D2/FMC_NBL0/LPTIM1_ETR/SAI2_MCLK_A/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='DCMI_D3/FMC_NBL1/LPTIM1_IN2/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SAI2_MCLK_B/SPI4_MOSI/SYS_TRACED3/TIM1_BKIN2/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R8',name='FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='N9',name='FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P9',name='DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/UART7_RTS/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R9',name='FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/UART7_CTS/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SAI2_SD_B/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='R10',name='FMC_D9/FMC_DA9/LTDC_B4/SAI2_SCK_B/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='R12',name='FMC_D10/FMC_DA10/LTDC_DE/SAI2_FS_B/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P11',name='FMC_D11/FMC_DA11/LTDC_CLK/SAI2_MCLK_B/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R11',name='FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='FMC_A0/I2C2_SDA/PF0',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='FMC_A1/I2C2_SCL/PF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='FMC_A2/I2C2_SMBA/PF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC3_IN9/FMC_A3/PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC3_IN14/FMC_A4/PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC3_IN15/FMC_A5/PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX/PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX/PF7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/UART7_RTS/PF8',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/UART7_CTS/PF9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='ADC3_IN8/DCMI_D11/LTDC_DE/PF10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P8',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SAI2_SD_B/SPI5_MOSI/PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='FMC_A6/PF12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='FMC_A7/I2C4_SMBA/PF13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P6',name='FMC_A8/I2C4_SCL/PF14',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='FMC_A9/I2C4_SDA/PF15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='PDR_ON',do_erc=True),
            Pin(num='J1',name='NRST',do_erc=True),
            Pin(num='L5',name='BYPASS_REG',do_erc=True),
            Pin(num='E6',name='BOOT0',do_erc=True),
            Pin(num='C1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='E11',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='L11',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='N1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='P1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='G13',name='PK0/LTDC_G5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F12',name='PK1/LTDC_G6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F13',name='PK2/LTDC_G7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PK3/LTDC_B4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PK4/LTDC_B5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PK5/LTDC_B6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PK6/LTDC_B7',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PK7/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='R6',name='PJ0/LTDC_R1',func=Pin.BIDIR,do_erc=True),
            Pin(num='R7',name='PJ1/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='P7',name='PJ2/LTDC_R3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N8',name='PJ3/LTDC_R4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PJ4/LTDC_R5',func=Pin.BIDIR,do_erc=True),
            Pin(num='M14',name='PJ5/LTDC_R6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='PJ6/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PJ7/LTDC_G0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PJ8/LTDC_G1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J13',name='PJ9/DAC_EXTI9/LTDC_G2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H13',name='PJ10/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G12',name='PJ11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LTDC_G4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PJ12/LTDC_B0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PJ13/LTDC_B1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PJ14/LTDC_B2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='PJ15/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E14',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D14',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK/TIM8_BKIN2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C14',name='PI2/DCMI_D9/FMC_D26/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/SAI2_MCLK_A/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/SAI2_SCK_A/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/SAI2_SD_A/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/SAI2_FS_A/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PI8/RTC_TAMP2/RTC_TS/SYS_WKUP3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/SYS_WKUP4/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI12/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PI13/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PI14/LTDC_CLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PI15/LTDC_R0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='K4',name='PH2/ETH_CRS/FMC_SDCKE0/LPTIM1_IN2/LTDC_R0/QUADSPI_BK2_IO0/SAI2_SCK_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1/QUADSPI_BK2_IO1/SAI2_MCLK_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='P13',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N13',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='P14',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='N14',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='P15',name='PH10/DCMI_D1/FMC_D18/I2C4_SMBA/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N15',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/I2C4_SCL/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M15',name='PH12/DCMI_D3/FMC_D20/I2C4_SDA/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PH15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J15',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='J14',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H14',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPDIFRX_IN2/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/SAI2_FS_B/SPDIFRX_IN3/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3/SAI2_SD_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/LTDC_B3/SPDIFRX_IN0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG12/FMC_NE4/LPTIM1_IN1/LTDC_B1/LTDC_B4/SPDIFRX_IN1/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PG13/ETH_TXD0/FMC_A24/LPTIM1_OUT/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PG14/ETH_TXD1/FMC_A25/LPTIM1_ETR/LTDC_B0/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='R1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='L6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F746VETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M7 STM32F7 STM32F7x6',description='Core: ARM Cortex-M7 Package: LQFP100 Flash: 512KB Ram: 320KB Frequency: 216MHz Voltage: 1.7..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F746VGTx'],pins=[
            Pin(num='22',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SAI2_SD_B/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/LTDC_R2/QUADSPI_BK1_IO3/SAI2_MCLK_B/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/LTDC_R1/SAI2_SCK_B/SYS_WKUP1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/TIM8_BKIN2/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN1_TX/LTDC_R5/SAI2_FS_B/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SPI3_MOSI/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_TX/CEC/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDMMC1_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDMMC1_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/SAI2_FS_B/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/RTC_TAMP3/RTC_TS/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/SYS_WKUP5/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/I2S1_MCK/SPDIFRX_IN2/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/SPDIFRX_IN3/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDMMC1_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDMMC1_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='DCMI_D2/SDMMC1_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDMMC1_D1/TIM3_CH4/TIM8_CH4/UART5_CTS/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDMMC1_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDMMC1_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='DCMI_D9/I2S3_SD/SDMMC1_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='97',name='PE0/DCMI_D2/FMC_NBL0/LPTIM1_ETR/SAI2_MCLK_A/TIM4_ETR/UART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/DCMI_D3/FMC_NBL1/LPTIM1_IN2/UART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/SAI1_SD_B/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SAI2_MCLK_B/SPI4_MOSI/SYS_TRACED3/TIM1_BKIN2/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PE7/FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE8/FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE9/DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/UART7_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE10/FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/UART7_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SAI2_SD_B/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE12/FMC_D9/FMC_DA9/LTDC_B4/SAI2_SCK_B/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE13/FMC_D10/FMC_DA10/LTDC_DE/SAI2_FS_B/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE14/FMC_D11/FMC_DA11/LTDC_CLK/SAI2_MCLK_B/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN1_RX/FMC_D2/FMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN1_TX/FMC_D3/FMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/DCMI_D11/SDMMC1_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FMC_NE1/SPDIFRX_IN0/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FMC_D13/FMC_DA13/SPDIFRX_IN1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FMC_D15/FMC_DA15/LTDC_B3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/I2C4_SMBA/QUADSPI_BK1_IO0/SAI2_SD_A/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FMC_A17/FMC_ALE/I2C4_SCL/LPTIM1_IN1/QUADSPI_BK1_IO1/SAI2_FS_A/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FMC_A18/I2C4_SDA/LPTIM1_OUT/QUADSPI_BK1_IO3/SAI2_SCK_A/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FMC_D0/FMC_DA0/TIM4_CH3/UART8_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/FMC_D1/FMC_DA1/TIM4_CH4/UART8_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F746ZETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M7 STM32F7 STM32F7x6',description='Core: ARM Cortex-M7 Package: LQFP144 Flash: 512KB Ram: 320KB Frequency: 216MHz Voltage: 1.7..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F746ZGTx'],pins=[
            Pin(num='34',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SAI2_SD_B/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/LTDC_R2/QUADSPI_BK1_IO3/SAI2_MCLK_B/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/LTDC_R1/SAI2_SCK_B/SYS_WKUP1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/TIM8_BKIN2/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN1_TX/LTDC_R5/SAI2_FS_B/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SPI3_MOSI/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='CAN2_TX/CEC/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDMMC1_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDMMC1_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/SAI2_FS_B/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/RTC_TAMP3/RTC_TS/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/SYS_WKUP5/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/I2S1_MCK/SPDIFRX_IN2/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/SPDIFRX_IN3/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDMMC1_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDMMC1_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='DCMI_D2/SDMMC1_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDMMC1_D1/TIM3_CH4/TIM8_CH4/UART5_CTS/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDMMC1_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDMMC1_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='DCMI_D9/I2S3_SD/SDMMC1_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D11/SDMMC1_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FMC_NE1/SPDIFRX_IN0/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FMC_D13/FMC_DA13/SPDIFRX_IN1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/I2C4_SMBA/QUADSPI_BK1_IO0/SAI2_SD_A/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FMC_A17/FMC_ALE/I2C4_SCL/LPTIM1_IN1/QUADSPI_BK1_IO1/SAI2_FS_A/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FMC_A18/I2C4_SDA/LPTIM1_OUT/QUADSPI_BK1_IO3/SAI2_SCK_A/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FMC_D0/FMC_DA0/TIM4_CH3/UART8_CTS/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='FMC_D1/FMC_DA1/TIM4_CH4/UART8_RTS/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='143',name='PDR_ON',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='106',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='56',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPDIFRX_IN2/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/SAI2_FS_B/SPDIFRX_IN3/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3/SAI2_SD_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/LTDC_B3/SPDIFRX_IN0',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FMC_NE4/LPTIM1_IN1/LTDC_B1/LTDC_B4/SPDIFRX_IN1/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/ETH_TXD0/FMC_A24/LPTIM1_OUT/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/ETH_TXD1/FMC_A25/LPTIM1_ETR/LTDC_B0/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/UART7_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/UART7_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC3_IN8/DCMI_D11/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SAI2_SD_B/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FMC_A7/I2C4_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FMC_A8/I2C4_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/FMC_A9/I2C4_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/DCMI_D2/FMC_NBL0/LPTIM1_ETR/SAI2_MCLK_A/TIM4_ETR/UART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/DCMI_D3/FMC_NBL1/LPTIM1_IN2/UART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/SAI1_SD_B/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SAI2_MCLK_B/SPI4_MOSI/SYS_TRACED3/TIM1_BKIN2/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/UART7_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/UART7_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SAI2_SD_B/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FMC_D9/FMC_DA9/LTDC_B4/SAI2_SCK_B/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FMC_D10/FMC_DA10/LTDC_DE/SAI2_FS_B/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FMC_D11/FMC_DA11/LTDC_CLK/SAI2_MCLK_B/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F746ZEYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M7 STM32F7 STM32F7x6',description='Core: ARM Cortex-M7 Package: WLCSP143 Flash: 512KB Ram: 320KB Frequency: 216MHz Voltage: 1.7..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32F746ZGYx'],pins=[
            Pin(num='K9',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SAI2_SD_B/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/LTDC_R2/QUADSPI_BK1_IO3/SAI2_MCLK_B/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/LTDC_R1/SAI2_SCK_B/SYS_WKUP1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='N10',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/TIM8_BKIN2/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='CAN1_TX/LTDC_R5/SAI2_FS_B/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='N8',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SPI3_MOSI/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='CAN2_TX/CEC/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDMMC1_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDMMC1_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N3',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N1',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/SAI2_FS_B/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/RTC_TAMP3/RTC_TS/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/SYS_WKUP5/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/I2S1_MCK/SPDIFRX_IN2/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='N9',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/SPDIFRX_IN3/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDMMC1_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDMMC1_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='DCMI_D2/SDMMC1_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDMMC1_D1/TIM3_CH4/TIM8_CH4/UART5_CTS/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDMMC1_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDMMC1_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='DCMI_D9/I2S3_SD/SDMMC1_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DCMI_D11/SDMMC1_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='FMC_NE1/SPDIFRX_IN0/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='FMC_D13/FMC_DA13/SPDIFRX_IN1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='M1',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/I2C4_SMBA/QUADSPI_BK1_IO0/SAI2_SD_A/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='FMC_A17/FMC_ALE/I2C4_SCL/LPTIM1_IN1/QUADSPI_BK1_IO1/SAI2_FS_A/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='FMC_A18/I2C4_SDA/LPTIM1_OUT/QUADSPI_BK1_IO3/SAI2_SCK_A/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='FMC_D0/FMC_DA0/TIM4_CH3/UART8_CTS/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='FMC_D1/FMC_DA1/TIM4_CH4/UART8_RTS/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='PDR_ON',do_erc=True),
            Pin(num='H9',name='NRST',do_erc=True),
            Pin(num='N11',name='BYPASS_REG',do_erc=True),
            Pin(num='C9',name='BOOT0',do_erc=True),
            Pin(num='C11',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='D1',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='L11',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='N2',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='J11',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H10',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='N6',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J1',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPDIFRX_IN2/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/SAI2_FS_B/SPDIFRX_IN3/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3/SAI2_SD_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/LTDC_B3/SPDIFRX_IN0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PG12/FMC_NE4/LPTIM1_IN1/LTDC_B1/LTDC_B4/SPDIFRX_IN1/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PG13/ETH_TXD0/FMC_A24/LPTIM1_OUT/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PG14/ETH_TXD1/FMC_A25/LPTIM1_ETR/LTDC_B0/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F11',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='G11',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G10',name='PF6/ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='PF7/ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PF8/ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/UART7_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='PF9/ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/UART7_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='PF10/ADC3_IN8/DCMI_D11/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SAI2_SD_B/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='PF13/FMC_A7/I2C4_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='PF14/FMC_A8/I2C4_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='PF15/FMC_A9/I2C4_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PE0/DCMI_D2/FMC_NBL0/LPTIM1_ETR/SAI2_MCLK_A/TIM4_ETR/UART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='PE1/DCMI_D3/FMC_NBL1/LPTIM1_IN2/UART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PE2/ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='PE3/FMC_A19/SAI1_SD_B/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='PE4/DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PE5/DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PE6/DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SAI2_MCLK_B/SPI4_MOSI/SYS_TRACED3/TIM1_BKIN2/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='PE7/FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='PE8/FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='PE9/DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/UART7_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PE10/FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/UART7_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SAI2_SD_B/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='PE12/FMC_D9/FMC_DA9/LTDC_B4/SAI2_SCK_B/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='PE13/FMC_D10/FMC_DA10/LTDC_DE/SAI2_FS_B/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='PE14/FMC_D11/FMC_DA11/LTDC_CLK/SAI2_MCLK_B/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PE15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L10',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='D2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F756BGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M7 STM32F7 STM32F7x6',description='Core: ARM Cortex-M7 Package: LQFP208 Flash: 1024KB Ram: 320KB Frequency: 216MHz Voltage: 1.7..3.6V IO-pins: 168',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='43',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SAI2_SD_B/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/LTDC_R2/QUADSPI_BK1_IO3/SAI2_MCLK_B/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/LTDC_R1/SAI2_SCK_B/SYS_WKUP1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/TIM8_BKIN2/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='143',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='144',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='145',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='146',name='CAN1_TX/LTDC_R5/SAI2_FS_B/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='147',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='159',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='160',name='CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SPI3_MOSI/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='192',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='193',name='I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='194',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='195',name='CAN2_TX/CEC/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='196',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='198',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDMMC1_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='199',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDMMC1_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='106',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='107',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/SAI2_FS_B/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/RTC_TAMP3/RTC_TS/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/SYS_WKUP5/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/I2S1_MCK/SPDIFRX_IN2/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/SPDIFRX_IN3/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='138',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDMMC1_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDMMC1_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='DCMI_D2/SDMMC1_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDMMC1_D1/TIM3_CH4/TIM8_CH4/UART5_CTS/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='161',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDMMC1_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='162',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDMMC1_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='163',name='DCMI_D9/I2S3_SD/SDMMC1_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='164',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='165',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='166',name='DCMI_D11/SDMMC1_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='167',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='168',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='169',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='172',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='173',name='FMC_NE1/SPDIFRX_IN0/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='108',name='FMC_D13/FMC_DA13/SPDIFRX_IN1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/I2C4_SMBA/QUADSPI_BK1_IO0/SAI2_SD_A/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='FMC_A17/FMC_ALE/I2C4_SCL/LPTIM1_IN1/QUADSPI_BK1_IO1/SAI2_FS_A/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='FMC_A18/I2C4_SDA/LPTIM1_OUT/QUADSPI_BK1_IO3/SAI2_SCK_A/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='FMC_D0/FMC_DA0/TIM4_CH3/UART8_CTS/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='FMC_D1/FMC_DA1/TIM4_CH4/UART8_RTS/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='200',name='DCMI_D2/FMC_NBL0/LPTIM1_ETR/SAI2_MCLK_A/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='201',name='DCMI_D3/FMC_NBL1/LPTIM1_IN2/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SAI2_MCLK_B/SPI4_MOSI/SYS_TRACED3/TIM1_BKIN2/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/UART7_RTS/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/UART7_CTS/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SAI2_SD_B/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='FMC_D9/FMC_DA9/LTDC_B4/SAI2_SCK_B/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='FMC_D10/FMC_DA10/LTDC_DE/SAI2_FS_B/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='FMC_D11/FMC_DA11/LTDC_CLK/SAI2_MCLK_B/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='FMC_A0/I2C2_SDA/PF0',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='FMC_A1/I2C2_SCL/PF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='FMC_A2/I2C2_SMBA/PF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC3_IN9/FMC_A3/PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC3_IN14/FMC_A4/PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC3_IN15/FMC_A5/PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX/PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX/PF7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/UART7_RTS/PF8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/UART7_CTS/PF9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC3_IN8/DCMI_D11/LTDC_DE/PF10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SAI2_SD_B/SPI5_MOSI/PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='FMC_A6/PF12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='FMC_A7/I2C4_SMBA/PF13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='FMC_A8/I2C4_SCL/PF14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='FMC_A9/I2C4_SDA/PF15',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='NRST',do_erc=True),
            Pin(num='203',name='PDR_ON',do_erc=True),
            Pin(num='197',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='41',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='92',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='148',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='126',name='PK0/LTDC_G5',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PK1/LTDC_G6',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PK2/LTDC_G7',func=Pin.BIDIR,do_erc=True),
            Pin(num='186',name='PK3/LTDC_B4',func=Pin.BIDIR,do_erc=True),
            Pin(num='187',name='PK4/LTDC_B5',func=Pin.BIDIR,do_erc=True),
            Pin(num='188',name='PK5/LTDC_B6',func=Pin.BIDIR,do_erc=True),
            Pin(num='189',name='PK6/LTDC_B7',func=Pin.BIDIR,do_erc=True),
            Pin(num='190',name='PK7/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PJ0/LTDC_R1',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PJ1/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PJ2/LTDC_R3',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PJ3/LTDC_R4',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='PJ4/LTDC_R5',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='PJ5/LTDC_R6',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='PJ6/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='PJ7/LTDC_G0',func=Pin.BIDIR,do_erc=True),
            Pin(num='120',name='PJ8/LTDC_G1',func=Pin.BIDIR,do_erc=True),
            Pin(num='121',name='PJ9/DAC_EXTI9/LTDC_G2',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='PJ10/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='PJ11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LTDC_G4',func=Pin.BIDIR,do_erc=True),
            Pin(num='174',name='PJ12/LTDC_B0',func=Pin.BIDIR,do_erc=True),
            Pin(num='175',name='PJ13/LTDC_B1',func=Pin.BIDIR,do_erc=True),
            Pin(num='176',name='PJ14/LTDC_B2',func=Pin.BIDIR,do_erc=True),
            Pin(num='177',name='PJ15/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='154',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='155',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK/TIM8_BKIN2',func=Pin.BIDIR,do_erc=True),
            Pin(num='156',name='PI2/DCMI_D9/FMC_D26/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='157',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='205',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/SAI2_MCLK_A/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='206',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/SAI2_SCK_A/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='207',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/SAI2_SD_A/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='208',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/SAI2_FS_A/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='PI8/RTC_TAMP2/RTC_TS/SYS_WKUP3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/SYS_WKUP4/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PI12/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PI13/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PI14/LTDC_CLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PI15/LTDC_R0',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='33',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='46',name='PH2/ETH_CRS/FMC_SDCKE0/LPTIM1_IN2/LTDC_R0/QUADSPI_BK2_IO0/SAI2_SCK_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1/QUADSPI_BK2_IO1/SAI2_MCLK_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='PH10/DCMI_D1/FMC_D18/I2C4_SMBA/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/I2C4_SCL/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='PH12/DCMI_D3/FMC_D20/I2C4_SDA/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='151',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='152',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='153',name='PH15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='130',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='131',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPDIFRX_IN2/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='178',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/SAI2_FS_B/SPDIFRX_IN3/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='179',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3/SAI2_SD_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='180',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/LTDC_B3/SPDIFRX_IN0',func=Pin.BIDIR,do_erc=True),
            Pin(num='181',name='PG12/FMC_NE4/LPTIM1_IN1/LTDC_B1/LTDC_B4/SPDIFRX_IN1/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='182',name='PG13/ETH_TXD0/FMC_A24/LPTIM1_OUT/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='183',name='PG14/ETH_TXD1/FMC_A25/LPTIM1_ETR/LTDC_B0/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='191',name='PG15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='59',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='103',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='115',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='124',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='150',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='158',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='171',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='185',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='204',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='42',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='137',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='25',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='60',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='82',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='93',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='114',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='125',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='136',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='149',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='170',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='184',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='202',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='40',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F756IGKx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M7 STM32F7 STM32F7x6',description='Core: ARM Cortex-M7 Package: UFBGA176 Flash: 1024KB Ram: 320KB Frequency: 216MHz Voltage: 1.7..3.6V IO-pins: 140',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='N3',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SAI2_SD_B/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/LTDC_R2/QUADSPI_BK1_IO3/SAI2_MCLK_B/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='P2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/LTDC_R1/SAI2_SCK_B/SYS_WKUP1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='R2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P4',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='P3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R3',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F15',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/TIM8_BKIN2/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E15',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D15',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C15',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B15',name='CAN1_TX/LTDC_R5/SAI2_FS_B/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A15',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A14',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A13',name='CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='R5',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='R4',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SPI3_MOSI/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN2_TX/CEC/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDMMC1_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDMMC1_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R12',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='R13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='P12',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='P13',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='R14',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R15',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/SAI2_FS_B/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/RTC_TAMP3/RTC_TS/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/SYS_WKUP5/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/I2S1_MCK/SPDIFRX_IN2/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P5',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/SPDIFRX_IN3/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H15',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDMMC1_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G15',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDMMC1_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G14',name='DCMI_D2/SDMMC1_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F14',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDMMC1_D1/TIM3_CH4/TIM8_CH4/UART5_CTS/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B14',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDMMC1_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDMMC1_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='DCMI_D9/I2S3_SD/SDMMC1_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DCMI_D11/SDMMC1_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='FMC_NE1/SPDIFRX_IN0/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P15',name='FMC_D13/FMC_DA13/SPDIFRX_IN1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P14',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='N15',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N14',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/I2C4_SMBA/QUADSPI_BK1_IO0/SAI2_SD_A/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='N13',name='FMC_A17/FMC_ALE/I2C4_SCL/LPTIM1_IN1/QUADSPI_BK1_IO1/SAI2_FS_A/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M15',name='FMC_A18/I2C4_SDA/LPTIM1_OUT/QUADSPI_BK1_IO3/SAI2_SCK_A/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='M14',name='FMC_D0/FMC_DA0/TIM4_CH3/UART8_CTS/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='L14',name='FMC_D1/FMC_DA1/TIM4_CH4/UART8_RTS/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='DCMI_D2/FMC_NBL0/LPTIM1_ETR/SAI2_MCLK_A/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DCMI_D3/FMC_NBL1/LPTIM1_IN2/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SAI2_MCLK_B/SPI4_MOSI/SYS_TRACED3/TIM1_BKIN2/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R8',name='FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='P8',name='FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P9',name='DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/UART7_RTS/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R9',name='FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/UART7_CTS/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SAI2_SD_B/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='R10',name='FMC_D9/FMC_DA9/LTDC_B4/SAI2_SCK_B/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='FMC_D10/FMC_DA10/LTDC_DE/SAI2_FS_B/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P11',name='FMC_D11/FMC_DA11/LTDC_CLK/SAI2_MCLK_B/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R11',name='FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PDR_ON',do_erc=True),
            Pin(num='J1',name='NRST',do_erc=True),
            Pin(num='L4',name='BYPASS_REG',do_erc=True),
            Pin(num='D6',name='BOOT0',do_erc=True),
            Pin(num='C1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='F13',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='M10',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='N1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='P1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='E14',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D14',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK/TIM8_BKIN2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C14',name='PI2/DCMI_D9/FMC_D26/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/SAI2_MCLK_A/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/SAI2_SCK_A/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/SAI2_SD_A/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/SAI2_FS_A/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PI8/RTC_TAMP2/RTC_TS/SYS_WKUP3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/SYS_WKUP4/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='F4',name='PH2/ETH_CRS/FMC_SDCKE0/LPTIM1_IN2/LTDC_R0/QUADSPI_BK2_IO0/SAI2_SCK_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1/QUADSPI_BK2_IO1/SAI2_MCLK_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='PH10/DCMI_D1/FMC_D18/I2C4_SMBA/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/I2C4_SCL/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='PH12/DCMI_D3/FMC_D20/I2C4_SDA/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PH15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L15',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K15',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K14',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J15',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='J14',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H14',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPDIFRX_IN2/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/SAI2_FS_B/SPDIFRX_IN3/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3/SAI2_SD_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/LTDC_B3/SPDIFRX_IN0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PG12/FMC_NE4/LPTIM1_IN1/LTDC_B1/LTDC_B4/SPDIFRX_IN1/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='PG13/ETH_TXD0/FMC_A24/LPTIM1_OUT/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG14/ETH_TXD1/FMC_A25/LPTIM1_ETR/LTDC_B0/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='PF6/ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='PF7/ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PF8/ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/UART7_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='PF9/ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/UART7_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='PF10/ADC3_IN8/DCMI_D11/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='R6',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SAI2_SD_B/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='P6',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='PF13/FMC_A7/I2C4_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='R7',name='PF14/FMC_A8/I2C4_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='P7',name='PF15/FMC_A9/I2C4_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J13',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='N10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='R1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='H13',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F756IGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M7 STM32F7 STM32F7x6',description='Core: ARM Cortex-M7 Package: LQFP176 Flash: 1024KB Ram: 320KB Frequency: 216MHz Voltage: 1.7..3.6V IO-pins: 140',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='40',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SAI2_SD_B/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/LTDC_R2/QUADSPI_BK1_IO3/SAI2_MCLK_B/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/LTDC_R1/SAI2_SCK_B/SYS_WKUP1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/TIM8_BKIN2/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='120',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='121',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='CAN1_TX/LTDC_R5/SAI2_FS_B/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='138',name='CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SPI3_MOSI/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='161',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='162',name='I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='163',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='164',name='CAN2_TX/CEC/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='165',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='167',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDMMC1_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='168',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDMMC1_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='94',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/SAI2_FS_B/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/RTC_TAMP3/RTC_TS/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/SYS_WKUP5/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/I2S1_MCK/SPDIFRX_IN2/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/SPDIFRX_IN3/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDMMC1_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDMMC1_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='DCMI_D2/SDMMC1_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDMMC1_D1/TIM3_CH4/TIM8_CH4/UART5_CTS/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDMMC1_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDMMC1_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='DCMI_D9/I2S3_SD/SDMMC1_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='143',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='144',name='DCMI_D11/SDMMC1_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='145',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='146',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='147',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='150',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='151',name='FMC_NE1/SPDIFRX_IN0/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='FMC_D13/FMC_DA13/SPDIFRX_IN1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/I2C4_SMBA/QUADSPI_BK1_IO0/SAI2_SD_A/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='FMC_A17/FMC_ALE/I2C4_SCL/LPTIM1_IN1/QUADSPI_BK1_IO1/SAI2_FS_A/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='FMC_A18/I2C4_SDA/LPTIM1_OUT/QUADSPI_BK1_IO3/SAI2_SCK_A/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='FMC_D0/FMC_DA0/TIM4_CH3/UART8_CTS/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='FMC_D1/FMC_DA1/TIM4_CH4/UART8_RTS/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='169',name='DCMI_D2/FMC_NBL0/LPTIM1_ETR/SAI2_MCLK_A/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='170',name='DCMI_D3/FMC_NBL1/LPTIM1_IN2/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SAI2_MCLK_B/SPI4_MOSI/SYS_TRACED3/TIM1_BKIN2/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/UART7_RTS/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/UART7_CTS/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SAI2_SD_B/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='FMC_D9/FMC_DA9/LTDC_B4/SAI2_SCK_B/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='FMC_D10/FMC_DA10/LTDC_DE/SAI2_FS_B/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FMC_D11/FMC_DA11/LTDC_CLK/SAI2_MCLK_B/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='NRST',do_erc=True),
            Pin(num='48',name='BYPASS_REG',do_erc=True),
            Pin(num='171',name='PDR_ON',do_erc=True),
            Pin(num='166',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='81',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='125',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK/TIM8_BKIN2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='PI2/DCMI_D9/FMC_D26/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='173',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/SAI2_MCLK_A/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='174',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/SAI2_SCK_A/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='175',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/SAI2_SD_A/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='176',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/SAI2_FS_A/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='PI8/RTC_TAMP2/RTC_TS/SYS_WKUP3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/SYS_WKUP4/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='30',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='43',name='PH2/ETH_CRS/FMC_SDCKE0/LPTIM1_IN2/LTDC_R0/QUADSPI_BK2_IO0/SAI2_SCK_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1/QUADSPI_BK2_IO1/SAI2_MCLK_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PH10/DCMI_D1/FMC_D18/I2C4_SMBA/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/I2C4_SCL/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PH12/DCMI_D3/FMC_D20/I2C4_SDA/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='130',name='PH15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='106',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='107',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='108',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPDIFRX_IN2/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='152',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/SAI2_FS_B/SPDIFRX_IN3/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='153',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3/SAI2_SD_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='154',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/LTDC_B3/SPDIFRX_IN0',func=Pin.BIDIR,do_erc=True),
            Pin(num='155',name='PG12/FMC_NE4/LPTIM1_IN1/LTDC_B1/LTDC_B4/SPDIFRX_IN1/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='156',name='PG13/ETH_TXD0/FMC_A24/LPTIM1_OUT/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='157',name='PG14/ETH_TXD1/FMC_A25/LPTIM1_ETR/LTDC_B0/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='160',name='PG15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PF6/ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PF7/ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PF8/ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/UART7_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PF9/ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/UART7_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PF10/ADC3_IN8/DCMI_D11/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SAI2_SD_B/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PF13/FMC_A7/I2C4_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PF14/FMC_A8/I2C4_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PF15/FMC_A9/I2C4_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='82',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='91',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='103',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='127',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='136',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='149',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='159',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='172',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='114',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='14',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='90',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='102',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='113',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='126',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='135',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='148',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='158',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='37',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F756NGHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M7 STM32F7 STM32F7x6',description='Core: ARM Cortex-M7 Package: TFBGA216 Flash: 1024KB Ram: 320KB Frequency: 216MHz Voltage: 1.7..3.6V IO-pins: 168',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='N3',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SAI2_SD_B/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N2',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/LTDC_R2/QUADSPI_BK1_IO3/SAI2_MCLK_B/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='P2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/LTDC_R1/SAI2_SCK_B/SYS_WKUP1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='R2',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P4',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='P3',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R3',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F15',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/TIM8_BKIN2/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E15',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D15',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C15',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B15',name='CAN1_TX/LTDC_R5/SAI2_FS_B/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A15',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A14',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A13',name='CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='R5',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='R4',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SPI3_MOSI/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='CAN2_TX/CEC/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDMMC1_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDMMC1_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='P12',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='R13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L13',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K14',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='R14',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R15',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/SAI2_FS_B/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/RTC_TAMP3/RTC_TS/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/SYS_WKUP5/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/I2S1_MCK/SPDIFRX_IN2/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='P5',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/SPDIFRX_IN3/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H15',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDMMC1_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G15',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDMMC1_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G14',name='DCMI_D2/SDMMC1_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F14',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDMMC1_D1/TIM3_CH4/TIM8_CH4/UART5_CTS/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B14',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDMMC1_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B13',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDMMC1_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='DCMI_D9/I2S3_SD/SDMMC1_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DCMI_D11/SDMMC1_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C11',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='FMC_NE1/SPDIFRX_IN0/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L15',name='FMC_D13/FMC_DA13/SPDIFRX_IN1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='L14',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='K15',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/I2C4_SMBA/QUADSPI_BK1_IO0/SAI2_SD_A/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='FMC_A17/FMC_ALE/I2C4_SCL/LPTIM1_IN1/QUADSPI_BK1_IO1/SAI2_FS_A/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='FMC_A18/I2C4_SDA/LPTIM1_OUT/QUADSPI_BK1_IO3/SAI2_SCK_A/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='FMC_D0/FMC_DA0/TIM4_CH3/UART8_CTS/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K13',name='FMC_D1/FMC_DA1/TIM4_CH4/UART8_RTS/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='DCMI_D2/FMC_NBL0/LPTIM1_ETR/SAI2_MCLK_A/TIM4_ETR/UART8_RX/PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='DCMI_D3/FMC_NBL1/LPTIM1_IN2/UART8_TX/PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK/PE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='FMC_A19/SAI1_SD_B/SYS_TRACED0/PE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1/PE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1/PE5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SAI2_MCLK_B/SPI4_MOSI/SYS_TRACED3/TIM1_BKIN2/TIM9_CH2/PE6',func=Pin.BIDIR,do_erc=True),
            Pin(num='R8',name='FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX/PE7',func=Pin.BIDIR,do_erc=True),
            Pin(num='N9',name='FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX/PE8',func=Pin.BIDIR,do_erc=True),
            Pin(num='P9',name='DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/UART7_RTS/PE9',func=Pin.BIDIR,do_erc=True),
            Pin(num='R9',name='FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/UART7_CTS/PE10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SAI2_SD_B/SPI4_NSS/TIM1_CH2/PE11',func=Pin.BIDIR,do_erc=True),
            Pin(num='R10',name='FMC_D9/FMC_DA9/LTDC_B4/SAI2_SCK_B/SPI4_SCK/TIM1_CH3N/PE12',func=Pin.BIDIR,do_erc=True),
            Pin(num='R12',name='FMC_D10/FMC_DA10/LTDC_DE/SAI2_FS_B/SPI4_MISO/TIM1_CH3/PE13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P11',name='FMC_D11/FMC_DA11/LTDC_CLK/SAI2_MCLK_B/SPI4_MOSI/TIM1_CH4/PE14',func=Pin.BIDIR,do_erc=True),
            Pin(num='R11',name='FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN/PE15',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='FMC_A0/I2C2_SDA/PF0',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='FMC_A1/I2C2_SCL/PF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='FMC_A2/I2C2_SMBA/PF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC3_IN9/FMC_A3/PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC3_IN14/FMC_A4/PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC3_IN15/FMC_A5/PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX/PF6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX/PF7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/UART7_RTS/PF8',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/UART7_CTS/PF9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='ADC3_IN8/DCMI_D11/LTDC_DE/PF10',func=Pin.BIDIR,do_erc=True),
            Pin(num='P8',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SAI2_SD_B/SPI5_MOSI/PF11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='FMC_A6/PF12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N6',name='FMC_A7/I2C4_SMBA/PF13',func=Pin.BIDIR,do_erc=True),
            Pin(num='P6',name='FMC_A8/I2C4_SCL/PF14',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='FMC_A9/I2C4_SDA/PF15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='PDR_ON',do_erc=True),
            Pin(num='J1',name='NRST',do_erc=True),
            Pin(num='L5',name='BYPASS_REG',do_erc=True),
            Pin(num='E6',name='BOOT0',do_erc=True),
            Pin(num='C1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='E11',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='L11',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='N1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='P1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='G13',name='PK0/LTDC_G5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F12',name='PK1/LTDC_G6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F13',name='PK2/LTDC_G7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PK3/LTDC_B4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PK4/LTDC_B5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PK5/LTDC_B6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PK6/LTDC_B7',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PK7/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='R6',name='PJ0/LTDC_R1',func=Pin.BIDIR,do_erc=True),
            Pin(num='R7',name='PJ1/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='P7',name='PJ2/LTDC_R3',func=Pin.BIDIR,do_erc=True),
            Pin(num='N8',name='PJ3/LTDC_R4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PJ4/LTDC_R5',func=Pin.BIDIR,do_erc=True),
            Pin(num='M14',name='PJ5/LTDC_R6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='PJ6/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PJ7/LTDC_G0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PJ8/LTDC_G1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J13',name='PJ9/DAC_EXTI9/LTDC_G2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H13',name='PJ10/LTDC_G3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G12',name='PJ11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LTDC_G4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PJ12/LTDC_B0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PJ13/LTDC_B1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PJ14/LTDC_B2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='PJ15/LTDC_B3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E14',name='PI0/DCMI_D13/FMC_D24/I2S2_WS/LTDC_G5/SPI2_NSS/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D14',name='PI1/DCMI_D8/FMC_D25/I2S2_CK/LTDC_G6/SPI2_SCK/TIM8_BKIN2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C14',name='PI2/DCMI_D9/FMC_D26/LTDC_G7/SPI2_MISO/TIM8_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C13',name='PI3/DCMI_D10/FMC_D27/I2S2_SD/SPI2_MOSI/TIM8_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PI4/DCMI_D5/FMC_NBL2/LTDC_B4/SAI2_MCLK_A/TIM8_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PI5/DCMI_VSYNC/FMC_NBL3/LTDC_B5/SAI2_SCK_A/TIM8_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PI6/DCMI_D6/FMC_D28/LTDC_B6/SAI2_SD_A/TIM8_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PI7/DCMI_D7/FMC_D29/LTDC_B7/SAI2_FS_A/TIM8_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PI8/RTC_TAMP2/RTC_TS/SYS_WKUP3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PI9/CAN1_RX/DAC_EXTI9/FMC_D30/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='PI10/ETH_RX_ER/FMC_D31/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PI11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/SYS_WKUP4/USB_OTG_HS_ULPI_DIR',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PI12/LTDC_HSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PI13/LTDC_VSYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PI14/LTDC_CLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PI15/LTDC_R0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='K4',name='PH2/ETH_CRS/FMC_SDCKE0/LPTIM1_IN2/LTDC_R0/QUADSPI_BK2_IO0/SAI2_SCK_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PH3/ETH_COL/FMC_SDNE0/LTDC_R1/QUADSPI_BK2_IO1/SAI2_MCLK_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PH4/I2C2_SCL/USB_OTG_HS_ULPI_NXT',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='PH5/FMC_SDNWE/I2C2_SDA/SPI5_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='P13',name='PH6/DCMI_D8/ETH_RXD2/FMC_SDNE1/I2C2_SMBA/SPI5_SCK/TIM12_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N13',name='PH7/DCMI_D9/ETH_RXD3/FMC_SDCKE1/I2C3_SCL/SPI5_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='P14',name='PH8/DCMI_HSYNC/FMC_D16/I2C3_SDA/LTDC_R2',func=Pin.BIDIR,do_erc=True),
            Pin(num='N14',name='PH9/DAC_EXTI9/DCMI_D0/FMC_D17/I2C3_SMBA/LTDC_R3/TIM12_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='P15',name='PH10/DCMI_D1/FMC_D18/I2C4_SMBA/LTDC_R4/TIM5_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='N15',name='PH11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D2/FMC_D19/I2C4_SCL/LTDC_R5/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M15',name='PH12/DCMI_D3/FMC_D20/I2C4_SDA/LTDC_R6/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='PH13/CAN1_TX/FMC_D21/LTDC_G2/TIM8_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='E13',name='PH14/DCMI_D4/FMC_D22/LTDC_G3/TIM8_CH2N',func=Pin.BIDIR,do_erc=True),
            Pin(num='D13',name='PH15/DCMI_D11/FMC_D23/LTDC_G4/TIM8_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M13',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='N12',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='N11',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J15',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='J14',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H14',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPDIFRX_IN2/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/SAI2_FS_B/SPDIFRX_IN3/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3/SAI2_SD_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/LTDC_B3/SPDIFRX_IN0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG12/FMC_NE4/LPTIM1_IN1/LTDC_B1/LTDC_B4/SPDIFRX_IN1/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PG13/ETH_TXD0/FMC_A24/LPTIM1_OUT/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PG14/ETH_TXD1/FMC_A25/LPTIM1_ETR/LTDC_B0/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PG15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='R1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='L6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F756VGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M7 STM32F7 STM32F7x6',description='Core: ARM Cortex-M7 Package: LQFP100 Flash: 1024KB Ram: 320KB Frequency: 216MHz Voltage: 1.7..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='22',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SAI2_SD_B/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/LTDC_R2/QUADSPI_BK1_IO3/SAI2_MCLK_B/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/LTDC_R1/SAI2_SCK_B/SYS_WKUP1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/TIM8_BKIN2/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN1_TX/LTDC_R5/SAI2_FS_B/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SPI3_MOSI/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='CAN2_TX/CEC/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDMMC1_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDMMC1_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/SAI2_FS_B/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/RTC_TAMP3/RTC_TS/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/SYS_WKUP5/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/I2S1_MCK/SPDIFRX_IN2/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/SPDIFRX_IN3/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDMMC1_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDMMC1_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='DCMI_D2/SDMMC1_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDMMC1_D1/TIM3_CH4/TIM8_CH4/UART5_CTS/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDMMC1_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDMMC1_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='DCMI_D9/I2S3_SD/SDMMC1_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='97',name='PE0/DCMI_D2/FMC_NBL0/LPTIM1_ETR/SAI2_MCLK_A/TIM4_ETR/UART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/DCMI_D3/FMC_NBL1/LPTIM1_IN2/UART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/SAI1_SD_B/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SAI2_MCLK_B/SPI4_MOSI/SYS_TRACED3/TIM1_BKIN2/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PE7/FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE8/FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE9/DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/UART7_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE10/FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/UART7_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SAI2_SD_B/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE12/FMC_D9/FMC_DA9/LTDC_B4/SAI2_SCK_B/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE13/FMC_D10/FMC_DA10/LTDC_DE/SAI2_FS_B/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE14/FMC_D11/FMC_DA11/LTDC_CLK/SAI2_MCLK_B/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN1_RX/FMC_D2/FMC_DA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN1_TX/FMC_D3/FMC_DA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/DCMI_D11/SDMMC1_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FMC_NOE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FMC_NE1/SPDIFRX_IN0/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FMC_D13/FMC_DA13/SPDIFRX_IN1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FMC_D15/FMC_DA15/LTDC_B3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/I2C4_SMBA/QUADSPI_BK1_IO0/SAI2_SD_A/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FMC_A17/FMC_ALE/I2C4_SCL/LPTIM1_IN1/QUADSPI_BK1_IO1/SAI2_FS_A/TIM4_CH1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FMC_A18/I2C4_SDA/LPTIM1_OUT/QUADSPI_BK1_IO3/SAI2_SCK_A/TIM4_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FMC_D0/FMC_DA0/TIM4_CH3/UART8_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/FMC_D1/FMC_DA1/TIM4_CH4/UART8_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='26',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F756ZGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M7 STM32F7 STM32F7x6',description='Core: ARM Cortex-M7 Package: LQFP144 Flash: 1024KB Ram: 320KB Frequency: 216MHz Voltage: 1.7..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='34',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SAI2_SD_B/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/LTDC_R2/QUADSPI_BK1_IO3/SAI2_MCLK_B/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/LTDC_R1/SAI2_SCK_B/SYS_WKUP1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/TIM8_BKIN2/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN1_TX/LTDC_R5/SAI2_FS_B/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SPI3_MOSI/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='CAN2_TX/CEC/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDMMC1_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDMMC1_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/SAI2_FS_B/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/RTC_TAMP3/RTC_TS/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/SYS_WKUP5/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/I2S1_MCK/SPDIFRX_IN2/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/SPDIFRX_IN3/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDMMC1_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDMMC1_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='DCMI_D2/SDMMC1_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDMMC1_D1/TIM3_CH4/TIM8_CH4/UART5_CTS/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDMMC1_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDMMC1_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='DCMI_D9/I2S3_SD/SDMMC1_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='DCMI_D11/SDMMC1_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FMC_NE1/SPDIFRX_IN0/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FMC_D13/FMC_DA13/SPDIFRX_IN1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/I2C4_SMBA/QUADSPI_BK1_IO0/SAI2_SD_A/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FMC_A17/FMC_ALE/I2C4_SCL/LPTIM1_IN1/QUADSPI_BK1_IO1/SAI2_FS_A/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FMC_A18/I2C4_SDA/LPTIM1_OUT/QUADSPI_BK1_IO3/SAI2_SCK_A/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FMC_D0/FMC_DA0/TIM4_CH3/UART8_CTS/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='FMC_D1/FMC_DA1/TIM4_CH4/UART8_RTS/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='143',name='PDR_ON',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='106',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='56',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPDIFRX_IN2/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/SAI2_FS_B/SPDIFRX_IN3/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3/SAI2_SD_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/LTDC_B3/SPDIFRX_IN0',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FMC_NE4/LPTIM1_IN1/LTDC_B1/LTDC_B4/SPDIFRX_IN1/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/ETH_TXD0/FMC_A24/LPTIM1_OUT/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/ETH_TXD1/FMC_A25/LPTIM1_ETR/LTDC_B0/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/UART7_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/UART7_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC3_IN8/DCMI_D11/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SAI2_SD_B/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/FMC_A7/I2C4_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/FMC_A8/I2C4_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/FMC_A9/I2C4_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/DCMI_D2/FMC_NBL0/LPTIM1_ETR/SAI2_MCLK_A/TIM4_ETR/UART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/DCMI_D3/FMC_NBL1/LPTIM1_IN2/UART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/SAI1_SD_B/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SAI2_MCLK_B/SPI4_MOSI/SYS_TRACED3/TIM1_BKIN2/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/UART7_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/UART7_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SAI2_SD_B/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FMC_D9/FMC_DA9/LTDC_B4/SAI2_SCK_B/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FMC_D10/FMC_DA10/LTDC_DE/SAI2_FS_B/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FMC_D11/FMC_DA11/LTDC_CLK/SAI2_MCLK_B/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32F756ZGYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M7 STM32F7 STM32F7x6',description='Core: ARM Cortex-M7 Package: WLCSP143 Flash: 1024KB Ram: 320KB Frequency: 216MHz Voltage: 1.7..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='K9',name='ADC1_IN0/ADC2_IN0/ADC3_IN0/ETH_CRS/SAI2_SD_B/SYS_WKUP0/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/ETH_REF_CLK/ETH_RX_CLK/LTDC_R2/QUADSPI_BK1_IO3/SAI2_MCLK_B/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/ETH_MDIO/LTDC_R1/SAI2_SCK_B/SYS_WKUP1/TIM2_CH3/TIM5_CH3/TIM9_CH1/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/ETH_COL/LTDC_B5/TIM2_CH4/TIM5_CH4/TIM9_CH2/USART2_RX/USB_OTG_HS_ULPI_D0/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='ADC1_IN4/ADC2_IN4/DAC_OUT1/DCMI_HSYNC/I2S1_WS/I2S3_WS/LTDC_VSYNC/SPI1_NSS/SPI3_NSS/USART2_CK/USB_OTG_HS_SOF/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='ADC1_IN5/ADC2_IN5/DAC_OUT2/I2S1_CK/LTDC_R4/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/USB_OTG_HS_ULPI_CK/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='N10',name='ADC1_IN6/ADC2_IN6/DCMI_PIXCLK/LTDC_G2/SPI1_MISO/TIM13_CH1/TIM1_BKIN/TIM3_CH1/TIM8_BKIN/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='ADC1_IN7/ADC2_IN7/ETH_CRS_DV/ETH_RX_DV/FMC_SDNWE/I2S1_SD/SPI1_MOSI/TIM14_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='I2C3_SCL/LTDC_R6/RCC_MCO_1/TIM1_CH1/TIM8_BKIN2/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='DAC_EXTI9/DCMI_D0/I2C3_SMBA/I2S2_CK/SPI2_SCK/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='DCMI_D1/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/LTDC_R4/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='CAN1_TX/LTDC_R5/SAI2_FS_B/TIM1_ETR/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='SYS_JTMS-SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='CEC/I2S1_WS/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='N8',name='ADC1_IN8/ADC2_IN8/ETH_RXD2/LTDC_R3/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/UART4_CTS/USB_OTG_HS_ULPI_D1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='ADC1_IN9/ADC2_IN9/ETH_RXD3/LTDC_R6/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USB_OTG_HS_ULPI_D2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='I2S3_SD/QUADSPI_CLK/SAI1_SD_A/SPI3_MOSI/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='I2S1_CK/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='I2S2_WS/SPI1_MISO/SPI2_NSS/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='CAN2_RX/DCMI_D10/ETH_PPS_OUT/FMC_SDCKE1/I2C1_SMBA/I2S1_SD/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/USB_OTG_HS_ULPI_D7/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='CAN2_TX/CEC/DCMI_D5/FMC_SDNE1/I2C1_SCL/QUADSPI_BK1_NCS/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='DCMI_VSYNC/FMC_NL/I2C1_SDA/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='CAN1_RX/DCMI_D6/ETH_TXD3/I2C1_SCL/LTDC_B6/SDMMC1_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='CAN1_TX/DAC_EXTI9/DCMI_D7/I2C1_SDA/I2S2_WS/LTDC_B7/SDMMC1_D5/SPI2_NSS/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ETH_RX_ER/I2C2_SCL/I2S2_CK/LTDC_G4/SPI2_SCK/TIM2_CH3/USART3_TX/USB_OTG_HS_ULPI_D3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='N3',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/ETH_TX_EN/I2C2_SDA/LTDC_G5/TIM2_CH4/USART3_RX/USB_OTG_HS_ULPI_D4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='CAN2_RX/ETH_TXD0/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM1_BKIN/USART3_CK/USB_OTG_HS_ID/USB_OTG_HS_ULPI_D5/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='N1',name='CAN2_TX/ETH_TXD1/I2S2_CK/SPI2_SCK/TIM1_CH1N/USART3_CTS/USB_OTG_HS_ULPI_D6/USB_OTG_HS_VBUS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='SPI2_MISO/TIM12_CH1/TIM1_CH2N/TIM8_CH2N/USART3_RTS/USB_OTG_HS_DM/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM12_CH2/TIM1_CH3N/TIM8_CH3N/USB_OTG_HS_DP/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='ADC1_IN10/ADC2_IN10/ADC3_IN10/FMC_SDNWE/LTDC_R5/SAI2_FS_B/USB_OTG_HS_ULPI_STP/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='ADC1_IN11/ADC2_IN11/ADC3_IN11/ETH_MDC/I2S2_SD/RTC_TAMP3/RTC_TS/SAI1_SD_A/SPI2_MOSI/SYS_TRACED0/SYS_WKUP5/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='ADC1_IN12/ADC2_IN12/ADC3_IN12/ETH_TXD2/FMC_SDNE0/SPI2_MISO/USB_OTG_HS_ULPI_DIR/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='ADC1_IN13/ADC2_IN13/ADC3_IN13/ETH_TX_CLK/FMC_SDCKE0/I2S2_SD/SPI2_MOSI/USB_OTG_HS_ULPI_NXT/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='ADC1_IN14/ADC2_IN14/ETH_RXD0/FMC_SDNE0/I2S1_MCK/SPDIFRX_IN2/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='N9',name='ADC1_IN15/ADC2_IN15/ETH_RXD1/FMC_SDCKE0/SPDIFRX_IN3/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='DCMI_D0/I2S2_MCK/LTDC_HSYNC/SDMMC1_D6/TIM3_CH1/TIM8_CH1/USART6_TX/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='DCMI_D1/I2S3_MCK/LTDC_G6/SDMMC1_D7/TIM3_CH2/TIM8_CH2/USART6_RX/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='DCMI_D2/SDMMC1_D0/SYS_TRACED1/TIM3_CH3/TIM8_CH3/UART5_RTS/USART6_CK/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='DAC_EXTI9/DCMI_D3/I2C3_SDA/I2S_CKIN/QUADSPI_BK1_IO0/RCC_MCO_2/SDMMC1_D1/TIM3_CH4/TIM8_CH4/UART5_CTS/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='DCMI_D8/I2S3_CK/LTDC_R2/QUADSPI_BK1_IO1/SDMMC1_D2/SPI3_SCK/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D4/QUADSPI_BK2_NCS/SDMMC1_D3/SPI3_MISO/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='DCMI_D9/I2S3_SD/SDMMC1_CK/SPI3_MOSI/SYS_TRACED3/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='CAN1_RX/FMC_D2/FMC_DA2/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='CAN1_TX/FMC_D3/FMC_DA3/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DCMI_D11/SDMMC1_CMD/SYS_TRACED2/TIM3_ETR/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='DCMI_D5/FMC_CLK/I2S2_CK/LTDC_G7/SPI2_SCK/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='FMC_NOE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='DCMI_D10/FMC_NWAIT/I2S3_SD/LTDC_B2/SAI1_SD_A/SPI3_MOSI/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='FMC_NE1/SPDIFRX_IN0/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='L2',name='FMC_D13/FMC_DA13/SPDIFRX_IN1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='M1',name='DAC_EXTI9/FMC_D14/FMC_DA14/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='FMC_D15/FMC_DA15/LTDC_B3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/I2C4_SMBA/QUADSPI_BK1_IO0/SAI2_SD_A/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='FMC_A17/FMC_ALE/I2C4_SCL/LPTIM1_IN1/QUADSPI_BK1_IO1/SAI2_FS_A/TIM4_CH1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='FMC_A18/I2C4_SDA/LPTIM1_OUT/QUADSPI_BK1_IO3/SAI2_SCK_A/TIM4_CH2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='FMC_D0/FMC_DA0/TIM4_CH3/UART8_CTS/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='FMC_D1/FMC_DA1/TIM4_CH4/UART8_RTS/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='PDR_ON',do_erc=True),
            Pin(num='H9',name='NRST',do_erc=True),
            Pin(num='N11',name='BYPASS_REG',do_erc=True),
            Pin(num='C9',name='BOOT0',do_erc=True),
            Pin(num='C11',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='D1',name='VCAP_2',func=Pin.PWRIN,do_erc=True),
            Pin(num='L11',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='N2',name='VCAP_1',func=Pin.PWRIN,do_erc=True),
            Pin(num='J11',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='H10',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='N6',name='PG0/FMC_A10',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='PG1/FMC_A11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J1',name='PG2/FMC_A12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PG3/FMC_A13',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='PG4/FMC_A14/FMC_BA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='PG5/FMC_A15/FMC_BA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PG6/DCMI_D12/LTDC_R7',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='PG7/DCMI_D13/FMC_INT3/LTDC_CLK/USART6_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PG8/ETH_PPS_OUT/FMC_SDCLK/SPDIFRX_IN2/SPI6_NSS/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='PG9/DAC_EXTI9/DCMI_VSYNC/FMC_NCE3/FMC_NE2/QUADSPI_BK2_IO2/SAI2_FS_B/SPDIFRX_IN3/USART6_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PG10/DCMI_D2/FMC_NE3/LTDC_B2/LTDC_G3/SAI2_SD_B',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D3/ETH_TX_EN/LTDC_B3/SPDIFRX_IN0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PG12/FMC_NE4/LPTIM1_IN1/LTDC_B1/LTDC_B4/SPDIFRX_IN1/SPI6_MISO/USART6_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PG13/ETH_TXD0/FMC_A24/LPTIM1_OUT/LTDC_R0/SPI6_SCK/SYS_TRACED0/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PG14/ETH_TXD1/FMC_A25/LPTIM1_ETR/LTDC_B0/QUADSPI_BK2_IO3/SPI6_MOSI/SYS_TRACED1/USART6_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='PG15/DCMI_D13/FMC_SDNCAS/USART6_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F11',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='G11',name='PF3/ADC3_IN9/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='PF4/ADC3_IN14/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='PF5/ADC3_IN15/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G10',name='PF6/ADC3_IN4/QUADSPI_BK1_IO3/SAI1_SD_B/SPI5_NSS/TIM10_CH1/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='PF7/ADC3_IN5/QUADSPI_BK1_IO2/SAI1_MCLK_B/SPI5_SCK/TIM11_CH1/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PF8/ADC3_IN6/QUADSPI_BK1_IO0/SAI1_SCK_B/SPI5_MISO/TIM13_CH1/UART7_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='PF9/ADC3_IN7/DAC_EXTI9/QUADSPI_BK1_IO1/SAI1_FS_B/SPI5_MOSI/TIM14_CH1/UART7_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='PF10/ADC3_IN8/DCMI_D11/LTDC_DE',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DCMI_D12/FMC_SDNRAS/SAI2_SD_B/SPI5_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='N7',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='PF13/FMC_A7/I2C4_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='PF14/FMC_A8/I2C4_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='PF15/FMC_A9/I2C4_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='PE0/DCMI_D2/FMC_NBL0/LPTIM1_ETR/SAI2_MCLK_A/TIM4_ETR/UART8_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='PE1/DCMI_D3/FMC_NBL1/LPTIM1_IN2/UART8_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PE2/ETH_TXD3/FMC_A23/QUADSPI_BK1_IO2/SAI1_MCLK_A/SPI4_SCK/SYS_TRACECLK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='PE3/FMC_A19/SAI1_SD_B/SYS_TRACED0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='PE4/DCMI_D4/FMC_A20/LTDC_B0/SAI1_FS_A/SPI4_NSS/SYS_TRACED1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PE5/DCMI_D6/FMC_A21/LTDC_G0/SAI1_SCK_A/SPI4_MISO/SYS_TRACED2/TIM9_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PE6/DCMI_D7/FMC_A22/LTDC_G1/SAI1_SD_A/SAI2_MCLK_B/SPI4_MOSI/SYS_TRACED3/TIM1_BKIN2/TIM9_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='PE7/FMC_D4/FMC_DA4/QUADSPI_BK2_IO0/TIM1_ETR/UART7_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='PE8/FMC_D5/FMC_DA5/QUADSPI_BK2_IO1/TIM1_CH1N/UART7_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='N5',name='PE9/DAC_EXTI9/FMC_D6/FMC_DA6/QUADSPI_BK2_IO2/TIM1_CH1/UART7_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PE10/FMC_D7/FMC_DA7/QUADSPI_BK2_IO3/TIM1_CH2N/UART7_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_D8/FMC_DA8/LTDC_G3/SAI2_SD_B/SPI4_NSS/TIM1_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='PE12/FMC_D9/FMC_DA9/LTDC_B4/SAI2_SCK_B/SPI4_SCK/TIM1_CH3N',func=Pin.BIDIR,do_erc=True),
            Pin(num='N4',name='PE13/FMC_D10/FMC_DA10/LTDC_DE/SAI2_FS_B/SPI4_MISO/TIM1_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='PE14/FMC_D11/FMC_DA11/LTDC_CLK/SAI2_MCLK_B/SPI4_MOSI/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='PE15/FMC_D12/FMC_DA12/LTDC_R7/TIM1_BKIN',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E10',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L10',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='D2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K10',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L031C4Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: LQFP48 Flash: 16KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 38',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L031C6Tx'],pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/LPTIM1_IN1/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/I2C1_SMBA/LPTIM1_IN2/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP3/RTC_TS/SYS_WKUP3/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/LPTIM1_IN1/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INM/COMP2_INM/LPTIM1_IN2/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/LPTIM1_ETR/LPUART1_CTS/SPI1_MISO/TIM22_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/LPTIM1_OUT/SPI1_MOSI/TIM22_CH2/USART2_CTS/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='LPTIM1_IN1/RCC_MCO/TIM2_CH1/USART2_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C1_SCL/RCC_MCO/TIM22_CH1/USART2_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2C1_SDA/TIM22_CH2/USART2_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TIM21_CH2/USART2_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/SPI1_MOSI/USART2_DE/USART2_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='LPTIM1_ETR/LPUART1_RX/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='I2C1_SMBA/LPTIM1_OUT/LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='1',name='PC0/LPTIM1_IN1/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/ANTI_TAMP/RTC_TAMP1/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/SPI1_MISO/SYS_VREF_OUT_PB0/TIM2_CH3/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SPI1_MOSI/SYS_VREF_OUT_PB1/TIM2_CH4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/LPTIM1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/SPI1_MISO/TIM22_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/TIM21_CH1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/I2C1_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/LPUART1_TX/TIM2_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/LPUART1_RX/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/SPI1_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/LPUART1_CTS/RCC_MCO/SPI1_SCK/TIM21_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI1_MISO/TIM21_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/RTC_REFIN/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L031E4Yx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: WLCSP25 Flash: 16KB Ram: 8KB Voltage: 1.65..3.6V IO-pins: 20',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L031E6Yx'],pins=[
            Pin(num='E5',name='ADC_IN0/COMP1_INM/COMP1_OUT/LPTIM1_IN1/RCC_CK_IN/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='ADC_IN1/COMP1_INP/I2C1_SMBA/LPTIM1_IN2/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP3/RTC_TS/SYS_WKUP3/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='ADC_IN4/COMP1_INM/COMP2_INM/LPTIM1_IN1/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='ADC_IN5/COMP1_INM/COMP2_INM/LPTIM1_IN2/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='ADC_IN6/COMP1_OUT/LPTIM1_ETR/LPUART1_CTS/SPI1_MISO/TIM22_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='ADC_IN7/COMP2_OUT/LPTIM1_OUT/SPI1_MOSI/TIM22_CH2/USART2_CTS/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='LPTIM1_IN1/RCC_MCO/TIM2_CH1/USART2_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='I2C1_SCL/RCC_MCO/TIM22_CH1/USART2_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='I2C1_SDA/TIM22_CH2/USART2_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='LPTIM1_ETR/LPUART1_RX/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='I2C1_SMBA/LPTIM1_OUT/LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='NRST',do_erc=True),
            Pin(num='A5',name='BOOT0',do_erc=True),
            Pin(num='B5',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PB0/ADC_IN8/SPI1_MISO/SYS_VREF_OUT_PB0/TIM2_CH3/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SPI1_MOSI/SYS_VREF_OUT_PB1/TIM2_CH4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/TIM21_CH1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C4',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='E1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L031F4Px',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: TSSOP20 Flash: 16KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 15',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L031F6Px'],pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/LPTIM1_IN1/RCC_CK_IN/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/I2C1_SMBA/LPTIM1_IN2/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP3/RTC_TS/SYS_WKUP3/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/LPTIM1_IN1/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/COMP1_INM/COMP2_INM/LPTIM1_IN2/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/LPTIM1_ETR/LPUART1_CTS/SPI1_MISO/TIM22_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/LPTIM1_OUT/SPI1_MOSI/TIM22_CH2/USART2_CTS/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='I2C1_SCL/RCC_MCO/TIM22_CH1/USART2_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='I2C1_SDA/TIM22_CH2/USART2_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='LPTIM1_ETR/LPUART1_RX/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SMBA/LPTIM1_OUT/LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='1',name='BOOT0',do_erc=True),
            Pin(num='2',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SPI1_MOSI/SYS_VREF_OUT_PB1/TIM2_CH4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='15',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L031G4Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: UFQFPN28 Flash: 16KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 23',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L031G6Ux'],pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/LPTIM1_IN1/RCC_CK_IN/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/I2C1_SMBA/LPTIM1_IN2/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP3/RTC_TS/SYS_WKUP3/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/LPTIM1_IN1/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/COMP1_INM/COMP2_INM/LPTIM1_IN2/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/LPTIM1_ETR/LPUART1_CTS/SPI1_MISO/TIM22_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/LPTIM1_OUT/SPI1_MOSI/TIM22_CH2/USART2_CTS/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='LPTIM1_IN1/RCC_MCO/TIM2_CH1/USART2_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='I2C1_SCL/RCC_MCO/TIM22_CH1/USART2_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SDA/TIM22_CH2/USART2_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='LPTIM1_ETR/LPUART1_RX/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='I2C1_SMBA/LPTIM1_OUT/LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='1',name='BOOT0',do_erc=True),
            Pin(num='2',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/SPI1_MISO/SYS_VREF_OUT_PB0/TIM2_CH3/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SPI1_MOSI/SYS_VREF_OUT_PB1/TIM2_CH4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB4/COMP2_INP/SPI1_MISO/TIM22_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/TIM21_CH1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='29',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L031K4Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: LQFP32 Flash: 16KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 25',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L031K6Tx'],pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/LPTIM1_IN1/RCC_CK_IN/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/I2C1_SMBA/LPTIM1_IN2/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP3/RTC_TS/SYS_WKUP3/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/LPTIM1_IN1/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/COMP1_INM/COMP2_INM/LPTIM1_IN2/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/LPTIM1_ETR/LPUART1_CTS/SPI1_MISO/TIM22_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/LPTIM1_OUT/SPI1_MOSI/TIM22_CH2/USART2_CTS/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='LPTIM1_IN1/RCC_MCO/TIM2_CH1/USART2_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='I2C1_SCL/RCC_MCO/TIM22_CH1/USART2_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SDA/TIM22_CH2/USART2_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TIM21_CH2/USART2_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='COMP2_OUT/SPI1_MOSI/USART2_DE/USART2_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='LPTIM1_ETR/LPUART1_RX/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='I2C1_SMBA/LPTIM1_OUT/LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/SPI1_MISO/SYS_VREF_OUT_PB0/TIM2_CH3/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SPI1_MOSI/SYS_VREF_OUT_PB1/TIM2_CH4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/COMP2_INP/SPI1_MISO/TIM22_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/TIM21_CH1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L031K4Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: UFQFPN32 Flash: 16KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 27',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L031K6Ux'],pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/LPTIM1_IN1/RCC_CK_IN/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/I2C1_SMBA/LPTIM1_IN2/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP3/RTC_TS/SYS_WKUP3/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/LPTIM1_IN1/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/COMP1_INM/COMP2_INM/LPTIM1_IN2/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/LPTIM1_ETR/LPUART1_CTS/SPI1_MISO/TIM22_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/LPTIM1_OUT/SPI1_MOSI/TIM22_CH2/USART2_CTS/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='LPTIM1_IN1/RCC_MCO/TIM2_CH1/USART2_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='I2C1_SCL/RCC_MCO/TIM22_CH1/USART2_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SDA/TIM22_CH2/USART2_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TIM21_CH2/USART2_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='COMP2_OUT/SPI1_MOSI/USART2_DE/USART2_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='LPTIM1_ETR/LPUART1_RX/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='I2C1_SMBA/LPTIM1_OUT/LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/SPI1_MISO/SYS_VREF_OUT_PB0/TIM2_CH3/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SPI1_MOSI/SYS_VREF_OUT_PB1/TIM2_CH4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PB2/LPTIM1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/COMP2_INP/SPI1_MISO/TIM22_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/TIM21_CH1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PB8/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L041C4Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: LQFP48 Flash: 16KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 38',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L041C6Tx'],pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/LPTIM1_IN1/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/I2C1_SMBA/LPTIM1_IN2/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP3/RTC_TS/SYS_WKUP3/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/LPTIM1_IN1/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INM/COMP2_INM/LPTIM1_IN2/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/LPTIM1_ETR/LPUART1_CTS/SPI1_MISO/TIM22_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/LPTIM1_OUT/SPI1_MOSI/TIM22_CH2/USART2_CTS/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='LPTIM1_IN1/RCC_MCO/TIM2_CH1/USART2_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C1_SCL/RCC_MCO/TIM22_CH1/USART2_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2C1_SDA/TIM22_CH2/USART2_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TIM21_CH2/USART2_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/SPI1_MOSI/USART2_DE/USART2_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='LPTIM1_ETR/LPUART1_RX/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='I2C1_SMBA/LPTIM1_OUT/LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='1',name='PC0/LPTIM1_IN1/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/ANTI_TAMP/RTC_TAMP1/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/SPI1_MISO/SYS_VREF_OUT_PB0/TIM2_CH3/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SPI1_MOSI/SYS_VREF_OUT_PB1/TIM2_CH4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/LPTIM1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/SPI1_MISO/TIM22_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/TIM21_CH1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/I2C1_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/LPUART1_TX/TIM2_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/LPUART1_RX/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/SPI1_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/LPUART1_CTS/RCC_MCO/SPI1_SCK/TIM21_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI1_MISO/TIM21_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/RTC_REFIN/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L041F6Px',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: TSSOP20 Flash: 32KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 15',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/LPTIM1_IN1/RCC_CK_IN/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/I2C1_SMBA/LPTIM1_IN2/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP3/RTC_TS/SYS_WKUP3/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/LPTIM1_IN1/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/COMP1_INM/COMP2_INM/LPTIM1_IN2/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/LPTIM1_ETR/LPUART1_CTS/SPI1_MISO/TIM22_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/LPTIM1_OUT/SPI1_MOSI/TIM22_CH2/USART2_CTS/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='I2C1_SCL/RCC_MCO/TIM22_CH1/USART2_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='I2C1_SDA/TIM22_CH2/USART2_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='LPTIM1_ETR/LPUART1_RX/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SMBA/LPTIM1_OUT/LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='1',name='BOOT0',do_erc=True),
            Pin(num='2',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SPI1_MOSI/SYS_VREF_OUT_PB1/TIM2_CH4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='15',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L041G6Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: UFQFPN28 Flash: 32KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 23',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/LPTIM1_IN1/RCC_CK_IN/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/I2C1_SMBA/LPTIM1_IN2/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP3/RTC_TS/SYS_WKUP3/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/LPTIM1_IN1/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/COMP1_INM/COMP2_INM/LPTIM1_IN2/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/LPTIM1_ETR/LPUART1_CTS/SPI1_MISO/TIM22_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/LPTIM1_OUT/SPI1_MOSI/TIM22_CH2/USART2_CTS/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='LPTIM1_IN1/RCC_MCO/TIM2_CH1/USART2_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='I2C1_SCL/RCC_MCO/TIM22_CH1/USART2_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SDA/TIM22_CH2/USART2_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='LPTIM1_ETR/LPUART1_RX/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='I2C1_SMBA/LPTIM1_OUT/LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='1',name='BOOT0',do_erc=True),
            Pin(num='2',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/SPI1_MISO/SYS_VREF_OUT_PB0/TIM2_CH3/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SPI1_MOSI/SYS_VREF_OUT_PB1/TIM2_CH4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB4/COMP2_INP/SPI1_MISO/TIM22_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/TIM21_CH1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='29',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L041K6Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: UFQFPN32 Flash: 32KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 27',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/LPTIM1_IN1/RCC_CK_IN/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/I2C1_SMBA/LPTIM1_IN2/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP3/RTC_TS/SYS_WKUP3/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/LPTIM1_IN1/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/COMP1_INM/COMP2_INM/LPTIM1_IN2/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/LPTIM1_ETR/LPUART1_CTS/SPI1_MISO/TIM22_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/LPTIM1_OUT/SPI1_MOSI/TIM22_CH2/USART2_CTS/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='LPTIM1_IN1/RCC_MCO/TIM2_CH1/USART2_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='I2C1_SCL/RCC_MCO/TIM22_CH1/USART2_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SDA/TIM22_CH2/USART2_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TIM21_CH2/USART2_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='COMP2_OUT/SPI1_MOSI/USART2_DE/USART2_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='LPTIM1_ETR/LPUART1_RX/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='I2C1_SMBA/LPTIM1_OUT/LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/SPI1_MISO/SYS_VREF_OUT_PB0/TIM2_CH3/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SPI1_MOSI/SYS_VREF_OUT_PB1/TIM2_CH4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PB2/LPTIM1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/COMP2_INP/SPI1_MISO/TIM22_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/TIM21_CH1/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PB8/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L051C6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: LQFP48 Flash: 32KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L051C8Tx'],pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CRS_SYNC/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='RCC_MCO/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/SPI1_MOSI/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/SYS_VREF_OUT_PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/LPTIM1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/SPI1_MISO/TIM22_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/I2C1_SDA/I2S2_WS/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/LPUART1_TX/SPI2_SCK/TIM2_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/LPUART1_RX/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C2_SCL/I2S2_CK/LPUART1_CTS/SPI2_SCK/TIM21_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/I2S2_SD/RTC_REFIN/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L051K6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: LQFP32 Flash: 32KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 25',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L051K8Tx'],pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/SPI1_MISO/TIM22_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='CRS_SYNC/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='RCC_MCO/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='COMP2_OUT/SPI1_MOSI/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/SYS_VREF_OUT_PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/SYS_VREF_OUT_PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/COMP2_INP/SPI1_MISO/TIM22_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L051K6Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: UFQFPN32 Flash: 32KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 27',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L051K8Ux'],pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/SPI1_MISO/TIM22_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='CRS_SYNC/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='RCC_MCO/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='COMP2_OUT/SPI1_MOSI/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/SYS_VREF_OUT_PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/SYS_VREF_OUT_PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PB2/LPTIM1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/COMP2_INP/SPI1_MISO/TIM22_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PB8/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L051R6Hx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: TFBGA64 Flash: 32KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L051R8Hx'],pins=[
            Pin(num='G2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC_IN3/COMP2_INP/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC_IN4/COMP1_INM/COMP2_INM/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='CRS_SYNC/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='RCC_MCO/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='COMP2_OUT/SPI1_MOSI/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN8/SYS_VREF_OUT_PB0/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='LPTIM1_OUT/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='COMP2_INM/SPI1_SCK/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='COMP2_INP/SPI1_MISO/TIM22_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='I2C1_SCL/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SDA/I2S2_WS/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='I2C2_SCL/LPUART1_TX/SPI2_SCK/TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_EXTI11/I2C2_SDA/LPUART1_RX/TIM2_CH4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='I2C2_SCL/I2S2_CK/LPUART1_CTS/SPI2_SCK/TIM21_CH1/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='B4',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='B5',name='PD2/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC0/ADC_IN10/LPTIM1_IN1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC1/ADC_IN11/LPTIM1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC2/ADC_IN12/I2S2_MCK/LPTIM1_IN2/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC_IN14/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC5/ADC_IN15/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC6/TIM22_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC7/TIM22_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC8/TIM22_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC9/TIM21_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC10/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC11/ADC_EXTI11/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L051R6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: LQFP64 Flash: 32KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L051R8Tx'],pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP2_INP/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INM/COMP2_INM/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='CRS_SYNC/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='RCC_MCO/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='COMP2_OUT/SPI1_MOSI/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/SYS_VREF_OUT_PB0/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='LPTIM1_OUT/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/SPI1_SCK/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/SPI1_MISO/TIM22_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='I2C1_SDA/I2S2_WS/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/LPUART1_TX/SPI2_SCK/TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/LPUART1_RX/TIM2_CH4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2C2_SCL/I2S2_CK/LPUART1_CTS/SPI2_SCK/TIM21_CH1/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/LPTIM1_IN1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/LPTIM1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/I2S2_MCK/LPTIM1_IN2/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/I2S2_SD/LPTIM1_ETR/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM22_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM22_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM22_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/TIM21_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L051T6Yx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: WLCSP36 Flash: 32KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 29',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L051T8Yx'],pins=[
            Pin(num='D4',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN3/COMP2_INP/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='ADC_IN4/COMP1_INM/COMP2_INM/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='CRS_SYNC/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_MCO/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='COMP2_OUT/SPI1_MOSI/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='NRST',do_erc=True),
            Pin(num='C5',name='BOOT0',do_erc=True),
            Pin(num='E6',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='A6',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PB0/ADC_IN8/SYS_VREF_OUT_PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PB2/LPTIM1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PB4/COMP2_INP/SPI1_MISO/TIM22_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='PB8/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PB10/I2C2_SCL/LPUART1_TX/TIM2_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PB11/ADC_EXTI11/I2C2_SDA/LPUART1_RX/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L052C6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x2',description='Core: ARM Cortex-M0+ Package: LQFP48 Flash: 32KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L052C8Tx'],pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CRS_SYNC/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/SYS_VREF_OUT_PB0/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/LPTIM1_OUT/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/SPI1_MISO/TIM22_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/I2S2_WS/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/LPUART1_RX/TIM2_CH4/TSC_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C2_SCL/I2S2_CK/LPUART1_CTS/SPI2_SCK/TIM21_CH1/TSC_G6_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/I2S2_SD/RTC_REFIN/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L052K6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x2',description='Core: ARM Cortex-M0+ Package: LQFP32 Flash: 32KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 25',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L052K8Tx'],pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/SPI1_MISO/TIM22_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='CRS_SYNC/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='DAC_EXTI9/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/SYS_VREF_OUT_PB0/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/SYS_VREF_OUT_PB1/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/COMP2_INP/SPI1_MISO/TIM22_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L052K6Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x2',description='Core: ARM Cortex-M0+ Package: UFQFPN32 Flash: 32KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 27',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L052K8Ux'],pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/SPI1_MISO/TIM22_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='CRS_SYNC/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='DAC_EXTI9/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/SYS_VREF_OUT_PB0/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/SYS_VREF_OUT_PB1/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PB2/LPTIM1_OUT/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/COMP2_INP/SPI1_MISO/TIM22_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PB8/I2C1_SCL/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L052R6Hx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x2',description='Core: ARM Cortex-M0+ Package: TFBGA64 Flash: 32KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L052R8Hx'],pins=[
            Pin(num='G2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC_IN3/COMP2_INP/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='CRS_SYNC/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='DAC_EXTI9/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN8/SYS_VREF_OUT_PB0/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='COMP2_INM/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='COMP2_INP/SPI1_MISO/TIM22_CH1/TSC_G5_IO2/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='I2C1_SCL/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='I2C2_SCL/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_EXTI11/I2C2_SDA/LPUART1_RX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='I2C2_SCL/I2S2_CK/LPUART1_CTS/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='B4',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='B5',name='PD2/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC0/ADC_IN10/LPTIM1_IN1/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC1/ADC_IN11/LPTIM1_OUT/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC2/ADC_IN12/I2S2_MCK/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC_IN14/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC5/ADC_IN15/LPUART1_RX/TSC_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC6/TIM22_CH1/TSC_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC7/TIM22_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC8/TIM22_ETR/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC9/DAC_EXTI9/TIM21_ETR/TSC_G8_IO4/USB_OE',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC10/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC11/ADC_EXTI11/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L052R6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x2',description='Core: ARM Cortex-M0+ Package: LQFP64 Flash: 32KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L052R8Tx'],pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP2_INP/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='CRS_SYNC/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/SYS_VREF_OUT_PB0/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/SPI1_MISO/TIM22_CH1/TSC_G5_IO2/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/LPUART1_RX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2C2_SCL/I2S2_CK/LPUART1_CTS/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/LPTIM1_IN1/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/LPTIM1_OUT/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/I2S2_MCK/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/I2S2_SD/LPTIM1_ETR/SPI2_MOSI/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/LPUART1_RX/TSC_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM22_CH1/TSC_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM22_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM22_ETR/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/TIM21_ETR/TSC_G8_IO4/USB_OE',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L052T6Yx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x2',description='Core: ARM Cortex-M0+ Package: WLCSP36 Flash: 32KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 29',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L052T8Yx'],pins=[
            Pin(num='D4',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN3/COMP2_INP/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='CRS_SYNC/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='DAC_EXTI9/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='NRST',do_erc=True),
            Pin(num='C5',name='BOOT0',do_erc=True),
            Pin(num='E6',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='A6',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PB0/ADC_IN8/SYS_VREF_OUT_PB0/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PB2/LPTIM1_OUT/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PB4/COMP2_INP/SPI1_MISO/TIM22_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='PB8/I2C1_SCL/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PB10/I2C2_SCL/LPUART1_TX/TIM2_CH3/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PB11/ADC_EXTI11/I2C2_SDA/LPUART1_RX/TIM2_CH4/TSC_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L053C6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x3',description='Core: ARM Cortex-M0+ Package: LQFP48 Flash: 32KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L053C8Tx'],pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/LCD_SEG1/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/LCD_SEG2/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/LCD_SEG3/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/LCD_SEG4/SPI1_MOSI/TIM22_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CRS_SYNC/LCD_COM0/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/LCD_COM1/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='LCD_COM2/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='LCD_SEG17/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/LCD_SEG5/LCD_VLCD3/SYS_VREF_OUT_PB0/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/LCD_SEG6/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/LCD_VLCD1/LPTIM1_OUT/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/LCD_SEG7/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/LCD_SEG8/SPI1_MISO/TIM22_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/LCD_SEG16/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/I2S2_WS/LCD_COM3/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/LCD_SEG10/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/LCD_SEG11/LPUART1_RX/TIM2_CH4/TSC_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2S2_WS/LCD_SEG12/LCD_VLCD2/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C2_SCL/I2S2_CK/LCD_SEG13/LPUART1_CTS/SPI2_SCK/TIM21_CH1/TSC_G6_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C2_SDA/I2S2_MCK/LCD_SEG14/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L053R6Hx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x3',description='Core: ARM Cortex-M0+ Package: TFBGA64 Flash: 32KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L053R8Hx'],pins=[
            Pin(num='G2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN2/COMP2_INM/COMP2_OUT/LCD_SEG1/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC_IN3/COMP2_INP/LCD_SEG2/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN6/COMP1_OUT/LCD_SEG3/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC_IN7/COMP2_OUT/LCD_SEG4/SPI1_MOSI/TIM22_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='CRS_SYNC/LCD_COM0/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='DAC_EXTI9/LCD_COM1/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='LCD_COM2/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='LCD_SEG17/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN8/LCD_SEG5/LCD_VLCD3/SYS_VREF_OUT_PB0/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN9/LCD_SEG6/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='LCD_VLCD1/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='COMP2_INM/LCD_SEG7/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='COMP2_INP/LCD_SEG8/SPI1_MISO/TIM22_CH1/TSC_G5_IO2/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='I2C1_SCL/LCD_SEG16/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/LCD_COM3/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='I2C2_SCL/LCD_SEG10/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/LPUART1_RX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='I2S2_WS/LCD_SEG12/LCD_VLCD2/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='I2C2_SCL/I2S2_CK/LCD_SEG13/LPUART1_CTS/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='I2C2_SDA/I2S2_MCK/LCD_SEG14/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='B4',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='B5',name='PD2/LCD_COM7/LCD_SEG31/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC0/ADC_IN10/LCD_SEG18/LPTIM1_IN1/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC1/ADC_IN11/LCD_SEG19/LPTIM1_OUT/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC2/ADC_IN12/I2S2_MCK/LCD_SEG20/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC_IN14/LCD_SEG22/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC5/ADC_IN15/LCD_SEG23/LPUART1_RX/TSC_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC6/LCD_SEG24/TIM22_CH1/TSC_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC7/LCD_SEG25/TIM22_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC8/LCD_SEG26/TIM22_ETR/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC9/DAC_EXTI9/LCD_SEG27/TIM21_ETR/TSC_G8_IO4/USB_OE',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC10/LCD_COM4/LCD_SEG28/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC12/LCD_COM6/LCD_SEG30',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L053R6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x3',description='Core: ARM Cortex-M0+ Package: LQFP64 Flash: 32KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L053R8Tx'],pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP2_INM/COMP2_OUT/LCD_SEG1/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP2_INP/LCD_SEG2/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_OUT/LCD_SEG3/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP2_OUT/LCD_SEG4/SPI1_MOSI/TIM22_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='CRS_SYNC/LCD_COM0/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/LCD_COM1/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='LCD_COM2/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='LCD_SEG17/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/LCD_SEG5/LCD_VLCD3/SYS_VREF_OUT_PB0/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/LCD_SEG6/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='LCD_VLCD1/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/LCD_SEG7/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/LCD_SEG8/SPI1_MISO/TIM22_CH1/TSC_G5_IO2/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/LCD_SEG16/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/LCD_COM3/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/LCD_SEG10/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/LPUART1_RX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2S2_WS/LCD_SEG12/LCD_VLCD2/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2C2_SCL/I2S2_CK/LCD_SEG13/LPUART1_CTS/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2C2_SDA/I2S2_MCK/LCD_SEG14/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LCD_COM7/LCD_SEG31/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/LCD_SEG18/LPTIM1_IN1/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/LCD_SEG19/LPTIM1_OUT/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/I2S2_MCK/LCD_SEG20/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/I2S2_SD/LCD_SEG21/LPTIM1_ETR/SPI2_MOSI/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/LCD_SEG22/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/LCD_SEG23/LPUART1_RX/TSC_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/LCD_SEG24/TIM22_CH1/TSC_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/LCD_SEG25/TIM22_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/LCD_SEG26/TIM22_ETR/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/LCD_SEG27/TIM21_ETR/TSC_G8_IO4/USB_OE',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/LCD_COM4/LCD_SEG28/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/LCD_COM6/LCD_SEG30',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L062K8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x2',description='Core: ARM Cortex-M0+ Package: LQFP32 Flash: 64KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 25',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/SPI1_MISO/TIM22_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='CRS_SYNC/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='DAC_EXTI9/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/SYS_VREF_OUT_PB0/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/SYS_VREF_OUT_PB1/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/COMP2_INP/SPI1_MISO/TIM22_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L062K8Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x2',description='Core: ARM Cortex-M0+ Package: UFQFPN32 Flash: 64KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 27',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/SPI1_MISO/TIM22_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='CRS_SYNC/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='DAC_EXTI9/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/SYS_VREF_OUT_PB0/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/SYS_VREF_OUT_PB1/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='PB2/LPTIM1_OUT/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/COMP2_INP/SPI1_MISO/TIM22_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='PB8/I2C1_SCL/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L063C8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x3',description='Core: ARM Cortex-M0+ Package: LQFP48 Flash: 64KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/LCD_SEG1/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/LCD_SEG2/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/LCD_SEG3/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/LCD_SEG4/SPI1_MOSI/TIM22_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CRS_SYNC/LCD_COM0/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/LCD_COM1/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='LCD_COM2/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='LCD_SEG17/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/LCD_SEG5/LCD_VLCD3/SYS_VREF_OUT_PB0/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/LCD_SEG6/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/LCD_VLCD1/LPTIM1_OUT/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/LCD_SEG7/SPI1_SCK/TIM2_CH2/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/LCD_SEG8/SPI1_MISO/TIM22_CH1/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/LCD_SEG16/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/I2S2_WS/LCD_COM3/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/LCD_SEG10/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/LCD_SEG11/LPUART1_RX/TIM2_CH4/TSC_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2S2_WS/LCD_SEG12/LCD_VLCD2/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C2_SCL/I2S2_CK/LCD_SEG13/LPUART1_CTS/SPI2_SCK/TIM21_CH1/TSC_G6_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C2_SDA/I2S2_MCK/LCD_SEG14/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L063R8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x3',description='Core: ARM Cortex-M0+ Package: LQFP64 Flash: 64KB Ram: 8KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP2_INM/COMP2_OUT/LCD_SEG1/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP2_INP/LCD_SEG2/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_OUT/LCD_SEG3/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP2_OUT/LCD_SEG4/SPI1_MOSI/TIM22_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='CRS_SYNC/LCD_COM0/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/LCD_COM1/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='LCD_COM2/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='LCD_SEG17/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/LCD_SEG5/LCD_VLCD3/SYS_VREF_OUT_PB0/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/LCD_SEG6/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='LCD_VLCD1/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/LCD_SEG7/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/LCD_SEG8/SPI1_MISO/TIM22_CH1/TSC_G5_IO2/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/LCD_SEG16/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/LCD_COM3/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/LCD_SEG10/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/LPUART1_RX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2S2_WS/LCD_SEG12/LCD_VLCD2/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2C2_SCL/I2S2_CK/LCD_SEG13/LPUART1_CTS/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2C2_SDA/I2S2_MCK/LCD_SEG14/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LCD_COM7/LCD_SEG31/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/LCD_SEG18/LPTIM1_IN1/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/LCD_SEG19/LPTIM1_OUT/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/I2S2_MCK/LCD_SEG20/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/I2S2_SD/LCD_SEG21/LPTIM1_ETR/SPI2_MOSI/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/LCD_SEG22/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/LCD_SEG23/LPUART1_RX/TSC_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/LCD_SEG24/TIM22_CH1/TSC_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/LCD_SEG25/TIM22_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/LCD_SEG26/TIM22_ETR/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/LCD_SEG27/TIM21_ETR/TSC_G8_IO4/USB_OE',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/LCD_COM4/LCD_SEG28/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/LCD_COM6/LCD_SEG30',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L071CBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: LQFP48 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L071CZTx'],pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C1_SCL/I2C3_SMBA/RCC_MCO/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2C1_SDA/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/SPI1_MOSI/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='LPUART1_RX/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/I2C3_SMBA/LPTIM1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2/USART1_DE/USART1_RTS/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/USART1_CTS/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/I2C1_SDA/I2S2_WS/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/LPUART1_RX/LPUART1_TX/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C2_SCL/I2S2_CK/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/I2S2_SD/RTC_REFIN/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L071CBYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: WLCSP49 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 40',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L071CZYx'],pins=[
            Pin(num='E5',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN4/COMP1_INM/COMP2_INM/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='I2C1_SCL/I2C3_SMBA/RCC_MCO/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='I2C1_SDA/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='COMP2_OUT/SPI1_MOSI/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='LPUART1_RX/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='NRST',do_erc=True),
            Pin(num='A5',name='BOOT0',do_erc=True),
            Pin(num='E6',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='D7',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='C5',name='PC0/ADC_IN10/I2C3_SCL/LPTIM1_IN1/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PC1/ADC_IN11/I2C3_SDA/LPTIM1_OUT/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC2/ADC_IN12/I2S2_MCK/LPTIM1_IN2/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PB0/ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PB2/I2C3_SMBA/LPTIM1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2/USART1_DE/USART1_RTS/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PB4/COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/USART1_CTS/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='PB8/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PB9/I2C1_SDA/I2S2_WS/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PB10/I2C2_SCL/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PB11/ADC_EXTI11/I2C2_SDA/LPUART1_RX/LPUART1_TX/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='PB12/I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PB13/I2C2_SCL/I2S2_CK/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PB14/I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='PB15/I2S2_SD/RTC_REFIN/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='B6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='A1',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L071C8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: LQFP48 Flash: 64KB Ram: 20KB IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='I2C1_SCL/I2C3_SMBA/RCC_MCO/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2C1_SDA/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/SPI1_MOSI/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='LPUART1_RX/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/I2C3_SMBA/LPTIM1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2/USART1_DE/USART1_RTS/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/USART1_CTS/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/I2C1_SDA/I2S2_WS/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/LPUART1_RX/LPUART1_TX/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C2_SCL/I2S2_CK/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/I2S2_SD/RTC_REFIN/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L071KBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: LQFP32 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 25',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L071KZTx'],pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='I2C1_SCL/I2C3_SMBA/RCC_MCO/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SDA/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='COMP2_OUT/SPI1_MOSI/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='LPUART1_RX/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2/USART1_DE/USART1_RTS/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/USART1_CTS/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L071KBUx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: UFQFPN32 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 23',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L071KZUx'],pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='I2C1_SCL/I2C3_SMBA/RCC_MCO/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SDA/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='COMP2_OUT/SPI1_MOSI/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='LPUART1_RX/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='NRST',do_erc=True),
            Pin(num='30',name='BOOT0',do_erc=True),
            Pin(num='1',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB4/COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/USART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='24',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L071K8Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: UFQFPN32 Flash: 64KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 23',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='I2C1_SCL/I2C3_SMBA/RCC_MCO/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SDA/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='COMP2_OUT/SPI1_MOSI/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='LPUART1_RX/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='NRST',do_erc=True),
            Pin(num='30',name='BOOT0',do_erc=True),
            Pin(num='1',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB4/COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/USART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='24',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L071RBHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: TFBGA64 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L071RZHx'],pins=[
            Pin(num='G2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC_IN4/COMP1_INM/COMP2_INM/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='I2C1_SCL/I2C3_SMBA/RCC_MCO/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='I2C1_SDA/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='COMP2_OUT/SPI1_MOSI/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='LPUART1_RX/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='I2C3_SMBA/LPTIM1_OUT/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='COMP2_INM/SPI1_SCK/TIM2_CH2/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='I2C1_SCL/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SDA/I2S2_WS/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='I2C2_SCL/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_EXTI11/I2C2_SDA/LPUART1_RX/LPUART1_TX/TIM2_CH4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='I2C2_SCL/I2S2_CK/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='B4',name='BOOT0',do_erc=True),
            Pin(num='G1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='B5',name='PD2/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC0/ADC_IN10/I2C3_SCL/LPTIM1_IN1/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC1/ADC_IN11/I2C3_SDA/LPTIM1_OUT/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC2/ADC_IN12/I2S2_MCK/LPTIM1_IN2/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC_IN14/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC5/ADC_IN15/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC6/TIM22_CH1/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC7/TIM22_CH2/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC8/TIM22_ETR/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC9/I2C3_SDA/TIM21_ETR/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC10/LPUART1_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC11/ADC_EXTI11/LPUART1_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC12/USART4_CK/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L071RBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: LQFP64 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L071RZTx'],pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INM/COMP2_INM/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='I2C1_SCL/I2C3_SMBA/RCC_MCO/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='I2C1_SDA/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='COMP2_OUT/SPI1_MOSI/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='LPUART1_RX/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='I2C3_SMBA/LPTIM1_OUT/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/SPI1_SCK/TIM2_CH2/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='I2C1_SDA/I2S2_WS/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/LPUART1_RX/LPUART1_TX/TIM2_CH4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2C2_SCL/I2S2_CK/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/I2C3_SCL/LPTIM1_IN1/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/I2C3_SDA/LPTIM1_OUT/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/I2S2_MCK/LPTIM1_IN2/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/I2S2_SD/LPTIM1_ETR/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM22_CH1/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM22_CH2/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM22_ETR/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/I2C3_SDA/TIM21_ETR/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/LPUART1_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/LPUART1_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/USART4_CK/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L071VBIx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: UFBGA100 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 84',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L071VZIx'],pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC_IN4/COMP1_INM/COMP2_INM/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='I2C1_SCL/I2C3_SMBA/RCC_MCO/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='I2C1_SDA/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='COMP2_OUT/SPI1_MOSI/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='LPUART1_RX/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='I2C3_SMBA/LPTIM1_OUT/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/SPI1_SCK/TIM2_CH2/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='I2C1_SDA/I2S2_WS/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC_EXTI11/I2C2_SDA/LPUART1_RX/LPUART1_TX/TIM2_CH4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='I2C2_SCL/I2S2_CK/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/I2C3_SCL/LPTIM1_IN1/LPUART1_RX/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/I2C3_SDA/LPTIM1_OUT/LPUART1_TX/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/I2S2_MCK/LPTIM1_IN2/SPI2_MISO/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/I2S2_SD/LPTIM1_ETR/SPI2_MOSI/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/LPUART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/LPUART1_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='TIM22_CH1/TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='TIM22_CH2/TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='TIM22_ETR/TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='I2C3_SDA/TIM21_ETR/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='LPUART1_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC_EXTI11/LPUART1_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='USART4_CK/USART5_TX/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='K1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='F2',name='PH9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PH10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/TIM22_CH1/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/TIM22_CH2/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/TIM21_CH1/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM21_CH2/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/TIM2_CH1/TIM2_ETR/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/TIM2_CH2/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC_EXTI11/TIM2_CH3/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/SPI1_NSS/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/SPI1_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0/I2S2_WS/SPI2_NSS/TIM21_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/I2S2_MCK/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/TIM21_CH2/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/ADC_EXTI11/LPUART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L071VBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: LQFP100 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 84',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L071VZTx'],pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INM/COMP2_INM/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='I2C1_SCL/I2C3_SMBA/RCC_MCO/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C1_SDA/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='COMP2_OUT/SPI1_MOSI/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='LPUART1_RX/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='I2C3_SMBA/LPTIM1_OUT/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/SPI1_SCK/TIM2_CH2/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='I2C1_SDA/I2S2_WS/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/LPUART1_RX/LPUART1_TX/TIM2_CH4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='I2C2_SCL/I2S2_CK/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/I2C3_SCL/LPTIM1_IN1/LPUART1_RX/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/I2C3_SDA/LPTIM1_OUT/LPUART1_TX/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/I2S2_MCK/LPTIM1_IN2/SPI2_MISO/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/I2S2_SD/LPTIM1_ETR/SPI2_MOSI/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/LPUART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/LPUART1_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='TIM22_CH1/TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='TIM22_CH2/TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM22_ETR/TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='I2C3_SDA/TIM21_ETR/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='LPUART1_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/LPUART1_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='USART4_CK/USART5_TX/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='10',name='PH9',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PH10',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/TIM22_CH1/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/TIM22_CH2/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/TIM21_CH1/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM21_CH2/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/TIM2_CH1/TIM2_ETR/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/TIM2_CH2/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/TIM2_CH3/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/SPI1_NSS/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/SPI1_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/I2S2_WS/SPI2_NSS/TIM21_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/I2S2_MCK/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM21_CH2/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/LPUART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L071V8Ix',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: UFBGA100 Flash: 64KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 84',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC_IN4/COMP1_INM/COMP2_INM/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='I2C1_SCL/I2C3_SMBA/RCC_MCO/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='I2C1_SDA/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='COMP2_OUT/SPI1_MOSI/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='LPUART1_RX/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='I2C3_SMBA/LPTIM1_OUT/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/SPI1_SCK/TIM2_CH2/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='I2C1_SDA/I2S2_WS/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC_EXTI11/I2C2_SDA/LPUART1_RX/LPUART1_TX/TIM2_CH4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='I2C2_SCL/I2S2_CK/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/I2C3_SCL/LPTIM1_IN1/LPUART1_RX/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/I2C3_SDA/LPTIM1_OUT/LPUART1_TX/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/I2S2_MCK/LPTIM1_IN2/SPI2_MISO/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/I2S2_SD/LPTIM1_ETR/SPI2_MOSI/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/LPUART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/LPUART1_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='TIM22_CH1/TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='TIM22_CH2/TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='TIM22_ETR/TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='I2C3_SDA/TIM21_ETR/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='LPUART1_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC_EXTI11/LPUART1_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='USART4_CK/USART5_TX/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='K1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='F2',name='PH9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PH10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/TIM22_CH1/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/TIM22_CH2/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/TIM21_CH1/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM21_CH2/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/TIM2_CH1/TIM2_ETR/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/TIM2_CH2/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC_EXTI11/TIM2_CH3/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/SPI1_NSS/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/SPI1_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0/I2S2_WS/SPI2_NSS/TIM21_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/I2S2_MCK/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/TIM21_CH2/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/ADC_EXTI11/LPUART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L071V8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x1',description='Core: ARM Cortex-M0+ Package: LQFP100 Flash: 64KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 84',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INM/COMP2_INM/SPI1_NSS/TIM22_ETR/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INM/COMP2_INM/SPI1_SCK/TIM2_CH1/TIM2_ETR/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='I2C1_SCL/I2C3_SMBA/RCC_MCO/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C1_SDA/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/USART1_CTS/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='COMP2_OUT/SPI1_MOSI/USART1_DE/USART1_RTS/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='LPUART1_RX/SYS_SWDIO/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='I2C3_SMBA/LPTIM1_OUT/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/SPI1_SCK/TIM2_CH2/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='I2C1_SDA/I2S2_WS/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/LPUART1_RX/LPUART1_TX/TIM2_CH4/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='I2C2_SCL/I2S2_CK/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/I2C3_SCL/LPTIM1_IN1/LPUART1_RX/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/I2C3_SDA/LPTIM1_OUT/LPUART1_TX/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/I2S2_MCK/LPTIM1_IN2/SPI2_MISO/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/I2S2_SD/LPTIM1_ETR/SPI2_MOSI/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/LPUART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/LPUART1_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='TIM22_CH1/TIM3_CH1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='TIM22_CH2/TIM3_CH2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM22_ETR/TIM3_CH3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='I2C3_SDA/TIM21_ETR/TIM3_CH4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='LPUART1_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/LPUART1_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='USART4_CK/USART5_TX/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='10',name='PH9',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PH10',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/TIM22_CH1/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/TIM22_CH2/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/TIM21_CH1/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM21_CH2/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/TIM2_CH1/TIM2_ETR/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/TIM2_CH2/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/TIM2_CH3/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/SPI1_NSS/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/SPI1_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/I2S2_WS/SPI2_NSS/TIM21_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/I2S2_MCK/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM21_CH2/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/LPUART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L072CBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x2',description='Core: ARM Cortex-M0+ Package: LQFP48 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L072CZTx'],pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CRS_SYNC/I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2C1_SDA/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/I2C3_SMBA/LPTIM1_OUT/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/I2S2_WS/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C2_SCL/I2S2_CK/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/I2S2_SD/RTC_REFIN/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L072CBYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x2',description='Core: ARM Cortex-M0+ Package: WLCSP49 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 40',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L072CZYx'],pins=[
            Pin(num='E5',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='CRS_SYNC/I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='I2C1_SDA/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='I2C3_SMBA/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='COMP2_INM/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2C1_SCL/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='I2C2_SCL/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_EXTI11/I2C2_SDA/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='I2C2_SCL/I2S2_CK/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='NRST',do_erc=True),
            Pin(num='A5',name='BOOT0',do_erc=True),
            Pin(num='B6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='D7',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='C5',name='PC0/ADC_IN10/I2C3_SCL/LPTIM1_IN1/LPUART1_RX/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PC1/ADC_IN11/I2C3_SDA/LPTIM1_OUT/LPUART1_TX/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC2/ADC_IN12/I2S2_MCK/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='A1',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L072KBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x2',description='Core: ARM Cortex-M0+ Package: LQFP32 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..--V IO-pins: 25',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L072KZTx'],pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='CRS_SYNC/I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SDA/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='NRST',do_erc=True),
            Pin(num='31',name='BOOT0',do_erc=True),
            Pin(num='2',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB3/COMP2_INM/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB4/COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VSS',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L072KBUx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x2',description='Core: ARM Cortex-M0+ Package: UFQFPN32 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..--V IO-pins: 23',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L072KZUx'],pins=[
            Pin(num='6',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='CRS_SYNC/I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='I2C1_SDA/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='NRST',do_erc=True),
            Pin(num='30',name='BOOT0',do_erc=True),
            Pin(num='1',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PB0/ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PB1/ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB4/COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB5/COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='24',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='4',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L072RBHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x2',description='Core: ARM Cortex-M0+ Package: TFBGA64 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L072RZHx'],pins=[
            Pin(num='G2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='CRS_SYNC/I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='I2C1_SDA/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='I2C3_SMBA/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='COMP2_INM/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='I2C1_SCL/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='I2C2_SCL/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_EXTI11/I2C2_SDA/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='I2C2_SCL/I2S2_CK/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='B4',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='B5',name='PD2/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC0/ADC_IN10/I2C3_SCL/LPTIM1_IN1/LPUART1_RX/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC1/ADC_IN11/I2C3_SDA/LPTIM1_OUT/LPUART1_TX/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC2/ADC_IN12/I2S2_MCK/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC_IN14/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC5/ADC_IN15/LPUART1_RX/TSC_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC6/TIM22_CH1/TIM3_CH1/TSC_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC7/TIM22_CH2/TIM3_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC8/TIM22_ETR/TIM3_CH3/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC9/DAC_EXTI9/I2C3_SDA/TIM21_ETR/TIM3_CH4/TSC_G8_IO4/USB_OE',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC10/LPUART1_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC11/ADC_EXTI11/LPUART1_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC12/USART4_CK/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L072RBIx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x2',description='Core: ARM Cortex-M0+ Package: UFBGA64 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L072RZIx'],pins=[
            Pin(num='G2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='CRS_SYNC/I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='I2C1_SDA/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='I2C3_SMBA/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='COMP2_INM/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='I2C1_SCL/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='I2C2_SCL/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_EXTI11/I2C2_SDA/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='I2C2_SCL/I2S2_CK/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='B4',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='B5',name='PD2/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC0/ADC_IN10/I2C3_SCL/LPTIM1_IN1/LPUART1_RX/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC1/ADC_IN11/I2C3_SDA/LPTIM1_OUT/LPUART1_TX/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC2/ADC_IN12/I2S2_MCK/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC_IN14/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC5/ADC_IN15/LPUART1_RX/TSC_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC6/TIM22_CH1/TIM3_CH1/TSC_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC7/TIM22_CH2/TIM3_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC8/TIM22_ETR/TIM3_CH3/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC9/DAC_EXTI9/I2C3_SDA/TIM21_ETR/TIM3_CH4/TSC_G8_IO4/USB_OE',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC10/LPUART1_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC11/ADC_EXTI11/LPUART1_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC12/USART4_CK/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L072RBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x2',description='Core: ARM Cortex-M0+ Package: LQFP64 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L072RZTx'],pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='CRS_SYNC/I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='I2C1_SDA/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='I2C3_SMBA/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2C2_SCL/I2S2_CK/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/I2C3_SCL/LPTIM1_IN1/LPUART1_RX/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/I2C3_SDA/LPTIM1_OUT/LPUART1_TX/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/I2S2_MCK/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/I2S2_SD/LPTIM1_ETR/SPI2_MOSI/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/LPUART1_RX/TSC_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM22_CH1/TIM3_CH1/TSC_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM22_CH2/TIM3_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM22_ETR/TIM3_CH3/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/I2C3_SDA/TIM21_ETR/TIM3_CH4/TSC_G8_IO4/USB_OE',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/LPUART1_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/LPUART1_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/USART4_CK/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L072VBIx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x2',description='Core: ARM Cortex-M0+ Package: UFBGA100 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 84',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L072VZIx'],pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='CRS_SYNC/I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='I2C1_SDA/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='I2C3_SMBA/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC_EXTI11/I2C2_SDA/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='I2C2_SCL/I2S2_CK/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/I2C3_SCL/LPTIM1_IN1/LPUART1_RX/TSC_G7_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/I2C3_SDA/LPTIM1_OUT/LPUART1_TX/TSC_G7_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/I2S2_MCK/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/I2S2_SD/LPTIM1_ETR/SPI2_MOSI/TSC_G7_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/LPUART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/LPUART1_RX/TSC_G3_IO1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='TIM22_CH1/TIM3_CH1/TSC_G8_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='TIM22_CH2/TIM3_CH2/TSC_G8_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='TIM22_ETR/TIM3_CH3/TSC_G8_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/I2C3_SDA/TIM21_ETR/TIM3_CH4/TSC_G8_IO4/USB_OE/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='LPUART1_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC_EXTI11/LPUART1_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='USART4_CK/USART5_TX/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='F2',name='PH9/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PH10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/TIM22_CH1/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/TIM22_CH2/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/TIM21_CH1/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM21_CH2/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/DAC_EXTI9/TIM2_CH1/TIM2_ETR/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/TIM2_CH2/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC_EXTI11/TIM2_CH3/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/SPI1_NSS/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/SPI1_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0/I2S2_WS/SPI2_NSS/TIM21_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/I2S2_MCK/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/TIM21_CH2/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9/DAC_EXTI9/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/ADC_EXTI11/LPUART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/CRS_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L072VBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x2',description='Core: ARM Cortex-M0+ Package: LQFP100 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 84',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L072VZTx'],pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='CRS_SYNC/I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C1_SDA/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='I2C3_SMBA/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='I2C2_SCL/I2S2_CK/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/I2C3_SCL/LPTIM1_IN1/LPUART1_RX/TSC_G7_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/I2C3_SDA/LPTIM1_OUT/LPUART1_TX/TSC_G7_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/I2S2_MCK/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/I2S2_SD/LPTIM1_ETR/SPI2_MOSI/TSC_G7_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/LPUART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/LPUART1_RX/TSC_G3_IO1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='TIM22_CH1/TIM3_CH1/TSC_G8_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='TIM22_CH2/TIM3_CH2/TSC_G8_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM22_ETR/TIM3_CH3/TSC_G8_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/I2C3_SDA/TIM21_ETR/TIM3_CH4/TSC_G8_IO4/USB_OE/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='LPUART1_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/LPUART1_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='USART4_CK/USART5_TX/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='10',name='PH9/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PH10',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/TIM22_CH1/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/TIM22_CH2/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/TIM21_CH1/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM21_CH2/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/TIM2_CH1/TIM2_ETR/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/TIM2_CH2/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/TIM2_CH3/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/SPI1_NSS/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/SPI1_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/I2S2_WS/SPI2_NSS/TIM21_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/I2S2_MCK/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM21_CH2/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/LPUART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/CRS_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L072V8Ix',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x2',description='Core: ARM Cortex-M0+ Package: UFBGA100 Flash: 64KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 84',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='CRS_SYNC/I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='I2C1_SDA/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='I2C3_SMBA/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC_EXTI11/I2C2_SDA/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='I2C2_SCL/I2S2_CK/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/I2C3_SCL/LPTIM1_IN1/LPUART1_RX/TSC_G7_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/I2C3_SDA/LPTIM1_OUT/LPUART1_TX/TSC_G7_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/I2S2_MCK/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/I2S2_SD/LPTIM1_ETR/SPI2_MOSI/TSC_G7_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/LPUART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/LPUART1_RX/TSC_G3_IO1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='TIM22_CH1/TIM3_CH1/TSC_G8_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='TIM22_CH2/TIM3_CH2/TSC_G8_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='TIM22_ETR/TIM3_CH3/TSC_G8_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/I2C3_SDA/TIM21_ETR/TIM3_CH4/TSC_G8_IO4/USB_OE/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='LPUART1_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC_EXTI11/LPUART1_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='USART4_CK/USART5_TX/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='F2',name='PH9/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PH10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/TIM22_CH1/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/TIM22_CH2/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/TIM21_CH1/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM21_CH2/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/DAC_EXTI9/TIM2_CH1/TIM2_ETR/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/TIM2_CH2/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC_EXTI11/TIM2_CH3/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/SPI1_NSS/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/SPI1_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0/I2S2_WS/SPI2_NSS/TIM21_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/I2S2_MCK/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/TIM21_CH2/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9/DAC_EXTI9/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/ADC_EXTI11/LPUART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/CRS_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L072V8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x2',description='Core: ARM Cortex-M0+ Package: LQFP100 Flash: 64KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 84',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP2_INM/COMP2_OUT/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP2_INP/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_OUT/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP2_OUT/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='CRS_SYNC/I2C3_SCL/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C1_SDA/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='I2C3_SMBA/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/I2C3_SDA/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2S2_WS/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='I2C2_SCL/I2S2_CK/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2C2_SDA/I2S2_MCK/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='I2S2_SD/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/I2C3_SCL/LPTIM1_IN1/LPUART1_RX/TSC_G7_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/I2C3_SDA/LPTIM1_OUT/LPUART1_TX/TSC_G7_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/I2S2_MCK/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/I2S2_SD/LPTIM1_ETR/SPI2_MOSI/TSC_G7_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/LPUART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/LPUART1_RX/TSC_G3_IO1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='TIM22_CH1/TIM3_CH1/TSC_G8_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='TIM22_CH2/TIM3_CH2/TSC_G8_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM22_ETR/TIM3_CH3/TSC_G8_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/I2C3_SDA/TIM21_ETR/TIM3_CH4/TSC_G8_IO4/USB_OE/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='LPUART1_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/LPUART1_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='USART4_CK/USART5_TX/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='10',name='PH9/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PH10',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/TIM22_CH1/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/TIM22_CH2/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/TIM21_CH1/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM21_CH2/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/TIM2_CH1/TIM2_ETR/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/TIM2_CH2/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/TIM2_CH3/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/SPI1_NSS/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/SPI1_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/I2S2_WS/SPI2_NSS/TIM21_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/I2S2_MCK/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM21_CH2/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/LPUART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/CRS_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L073CBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x3',description='Core: ARM Cortex-M0+ Package: LQFP48 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L073CZTx'],pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/LCD_SEG1/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/LCD_SEG2/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/LCD_SEG3/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/LCD_SEG4/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CRS_SYNC/I2C3_SCL/LCD_COM0/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/LCD_COM1/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2C1_SDA/LCD_COM2/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='LCD_SEG17/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/LCD_SEG5/LCD_VLCD3/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/LCD_SEG6/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/I2C3_SMBA/LCD_VLCD1/LPTIM1_OUT/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/LCD_SEG7/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/I2C3_SDA/LCD_SEG8/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/LCD_SEG16/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/I2S2_WS/LCD_COM3/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/LCD_SEG10/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/LCD_SEG11/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2S2_WS/LCD_SEG12/LCD_VLCD2/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C2_SCL/I2S2_CK/LCD_SEG13/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C2_SDA/I2S2_MCK/LCD_SEG14/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L073RBHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x3',description='Core: ARM Cortex-M0+ Package: TFBGA64 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L073RZHx'],pins=[
            Pin(num='G2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN2/COMP2_INM/COMP2_OUT/LCD_SEG1/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC_IN3/COMP2_INP/LCD_SEG2/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN6/COMP1_OUT/LCD_SEG3/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC_IN7/COMP2_OUT/LCD_SEG4/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='CRS_SYNC/I2C3_SCL/LCD_COM0/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/LCD_COM1/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='I2C1_SDA/LCD_COM2/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='LCD_SEG17/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN8/LCD_SEG5/LCD_VLCD3/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN9/LCD_SEG6/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='I2C3_SMBA/LCD_VLCD1/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='COMP2_INM/LCD_SEG7/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='COMP2_INP/I2C3_SDA/LCD_SEG8/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='I2C1_SCL/LCD_SEG16/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/LCD_COM3/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='I2C2_SCL/LCD_SEG10/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='I2S2_WS/LCD_SEG12/LCD_VLCD2/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='I2C2_SCL/I2S2_CK/LCD_SEG13/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='I2C2_SDA/I2S2_MCK/LCD_SEG14/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='B4',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='B5',name='PD2/LCD_COM7/LCD_SEG31/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC0/ADC_IN10/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPUART1_RX/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC1/ADC_IN11/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC2/ADC_IN12/I2S2_MCK/LCD_SEG20/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC_IN14/LCD_SEG22/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC5/ADC_IN15/LCD_SEG23/LPUART1_RX/TSC_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC6/LCD_SEG24/TIM22_CH1/TIM3_CH1/TSC_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC7/LCD_SEG25/TIM22_CH2/TIM3_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC8/LCD_SEG26/TIM22_ETR/TIM3_CH3/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC9/DAC_EXTI9/I2C3_SDA/LCD_SEG27/TIM21_ETR/TIM3_CH4/TSC_G8_IO4/USB_OE',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC10/LCD_COM4/LCD_SEG28/LPUART1_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/LPUART1_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC12/LCD_COM6/LCD_SEG30/USART4_CK/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L073RBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x3',description='Core: ARM Cortex-M0+ Package: LQFP64 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L073RZTx'],pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP2_INM/COMP2_OUT/LCD_SEG1/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP2_INP/LCD_SEG2/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_OUT/LCD_SEG3/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP2_OUT/LCD_SEG4/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='CRS_SYNC/I2C3_SCL/LCD_COM0/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/LCD_COM1/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='I2C1_SDA/LCD_COM2/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='LCD_SEG17/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/LCD_SEG5/LCD_VLCD3/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/LCD_SEG6/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='I2C3_SMBA/LCD_VLCD1/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/LCD_SEG7/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/I2C3_SDA/LCD_SEG8/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/LCD_SEG16/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/LCD_COM3/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/LCD_SEG10/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2S2_WS/LCD_SEG12/LCD_VLCD2/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2C2_SCL/I2S2_CK/LCD_SEG13/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2C2_SDA/I2S2_MCK/LCD_SEG14/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LCD_COM7/LCD_SEG31/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPUART1_RX/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/I2S2_MCK/LCD_SEG20/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/I2S2_SD/LCD_SEG21/LPTIM1_ETR/SPI2_MOSI/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/LCD_SEG22/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/LCD_SEG23/LPUART1_RX/TSC_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/LCD_SEG24/TIM22_CH1/TIM3_CH1/TSC_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/LCD_SEG25/TIM22_CH2/TIM3_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/LCD_SEG26/TIM22_ETR/TIM3_CH3/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/I2C3_SDA/LCD_SEG27/TIM21_ETR/TIM3_CH4/TSC_G8_IO4/USB_OE',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/LCD_COM4/LCD_SEG28/LPUART1_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/LPUART1_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/LCD_COM6/LCD_SEG30/USART4_CK/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L073VBIx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x3',description='Core: ARM Cortex-M0+ Package: UFBGA100 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 84',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L073VZIx'],pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP2_INM/COMP2_OUT/LCD_SEG1/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP2_INP/LCD_SEG2/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_OUT/LCD_SEG3/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC_IN7/COMP2_OUT/LCD_SEG4/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='CRS_SYNC/I2C3_SCL/LCD_COM0/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/LCD_COM1/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='I2C1_SDA/LCD_COM2/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='LCD_SEG17/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/LCD_SEG5/LCD_VLCD3/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/LCD_SEG6/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='I2C3_SMBA/LCD_VLCD1/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/LCD_SEG7/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/I2C3_SDA/LCD_SEG8/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/LCD_SEG16/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/LCD_COM3/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/LCD_SEG10/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='I2S2_WS/LCD_SEG12/LCD_VLCD2/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='I2C2_SCL/I2S2_CK/LCD_SEG13/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='I2C2_SDA/I2S2_MCK/LCD_SEG14/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPUART1_RX/TSC_G7_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX/TSC_G7_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/I2S2_MCK/LCD_SEG20/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/I2S2_SD/LCD_SEG21/LPTIM1_ETR/SPI2_MOSI/TSC_G7_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/LCD_SEG22/LPUART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/LCD_SEG23/LPUART1_RX/TSC_G3_IO1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='LCD_SEG24/TIM22_CH1/TIM3_CH1/TSC_G8_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='LCD_SEG25/TIM22_CH2/TIM3_CH2/TSC_G8_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='LCD_SEG26/TIM22_ETR/TIM3_CH3/TSC_G8_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/I2C3_SDA/LCD_SEG27/TIM21_ETR/TIM3_CH4/TSC_G8_IO4/USB_OE/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='LCD_COM4/LCD_SEG28/LCD_SEG48/LPUART1_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG49/LPUART1_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='LCD_COM6/LCD_SEG30/LCD_SEG50/USART4_CK/USART5_TX/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='F2',name='PH9/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PH10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/LCD_SEG36',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/LCD_SEG37',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/LCD_SEG38/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/LCD_SEG39/TIM22_CH1/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/TIM22_CH2/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/TIM21_CH1/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM21_CH2/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/LCD_SEG45/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/LCD_SEG46/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/DAC_EXTI9/LCD_SEG47/TIM2_CH1/TIM2_ETR/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/LCD_SEG40/TIM2_CH2/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC_EXTI11/LCD_VLCD2/TIM2_CH3/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/LCD_VLCD3/SPI1_NSS/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/LCD_SEG41/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/LCD_SEG42/SPI1_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/LCD_SEG43/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0/I2S2_WS/SPI2_NSS/TIM21_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG51/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/I2S2_MCK/LCD_SEG44/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/TIM21_CH2/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/LCD_SEG28/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9/DAC_EXTI9/LCD_SEG29/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10/LCD_SEG30',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/ADC_EXTI11/LCD_SEG31/LPUART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/LCD_SEG32/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13/LCD_SEG33',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14/LCD_SEG34',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/CRS_SYNC/LCD_SEG35',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L073VBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x3',description='Core: ARM Cortex-M0+ Package: LQFP100 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 84',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L073VZTx'],pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP2_INM/COMP2_OUT/LCD_SEG1/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP2_INP/LCD_SEG2/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_OUT/LCD_SEG3/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP2_OUT/LCD_SEG4/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='CRS_SYNC/I2C3_SCL/LCD_COM0/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/LCD_COM1/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C1_SDA/LCD_COM2/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='LCD_SEG17/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/LCD_SEG5/LCD_VLCD3/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/LCD_SEG6/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='I2C3_SMBA/LCD_VLCD1/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/LCD_SEG7/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/I2C3_SDA/LCD_SEG8/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/LCD_SEG16/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/LCD_COM3/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/LCD_SEG10/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2S2_WS/LCD_SEG12/LCD_VLCD2/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='I2C2_SCL/I2S2_CK/LCD_SEG13/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2C2_SDA/I2S2_MCK/LCD_SEG14/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPUART1_RX/TSC_G7_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX/TSC_G7_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/I2S2_MCK/LCD_SEG20/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/I2S2_SD/LCD_SEG21/LPTIM1_ETR/SPI2_MOSI/TSC_G7_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/LCD_SEG22/LPUART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/LCD_SEG23/LPUART1_RX/TSC_G3_IO1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='LCD_SEG24/TIM22_CH1/TIM3_CH1/TSC_G8_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='LCD_SEG25/TIM22_CH2/TIM3_CH2/TSC_G8_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='LCD_SEG26/TIM22_ETR/TIM3_CH3/TSC_G8_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/I2C3_SDA/LCD_SEG27/TIM21_ETR/TIM3_CH4/TSC_G8_IO4/USB_OE/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='LCD_COM4/LCD_SEG28/LCD_SEG48/LPUART1_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG49/LPUART1_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='LCD_COM6/LCD_SEG30/LCD_SEG50/USART4_CK/USART5_TX/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='10',name='PH9/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PH10',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/LCD_SEG36',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/LCD_SEG37',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/LCD_SEG38/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/LCD_SEG39/TIM22_CH1/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/TIM22_CH2/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/TIM21_CH1/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM21_CH2/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/LCD_SEG45/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/LCD_SEG46/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/LCD_SEG47/TIM2_CH1/TIM2_ETR/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/LCD_SEG40/TIM2_CH2/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/LCD_VLCD2/TIM2_CH3/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/LCD_VLCD3/SPI1_NSS/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/LCD_SEG41/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/LCD_SEG42/SPI1_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/LCD_SEG43/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/I2S2_WS/SPI2_NSS/TIM21_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG51/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/I2S2_MCK/LCD_SEG44/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM21_CH2/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/LCD_SEG28/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/LCD_SEG29/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/LCD_SEG30',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/LCD_SEG31/LPUART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/LCD_SEG32/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/LCD_SEG33',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/LCD_SEG34',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/CRS_SYNC/LCD_SEG35',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L073V8Ix',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x3',description='Core: ARM Cortex-M0+ Package: UFBGA100 Flash: 64KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 84',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP2_INM/COMP2_OUT/LCD_SEG1/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP2_INP/LCD_SEG2/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_OUT/LCD_SEG3/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC_IN7/COMP2_OUT/LCD_SEG4/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='CRS_SYNC/I2C3_SCL/LCD_COM0/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/LCD_COM1/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='I2C1_SDA/LCD_COM2/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='LCD_SEG17/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/LCD_SEG5/LCD_VLCD3/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/LCD_SEG6/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='I2C3_SMBA/LCD_VLCD1/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/LCD_SEG7/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/I2C3_SDA/LCD_SEG8/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/LCD_SEG16/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/LCD_COM3/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/LCD_SEG10/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='I2S2_WS/LCD_SEG12/LCD_VLCD2/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='I2C2_SCL/I2S2_CK/LCD_SEG13/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='I2C2_SDA/I2S2_MCK/LCD_SEG14/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPUART1_RX/TSC_G7_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX/TSC_G7_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/I2S2_MCK/LCD_SEG20/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/I2S2_SD/LCD_SEG21/LPTIM1_ETR/SPI2_MOSI/TSC_G7_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/LCD_SEG22/LPUART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/LCD_SEG23/LPUART1_RX/TSC_G3_IO1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='LCD_SEG24/TIM22_CH1/TIM3_CH1/TSC_G8_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='LCD_SEG25/TIM22_CH2/TIM3_CH2/TSC_G8_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='LCD_SEG26/TIM22_ETR/TIM3_CH3/TSC_G8_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/I2C3_SDA/LCD_SEG27/TIM21_ETR/TIM3_CH4/TSC_G8_IO4/USB_OE/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='LCD_COM4/LCD_SEG28/LCD_SEG48/LPUART1_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG49/LPUART1_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='LCD_COM6/LCD_SEG30/LCD_SEG50/USART4_CK/USART5_TX/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='F2',name='PH9/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PH10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/LCD_SEG36',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/LCD_SEG37',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/LCD_SEG38/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/LCD_SEG39/TIM22_CH1/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/TIM22_CH2/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/TIM21_CH1/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM21_CH2/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/LCD_SEG45/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/LCD_SEG46/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/DAC_EXTI9/LCD_SEG47/TIM2_CH1/TIM2_ETR/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/LCD_SEG40/TIM2_CH2/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC_EXTI11/LCD_VLCD2/TIM2_CH3/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/LCD_VLCD3/SPI1_NSS/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/LCD_SEG41/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/LCD_SEG42/SPI1_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/LCD_SEG43/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0/I2S2_WS/SPI2_NSS/TIM21_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG51/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/I2S2_MCK/LCD_SEG44/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/TIM21_CH2/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/LCD_SEG28/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9/DAC_EXTI9/LCD_SEG29/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10/LCD_SEG30',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/ADC_EXTI11/LCD_SEG31/LPUART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/LCD_SEG32/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13/LCD_SEG33',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14/LCD_SEG34',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/CRS_SYNC/LCD_SEG35',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L073V8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x3',description='Core: ARM Cortex-M0+ Package: LQFP100 Flash: 64KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 84',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP2_INM/COMP2_OUT/LCD_SEG1/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP2_INP/LCD_SEG2/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_OUT/LCD_SEG3/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP2_OUT/LCD_SEG4/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='CRS_SYNC/I2C3_SCL/LCD_COM0/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/LCD_COM1/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C1_SDA/LCD_COM2/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='LCD_SEG17/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/LCD_SEG5/LCD_VLCD3/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/LCD_SEG6/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='I2C3_SMBA/LCD_VLCD1/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/LCD_SEG7/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/I2C3_SDA/LCD_SEG8/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/LCD_SEG16/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/LCD_COM3/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/LCD_SEG10/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2S2_WS/LCD_SEG12/LCD_VLCD2/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='I2C2_SCL/I2S2_CK/LCD_SEG13/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2C2_SDA/I2S2_MCK/LCD_SEG14/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPUART1_RX/TSC_G7_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX/TSC_G7_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/I2S2_MCK/LCD_SEG20/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/I2S2_SD/LCD_SEG21/LPTIM1_ETR/SPI2_MOSI/TSC_G7_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/LCD_SEG22/LPUART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/LCD_SEG23/LPUART1_RX/TSC_G3_IO1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='LCD_SEG24/TIM22_CH1/TIM3_CH1/TSC_G8_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='LCD_SEG25/TIM22_CH2/TIM3_CH2/TSC_G8_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='LCD_SEG26/TIM22_ETR/TIM3_CH3/TSC_G8_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/I2C3_SDA/LCD_SEG27/TIM21_ETR/TIM3_CH4/TSC_G8_IO4/USB_OE/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='LCD_COM4/LCD_SEG28/LCD_SEG48/LPUART1_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG49/LPUART1_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='LCD_COM6/LCD_SEG30/LCD_SEG50/USART4_CK/USART5_TX/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='10',name='PH9/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PH10',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/LCD_SEG36',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/LCD_SEG37',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/LCD_SEG38/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/LCD_SEG39/TIM22_CH1/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/TIM22_CH2/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/TIM21_CH1/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM21_CH2/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/LCD_SEG45/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/LCD_SEG46/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/LCD_SEG47/TIM2_CH1/TIM2_ETR/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/LCD_SEG40/TIM2_CH2/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/LCD_VLCD2/TIM2_CH3/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/LCD_VLCD3/SPI1_NSS/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/LCD_SEG41/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/LCD_SEG42/SPI1_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/LCD_SEG43/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/I2S2_WS/SPI2_NSS/TIM21_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG51/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/I2S2_MCK/LCD_SEG44/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM21_CH2/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/LCD_SEG28/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/LCD_SEG29/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/LCD_SEG30',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/LCD_SEG31/LPUART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/LCD_SEG32/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/LCD_SEG33',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/LCD_SEG34',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/CRS_SYNC/LCD_SEG35',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L083CBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x3',description='Core: ARM Cortex-M0+ Package: LQFP48 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L083CZTx'],pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP2_INM/COMP2_OUT/LCD_SEG1/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP2_INP/LCD_SEG2/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_OUT/LCD_SEG3/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP2_OUT/LCD_SEG4/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='CRS_SYNC/I2C3_SCL/LCD_COM0/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/LCD_COM1/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='I2C1_SDA/LCD_COM2/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='LCD_SEG17/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/LCD_SEG5/LCD_VLCD3/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/LCD_SEG6/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/I2C3_SMBA/LCD_VLCD1/LPTIM1_OUT/TSC_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/LCD_SEG7/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/I2C3_SDA/LCD_SEG8/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/LCD_SEG16/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/I2S2_WS/LCD_COM3/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/LCD_SEG10/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/LCD_SEG11/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/I2S2_WS/LCD_SEG12/LCD_VLCD2/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/I2C2_SCL/I2S2_CK/LCD_SEG13/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/I2C2_SDA/I2S2_MCK/LCD_SEG14/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L083RBHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x3',description='Core: ARM Cortex-M0+ Package: TFBGA64 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L083RZHx'],pins=[
            Pin(num='G2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN2/COMP2_INM/COMP2_OUT/LCD_SEG1/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC_IN3/COMP2_INP/LCD_SEG2/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN6/COMP1_OUT/LCD_SEG3/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC_IN7/COMP2_OUT/LCD_SEG4/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='CRS_SYNC/I2C3_SCL/LCD_COM0/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/LCD_COM1/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='I2C1_SDA/LCD_COM2/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='LCD_SEG17/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN8/LCD_SEG5/LCD_VLCD3/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN9/LCD_SEG6/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='I2C3_SMBA/LCD_VLCD1/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='COMP2_INM/LCD_SEG7/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='COMP2_INP/I2C3_SDA/LCD_SEG8/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='I2C1_SCL/LCD_SEG16/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/LCD_COM3/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='I2C2_SCL/LCD_SEG10/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='I2S2_WS/LCD_SEG12/LCD_VLCD2/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='I2C2_SCL/I2S2_CK/LCD_SEG13/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='I2C2_SDA/I2S2_MCK/LCD_SEG14/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='B4',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='B5',name='PD2/LCD_COM7/LCD_SEG31/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC0/ADC_IN10/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPUART1_RX/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC1/ADC_IN11/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC2/ADC_IN12/I2S2_MCK/LCD_SEG20/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC_IN14/LCD_SEG22/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC5/ADC_IN15/LCD_SEG23/LPUART1_RX/TSC_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC6/LCD_SEG24/TIM22_CH1/TIM3_CH1/TSC_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC7/LCD_SEG25/TIM22_CH2/TIM3_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC8/LCD_SEG26/TIM22_ETR/TIM3_CH3/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC9/DAC_EXTI9/I2C3_SDA/LCD_SEG27/TIM21_ETR/TIM3_CH4/TSC_G8_IO4/USB_OE',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC10/LCD_COM4/LCD_SEG28/LPUART1_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/LPUART1_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC12/LCD_COM6/LCD_SEG30/USART4_CK/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L083RBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x3',description='Core: ARM Cortex-M0+ Package: LQFP64 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..--V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L083RZTx'],pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP2_INM/COMP2_OUT/LCD_SEG1/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP2_INP/LCD_SEG2/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_OUT/LCD_SEG3/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP2_OUT/LCD_SEG4/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='CRS_SYNC/I2C3_SCL/LCD_COM0/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/LCD_COM1/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='I2C1_SDA/LCD_COM2/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='LCD_SEG17/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/LCD_SEG5/LCD_VLCD3/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/LCD_SEG6/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='I2C3_SMBA/LCD_VLCD1/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/LCD_SEG7/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/I2C3_SDA/LCD_SEG8/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/LCD_SEG16/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/LCD_COM3/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/LCD_SEG10/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='I2S2_WS/LCD_SEG12/LCD_VLCD2/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='I2C2_SCL/I2S2_CK/LCD_SEG13/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='I2C2_SDA/I2S2_MCK/LCD_SEG14/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LCD_COM7/LCD_SEG31/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPUART1_RX/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/I2S2_MCK/LCD_SEG20/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/I2S2_SD/LCD_SEG21/LPTIM1_ETR/SPI2_MOSI/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/LCD_SEG22/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/LCD_SEG23/LPUART1_RX/TSC_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/LCD_SEG24/TIM22_CH1/TIM3_CH1/TSC_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/LCD_SEG25/TIM22_CH2/TIM3_CH2/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/LCD_SEG26/TIM22_ETR/TIM3_CH3/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/I2C3_SDA/LCD_SEG27/TIM21_ETR/TIM3_CH4/TSC_G8_IO4/USB_OE',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/LCD_COM4/LCD_SEG28/LPUART1_TX/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/LPUART1_RX/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/LCD_COM6/LCD_SEG30/USART4_CK/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L083VBIx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x3',description='Core: ARM Cortex-M0+ Package: UFBGA100 Flash: 128KB Ram: 20KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 84',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L083VZIx'],pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP2_INM/COMP2_OUT/LCD_SEG1/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP2_INP/LCD_SEG2/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_OUT/LCD_SEG3/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC_IN7/COMP2_OUT/LCD_SEG4/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='CRS_SYNC/I2C3_SCL/LCD_COM0/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/LCD_COM1/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='I2C1_SDA/LCD_COM2/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='LCD_SEG17/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/LCD_SEG5/LCD_VLCD3/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/LCD_SEG6/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='I2C3_SMBA/LCD_VLCD1/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/LCD_SEG7/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/I2C3_SDA/LCD_SEG8/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/LCD_SEG16/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/LCD_COM3/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/LCD_SEG10/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='I2S2_WS/LCD_SEG12/LCD_VLCD2/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='I2C2_SCL/I2S2_CK/LCD_SEG13/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='I2C2_SDA/I2S2_MCK/LCD_SEG14/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPUART1_RX/TSC_G7_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX/TSC_G7_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/I2S2_MCK/LCD_SEG20/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/I2S2_SD/LCD_SEG21/LPTIM1_ETR/SPI2_MOSI/TSC_G7_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/LCD_SEG22/LPUART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/LCD_SEG23/LPUART1_RX/TSC_G3_IO1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='LCD_SEG24/TIM22_CH1/TIM3_CH1/TSC_G8_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='LCD_SEG25/TIM22_CH2/TIM3_CH2/TSC_G8_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='LCD_SEG26/TIM22_ETR/TIM3_CH3/TSC_G8_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/I2C3_SDA/LCD_SEG27/TIM21_ETR/TIM3_CH4/TSC_G8_IO4/USB_OE/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='LCD_COM4/LCD_SEG28/LCD_SEG48/LPUART1_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG49/LPUART1_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='LCD_COM6/LCD_SEG30/LCD_SEG50/USART4_CK/USART5_TX/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='F2',name='PH9/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PH10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/LCD_SEG36',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/LCD_SEG37',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/LCD_SEG38/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/LCD_SEG39/TIM22_CH1/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/TIM22_CH2/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/TIM21_CH1/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM21_CH2/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/LCD_SEG45/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/LCD_SEG46/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/DAC_EXTI9/LCD_SEG47/TIM2_CH1/TIM2_ETR/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/LCD_SEG40/TIM2_CH2/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC_EXTI11/LCD_VLCD2/TIM2_CH3/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/LCD_VLCD3/SPI1_NSS/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/LCD_SEG41/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/LCD_SEG42/SPI1_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/LCD_SEG43/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0/I2S2_WS/SPI2_NSS/TIM21_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG51/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/I2S2_MCK/LCD_SEG44/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/TIM21_CH2/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/LCD_SEG28/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9/DAC_EXTI9/LCD_SEG29/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10/LCD_SEG30',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/ADC_EXTI11/LCD_SEG31/LPUART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/LCD_SEG32/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13/LCD_SEG33',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14/LCD_SEG34',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/CRS_SYNC/LCD_SEG35',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L083VBTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x3',description='Core: ARM Cortex-M0+ Package: LQFP100 Flash: 128KB Ram: 20KB Voltage: 1.65..3.6V IO-pins: 84',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L083VZTx'],pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP2_INM/COMP2_OUT/LCD_SEG1/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP2_INP/LCD_SEG2/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_OUT/LCD_SEG3/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP2_OUT/LCD_SEG4/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='CRS_SYNC/I2C3_SCL/LCD_COM0/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/LCD_COM1/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C1_SDA/LCD_COM2/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='LCD_SEG17/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/LCD_SEG5/LCD_VLCD3/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/LCD_SEG6/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='I2C3_SMBA/LCD_VLCD1/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/LCD_SEG7/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/I2C3_SDA/LCD_SEG8/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/LCD_SEG16/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/LCD_COM3/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/LCD_SEG10/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2S2_WS/LCD_SEG12/LCD_VLCD2/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='I2C2_SCL/I2S2_CK/LCD_SEG13/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2C2_SDA/I2S2_MCK/LCD_SEG14/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPUART1_RX/TSC_G7_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX/TSC_G7_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/I2S2_MCK/LCD_SEG20/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/I2S2_SD/LCD_SEG21/LPTIM1_ETR/SPI2_MOSI/TSC_G7_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/LCD_SEG22/LPUART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/LCD_SEG23/LPUART1_RX/TSC_G3_IO1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='LCD_SEG24/TIM22_CH1/TIM3_CH1/TSC_G8_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='LCD_SEG25/TIM22_CH2/TIM3_CH2/TSC_G8_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='LCD_SEG26/TIM22_ETR/TIM3_CH3/TSC_G8_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/I2C3_SDA/LCD_SEG27/TIM21_ETR/TIM3_CH4/TSC_G8_IO4/USB_OE/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='LCD_COM4/LCD_SEG28/LCD_SEG48/LPUART1_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG49/LPUART1_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='LCD_COM6/LCD_SEG30/LCD_SEG50/USART4_CK/USART5_TX/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='10',name='PH9/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PH10',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/LCD_SEG36',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/LCD_SEG37',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/LCD_SEG38/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/LCD_SEG39/TIM22_CH1/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/TIM22_CH2/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/TIM21_CH1/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM21_CH2/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/LCD_SEG45/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/LCD_SEG46/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/LCD_SEG47/TIM2_CH1/TIM2_ETR/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/LCD_SEG40/TIM2_CH2/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/LCD_VLCD2/TIM2_CH3/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/LCD_VLCD3/SPI1_NSS/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/LCD_SEG41/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/LCD_SEG42/SPI1_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/LCD_SEG43/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/I2S2_WS/SPI2_NSS/TIM21_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG51/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/I2S2_MCK/LCD_SEG44/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM21_CH2/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/LCD_SEG28/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/LCD_SEG29/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/LCD_SEG30',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/LCD_SEG31/LPUART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/LCD_SEG32/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/LCD_SEG33',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/LCD_SEG34',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/CRS_SYNC/LCD_SEG35',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L083V8Ix',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x3',description='Core: ARM Cortex-M0+ Package: UFBGA100 Flash: 64KB Ram: 20KB IO-pins: 84',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP2_INM/COMP2_OUT/LCD_SEG1/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP2_INP/LCD_SEG2/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_OUT/LCD_SEG3/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC_IN7/COMP2_OUT/LCD_SEG4/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='CRS_SYNC/I2C3_SCL/LCD_COM0/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/LCD_COM1/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='I2C1_SDA/LCD_COM2/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='LCD_SEG17/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/LCD_SEG5/LCD_VLCD3/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/LCD_SEG6/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='I2C3_SMBA/LCD_VLCD1/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/LCD_SEG7/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/I2C3_SDA/LCD_SEG8/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/LCD_SEG16/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/LCD_COM3/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/LCD_SEG10/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='I2S2_WS/LCD_SEG12/LCD_VLCD2/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='I2C2_SCL/I2S2_CK/LCD_SEG13/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='I2C2_SDA/I2S2_MCK/LCD_SEG14/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPUART1_RX/TSC_G7_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX/TSC_G7_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/I2S2_MCK/LCD_SEG20/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/I2S2_SD/LCD_SEG21/LPTIM1_ETR/SPI2_MOSI/TSC_G7_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/LCD_SEG22/LPUART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/LCD_SEG23/LPUART1_RX/TSC_G3_IO1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='LCD_SEG24/TIM22_CH1/TIM3_CH1/TSC_G8_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='LCD_SEG25/TIM22_CH2/TIM3_CH2/TSC_G8_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='LCD_SEG26/TIM22_ETR/TIM3_CH3/TSC_G8_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/I2C3_SDA/LCD_SEG27/TIM21_ETR/TIM3_CH4/TSC_G8_IO4/USB_OE/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='LCD_COM4/LCD_SEG28/LCD_SEG48/LPUART1_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG49/LPUART1_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='LCD_COM6/LCD_SEG30/LCD_SEG50/USART4_CK/USART5_TX/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='F2',name='PH9/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='PH10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/LCD_SEG36',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/LCD_SEG37',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/LCD_SEG38/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/LCD_SEG39/TIM22_CH1/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/TIM22_CH2/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/TIM21_CH1/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM21_CH2/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/LCD_SEG45/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/LCD_SEG46/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/DAC_EXTI9/LCD_SEG47/TIM2_CH1/TIM2_ETR/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/LCD_SEG40/TIM2_CH2/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC_EXTI11/LCD_VLCD2/TIM2_CH3/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/LCD_VLCD3/SPI1_NSS/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/LCD_SEG41/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/LCD_SEG42/SPI1_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/LCD_SEG43/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0/I2S2_WS/SPI2_NSS/TIM21_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG51/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/I2S2_MCK/LCD_SEG44/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/TIM21_CH2/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/LCD_SEG28/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9/DAC_EXTI9/LCD_SEG29/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10/LCD_SEG30',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/ADC_EXTI11/LCD_SEG31/LPUART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/LCD_SEG32/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13/LCD_SEG33',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14/LCD_SEG34',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/CRS_SYNC/LCD_SEG35',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L083V8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M0+ STM32L0 STM32L0x3',description='Core: ARM Cortex-M0+ Package: LQFP100 Flash: 64KB Ram: 20KB Voltage: 1.65..3.6V IO-pins: 84',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INM/COMP1_OUT/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TSC_G1_IO1/USART2_CTS/USART4_TX/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM21_ETR/TIM2_CH2/TSC_G1_IO2/USART2_DE/USART2_RTS/USART4_RX/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP2_INM/COMP2_OUT/LCD_SEG1/LPUART1_TX/TIM21_CH1/TIM2_CH3/TSC_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP2_INP/LCD_SEG2/LPUART1_RX/TIM21_CH2/TIM2_CH4/TSC_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INM/COMP2_INM/DAC_OUT1/SPI1_NSS/TIM22_ETR/TSC_G2_IO1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INM/COMP2_INM/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TSC_G2_IO2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_OUT/LCD_SEG3/LPUART1_CTS/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G2_IO3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP2_OUT/LCD_SEG4/SPI1_MOSI/TIM22_CH2/TIM3_CH2/TSC_G2_IO4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='CRS_SYNC/I2C3_SCL/LCD_COM0/RCC_MCO/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/I2C1_SCL/I2C3_SMBA/LCD_COM1/RCC_MCO/TSC_G4_IO1/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C1_SDA/LCD_COM2/TSC_G4_IO2/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/COMP1_OUT/SPI1_MISO/TSC_G4_IO3/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='COMP2_OUT/SPI1_MOSI/TSC_G4_IO4/USART1_DE/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='LPUART1_RX/SYS_SWDIO/USB_OE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='LPUART1_TX/SYS_SWCLK/USART2_TX/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='LCD_SEG17/SPI1_NSS/TIM2_CH1/TIM2_ETR/USART2_RX/USART4_DE/USART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/LCD_SEG5/LCD_VLCD3/SYS_VREF_OUT_PB0/TIM3_CH3/TSC_G3_IO2/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/LCD_SEG6/LPUART1_DE/LPUART1_RTS/SYS_VREF_OUT_PB1/TIM3_CH4/TSC_G3_IO3/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='I2C3_SMBA/LCD_VLCD1/LPTIM1_OUT/TSC_G3_IO4/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/LCD_SEG7/SPI1_SCK/TIM2_CH2/TSC_G5_IO1/USART1_DE/USART1_RTS/USART5_TX/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/I2C3_SDA/LCD_SEG8/SPI1_MISO/TIM22_CH1/TIM3_CH1/TSC_G5_IO2/USART1_CTS/USART5_RX/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SPI1_MOSI/TIM22_CH2/TIM3_CH2/USART1_CK/USART5_CK/USART5_DE/USART5_RTS/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/I2C1_SCL/LPTIM1_ETR/TSC_G5_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INP/I2C1_SDA/LPTIM1_IN2/SYS_PVD_IN/TSC_G5_IO4/USART1_RX/USART4_CTS/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/LCD_SEG16/TSC_SYNC/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/I2S2_WS/LCD_COM3/SPI2_NSS/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/LCD_SEG10/LPUART1_RX/LPUART1_TX/SPI2_SCK/TIM2_CH3/TSC_SYNC/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/LPUART1_RX/LPUART1_TX/TIM2_CH4/TSC_G6_IO1/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='I2S2_WS/LCD_SEG12/LCD_VLCD2/LPUART1_DE/LPUART1_RTS/SPI2_NSS/TSC_G6_IO2/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='I2C2_SCL/I2S2_CK/LCD_SEG13/LPUART1_CTS/RCC_MCO/SPI2_SCK/TIM21_CH1/TSC_G6_IO3/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='I2C2_SDA/I2S2_MCK/LCD_SEG14/LPUART1_DE/LPUART1_RTS/RTC_OUT_ALARM/RTC_OUT_CALIB/SPI2_MISO/TIM21_CH2/TSC_G6_IO4/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPUART1_RX/TSC_G7_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX/TSC_G7_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/I2S2_MCK/LCD_SEG20/LPTIM1_IN2/SPI2_MISO/TSC_G7_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/I2S2_SD/LCD_SEG21/LPTIM1_ETR/SPI2_MOSI/TSC_G7_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/LCD_SEG22/LPUART1_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/LCD_SEG23/LPUART1_RX/TSC_G3_IO1/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='LCD_SEG24/TIM22_CH1/TIM3_CH1/TSC_G8_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='LCD_SEG25/TIM22_CH2/TIM3_CH2/TSC_G8_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='LCD_SEG26/TIM22_ETR/TIM3_CH3/TSC_G8_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/I2C3_SDA/LCD_SEG27/TIM21_ETR/TIM3_CH4/TSC_G8_IO4/USB_OE/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='LCD_COM4/LCD_SEG28/LCD_SEG48/LPUART1_TX/USART4_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG49/LPUART1_RX/USART4_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='LCD_COM6/LCD_SEG30/LCD_SEG50/USART4_CK/USART5_TX/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/CRS_SYNC/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='10',name='PH9/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PH10',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/LCD_SEG36',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/LCD_SEG37',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/LCD_SEG38/TIM3_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/LCD_SEG39/TIM22_CH1/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/TIM22_CH2/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/TIM21_CH1/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_WKUP3/TIM21_CH2/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/LCD_SEG45/USART5_CK/USART5_DE/USART5_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/LCD_SEG46/USART4_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC_EXTI9/LCD_SEG47/TIM2_CH1/TIM2_ETR/USART4_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/LCD_SEG40/TIM2_CH2/USART5_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/LCD_VLCD2/TIM2_CH3/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/LCD_VLCD3/SPI1_NSS/TIM2_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/LCD_SEG41/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/LCD_SEG42/SPI1_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/LCD_SEG43/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/I2S2_WS/SPI2_NSS/TIM21_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/I2S2_CK/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG51/LPUART1_DE/LPUART1_RTS/TIM3_ETR/USART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/I2S2_MCK/LCD_SEG44/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM21_CH2/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/LCD_SEG28/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/LCD_SEG29/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/LCD_SEG30',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/LCD_SEG31/LPUART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/LCD_SEG32/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/LCD_SEG33',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/LCD_SEG34',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/CRS_SYNC/LCD_SEG35',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD_USB',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L100C6Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L100 Value Line',description='Core: ARM Cortex-M3 Package: UFQFPN48 Flash: 32KB Ram: 4KB Frequency: 32MHz Voltage: 1.8..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INP/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM2_CH2/TIMX_IC2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP1_INP/LCD_SEG1/TIM2_CH3/TIM9_CH1/TIMX_IC3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP1_INP/LCD_SEG2/TIM2_CH4/TIM9_CH2/TIMX_IC4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_INP/LCD_SEG3/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP1_INP/LCD_SEG4/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='LCD_COM0/RCC_MCO/TIMX_IC1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='LCD_COM2/TIMX_IC3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/TIMX_IC2/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/TIMX_IC3/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC_EXTI15/LCD_SEG17/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/COMP1_INP/LCD_SEG5/SYS_V_REF_OUT/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/LCD_SEG7/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/LCD_SEG8/SPI1_MISO/SYS_JTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/LCD_SEG9/SPI1_MOSI/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM4_CH1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/ADC_IN18/COMP1_INP/I2C2_SMBA/LCD_SEG12/SPI2_NSS/TIM10_CH1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC_IN19/COMP1_INP/LCD_SEG13/SPI2_SCK/TIM9_CH1/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC_EXTI15/ADC_IN21/COMP1_INP/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L100C6UxA',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L100 Value Line',description='Core: ARM Cortex-M3 Package: UFQFPN48 Flash: 32KB Ram: 10KB Frequency: 32MHz Voltage: 1.8..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM2_CH2/TIMX_IC2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP1_INP/LCD_SEG1/TIM2_CH3/TIM9_CH1/TIMX_IC3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP1_INP/LCD_SEG2/TIM2_CH4/TIM9_CH2/TIMX_IC4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_INP/LCD_SEG3/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP1_INP/LCD_SEG4/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='LCD_COM0/RCC_MCO/TIMX_IC1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='LCD_COM2/TIMX_IC3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/TIMX_IC2/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/TIMX_IC3/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC_EXTI15/LCD_SEG17/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/COMP1_INP/LCD_SEG5/SYS_V_REF_OUT/TIM3_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1/COMP1_INP',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/LCD_SEG7/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/LCD_SEG8/SPI1_MISO/SYS_JTRST/TIM3_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/LCD_SEG9/SPI1_MOSI/TIM3_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM4_CH1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/ADC_IN18/COMP1_INP/I2C2_SMBA/LCD_SEG12/SPI2_NSS/TIM10_CH1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC_IN19/COMP1_INP/LCD_SEG13/SPI2_SCK/TIM9_CH1/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC_EXTI15/ADC_IN21/COMP1_INP/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L100R8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L100 Value Line',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 64KB Ram: 8KB Frequency: 32MHz Voltage: 1.8..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L100RBTx'],pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INP/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM2_CH2/TIMX_IC2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP1_INP/LCD_SEG1/TIM2_CH3/TIM9_CH1/TIMX_IC3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP1_INP/LCD_SEG2/TIM2_CH4/TIM9_CH2/TIMX_IC4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_INP/LCD_SEG3/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP1_INP/LCD_SEG4/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='LCD_COM0/RCC_MCO/TIMX_IC1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='LCD_COM2/TIMX_IC3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/TIMX_IC2/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/TIMX_IC3/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC_EXTI15/LCD_SEG17/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/COMP1_INP/LCD_SEG5/SYS_V_REF_OUT/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/LCD_SEG7/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/SPI1_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/SYS_PVD_IN/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN18/COMP1_INP/I2C2_SMBA/LCD_SEG12/SPI2_NSS/TIM10_CH1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN19/COMP1_INP/LCD_SEG13/SPI2_SCK/TIM9_CH1/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_EXTI15/ADC_IN21/COMP1_INP/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LCD_COM7/LCD_SEG31/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/LCD_SEG24/TIM3_CH1/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/LCD_SEG25/TIM3_CH2/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/LCD_SEG26/TIM3_CH3/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/LCD_COM4/LCD_SEG28/TIMX_IC3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/TIMX_IC4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/LCD_COM6/LCD_SEG30/TIMX_IC1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L100R8TxA',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L100 Value Line',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 64KB Ram: 10KB Frequency: 32MHz Voltage: 1.8..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L100RBTxA'],pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM2_CH2/TIMX_IC2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP1_INP/LCD_SEG1/TIM2_CH3/TIM9_CH1/TIMX_IC3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP1_INP/LCD_SEG2/TIM2_CH4/TIM9_CH2/TIMX_IC4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_INP/LCD_SEG3/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP1_INP/LCD_SEG4/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='LCD_COM0/RCC_MCO/TIMX_IC1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='LCD_COM2/TIMX_IC3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/TIMX_IC2/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/TIMX_IC3/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC_EXTI15/LCD_SEG17/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/COMP1_INP/LCD_SEG5/SYS_V_REF_OUT/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/COMP1_INP/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/LCD_SEG7/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/SPI1_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/SYS_PVD_IN/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN18/COMP1_INP/I2C2_SMBA/LCD_SEG12/SPI2_NSS/TIM10_CH1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN19/COMP1_INP/LCD_SEG13/SPI2_SCK/TIM9_CH1/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_EXTI15/ADC_IN21/COMP1_INP/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/LCD_SEG24/TIM3_CH1/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/LCD_SEG25/TIM3_CH2/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/LCD_SEG26/TIM3_CH3/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/LCD_COM4/LCD_SEG28/LCD_SEG40/TIMX_IC3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/TIMX_IC4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/LCD_COM6/LCD_SEG30/LCD_SEG42/TIMX_IC1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L100RCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L100 Value Line',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 256KB Ram: 16KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM2_CH2/TIMX_IC2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP1_INP/LCD_SEG1/TIM2_CH3/TIM9_CH1/TIMX_IC3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP1_INP/LCD_SEG2/TIM2_CH4/TIM9_CH2/TIMX_IC4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_INP/LCD_SEG3/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP1_INP/LCD_SEG4/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='LCD_COM0/RCC_MCO/TIMX_IC1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='LCD_COM2/TIMX_IC3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/TIMX_IC2/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/TIMX_IC3/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/COMP1_INP/LCD_SEG5/SYS_V_REF_OUT/TIM3_CH3/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/COMP1_INP/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/LCD_SEG26/TIM3_CH3/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151C6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP48 Flash: 32KB Ram: 10KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L151C8Tx', 'STM32L151CBTx'],pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INP/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP1_INP/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP1_INP/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_INP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP1_INP/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/COMP1_INP/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/SPI1_MOSI/TIM3_CH2/TS_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM4_CH1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TIM10_CH1/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/TIM2_CH3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/ADC_IN18/COMP1_INP/I2C2_SMBA/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC_IN19/COMP1_INP/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC_EXTI15/ADC_IN21/COMP1_INP/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151C6TxA',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP48 Flash: 32KB Ram: 16KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L151C8TxA', 'STM32L151CBTxA'],pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP1_INP/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP1_INP/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_INP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP1_INP/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/COMP1_INP/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1/COMP1_INP/TS_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/SPI1_MOSI/TIM3_CH2/TS_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TIM10_CH1/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/TIM2_CH3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/ADC_IN18/COMP1_INP/I2C2_SMBA/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC_IN19/COMP1_INP/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC_EXTI15/ADC_IN21/COMP1_INP/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151C6Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: UFQFPN48 Flash: 32KB Ram: 10KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L151C8Ux', 'STM32L151CBUx'],pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INP/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP1_INP/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP1_INP/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_INP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP1_INP/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/COMP1_INP/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/SPI1_MOSI/TIM3_CH2/TS_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM4_CH1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TIM10_CH1/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/TIM2_CH3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/ADC_IN18/COMP1_INP/I2C2_SMBA/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC_IN19/COMP1_INP/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC_EXTI15/ADC_IN21/COMP1_INP/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151C6UxA',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: UFQFPN48 Flash: 32KB Ram: 16KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L151C8UxA', 'STM32L151CBUxA'],pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP1_INP/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP1_INP/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_INP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP1_INP/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/COMP1_INP/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1/COMP1_INP/TS_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/SPI1_MOSI/TIM3_CH2/TS_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TIM10_CH1/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/TIM2_CH3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/ADC_IN18/COMP1_INP/I2C2_SMBA/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC_IN19/COMP1_INP/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC_EXTI15/ADC_IN21/COMP1_INP/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151CCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP48 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP1_INP/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP1_INP/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_INP/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP1_INP/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/COMP1_INP/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1/COMP1_INP/TS_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TIM10_CH1/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/TIM2_CH3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC_IN19/COMP1_INP/I2S2_CK/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151CCUx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: UFQFPN48 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP1_INP/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP1_INP/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_INP/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP1_INP/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/COMP1_INP/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1/COMP1_INP/TS_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/TIM10_CH1/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/TIM2_CH3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC_IN19/COMP1_INP/I2S2_CK/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151QCHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: UFBGA132 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 112',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP1_INP/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP1_INP/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_INP/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='ADC_IN7/COMP1_INP/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ADC_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/COMP1_INP/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='ADC_IN19/COMP1_INP/I2S2_CK/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/COMP1_INP/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='I2S2_MCK/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='I2S3_MCK/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='I2S3_CK/SPI3_SCK/TIMX_IC3/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC_EXTI11/SPI3_MISO/TIMX_IC4/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='I2S3_SD/SPI3_MOSI/TIMX_IC1/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='I2S2_CK/SPI2_SCK/TIMX_IC2/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='TIM3_ETR/TIMX_IC3/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='SPI2_MISO/TIMX_IC4/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='TIMX_IC2/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='TIMX_IC3/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='TIM9_CH2/TIMX_IC4/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='TIMX_IC1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='DAC_EXTI9/TIMX_IC2/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='TIMX_IC3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='ADC_EXTI11/TIMX_IC4/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='TIM4_CH1/TIMX_IC1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='TIM4_CH2/TIMX_IC2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='TIM4_CH3/TIMX_IC3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='ADC_EXTI15/TIM4_CH4/TIMX_IC4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='OPAMP3_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='OPAMP1_VINM/OPAMP1_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='OPAMP2_VINM/OPAMP2_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='C11',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='PG0/ADC_IN8b/TS_G2_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='PG1/ADC_IN9b/TS_G2_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G10',name='PG2/ADC_IN10b/TS_G7_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='PG3/ADC_IN11b/TS_G7_IO6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='PG4/ADC_IN12b/TS_G7_IO7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='PG5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PG9/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PG10',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PG12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG13',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PG14',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PF0',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='PF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PF6/ADC_IN27/COMP1_INP/TIM5_CH1/TIM5_ETR/TS_G11_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PF7/ADC_IN28/COMP1_INP/TIM5_CH2/TS_G11_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PF8/ADC_IN29/COMP1_INP/TIM5_CH3/TS_G11_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PF9/ADC_IN30/COMP1_INP/DAC_EXTI9/TIM5_CH4/TS_G11_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='PF11/ADC_EXTI11/ADC_IN1b/TS_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='PF12/ADC_IN2b/TS_G3_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='PF13/ADC_IN3b/TS_G9_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='PF14/ADC_IN6b/TS_G9_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='PF15/ADC_EXTI15/ADC_IN7b/TS_G2_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151QDHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: UFBGA132 Flash: 384KB Ram: 48KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 112',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP1_INP/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP1_INP/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_INP/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='ADC_IN7/COMP1_INP/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ADC_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/COMP1_INP/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/FSMC_NL/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DAC_EXTI9/I2C1_SDA/SDIO_D5/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='ADC_IN19/COMP1_INP/I2S2_CK/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/COMP1_INP/OPAMP3_VINP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/COMP1_INP/OPAMP3_VOUT/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='I2S2_MCK/SDIO_D6/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='I2S3_MCK/SDIO_D7/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='SDIO_D0/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/SDIO_D1/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='I2S3_CK/SDIO_D2/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC_EXTI11/SDIO_D3/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='I2S3_SD/SDIO_CK/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='FSMC_D2/FSMC_DA2/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='FSMC_D3/FSMC_DA3/I2S2_CK/SPI2_SCK/TIMX_IC2/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='SDIO_CMD/TIM3_ETR/TIMX_IC3/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='FSMC_CLK/SPI2_MISO/TIMX_IC4/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='FSMC_NOE/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='FSMC_NWE/TIMX_IC2/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='FSMC_NWAIT/TIMX_IC3/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='FSMC_NE1/TIM9_CH2/TIMX_IC4/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='FSMC_D13/FSMC_DA13/TIMX_IC1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/TIMX_IC2/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='FSMC_D15/FSMC_DA15/TIMX_IC3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='ADC_EXTI11/FSMC_A16/TIMX_IC4/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='FSMC_A17/TIM4_CH1/TIMX_IC1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='FSMC_A18/TIM4_CH2/TIMX_IC2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='FSMC_D0/FSMC_DA0/TIM4_CH3/TIMX_IC3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='ADC_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/TIMX_IC4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='OPAMP3_VINM/OPAMP3_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='OPAMP1_VINM/OPAMP1_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='OPAMP2_VINM/OPAMP2_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='C11',name='PH2/FSMC_A22',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='PG0/ADC_IN8b/FSMC_A10/TS_G2_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='PG1/ADC_IN9b/FSMC_A11/TS_G2_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G10',name='PG2/ADC_IN10b/FSMC_A12/TS_G7_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='PG3/ADC_IN11b/FSMC_A13/TS_G7_IO6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='PG4/ADC_IN12b/FSMC_A14/TS_G7_IO7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PG9/DAC_EXTI9/FSMC_NE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PG10/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PG12/FSMC_NE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG13/FSMC_A24',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PG14/FSMC_A25',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PF0/FSMC_A0',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='PF1/FSMC_A1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PF2/FSMC_A2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PF3/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PF4/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='PF5/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PF6/ADC_IN27/COMP1_INP/TIM5_CH1/TIM5_ETR/TS_G11_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PF7/ADC_IN28/COMP1_INP/TIM5_CH2/TS_G11_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PF8/ADC_IN29/COMP1_INP/TIM5_CH3/TS_G11_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PF9/ADC_IN30/COMP1_INP/DAC_EXTI9/TIM5_CH4/TS_G11_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='PF11/ADC_EXTI11/ADC_IN1b/TS_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='PF12/ADC_IN2b/FSMC_A6/TS_G3_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='PF13/ADC_IN3b/FSMC_A7/TS_G9_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='PF14/ADC_IN6b/FSMC_A8/TS_G9_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='PF15/ADC_EXTI15/ADC_IN7b/FSMC_A9/TS_G2_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/FSMC_NBL0/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/FSMC_NBL1/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/FSMC_A23/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/FSMC_A19/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/FSMC_A20/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/FSMC_A21/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/ADC_IN22/COMP1_INP/FSMC_D4/FSMC_DA4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/ADC_IN23/COMP1_INP/FSMC_D5/FSMC_DA5/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/ADC_IN25/COMP1_INP/FSMC_D7/FSMC_DA7/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC_EXTI11/FSMC_D8/FSMC_DA8/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/FSMC_D9/FSMC_DA9/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/FSMC_D10/FSMC_DA10/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/FSMC_D11/FSMC_DA11/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/ADC_EXTI15/FSMC_D12/FSMC_DA12/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151QEHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: UFBGA132 Flash: 512KB Ram: 80KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 112',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP1_INP/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP1_INP/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_INP/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='ADC_IN7/COMP1_INP/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ADC_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/COMP1_INP/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='ADC_IN19/COMP1_INP/I2S2_CK/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/COMP1_INP/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='I2S2_MCK/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='I2S3_MCK/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='I2S3_CK/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC_EXTI11/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='I2S3_SD/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='I2S2_CK/SPI2_SCK/TIMX_IC2/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='TIM3_ETR/TIMX_IC3/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='SPI2_MISO/TIMX_IC4/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='TIMX_IC2/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='TIMX_IC3/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='TIM9_CH2/TIMX_IC4/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='TIMX_IC1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='DAC_EXTI9/TIMX_IC2/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='TIMX_IC3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='ADC_EXTI11/TIMX_IC4/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='TIM4_CH1/TIMX_IC1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='TIM4_CH2/TIMX_IC2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='TIM4_CH3/TIMX_IC3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='ADC_EXTI15/TIM4_CH4/TIMX_IC4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='NC',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='AOP1_INN/OPAMP1_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='AOP2_INN/OPAMP2_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='C11',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='PG0/ADC_IN8b/TS_G2_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='PG1/ADC_IN9b/TS_G2_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G10',name='PG2/ADC_IN10b/TS_G7_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='PG3/ADC_IN11b/TS_G7_IO6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='PG4/ADC_IN12b/TS_G7_IO7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='PG5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PG9/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PG10',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PG12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG13',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PG14',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PF0',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='PF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PF6/ADC_IN27/COMP1_INP/TIM5_CH1/TIM5_ETR/TS_G11_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PF7/ADC_IN28/COMP1_INP/TIM5_CH2/TS_G11_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PF8/ADC_IN29/COMP1_INP/TIM5_CH3/TS_G11_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PF9/ADC_IN30/COMP1_INP/DAC_EXTI9/TIM5_CH4/TS_G11_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='PF11/ADC_EXTI11/ADC_IN1b/TS_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='PF12/ADC_IN2b/TS_G3_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='PF13/ADC_IN3b/TS_G9_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='PF14/ADC_IN6b/TS_G9_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='PF15/ADC_EXTI15/ADC_IN7b/TS_G2_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151R6Hx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: TFBGA64 Flash: 32KB Ram: 10KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L151R8Hx', 'STM32L151RBHx'],pins=[
            Pin(num='G2',name='ADC_IN0/COMP1_INP/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC_IN1/COMP1_INP/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN2/COMP1_INP/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC_IN3/COMP1_INP/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN6/COMP1_INP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC_IN7/COMP1_INP/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='ADC_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN8/COMP1_INP/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='COMP2_INM/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='COMP2_INP/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='COMP2_INP/I2C1_SMBA/SPI1_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='I2C1_SDA/SYS_PVD_IN/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='ADC_IN18/COMP1_INP/I2C2_SMBA/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='ADC_IN19/COMP1_INP/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='ADC_EXTI15/ADC_IN21/COMP1_INP/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='B4',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='B5',name='PD2/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC0/ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC1/ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC2/ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC5/ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC6/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC7/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC8/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC9/DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC10/TIMX_IC3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC11/ADC_EXTI11/TIMX_IC4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC12/TIMX_IC1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151R6HxA',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: TFBGA64 Flash: 32KB Ram: 16KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L151R8HxA', 'STM32L151RBHxA'],pins=[
            Pin(num='G2',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC_IN1/COMP1_INP/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN2/COMP1_INP/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC_IN3/COMP1_INP/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN6/COMP1_INP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC_IN7/COMP1_INP/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='ADC_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN8/COMP1_INP/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='BOOT1/COMP1_INP/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='COMP2_INM/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='COMP2_INP/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='COMP2_INP/I2C1_SMBA/SPI1_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='ADC_IN18/COMP1_INP/I2C2_SMBA/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='ADC_IN19/COMP1_INP/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='ADC_EXTI15/ADC_IN21/COMP1_INP/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='B4',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='B5',name='PD2/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC0/ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC1/ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC2/ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC5/ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC6/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC7/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC8/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC9/DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC10/TIMX_IC3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC11/ADC_EXTI11/TIMX_IC4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC12/TIMX_IC1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151R6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 32KB Ram: 10KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L151R8Tx', 'STM32L151RBTx'],pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INP/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP1_INP/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP1_INP/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_INP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP1_INP/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/COMP1_INP/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/SPI1_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/SYS_PVD_IN/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN18/COMP1_INP/I2C2_SMBA/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN19/COMP1_INP/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_EXTI15/ADC_IN21/COMP1_INP/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/COMP1_INP/TIMX_IC4/TS_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/TIMX_IC3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/TIMX_IC4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/TIMX_IC1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151R6TxA',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 32KB Ram: 16KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L151R8TxA', 'STM32L151RBTxA'],pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP1_INP/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP1_INP/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_INP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP1_INP/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/COMP1_INP/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/COMP1_INP/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/SPI1_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN18/COMP1_INP/I2C2_SMBA/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN19/COMP1_INP/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_EXTI15/ADC_IN21/COMP1_INP/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/COMP1_INP/TIMX_IC4/TS_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/TIMX_IC3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/TIMX_IC4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/TIMX_IC1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151RCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP1_INP/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP1_INP/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_INP/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP1_INP/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/COMP1_INP/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/COMP1_INP/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN19/COMP1_INP/I2S2_CK/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/COMP1_INP/TIMX_IC4/TS_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/SPI3_SCK/TIMX_IC3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/SPI3_MISO/TIMX_IC4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SPI3_MOSI/TIMX_IC1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151RCTxA',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP1_INP/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP1_INP/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_INP/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP1_INP/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/COMP1_INP/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN19/COMP1_INP/I2S2_CK/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/COMP1_INP/TIMX_IC4/TS_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/SPI3_SCK/TIMX_IC3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/SPI3_MISO/TIMX_IC4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SPI3_MOSI/TIMX_IC1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151RCYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: WLCSP64 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='F6',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='E6',name='ADC_IN1/COMP1_INP/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='ADC_IN2/COMP1_INP/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='ADC_IN3/COMP1_INP/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN6/COMP1_INP/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN7/COMP1_INP/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='ADC_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC_IN8/COMP1_INP/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='BOOT1/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='COMP2_INM/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='COMP2_INP/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='ADC_IN19/COMP1_INP/I2S2_CK/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='NRST',do_erc=True),
            Pin(num='A6',name='BOOT0',do_erc=True),
            Pin(num='C6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D8',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='D7',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='A3',name='PD2/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC0/ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='PC1/ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PC2/ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='PC3/ADC_IN13/COMP1_INP/TIMX_IC4/TS_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC4/ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC5/ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='PC6/I2S2_MCK/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC7/I2S3_MCK/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC8/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='PC9/DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC10/I2S3_CK/SPI3_SCK/TIMX_IC3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PC11/ADC_EXTI11/SPI3_MISO/TIMX_IC4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PC12/I2S3_SD/SPI3_MOSI/TIMX_IC1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='A8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='A7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='B1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E7',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151RDTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 384KB Ram: 48KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP1_INP/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP1_INP/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_INP/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP1_INP/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/COMP1_INP/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/SDIO_D5/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN19/COMP1_INP/I2S2_CK/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/SDIO_CMD/TIM3_ETR/TIMX_IC3/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/COMP1_INP/OPAMP3_VINP/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/COMP1_INP/OPAMP3_VINM/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/COMP1_INP/OPAMP3_VOUT/TIMX_IC4/TS_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/SDIO_D6/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/SDIO_D7/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/SDIO_D0/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/SDIO_D1/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/SDIO_D2/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/SDIO_D3/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SDIO_CK/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151RDYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: WLCSP64 Flash: 384KB Ram: 48KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='F6',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='E6',name='ADC_IN1/COMP1_INP/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='ADC_IN2/COMP1_INP/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='ADC_IN3/COMP1_INP/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN6/COMP1_INP/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN7/COMP1_INP/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='ADC_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC_IN8/COMP1_INP/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='BOOT1/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='COMP2_INM/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='COMP2_INP/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='DAC_EXTI9/I2C1_SDA/SDIO_D5/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='ADC_IN19/COMP1_INP/I2S2_CK/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='NRST',do_erc=True),
            Pin(num='A6',name='BOOT0',do_erc=True),
            Pin(num='C6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D8',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='D7',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='A3',name='PD2/SDIO_CMD/TIM3_ETR/TIMX_IC3/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC0/ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='PC1/ADC_IN11/COMP1_INP/OPAMP3_VINP/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PC2/ADC_IN12/COMP1_INP/OPAMP3_VINM/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='PC3/ADC_IN13/COMP1_INP/OPAMP3_VOUT/TIMX_IC4/TS_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC4/ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC5/ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='PC6/I2S2_MCK/SDIO_D6/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC7/I2S3_MCK/SDIO_D7/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC8/SDIO_D0/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='PC9/DAC_EXTI9/SDIO_D1/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC10/I2S3_CK/SDIO_D2/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PC11/ADC_EXTI11/SDIO_D3/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PC12/I2S3_SD/SDIO_CK/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='A8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='A7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='B1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E7',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151RETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 512KB Ram: 80KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP1_INP/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP1_INP/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_INP/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP1_INP/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/COMP1_INP/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN19/COMP1_INP/I2S2_CK/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/TIM3_ETR/TIMX_IC3/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/COMP1_INP/TIMX_IC4/TS_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151UCYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: WLCSP63 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='E4',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN1/COMP1_INP/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='ADC_IN2/COMP1_INP/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='ADC_IN3/COMP1_INP/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN6/COMP1_INP/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='ADC_IN7/COMP1_INP/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ADC_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN8/COMP1_INP/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='BOOT1/COMP1_INP/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='COMP2_INM/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='COMP2_INP/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='COMP2_INP/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='ADC_IN19/COMP1_INP/I2S2_CK/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='NRST',do_erc=True),
            Pin(num='A6',name='BOOT0',do_erc=True),
            Pin(num='C7',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='F7',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='A4',name='PD2/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E6',name='PC0/ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='PC1/ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='PC2/ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='PC3/ADC_IN13/COMP1_INP/TIMX_IC4/TS_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='PC4/ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='PC5/ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PC6/I2S2_MCK/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='PC7/I2S3_MCK/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='PC8/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC9/DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PC10/I2S3_CK/SPI3_SCK/TIMX_IC3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PC11/ADC_EXTI11/SPI3_MISO/TIMX_IC4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PC12/I2S3_SD/SPI3_MOSI/TIMX_IC1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='B7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H7',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='A1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='A7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151V8Hx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: UFBGA100 Flash: 64KB Ram: 10KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L151VBHx'],pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INP/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP1_INP/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP1_INP/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_INP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC_IN7/COMP1_INP/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ADC_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/COMP1_INP/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SMBA/SPI1_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='I2C1_SDA/SYS_PVD_IN/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='ADC_IN18/COMP1_INP/I2C2_SMBA/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='ADC_IN19/COMP1_INP/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='ADC_EXTI15/ADC_IN21/COMP1_INP/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/COMP1_INP/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='TIMX_IC3/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC_EXTI11/TIMX_IC4/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='TIMX_IC1/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='C11',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9/DAC_EXTI9/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/ADC_EXTI11/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/ADC_EXTI15/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151V8HxA',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: UFBGA100 Flash: 64KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L151VBHxA'],pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP1_INP/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP1_INP/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_INP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC_IN7/COMP1_INP/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ADC_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/COMP1_INP/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='BOOT1/COMP1_INP/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SMBA/SPI1_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='ADC_IN18/COMP1_INP/I2C2_SMBA/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='ADC_IN19/COMP1_INP/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='ADC_EXTI15/ADC_IN21/COMP1_INP/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/COMP1_INP/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='TIMX_IC3/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC_EXTI11/TIMX_IC4/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='TIMX_IC1/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='C11',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9/DAC_EXTI9/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/ADC_EXTI11/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/ADC_EXTI15/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151V8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 64KB Ram: 10KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L151VBTx'],pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INP/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP1_INP/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP1_INP/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_INP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP1_INP/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/COMP1_INP/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/SPI1_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/SYS_PVD_IN/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC_IN18/COMP1_INP/I2C2_SMBA/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC_IN19/COMP1_INP/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC_EXTI15/ADC_IN21/COMP1_INP/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/COMP1_INP/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='TIMX_IC3/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/TIMX_IC4/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='TIMX_IC1/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC_EXTI15/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151V8TxA',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 64KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L151VBTxA'],pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP1_INP/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP1_INP/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_INP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP1_INP/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC_EXTI15/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/COMP1_INP/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/COMP1_INP/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/SPI1_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC_IN18/COMP1_INP/I2C2_SMBA/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC_IN19/COMP1_INP/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC_EXTI15/ADC_IN21/COMP1_INP/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/COMP1_INP/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='TIMX_IC3/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/TIMX_IC4/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='TIMX_IC1/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC_EXTI15/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151VCHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: UFBGA100 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP1_INP/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP1_INP/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_INP/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC_IN7/COMP1_INP/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ADC_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/COMP1_INP/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='BOOT1/COMP1_INP/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='ADC_IN19/COMP1_INP/I2S2_CK/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/COMP1_INP/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='I2S2_MCK/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='I2S3_MCK/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='I2S3_CK/SPI3_SCK/TIMX_IC3/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC_EXTI11/SPI3_MISO/TIMX_IC4/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='I2S3_SD/SPI3_MOSI/TIMX_IC1/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='C11',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIM5_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1/I2S2_CK/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9/DAC_EXTI9/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/ADC_EXTI11/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/ADC_EXTI15/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151VCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP1_INP/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP1_INP/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_INP/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP1_INP/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/COMP1_INP/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/COMP1_INP/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC_IN19/COMP1_INP/I2S2_CK/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/COMP1_INP/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/SPI3_SCK/TIMX_IC3/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/SPI3_MISO/TIMX_IC4/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/SPI3_MOSI/TIMX_IC1/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIM5_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/I2S2_CK/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC_EXTI15/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151VCTxA',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP1_INP/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP1_INP/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_INP/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP1_INP/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/COMP1_INP/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC_IN19/COMP1_INP/I2S2_CK/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/COMP1_INP/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/SPI3_SCK/TIMX_IC3/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/SPI3_MISO/TIMX_IC4/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/SPI3_MOSI/TIMX_IC1/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/I2S2_CK/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC_EXTI15/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151VDTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 384KB Ram: 48KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP1_INP/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP1_INP/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_INP/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP1_INP/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/COMP1_INP/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INP/FSMC_NL/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/SDIO_D5/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC_IN19/COMP1_INP/I2S2_CK/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/COMP1_INP/OPAMP3_VINP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/COMP1_INP/OPAMP3_VINM/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/COMP1_INP/OPAMP3_VOUT/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/SDIO_D6/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/SDIO_D7/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='SDIO_D0/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/SDIO_D1/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/SDIO_D2/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/SDIO_D3/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/SDIO_CK/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='PH2/FSMC_A22',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/FSMC_NBL0/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/FSMC_NBL1/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/ADC_IN22/COMP1_INP/FSMC_D4/FSMC_DA4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/ADC_IN23/COMP1_INP/FSMC_D5/FSMC_DA5/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/ADC_IN25/COMP1_INP/FSMC_D7/FSMC_DA7/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/FSMC_D8/FSMC_DA8/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/FSMC_D9/FSMC_DA9/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/FSMC_D10/FSMC_DA10/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FSMC_D11/FSMC_DA11/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC_EXTI15/FSMC_D12/FSMC_DA12/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/FSMC_D2/FSMC_DA2/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/FSMC_D3/FSMC_DA3/I2S2_CK/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/SDIO_CMD/TIM3_ETR/TIMX_IC3/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/FSMC_CLK/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FSMC_NOE/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FSMC_NWE/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/FSMC_NWAIT/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FSMC_NE1/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FSMC_D13/FSMC_DA13/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FSMC_D14/FSMC_DA14/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FSMC_D15/FSMC_DA15/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/FSMC_A16/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FSMC_A17/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FSMC_A18/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FSMC_D0/FSMC_DA0/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151VDYxX',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: WLCSP104 Flash: 384KB Ram: 80KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='K9',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='ADC_IN1/COMP1_INP/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='ADC_IN2/COMP1_INP/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_IN3/COMP1_INP/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='ADC_IN6/COMP1_INP/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='ADC_IN7/COMP1_INP/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='ADC_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='ADC_IN8/COMP1_INP/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INM/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='COMP2_INP/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='COMP2_INP/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN19/COMP1_INP/I2S2_CK/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='ADC_IN13/COMP1_INP/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='I2S2_MCK/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='I2S3_MCK/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='I2S3_CK/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='ADC_EXTI11/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='I2S3_SD/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='NRST',do_erc=True),
            Pin(num='A7',name='BOOT0',do_erc=True),
            Pin(num='E7',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='F9',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='D1',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PE0/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='PE1/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PE2/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PE3/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E6',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PD0/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PD1/I2S2_CK/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PD2/TIM3_ETR/TIMX_IC3/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PD4/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PD8/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='PD9/DAC_EXTI9/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='PD10/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PD11/ADC_EXTI11/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PD12/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='PD13/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J1',name='PD14/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PD15/ADC_EXTI15/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='B8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='A1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='C7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='L2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J9',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151VETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 512KB Ram: 80KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP1_INP/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP1_INP/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_INP/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP1_INP/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/COMP1_INP/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC_IN19/COMP1_INP/I2S2_CK/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/COMP1_INP/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/I2S2_CK/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/TIM3_ETR/TIMX_IC3/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC_EXTI15/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151VEYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: WLCSP104 Flash: 512KB Ram: 80KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='K9',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='ADC_IN1/COMP1_INP/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='ADC_IN2/COMP1_INP/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_IN3/COMP1_INP/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='ADC_IN6/COMP1_INP/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='ADC_IN7/COMP1_INP/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='ADC_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='ADC_IN8/COMP1_INP/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INM/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='COMP2_INP/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='COMP2_INP/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN19/COMP1_INP/I2S2_CK/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='ADC_IN13/COMP1_INP/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='I2S2_MCK/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='I2S3_MCK/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='I2S3_CK/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='ADC_EXTI11/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='I2S3_SD/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='NRST',do_erc=True),
            Pin(num='A7',name='BOOT0',do_erc=True),
            Pin(num='E7',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='F9',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='D1',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PE0/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='PE1/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PE2/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PE3/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E6',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PD0/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PD1/I2S2_CK/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PD2/TIM3_ETR/TIMX_IC3/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PD4/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PD8/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='PD9/DAC_EXTI9/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='PD10/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PD11/ADC_EXTI11/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PD12/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='PD13/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J1',name='PD14/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PD15/ADC_EXTI15/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='B8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='A1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='C7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='L2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J9',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151ZCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP144 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 115',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='34',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN1/COMP1_INP/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN2/COMP1_INP/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC_IN3/COMP1_INP/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC_IN6/COMP1_INP/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC_IN7/COMP1_INP/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC_IN8/COMP1_INP/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='COMP2_INM/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='COMP2_INP/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='COMP2_INP/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='ADC_IN19/COMP1_INP/I2S2_CK/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN13/COMP1_INP/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='I2S2_MCK/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='I2S3_MCK/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='I2S3_CK/SPI3_SCK/TIMX_IC3/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC_EXTI11/SPI3_MISO/TIMX_IC4/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='I2S3_SD/SPI3_MOSI/TIMX_IC1/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='I2S2_CK/SPI2_SCK/TIMX_IC2/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='TIM3_ETR/TIMX_IC3/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='SPI2_MISO/TIMX_IC4/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='TIMX_IC2/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='TIMX_IC3/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='TIM9_CH2/TIMX_IC4/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='TIMX_IC1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/TIMX_IC2/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='TIMX_IC3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC_EXTI11/TIMX_IC4/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='TIM4_CH1/TIMX_IC1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='TIM4_CH2/TIMX_IC2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='TIM4_CH3/TIMX_IC3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC_EXTI15/TIM4_CH4/TIMX_IC4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='106',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PG0/ADC_IN8b/TS_G2_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/ADC_IN9b/TS_G2_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/ADC_IN10b/TS_G7_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/ADC_IN11b/TS_G7_IO6',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/ADC_IN12b/TS_G7_IO7',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC_IN27/COMP1_INP/TIM5_CH1/TIM5_ETR/TS_G11_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC_IN28/COMP1_INP/TIM5_CH2/TS_G11_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC_IN29/COMP1_INP/TIM5_CH3/TS_G11_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC_IN30/COMP1_INP/DAC_EXTI9/TIM5_CH4/TS_G11_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC_IN31/COMP1_INP/TS_G11_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC_EXTI11/ADC_IN1b/TS_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/ADC_IN2b/TS_G3_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/ADC_IN3b/TS_G9_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/ADC_IN6b/TS_G9_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC_EXTI15/ADC_IN7b/TS_G2_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='143',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151ZDTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP144 Flash: 384KB Ram: 48KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 115',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='34',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN1/COMP1_INP/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN2/COMP1_INP/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC_IN3/COMP1_INP/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC_IN6/COMP1_INP/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC_IN7/COMP1_INP/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC_IN8/COMP1_INP/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='COMP2_INM/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='COMP2_INP/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='COMP2_INP/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='COMP2_INP/FSMC_NL/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='I2C1_SCL/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='DAC_EXTI9/I2C1_SDA/SDIO_D5/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='ADC_IN19/COMP1_INP/I2S2_CK/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN11/COMP1_INP/OPAMP3_VINP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC_IN12/COMP1_INP/OPAMP3_VINM/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN13/COMP1_INP/OPAMP3_VOUT/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='I2S2_MCK/SDIO_D6/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='I2S3_MCK/SDIO_D7/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='SDIO_D0/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/SDIO_D1/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='I2S3_CK/SDIO_D2/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC_EXTI11/SDIO_D3/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='I2S3_SD/SDIO_CK/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='FSMC_D2/FSMC_DA2/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='FSMC_D3/FSMC_DA3/I2S2_CK/SPI2_SCK/TIMX_IC2/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='SDIO_CMD/TIM3_ETR/TIMX_IC3/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='FSMC_CLK/SPI2_MISO/TIMX_IC4/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FSMC_NOE/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FSMC_NWE/TIMX_IC2/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='FSMC_NWAIT/TIMX_IC3/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FSMC_NE1/TIM9_CH2/TIMX_IC4/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FSMC_D13/FSMC_DA13/TIMX_IC1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/TIMX_IC2/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FSMC_D15/FSMC_DA15/TIMX_IC3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC_EXTI11/FSMC_A16/TIMX_IC4/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FSMC_A17/TIM4_CH1/TIMX_IC1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FSMC_A18/TIM4_CH2/TIMX_IC2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FSMC_D0/FSMC_DA0/TIM4_CH3/TIMX_IC3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC_EXTI15/FSMC_D1/FSMC_DA1/TIM4_CH4/TIMX_IC4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='106',name='PH2/FSMC_A22',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PG0/ADC_IN8b/FSMC_A10/TS_G2_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/ADC_IN9b/FSMC_A11/TS_G2_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/ADC_IN10b/FSMC_A12/TS_G7_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/ADC_IN11b/FSMC_A13/TS_G7_IO6',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/ADC_IN12b/FSMC_A14/TS_G7_IO7',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/FSMC_NE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FSMC_NE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/FSMC_A24',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/FSMC_A25',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FSMC_A0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FSMC_A1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FSMC_A2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC_IN27/COMP1_INP/TIM5_CH1/TIM5_ETR/TS_G11_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC_IN28/COMP1_INP/TIM5_CH2/TS_G11_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC_IN29/COMP1_INP/TIM5_CH3/TS_G11_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC_IN30/COMP1_INP/DAC_EXTI9/TIM5_CH4/TS_G11_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC_IN31/COMP1_INP/TS_G11_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC_EXTI11/ADC_IN1b/TS_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/ADC_IN2b/FSMC_A6/TS_G3_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/ADC_IN3b/FSMC_A7/TS_G9_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/ADC_IN6b/FSMC_A8/TS_G9_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC_EXTI15/ADC_IN7b/FSMC_A9/TS_G2_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/FSMC_NBL0/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/FSMC_NBL1/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/ADC_IN22/COMP1_INP/FSMC_D4/FSMC_DA4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/ADC_IN23/COMP1_INP/FSMC_D5/FSMC_DA5/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/ADC_IN25/COMP1_INP/FSMC_D7/FSMC_DA7/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC_EXTI11/FSMC_D8/FSMC_DA8/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FSMC_D9/FSMC_DA9/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FSMC_D10/FSMC_DA10/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FSMC_D11/FSMC_DA11/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC_EXTI15/FSMC_D12/FSMC_DA12/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='143',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L151ZETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP144 Flash: 512KB Ram: 80KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 115',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='34',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN1/COMP1_INP/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN2/COMP1_INP/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC_IN3/COMP1_INP/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC_IN6/COMP1_INP/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC_IN7/COMP1_INP/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC_EXTI15/I2S3_WS/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC_IN8/COMP1_INP/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC_IN9/COMP1_INP/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='COMP2_INM/I2S3_CK/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='COMP2_INP/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='COMP2_INP/I2C1_SMBA/I2S3_SD/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='I2C1_SCL/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='DAC_EXTI9/I2C1_SDA/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C2_SCL/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/I2C2_SDA/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='ADC_IN19/COMP1_INP/I2S2_CK/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='ADC_IN20/COMP1_INP/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN10/COMP1_INP/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN11/COMP1_INP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC_IN12/COMP1_INP/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN13/COMP1_INP/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_IN14/COMP1_INP/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC_IN15/COMP1_INP/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='I2S2_MCK/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='I2S3_MCK/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='I2S3_CK/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC_EXTI11/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='I2S3_SD/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='I2S2_CK/SPI2_SCK/TIMX_IC2/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='TIM3_ETR/TIMX_IC3/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='SPI2_MISO/TIMX_IC4/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='TIMX_IC2/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='TIMX_IC3/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='TIM9_CH2/TIMX_IC4/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='TIMX_IC1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/TIMX_IC2/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='TIMX_IC3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC_EXTI11/TIMX_IC4/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='TIM4_CH1/TIMX_IC1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='TIM4_CH2/TIMX_IC2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='TIM4_CH3/TIMX_IC3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC_EXTI15/TIM4_CH4/TIMX_IC4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='106',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PG0/ADC_IN8b/TS_G2_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/ADC_IN9b/TS_G2_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/ADC_IN10b/TS_G7_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/ADC_IN11b/TS_G7_IO6',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/ADC_IN12b/TS_G7_IO7',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC_IN27/COMP1_INP/TIM5_CH1/TIM5_ETR/TS_G11_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC_IN28/COMP1_INP/TIM5_CH2/TS_G11_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC_IN29/COMP1_INP/TIM5_CH3/TS_G11_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC_IN30/COMP1_INP/DAC_EXTI9/TIM5_CH4/TS_G11_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC_IN31/COMP1_INP/TS_G11_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC_EXTI11/ADC_IN1b/TS_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/ADC_IN2b/TS_G3_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/ADC_IN3b/TS_G9_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/ADC_IN6b/TS_G9_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC_EXTI15/ADC_IN7b/TS_G2_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='143',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152C6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP48 Flash: 32KB Ram: 10KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L152C8Tx', 'STM32L152CBTx'],pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INP/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP1_INP/LCD_SEG1/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP1_INP/LCD_SEG2/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_INP/LCD_SEG3/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP1_INP/LCD_SEG4/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC_EXTI15/LCD_SEG17/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/COMP1_INP/LCD_SEG5/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/LCD_SEG7/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/LCD_SEG8/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/LCD_SEG9/SPI1_MOSI/TIM3_CH2/TS_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM4_CH1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/ADC_IN18/COMP1_INP/I2C2_SMBA/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC_IN19/COMP1_INP/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC_EXTI15/ADC_IN21/COMP1_INP/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152C6TxA',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP48 Flash: 32KB Ram: 16KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L152C8TxA', 'STM32L152CBTxA'],pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP1_INP/LCD_SEG1/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP1_INP/LCD_SEG2/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_INP/LCD_SEG3/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP1_INP/LCD_SEG4/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC_EXTI15/LCD_SEG17/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/COMP1_INP/LCD_SEG5/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1/COMP1_INP/TS_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/LCD_SEG7/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/LCD_SEG8/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/LCD_SEG9/SPI1_MOSI/TIM3_CH2/TS_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/ADC_IN18/COMP1_INP/I2C2_SMBA/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC_IN19/COMP1_INP/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC_EXTI15/ADC_IN21/COMP1_INP/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152C6Ux',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: UFQFPN48 Flash: 32KB Ram: 10KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L152C8Ux', 'STM32L152CBUx'],pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INP/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP1_INP/LCD_SEG1/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP1_INP/LCD_SEG2/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_INP/LCD_SEG3/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP1_INP/LCD_SEG4/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC_EXTI15/LCD_SEG17/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/COMP1_INP/LCD_SEG5/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/LCD_SEG7/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/LCD_SEG8/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/LCD_SEG9/SPI1_MOSI/TIM3_CH2/TS_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM4_CH1/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/ADC_IN18/COMP1_INP/I2C2_SMBA/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC_IN19/COMP1_INP/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC_EXTI15/ADC_IN21/COMP1_INP/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152C6UxA',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: UFQFPN48 Flash: 32KB Ram: 16KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L152C8UxA', 'STM32L152CBUxA'],pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP1_INP/LCD_SEG1/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP1_INP/LCD_SEG2/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_INP/LCD_SEG3/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP1_INP/LCD_SEG4/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC_EXTI15/LCD_SEG17/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/COMP1_INP/LCD_SEG5/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1/COMP1_INP/TS_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/LCD_SEG7/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/LCD_SEG8/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/LCD_SEG9/SPI1_MOSI/TIM3_CH2/TS_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/ADC_IN18/COMP1_INP/I2C2_SMBA/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC_IN19/COMP1_INP/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC_EXTI15/ADC_IN21/COMP1_INP/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152CCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP48 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1/COMP1_INP/TS_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152CCUx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: UFQFPN48 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 37',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='10',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='44',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PB0/ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PB1/ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PB2/BOOT1/COMP1_INP/TS_G3_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PB3/COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PB4/COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PB5/COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PB6/COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PB7/COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PB8/I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PB9/DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PB10/I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PB11/ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PB12/ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='PB13/ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='PB14/ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='PB15/ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='36',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='35',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='8',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152QCHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: UFBGA132 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 112',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP1_INP/LCD_SEG1/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='ADC_IN7/COMP1_INP/LCD_SEG4/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='I2S2_CK/SPI2_SCK/TIMX_IC2/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='SPI2_MISO/TIMX_IC4/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='TIMX_IC2/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='TIMX_IC3/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='TIM9_CH2/TIMX_IC4/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='LCD_SEG28/TIMX_IC1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='DAC_EXTI9/LCD_SEG29/TIMX_IC2/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='LCD_SEG30/TIMX_IC3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='ADC_EXTI11/LCD_SEG31/TIMX_IC4/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='LCD_SEG33/TIM4_CH2/TIMX_IC2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='LCD_SEG34/TIM4_CH3/TIMX_IC3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='ADC_EXTI15/LCD_SEG35/TIM4_CH4/TIMX_IC4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='OPAMP3_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='OPAMP1_VINM/OPAMP1_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='OPAMP2_VINM/OPAMP2_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='C11',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='PG0/ADC_IN8b/TS_G2_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='PG1/ADC_IN9b/TS_G2_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G10',name='PG2/ADC_IN10b/TS_G7_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='PG3/ADC_IN11b/TS_G7_IO6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='PG4/ADC_IN12b/TS_G7_IO7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='PG5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PG9/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PG10',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PG12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG13',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PG14',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PF0',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='PF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PF6/ADC_IN27/COMP1_INP/TIM5_CH1/TIM5_ETR/TS_G11_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PF7/ADC_IN28/COMP1_INP/TIM5_CH2/TS_G11_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PF8/ADC_IN29/COMP1_INP/TIM5_CH3/TS_G11_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PF9/ADC_IN30/COMP1_INP/DAC_EXTI9/TIM5_CH4/TS_G11_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='PF11/ADC_EXTI11/ADC_IN1b/TS_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='PF12/ADC_IN2b/TS_G3_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='PF13/ADC_IN3b/TS_G9_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='PF14/ADC_IN6b/TS_G9_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='PF15/ADC_EXTI15/ADC_IN7b/TS_G2_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152QDHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: UFBGA132 Flash: 384KB Ram: 48KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 112',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP1_INP/LCD_SEG1/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='ADC_IN7/COMP1_INP/LCD_SEG4/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/FSMC_NL/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/LCD_SEG16/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/SDIO_D5/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/COMP1_INP/LCD_SEG19/OPAMP3_VINP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/COMP1_INP/LCD_SEG21/OPAMP3_VOUT/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='I2S2_MCK/LCD_SEG24/SDIO_D6/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='I2S3_MCK/LCD_SEG25/SDIO_D7/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='LCD_SEG26/SDIO_D0/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/LCD_SEG27/SDIO_D1/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SDIO_D2/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SDIO_D3/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SDIO_CK/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='FSMC_D2/FSMC_DA2/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='FSMC_D3/FSMC_DA3/I2S2_CK/SPI2_SCK/TIMX_IC2/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='LCD_COM7/LCD_SEG31/LCD_SEG43/SDIO_CMD/TIM3_ETR/TIMX_IC3/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='FSMC_CLK/SPI2_MISO/TIMX_IC4/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='FSMC_NOE/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='FSMC_NWE/TIMX_IC2/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='FSMC_NWAIT/TIMX_IC3/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='FSMC_NE1/TIM9_CH2/TIMX_IC4/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='FSMC_D13/FSMC_DA13/LCD_SEG28/TIMX_IC1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/LCD_SEG29/TIMX_IC2/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='FSMC_D15/FSMC_DA15/LCD_SEG30/TIMX_IC3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='ADC_EXTI11/FSMC_A16/LCD_SEG31/TIMX_IC4/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='FSMC_A17/LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='FSMC_A18/LCD_SEG33/TIM4_CH2/TIMX_IC2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='FSMC_D0/FSMC_DA0/LCD_SEG34/TIM4_CH3/TIMX_IC3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='ADC_EXTI15/FSMC_D1/FSMC_DA1/LCD_SEG35/TIM4_CH4/TIMX_IC4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='OPAMP3_VINM/OPAMP3_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='OPAMP1_VINM/OPAMP1_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='OPAMP2_VINM/OPAMP2_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='C11',name='PH2/FSMC_A22',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='PG0/ADC_IN8b/FSMC_A10/TS_G2_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='PG1/ADC_IN9b/FSMC_A11/TS_G2_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G10',name='PG2/ADC_IN10b/FSMC_A12/TS_G7_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='PG3/ADC_IN11b/FSMC_A13/TS_G7_IO6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='PG4/ADC_IN12b/FSMC_A14/TS_G7_IO7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PG9/DAC_EXTI9/FSMC_NE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PG10/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PG12/FSMC_NE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG13/FSMC_A24',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PG14/FSMC_A25',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PF0/FSMC_A0',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='PF1/FSMC_A1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PF2/FSMC_A2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PF3/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PF4/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='PF5/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PF6/ADC_IN27/COMP1_INP/TIM5_CH1/TIM5_ETR/TS_G11_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PF7/ADC_IN28/COMP1_INP/TIM5_CH2/TS_G11_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PF8/ADC_IN29/COMP1_INP/TIM5_CH3/TS_G11_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PF9/ADC_IN30/COMP1_INP/DAC_EXTI9/TIM5_CH4/TS_G11_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='PF11/ADC_EXTI11/ADC_IN1b/TS_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='PF12/ADC_IN2b/FSMC_A6/TS_G3_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='PF13/ADC_IN3b/FSMC_A7/TS_G9_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='PF14/ADC_IN6b/FSMC_A8/TS_G9_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='PF15/ADC_EXTI15/ADC_IN7b/FSMC_A9/TS_G2_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/FSMC_NBL0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/FSMC_NBL1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/FSMC_A23/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/FSMC_A19/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/FSMC_A20/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/FSMC_A21/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/ADC_IN22/COMP1_INP/FSMC_D4/FSMC_DA4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/ADC_IN23/COMP1_INP/FSMC_D5/FSMC_DA5/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/ADC_IN25/COMP1_INP/FSMC_D7/FSMC_DA7/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC_EXTI11/FSMC_D8/FSMC_DA8/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/FSMC_D9/FSMC_DA9/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/FSMC_D10/FSMC_DA10/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/FSMC_D11/FSMC_DA11/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/ADC_EXTI15/FSMC_D12/FSMC_DA12/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152QEHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: UFBGA132 Flash: 512KB Ram: 80KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 112',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP1_INP/LCD_SEG1/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='ADC_IN7/COMP1_INP/LCD_SEG4/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='I2S2_CK/SPI2_SCK/TIMX_IC2/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='SPI2_MISO/TIMX_IC4/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='TIMX_IC2/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='TIMX_IC3/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='TIM9_CH2/TIMX_IC4/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='LCD_SEG28/TIMX_IC1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='DAC_EXTI9/LCD_SEG29/TIMX_IC2/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='LCD_SEG30/TIMX_IC3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='ADC_EXTI11/LCD_SEG31/TIMX_IC4/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='LCD_SEG33/TIM4_CH2/TIMX_IC2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='LCD_SEG34/TIM4_CH3/TIMX_IC3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='ADC_EXTI15/LCD_SEG35/TIM4_CH4/TIMX_IC4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='NC',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='AOP1_INN/OPAMP1_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='AOP2_INN/OPAMP2_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='C11',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='PG0/ADC_IN8b/TS_G2_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='PG1/ADC_IN9b/TS_G2_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G10',name='PG2/ADC_IN10b/TS_G7_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='PG3/ADC_IN11b/TS_G7_IO6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='PG4/ADC_IN12b/TS_G7_IO7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='PG5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PG9/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PG10',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PG12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG13',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PG14',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PF0',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='PF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PF6/ADC_IN27/COMP1_INP/TIM5_CH1/TIM5_ETR/TS_G11_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PF7/ADC_IN28/COMP1_INP/TIM5_CH2/TS_G11_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PF8/ADC_IN29/COMP1_INP/TIM5_CH3/TS_G11_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PF9/ADC_IN30/COMP1_INP/DAC_EXTI9/TIM5_CH4/TS_G11_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='PF11/ADC_EXTI11/ADC_IN1b/TS_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='PF12/ADC_IN2b/TS_G3_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='PF13/ADC_IN3b/TS_G9_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='PF14/ADC_IN6b/TS_G9_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='PF15/ADC_EXTI15/ADC_IN7b/TS_G2_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152R6Hx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: TFBGA64 Flash: 32KB Ram: 10KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L152R8Hx', 'STM32L152RBHx'],pins=[
            Pin(num='G2',name='ADC_IN0/COMP1_INP/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN2/COMP1_INP/LCD_SEG1/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC_IN3/COMP1_INP/LCD_SEG2/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN6/COMP1_INP/LCD_SEG3/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC_IN7/COMP1_INP/LCD_SEG4/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='ADC_EXTI15/LCD_SEG17/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN8/COMP1_INP/LCD_SEG5/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='COMP2_INM/LCD_SEG7/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/SPI1_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='I2C1_SDA/SYS_PVD_IN/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='ADC_IN18/COMP1_INP/I2C2_SMBA/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='ADC_IN19/COMP1_INP/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='ADC_EXTI15/ADC_IN21/COMP1_INP/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='B4',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='B5',name='PD2/LCD_COM7/LCD_SEG31/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC0/ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC1/ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC2/ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC5/ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC6/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC7/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC8/LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC9/DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC10/LCD_COM4/LCD_SEG28/TIMX_IC3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/TIMX_IC4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC12/LCD_COM6/LCD_SEG30/TIMX_IC1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152R6HxA',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: TFBGA64 Flash: 32KB Ram: 16KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 50',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L152R8HxA', 'STM32L152RBHxA'],pins=[
            Pin(num='G2',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_IN2/COMP1_INP/LCD_SEG1/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC_IN3/COMP1_INP/LCD_SEG2/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN6/COMP1_INP/LCD_SEG3/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC_IN7/COMP1_INP/LCD_SEG4/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='ADC_EXTI15/LCD_SEG17/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='ADC_IN8/COMP1_INP/LCD_SEG5/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='BOOT1/COMP1_INP/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='COMP2_INM/LCD_SEG7/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/SPI1_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='ADC_IN18/COMP1_INP/I2C2_SMBA/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='ADC_IN19/COMP1_INP/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='ADC_EXTI15/ADC_IN21/COMP1_INP/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='NRST',do_erc=True),
            Pin(num='B4',name='BOOT0',do_erc=True),
            Pin(num='B2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='D1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='B5',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC0/ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC1/ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC2/ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC4/ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC5/ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PC6/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='PC7/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC8/LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PC9/DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC10/LCD_COM4/LCD_SEG28/LCD_SEG40/TIMX_IC3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/TIMX_IC4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PC12/LCD_COM6/LCD_SEG30/LCD_SEG42/TIMX_IC1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E5',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='C2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D4',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152R6Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 32KB Ram: 10KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L152R8Tx', 'STM32L152RBTx'],pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INP/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP1_INP/LCD_SEG1/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP1_INP/LCD_SEG2/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_INP/LCD_SEG3/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP1_INP/LCD_SEG4/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC_EXTI15/LCD_SEG17/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/COMP1_INP/LCD_SEG5/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/LCD_SEG7/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/SPI1_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/SYS_PVD_IN/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN18/COMP1_INP/I2C2_SMBA/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN19/COMP1_INP/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_EXTI15/ADC_IN21/COMP1_INP/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LCD_COM7/LCD_SEG31/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/LCD_COM4/LCD_SEG28/TIMX_IC3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/TIMX_IC4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/LCD_COM6/LCD_SEG30/TIMX_IC1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152R6TxA',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 32KB Ram: 16KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L152R8TxA', 'STM32L152RBTxA'],pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP1_INP/LCD_SEG1/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP1_INP/LCD_SEG2/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_INP/LCD_SEG3/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP1_INP/LCD_SEG4/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC_EXTI15/LCD_SEG17/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/COMP1_INP/LCD_SEG5/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/COMP1_INP/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/LCD_SEG7/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/SPI1_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN18/COMP1_INP/I2C2_SMBA/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN19/COMP1_INP/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_EXTI15/ADC_IN21/COMP1_INP/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/LCD_COM4/LCD_SEG28/LCD_SEG40/TIMX_IC3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/TIMX_IC4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/LCD_COM6/LCD_SEG30/LCD_SEG42/TIMX_IC1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152RCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/COMP1_INP/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152RCTxA',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152RDTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 384KB Ram: 48KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/LCD_SEG16/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/SDIO_D5/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/SDIO_CMD/TIM3_ETR/TIMX_IC3/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/COMP1_INP/LCD_SEG19/OPAMP3_VINP/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/COMP1_INP/LCD_SEG20/OPAMP3_VINM/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/COMP1_INP/LCD_SEG21/OPAMP3_VOUT/TIMX_IC4/TS_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/LCD_SEG24/SDIO_D6/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/LCD_SEG25/SDIO_D7/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/LCD_SEG26/SDIO_D0/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/LCD_SEG27/SDIO_D1/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SDIO_D2/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SDIO_D3/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SDIO_CK/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152RDYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: WLCSP64 Flash: 384KB Ram: 48KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='F6',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='E6',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='BOOT1/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='I2C1_SCL/LCD_SEG16/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/SDIO_D5/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='NRST',do_erc=True),
            Pin(num='A6',name='BOOT0',do_erc=True),
            Pin(num='C6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D8',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='D7',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='A3',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/SDIO_CMD/TIM3_ETR/TIMX_IC3/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC0/ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='PC1/ADC_IN11/COMP1_INP/LCD_SEG19/OPAMP3_VINP/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PC2/ADC_IN12/COMP1_INP/LCD_SEG20/OPAMP3_VINM/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='PC3/ADC_IN13/COMP1_INP/LCD_SEG21/OPAMP3_VOUT/TIMX_IC4/TS_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC4/ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC5/ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='PC6/I2S2_MCK/LCD_SEG24/SDIO_D6/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC7/I2S3_MCK/LCD_SEG25/SDIO_D7/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC8/LCD_SEG26/SDIO_D0/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='PC9/DAC_EXTI9/LCD_SEG27/SDIO_D1/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC10/I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SDIO_D2/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SDIO_D3/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PC12/I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SDIO_CK/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='A8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='A7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='B1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E7',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152RETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 512KB Ram: 80KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152V8Hx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: UFBGA100 Flash: 64KB Ram: 10KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L152VBHx'],pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INP/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP1_INP/LCD_SEG1/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP1_INP/LCD_SEG2/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_INP/LCD_SEG3/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC_IN7/COMP1_INP/LCD_SEG4/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ADC_EXTI15/LCD_SEG17/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/COMP1_INP/LCD_SEG5/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/LCD_SEG7/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/SPI1_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='I2C1_SDA/SYS_PVD_IN/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='ADC_IN18/COMP1_INP/I2C2_SMBA/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='ADC_IN19/COMP1_INP/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='ADC_EXTI15/ADC_IN21/COMP1_INP/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='LCD_COM4/LCD_SEG28/LCD_SEG40/TIMX_IC3/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/TIMX_IC4/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='LCD_COM6/LCD_SEG30/LCD_SEG42/TIMX_IC1/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='C11',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/LCD_SEG28/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9/DAC_EXTI9/LCD_SEG29/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10/LCD_SEG30/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/ADC_EXTI11/LCD_SEG31/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13/LCD_SEG33/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14/LCD_SEG34/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/ADC_EXTI15/LCD_SEG35/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152V8HxA',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: UFBGA100 Flash: 64KB Ram: 10KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L152VBHxA'],pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP1_INP/LCD_SEG1/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP1_INP/LCD_SEG2/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_INP/LCD_SEG3/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC_IN7/COMP1_INP/LCD_SEG4/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ADC_EXTI15/LCD_SEG17/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/COMP1_INP/LCD_SEG5/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='BOOT1/COMP1_INP/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/LCD_SEG7/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/SPI1_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='ADC_IN18/COMP1_INP/I2C2_SMBA/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='ADC_IN19/COMP1_INP/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='ADC_EXTI15/ADC_IN21/COMP1_INP/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='LCD_COM4/LCD_SEG28/LCD_SEG40/TIMX_IC3/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/TIMX_IC4/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='LCD_COM6/LCD_SEG30/LCD_SEG42/TIMX_IC1/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='C11',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/LCD_SEG28/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9/DAC_EXTI9/LCD_SEG29/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10/LCD_SEG30/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/ADC_EXTI11/LCD_SEG31/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13/LCD_SEG33/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14/LCD_SEG34/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/ADC_EXTI15/LCD_SEG35/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152V8Tx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 64KB Ram: 10KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L152VBTx'],pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INP/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP1_INP/LCD_SEG1/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP1_INP/LCD_SEG2/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_INP/LCD_SEG3/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP1_INP/LCD_SEG4/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC_EXTI15/LCD_SEG17/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/COMP1_INP/LCD_SEG5/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/LCD_SEG7/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/SPI1_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM4_CH1/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/SYS_PVD_IN/TIM4_CH2/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC_IN18/COMP1_INP/I2C2_SMBA/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC_IN19/COMP1_INP/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC_EXTI15/ADC_IN21/COMP1_INP/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='LCD_COM4/LCD_SEG28/LCD_SEG40/TIMX_IC3/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/TIMX_IC4/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='LCD_COM6/LCD_SEG30/LCD_SEG42/TIMX_IC1/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/LCD_SEG28/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/LCD_SEG29/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/LCD_SEG30/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/LCD_SEG31/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/LCD_SEG33/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/LCD_SEG34/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC_EXTI15/LCD_SEG35/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152V8TxA',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 64KB Ram: 10KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L152VBTxA'],pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/LCD_SEG0/TIM2_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP1_INP/LCD_SEG1/TIM2_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP1_INP/LCD_SEG2/TIM2_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INP/DAC_OUT1/SPI1_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_INP/LCD_SEG3/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP1_INP/LCD_SEG4/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC_EXTI15/LCD_SEG17/SPI1_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/COMP1_INP/LCD_SEG5/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/COMP1_INP/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/LCD_SEG7/SPI1_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/LCD_SEG9/SPI1_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC_IN18/COMP1_INP/I2C2_SMBA/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC_IN19/COMP1_INP/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC_EXTI15/ADC_IN21/COMP1_INP/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='LCD_COM4/LCD_SEG28/LCD_SEG40/TIMX_IC3/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/TIMX_IC4/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='LCD_COM6/LCD_SEG30/LCD_SEG42/TIMX_IC1/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/LCD_SEG28/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/LCD_SEG29/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/LCD_SEG30/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/LCD_SEG31/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/LCD_SEG33/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/LCD_SEG34/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC_EXTI15/LCD_SEG35/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152VCHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: UFBGA100 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='BOOT1/COMP1_INP/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='C11',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIM5_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1/I2S2_CK/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/LCD_SEG28/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9/DAC_EXTI9/LCD_SEG29/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10/LCD_SEG30/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/ADC_EXTI11/LCD_SEG31/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13/LCD_SEG33/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14/LCD_SEG34/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/ADC_EXTI15/LCD_SEG35/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152VCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/COMP1_INP/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIM5_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/I2S2_CK/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/LCD_SEG28/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/LCD_SEG29/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/LCD_SEG30/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/LCD_SEG31/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/LCD_SEG33/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/LCD_SEG34/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC_EXTI15/LCD_SEG35/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152VCTxA',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/I2S2_CK/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/LCD_SEG28/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/LCD_SEG29/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/LCD_SEG30/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/LCD_SEG31/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/LCD_SEG33/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/LCD_SEG34/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC_EXTI15/LCD_SEG35/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152VDTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 384KB Ram: 48KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INP/FSMC_NL/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/LCD_SEG16/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/SDIO_D5/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/COMP1_INP/LCD_SEG19/OPAMP3_VINP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/COMP1_INP/LCD_SEG20/OPAMP3_VINM/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/COMP1_INP/LCD_SEG21/OPAMP3_VOUT/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/LCD_SEG24/SDIO_D6/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/LCD_SEG25/SDIO_D7/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='LCD_SEG26/SDIO_D0/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/LCD_SEG27/SDIO_D1/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SDIO_D2/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SDIO_D3/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SDIO_CK/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='PH2/FSMC_A22',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/FSMC_NBL0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/FSMC_NBL1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/ADC_IN22/COMP1_INP/FSMC_D4/FSMC_DA4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/ADC_IN23/COMP1_INP/FSMC_D5/FSMC_DA5/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/ADC_IN25/COMP1_INP/FSMC_D7/FSMC_DA7/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/FSMC_D8/FSMC_DA8/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/FSMC_D9/FSMC_DA9/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/FSMC_D10/FSMC_DA10/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FSMC_D11/FSMC_DA11/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC_EXTI15/FSMC_D12/FSMC_DA12/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/FSMC_D2/FSMC_DA2/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/FSMC_D3/FSMC_DA3/I2S2_CK/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/SDIO_CMD/TIM3_ETR/TIMX_IC3/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/FSMC_CLK/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FSMC_NOE/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FSMC_NWE/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/FSMC_NWAIT/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FSMC_NE1/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FSMC_D13/FSMC_DA13/LCD_SEG28/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FSMC_D14/FSMC_DA14/LCD_SEG29/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FSMC_D15/FSMC_DA15/LCD_SEG30/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/FSMC_A16/LCD_SEG31/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FSMC_A17/LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FSMC_A18/LCD_SEG33/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FSMC_D0/FSMC_DA0/LCD_SEG34/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC_EXTI15/FSMC_D1/FSMC_DA1/LCD_SEG35/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152VDTxX',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 384KB Ram: 48KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/I2S2_CK/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/LCD_SEG28/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/LCD_SEG29/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/LCD_SEG30/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/LCD_SEG31/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/LCD_SEG33/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/LCD_SEG34/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC_EXTI15/LCD_SEG35/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152VETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 512KB Ram: 80KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/I2S2_CK/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/LCD_SEG28/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/LCD_SEG29/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/LCD_SEG30/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/LCD_SEG31/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/LCD_SEG33/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/LCD_SEG34/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC_EXTI15/LCD_SEG35/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152VEYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: WLCSP104 Flash: 512KB Ram: 80KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='K9',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='NRST',do_erc=True),
            Pin(num='A7',name='BOOT0',do_erc=True),
            Pin(num='E7',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='F9',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='D1',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PE0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='PE1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PE2/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PE3/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E6',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PD0/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PD1/I2S2_CK/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PD4/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PD8/LCD_SEG28/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='PD9/DAC_EXTI9/LCD_SEG29/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='PD10/LCD_SEG30/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PD11/ADC_EXTI11/LCD_SEG31/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PD12/LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='PD13/LCD_SEG33/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J1',name='PD14/LCD_SEG34/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PD15/ADC_EXTI15/LCD_SEG35/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='B8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='A1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='C7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='L2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J9',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152ZCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP144 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 115',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='34',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='I2S2_CK/SPI2_SCK/TIMX_IC2/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='SPI2_MISO/TIMX_IC4/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='TIMX_IC2/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='TIMX_IC3/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='TIM9_CH2/TIMX_IC4/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='LCD_SEG28/TIMX_IC1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/LCD_SEG29/TIMX_IC2/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='LCD_SEG30/TIMX_IC3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC_EXTI11/LCD_SEG31/TIMX_IC4/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='LCD_SEG33/TIM4_CH2/TIMX_IC2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='LCD_SEG34/TIM4_CH3/TIMX_IC3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC_EXTI15/LCD_SEG35/TIM4_CH4/TIMX_IC4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='106',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PG0/ADC_IN8b/TS_G2_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/ADC_IN9b/TS_G2_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/ADC_IN10b/TS_G7_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/ADC_IN11b/TS_G7_IO6',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/ADC_IN12b/TS_G7_IO7',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC_IN27/COMP1_INP/TIM5_CH1/TIM5_ETR/TS_G11_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC_IN28/COMP1_INP/TIM5_CH2/TS_G11_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC_IN29/COMP1_INP/TIM5_CH3/TS_G11_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC_IN30/COMP1_INP/DAC_EXTI9/TIM5_CH4/TS_G11_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC_IN31/COMP1_INP/TS_G11_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC_EXTI11/ADC_IN1b/TS_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/ADC_IN2b/TS_G3_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/ADC_IN3b/TS_G9_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/ADC_IN6b/TS_G9_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC_EXTI15/ADC_IN7b/TS_G2_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='143',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152ZDTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP144 Flash: 384KB Ram: 48KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 115',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='34',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='COMP2_INP/FSMC_NL/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='I2C1_SCL/LCD_SEG16/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/SDIO_D5/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN11/COMP1_INP/LCD_SEG19/OPAMP3_VINP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC_IN12/COMP1_INP/LCD_SEG20/OPAMP3_VINM/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN13/COMP1_INP/LCD_SEG21/OPAMP3_VOUT/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='I2S2_MCK/LCD_SEG24/SDIO_D6/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='I2S3_MCK/LCD_SEG25/SDIO_D7/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='LCD_SEG26/SDIO_D0/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/LCD_SEG27/SDIO_D1/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SDIO_D2/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SDIO_D3/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SDIO_CK/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='FSMC_D2/FSMC_DA2/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='FSMC_D3/FSMC_DA3/I2S2_CK/SPI2_SCK/TIMX_IC2/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='LCD_COM7/LCD_SEG31/LCD_SEG43/SDIO_CMD/TIM3_ETR/TIMX_IC3/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='FSMC_CLK/SPI2_MISO/TIMX_IC4/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FSMC_NOE/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FSMC_NWE/TIMX_IC2/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='FSMC_NWAIT/TIMX_IC3/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FSMC_NE1/TIM9_CH2/TIMX_IC4/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FSMC_D13/FSMC_DA13/LCD_SEG28/TIMX_IC1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/LCD_SEG29/TIMX_IC2/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FSMC_D15/FSMC_DA15/LCD_SEG30/TIMX_IC3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC_EXTI11/FSMC_A16/LCD_SEG31/TIMX_IC4/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FSMC_A17/LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FSMC_A18/LCD_SEG33/TIM4_CH2/TIMX_IC2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FSMC_D0/FSMC_DA0/LCD_SEG34/TIM4_CH3/TIMX_IC3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC_EXTI15/FSMC_D1/FSMC_DA1/LCD_SEG35/TIM4_CH4/TIMX_IC4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='106',name='PH2/FSMC_A22',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PG0/ADC_IN8b/FSMC_A10/TS_G2_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/ADC_IN9b/FSMC_A11/TS_G2_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/ADC_IN10b/FSMC_A12/TS_G7_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/ADC_IN11b/FSMC_A13/TS_G7_IO6',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/ADC_IN12b/FSMC_A14/TS_G7_IO7',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/FSMC_NE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FSMC_NE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/FSMC_A24',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/FSMC_A25',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FSMC_A0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FSMC_A1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FSMC_A2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC_IN27/COMP1_INP/TIM5_CH1/TIM5_ETR/TS_G11_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC_IN28/COMP1_INP/TIM5_CH2/TS_G11_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC_IN29/COMP1_INP/TIM5_CH3/TS_G11_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC_IN30/COMP1_INP/DAC_EXTI9/TIM5_CH4/TS_G11_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC_IN31/COMP1_INP/TS_G11_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC_EXTI11/ADC_IN1b/TS_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/ADC_IN2b/FSMC_A6/TS_G3_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/ADC_IN3b/FSMC_A7/TS_G9_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/ADC_IN6b/FSMC_A8/TS_G9_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC_EXTI15/ADC_IN7b/FSMC_A9/TS_G2_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/FSMC_NBL0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/FSMC_NBL1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/ADC_IN22/COMP1_INP/FSMC_D4/FSMC_DA4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/ADC_IN23/COMP1_INP/FSMC_D5/FSMC_DA5/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/ADC_IN25/COMP1_INP/FSMC_D7/FSMC_DA7/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC_EXTI11/FSMC_D8/FSMC_DA8/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FSMC_D9/FSMC_DA9/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FSMC_D10/FSMC_DA10/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FSMC_D11/FSMC_DA11/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC_EXTI15/FSMC_D12/FSMC_DA12/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='143',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L152ZETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L151/152',description='Core: ARM Cortex-M3 Package: LQFP144 Flash: 512KB Ram: 80KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 115',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='34',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='I2S2_CK/SPI2_SCK/TIMX_IC2/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='SPI2_MISO/TIMX_IC4/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='TIMX_IC2/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='TIMX_IC3/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='TIM9_CH2/TIMX_IC4/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='LCD_SEG28/TIMX_IC1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/LCD_SEG29/TIMX_IC2/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='LCD_SEG30/TIMX_IC3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC_EXTI11/LCD_SEG31/TIMX_IC4/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='LCD_SEG33/TIM4_CH2/TIMX_IC2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='LCD_SEG34/TIM4_CH3/TIMX_IC3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC_EXTI15/LCD_SEG35/TIM4_CH4/TIMX_IC4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='106',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PG0/ADC_IN8b/TS_G2_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/ADC_IN9b/TS_G2_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/ADC_IN10b/TS_G7_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/ADC_IN11b/TS_G7_IO6',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/ADC_IN12b/TS_G7_IO7',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC_IN27/COMP1_INP/TIM5_CH1/TIM5_ETR/TS_G11_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC_IN28/COMP1_INP/TIM5_CH2/TS_G11_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC_IN29/COMP1_INP/TIM5_CH3/TS_G11_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC_IN30/COMP1_INP/DAC_EXTI9/TIM5_CH4/TS_G11_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC_IN31/COMP1_INP/TS_G11_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC_EXTI11/ADC_IN1b/TS_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/ADC_IN2b/TS_G3_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/ADC_IN3b/TS_G9_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/ADC_IN6b/TS_G9_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC_EXTI15/ADC_IN7b/TS_G2_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='143',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L162QDHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L162',description='Core: ARM Cortex-M3 Package: UFBGA132 Flash: 384KB Ram: 48KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 112',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP1_INP/LCD_SEG1/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='ADC_IN7/COMP1_INP/LCD_SEG4/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/FSMC_NL/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/LCD_SEG16/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/SDIO_D5/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/COMP1_INP/LCD_SEG19/OPAMP3_VINP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/COMP1_INP/LCD_SEG21/OPAMP3_VOUT/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='I2S2_MCK/LCD_SEG24/SDIO_D6/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='I2S3_MCK/LCD_SEG25/SDIO_D7/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='LCD_SEG26/SDIO_D0/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/LCD_SEG27/SDIO_D1/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SDIO_D2/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SDIO_D3/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SDIO_CK/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='FSMC_D2/FSMC_DA2/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='FSMC_D3/FSMC_DA3/I2S2_CK/SPI2_SCK/TIMX_IC2/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='LCD_COM7/LCD_SEG31/LCD_SEG43/SDIO_CMD/TIM3_ETR/TIMX_IC3/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='FSMC_CLK/SPI2_MISO/TIMX_IC4/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='FSMC_NOE/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='FSMC_NWE/TIMX_IC2/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='FSMC_NWAIT/TIMX_IC3/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='FSMC_NE1/TIM9_CH2/TIMX_IC4/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='FSMC_D13/FSMC_DA13/LCD_SEG28/TIMX_IC1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/LCD_SEG29/TIMX_IC2/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='FSMC_D15/FSMC_DA15/LCD_SEG30/TIMX_IC3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='ADC_EXTI11/FSMC_A16/LCD_SEG31/TIMX_IC4/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='FSMC_A17/LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='FSMC_A18/LCD_SEG33/TIM4_CH2/TIMX_IC2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='FSMC_D0/FSMC_DA0/LCD_SEG34/TIM4_CH3/TIMX_IC3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='ADC_EXTI15/FSMC_D1/FSMC_DA1/LCD_SEG35/TIM4_CH4/TIMX_IC4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='OPAMP3_VINM/OPAMP3_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='OPAMP1_VINM/OPAMP1_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='OPAMP2_VINM/OPAMP2_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='C11',name='PH2/FSMC_A22',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='PG0/ADC_IN8b/FSMC_A10/TS_G2_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='PG1/ADC_IN9b/FSMC_A11/TS_G2_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G10',name='PG2/ADC_IN10b/FSMC_A12/TS_G7_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='PG3/ADC_IN11b/FSMC_A13/TS_G7_IO6',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='PG4/ADC_IN12b/FSMC_A14/TS_G7_IO7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PG9/DAC_EXTI9/FSMC_NE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PG10/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PG12/FSMC_NE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG13/FSMC_A24',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PG14/FSMC_A25',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PF0/FSMC_A0',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='PF1/FSMC_A1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PF2/FSMC_A2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PF3/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PF4/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='PF5/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PF6/ADC_IN27/COMP1_INP/TIM5_CH1/TIM5_ETR/TS_G11_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PF7/ADC_IN28/COMP1_INP/TIM5_CH2/TS_G11_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PF8/ADC_IN29/COMP1_INP/TIM5_CH3/TS_G11_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PF9/ADC_IN30/COMP1_INP/DAC_EXTI9/TIM5_CH4/TS_G11_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='PF11/ADC_EXTI11/ADC_IN1b/TS_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='PF12/ADC_IN2b/FSMC_A6/TS_G3_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='PF13/ADC_IN3b/FSMC_A7/TS_G9_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='PF14/ADC_IN6b/FSMC_A8/TS_G9_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='PF15/ADC_EXTI15/ADC_IN7b/FSMC_A9/TS_G2_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/FSMC_NBL0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/FSMC_NBL1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/FSMC_A23/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/FSMC_A19/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/FSMC_A20/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/FSMC_A21/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/ADC_IN22/COMP1_INP/FSMC_D4/FSMC_DA4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/ADC_IN23/COMP1_INP/FSMC_D5/FSMC_DA5/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/ADC_IN25/COMP1_INP/FSMC_D7/FSMC_DA7/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC_EXTI11/FSMC_D8/FSMC_DA8/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/FSMC_D9/FSMC_DA9/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/FSMC_D10/FSMC_DA10/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/FSMC_D11/FSMC_DA11/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/ADC_EXTI15/FSMC_D12/FSMC_DA12/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L162RCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L162',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/COMP1_INP/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L162RCTxA',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L162',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L162RDTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L162',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 384KB Ram: 48KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/LCD_SEG16/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/SDIO_D5/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/SDIO_CMD/TIM3_ETR/TIMX_IC3/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/COMP1_INP/LCD_SEG19/OPAMP3_VINP/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/COMP1_INP/LCD_SEG20/OPAMP3_VINM/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/COMP1_INP/LCD_SEG21/OPAMP3_VOUT/TIMX_IC4/TS_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/LCD_SEG24/SDIO_D6/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/LCD_SEG25/SDIO_D7/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/LCD_SEG26/SDIO_D0/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/LCD_SEG27/SDIO_D1/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SDIO_D2/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SDIO_D3/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SDIO_CK/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L162RDYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L162',description='Core: ARM Cortex-M3 Package: WLCSP64 Flash: 384KB Ram: 48KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='F6',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='E6',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H8',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='BOOT1/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='I2C1_SCL/LCD_SEG16/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/SDIO_D5/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='NRST',do_erc=True),
            Pin(num='A6',name='BOOT0',do_erc=True),
            Pin(num='C6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='D8',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='D7',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='A3',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/SDIO_CMD/TIM3_ETR/TIMX_IC3/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='PC0/ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='PC1/ADC_IN11/COMP1_INP/LCD_SEG19/OPAMP3_VINP/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PC2/ADC_IN12/COMP1_INP/LCD_SEG20/OPAMP3_VINM/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='PC3/ADC_IN13/COMP1_INP/LCD_SEG21/OPAMP3_VOUT/TIMX_IC4/TS_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='PC4/ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='PC5/ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='PC6/I2S2_MCK/LCD_SEG24/SDIO_D6/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='PC7/I2S3_MCK/LCD_SEG25/SDIO_D7/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='PC8/LCD_SEG26/SDIO_D0/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='PC9/DAC_EXTI9/LCD_SEG27/SDIO_D1/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PC10/I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SDIO_D2/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SDIO_D3/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PC12/I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SDIO_CK/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='A8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='A7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='B1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F5',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='H2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E7',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L162RETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L162',description='Core: ARM Cortex-M3 Package: LQFP64 Flash: 512KB Ram: 80KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L162VCHx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L162',description='Core: ARM Cortex-M3 Package: UFBGA100 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='L2',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='BOOT1/COMP1_INP/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K1',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='F1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='C11',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIM5_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PD0/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PD1/I2S2_CK/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PD4/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='PD8/LCD_SEG28/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='PD9/DAC_EXTI9/LCD_SEG29/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='PD10/LCD_SEG30/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='PD11/ADC_EXTI11/LCD_SEG31/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='PD12/LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='PD13/LCD_SEG33/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='PD14/LCD_SEG34/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='PD15/ADC_EXTI15/LCD_SEG35/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L162VCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L162',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/COMP1_INP/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIM5_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/I2S2_CK/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/LCD_SEG28/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/LCD_SEG29/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/LCD_SEG30/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/LCD_SEG31/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/LCD_SEG33/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/LCD_SEG34/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC_EXTI15/LCD_SEG35/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L162VCTxA',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L162',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 256KB Ram: 32KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/I2S2_CK/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/LCD_SEG28/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/LCD_SEG29/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/LCD_SEG30/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/LCD_SEG31/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/LCD_SEG33/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/LCD_SEG34/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC_EXTI15/LCD_SEG35/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L162VDTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L162',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 384KB Ram: 48KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INP/FSMC_NL/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/LCD_SEG16/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/SDIO_D5/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/COMP1_INP/LCD_SEG19/OPAMP3_VINP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/COMP1_INP/LCD_SEG20/OPAMP3_VINM/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/COMP1_INP/LCD_SEG21/OPAMP3_VOUT/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/LCD_SEG24/SDIO_D6/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/LCD_SEG25/SDIO_D7/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='LCD_SEG26/SDIO_D0/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/LCD_SEG27/SDIO_D1/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SDIO_D2/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SDIO_D3/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SDIO_CK/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='PH2/FSMC_A22',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/FSMC_NBL0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/FSMC_NBL1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/ADC_IN22/COMP1_INP/FSMC_D4/FSMC_DA4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/ADC_IN23/COMP1_INP/FSMC_D5/FSMC_DA5/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/ADC_IN25/COMP1_INP/FSMC_D7/FSMC_DA7/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/FSMC_D8/FSMC_DA8/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/FSMC_D9/FSMC_DA9/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/FSMC_D10/FSMC_DA10/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FSMC_D11/FSMC_DA11/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC_EXTI15/FSMC_D12/FSMC_DA12/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/FSMC_D2/FSMC_DA2/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/FSMC_D3/FSMC_DA3/I2S2_CK/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/SDIO_CMD/TIM3_ETR/TIMX_IC3/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/FSMC_CLK/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/FSMC_NOE/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FSMC_NWE/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/FSMC_NWAIT/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/FSMC_NE1/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FSMC_D13/FSMC_DA13/LCD_SEG28/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/FSMC_D14/FSMC_DA14/LCD_SEG29/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FSMC_D15/FSMC_DA15/LCD_SEG30/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/FSMC_A16/LCD_SEG31/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FSMC_A17/LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FSMC_A18/LCD_SEG33/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FSMC_D0/FSMC_DA0/LCD_SEG34/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC_EXTI15/FSMC_D1/FSMC_DA1/LCD_SEG35/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L162VDYxX',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L162',description='Core: ARM Cortex-M3 Package: WLCSP104 Flash: 384KB Ram: 80KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='K9',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='NRST',do_erc=True),
            Pin(num='A7',name='BOOT0',do_erc=True),
            Pin(num='E7',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='F9',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='D1',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PE0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='PE1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PE2/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PE3/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E6',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PD0/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PD1/I2S2_CK/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PD4/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PD8/LCD_SEG28/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='PD9/DAC_EXTI9/LCD_SEG29/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='PD10/LCD_SEG30/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PD11/ADC_EXTI11/LCD_SEG31/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PD12/LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='PD13/LCD_SEG33/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J1',name='PD14/LCD_SEG34/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PD15/ADC_EXTI15/LCD_SEG35/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='B8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='A1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='C7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='L2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J9',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L162VETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L162',description='Core: ARM Cortex-M3 Package: LQFP100 Flash: 512KB Ram: 80KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='73',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='PE0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/I2S2_CK/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/LCD_SEG28/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC_EXTI9/LCD_SEG29/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/LCD_SEG30/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC_EXTI11/LCD_SEG31/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/LCD_SEG33/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/LCD_SEG34/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC_EXTI15/LCD_SEG35/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L162VEYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L162',description='Core: ARM Cortex-M3 Package: WLCSP104 Flash: 512KB Ram: 80KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 83',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='K9',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='L1',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='H9',name='ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='G8',name='ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='NRST',do_erc=True),
            Pin(num='A7',name='BOOT0',do_erc=True),
            Pin(num='E7',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='H8',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='F8',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='F9',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='D1',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='PE0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='PE1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PE2/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PE3/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='E6',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PD0/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PD1/I2S2_CK/SPI2_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3/UART5_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PD3/SPI2_MISO/TIMX_IC4/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PD4/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PD5/TIMX_IC2/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PD6/TIMX_IC3/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='A4',name='PD7/TIM9_CH2/TIMX_IC4/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PD8/LCD_SEG28/TIMX_IC1/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='PD9/DAC_EXTI9/LCD_SEG29/TIMX_IC2/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='PD10/LCD_SEG30/TIMX_IC3/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PD11/ADC_EXTI11/LCD_SEG31/TIMX_IC4/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='PD12/LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='PD13/LCD_SEG33/TIM4_CH2/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='J1',name='PD14/LCD_SEG34/TIM4_CH3/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PD15/ADC_EXTI15/LCD_SEG35/TIM4_CH4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='B8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='C1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='K3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='L8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='A1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='C7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='D2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='K8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='L2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J9',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L162ZDTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L162',description='Core: ARM Cortex-M3 Package: LQFP144 Flash: 384KB Ram: 48KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 115',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='34',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='COMP2_INP/FSMC_NL/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='I2C1_SCL/LCD_SEG16/SDIO_D4/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/SDIO_D5/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN11/COMP1_INP/LCD_SEG19/OPAMP3_VINP/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC_IN12/COMP1_INP/LCD_SEG20/OPAMP3_VINM/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN13/COMP1_INP/LCD_SEG21/OPAMP3_VOUT/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='I2S2_MCK/LCD_SEG24/SDIO_D6/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='I2S3_MCK/LCD_SEG25/SDIO_D7/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='LCD_SEG26/SDIO_D0/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/LCD_SEG27/SDIO_D1/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SDIO_D2/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SDIO_D3/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SDIO_CK/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='FSMC_D2/FSMC_DA2/I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='FSMC_D3/FSMC_DA3/I2S2_CK/SPI2_SCK/TIMX_IC2/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='LCD_COM7/LCD_SEG31/LCD_SEG43/SDIO_CMD/TIM3_ETR/TIMX_IC3/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='FSMC_CLK/SPI2_MISO/TIMX_IC4/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='FSMC_NOE/I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FSMC_NWE/TIMX_IC2/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='FSMC_NWAIT/TIMX_IC3/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='FSMC_NE1/TIM9_CH2/TIMX_IC4/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FSMC_D13/FSMC_DA13/LCD_SEG28/TIMX_IC1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/FSMC_D14/FSMC_DA14/LCD_SEG29/TIMX_IC2/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FSMC_D15/FSMC_DA15/LCD_SEG30/TIMX_IC3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC_EXTI11/FSMC_A16/LCD_SEG31/TIMX_IC4/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FSMC_A17/LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FSMC_A18/LCD_SEG33/TIM4_CH2/TIMX_IC2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FSMC_D0/FSMC_DA0/LCD_SEG34/TIM4_CH3/TIMX_IC3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC_EXTI15/FSMC_D1/FSMC_DA1/LCD_SEG35/TIM4_CH4/TIMX_IC4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='106',name='PH2/FSMC_A22',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PG0/ADC_IN8b/FSMC_A10/TS_G2_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/ADC_IN9b/FSMC_A11/TS_G2_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/ADC_IN10b/FSMC_A12/TS_G7_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/ADC_IN11b/FSMC_A13/TS_G7_IO6',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/ADC_IN12b/FSMC_A14/TS_G7_IO7',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FSMC_A15',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9/FSMC_NE2',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/FSMC_NE3',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FSMC_NE4',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/FSMC_A24',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/FSMC_A25',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FSMC_A0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FSMC_A1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FSMC_A2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/FSMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/FSMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/FSMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC_IN27/COMP1_INP/TIM5_CH1/TIM5_ETR/TS_G11_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC_IN28/COMP1_INP/TIM5_CH2/TS_G11_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC_IN29/COMP1_INP/TIM5_CH3/TS_G11_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC_IN30/COMP1_INP/DAC_EXTI9/TIM5_CH4/TS_G11_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC_IN31/COMP1_INP/TS_G11_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC_EXTI11/ADC_IN1b/TS_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/ADC_IN2b/FSMC_A6/TS_G3_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/ADC_IN3b/FSMC_A7/TS_G9_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/ADC_IN6b/FSMC_A8/TS_G9_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC_EXTI15/ADC_IN7b/FSMC_A9/TS_G2_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/FSMC_NBL0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/FSMC_NBL1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FSMC_A23/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FSMC_A19/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/FSMC_A20/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/FSMC_A21/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/ADC_IN22/COMP1_INP/FSMC_D4/FSMC_DA4/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/ADC_IN23/COMP1_INP/FSMC_D5/FSMC_DA5/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/FSMC_D6/FSMC_DA6/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/ADC_IN25/COMP1_INP/FSMC_D7/FSMC_DA7/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC_EXTI11/FSMC_D8/FSMC_DA8/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/FSMC_D9/FSMC_DA9/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/FSMC_D10/FSMC_DA10/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FSMC_D11/FSMC_DA11/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC_EXTI15/FSMC_D12/FSMC_DA12/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='143',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L162ZETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M3 STM32L1 STM32L162',description='Core: ARM Cortex-M3 Package: LQFP144 Flash: 512KB Ram: 80KB Frequency: 32MHz Voltage: 1.65..3.6V IO-pins: 115',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='34',name='ADC_IN0/COMP1_INP/RTC_TAMP2/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIMX_IC1/TS_G1_IO1/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC_IN1/COMP1_INP/LCD_SEG0/OPAMP1_VINP/TIM2_CH2/TIM5_CH2/TIMX_IC2/TS_G1_IO2/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC_IN2/COMP1_INP/LCD_SEG1/OPAMP1_VINM/TIM2_CH3/TIM5_CH3/TIM9_CH1/TIMX_IC3/TS_G1_IO3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC_IN3/COMP1_INP/LCD_SEG2/OPAMP1_VOUT/TIM2_CH4/TIM5_CH4/TIM9_CH2/TIMX_IC4/TS_G1_IO4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC_IN4/COMP1_INP/DAC_OUT1/I2S3_WS/SPI1_NSS/SPI3_NSS/TIMX_IC1/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC_IN5/COMP1_INP/DAC_OUT2/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIMX_IC2/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC_IN6/COMP1_INP/LCD_SEG3/OPAMP2_VINP/SPI1_MISO/TIM10_CH1/TIM3_CH1/TIMX_IC3/TS_G2_IO1/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC_IN7/COMP1_INP/LCD_SEG4/OPAMP2_VINM/SPI1_MOSI/TIM11_CH1/TIM3_CH2/TIMX_IC4/TS_G2_IO2/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='LCD_COM0/RCC_MCO/TIMX_IC1/TS_G4_IO1/USART1_CK/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC_EXTI9/LCD_COM1/TIMX_IC2/TS_G4_IO2/USART1_TX/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='LCD_COM2/TIMX_IC3/TS_G4_IO3/USART1_RX/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC_EXTI11/SPI1_MISO/TIMX_IC4/USART1_CTS/USB_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='SPI1_MOSI/TIMX_IC1/USART1_RTS/USB_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='SYS_JTMS-SWDIO/TIMX_IC2/TS_G5_IO1/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/TIMX_IC3/TS_G5_IO2/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC_EXTI15/I2S3_WS/LCD_SEG17/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TIMX_IC4/TS_G5_IO3/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC_IN8/COMP1_INP/LCD_SEG5/OPAMP2_VOUT/SYS_V_REF_OUT/TIM3_CH3/TS_G3_IO1/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC_IN9/COMP1_INP/LCD_SEG6/SYS_V_REF_OUT/TIM3_CH4/TS_G3_IO2/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='BOOT1/ADC_IN0b/TS_G3_IO3/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='COMP2_INM/I2S3_CK/LCD_SEG7/SPI1_SCK/SPI3_SCK/SYS_JTDO-TRACESWO/TIM2_CH2/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='COMP2_INP/LCD_SEG8/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM3_CH1/TS_G6_IO1/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='COMP2_INP/I2C1_SMBA/I2S3_SD/LCD_SEG9/SPI1_MOSI/SPI3_MOSI/TIM3_CH2/TS_G6_IO2/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='COMP2_INP/I2C1_SCL/TIM4_CH1/TS_G6_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='COMP2_INP/I2C1_SDA/SYS_PVD_IN/TIM4_CH2/TS_G6_IO4/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='I2C1_SCL/LCD_SEG16/TIM10_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='DAC_EXTI9/I2C1_SDA/LCD_COM3/TIM11_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='I2C2_SCL/LCD_SEG10/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC_EXTI11/I2C2_SDA/LCD_SEG11/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='ADC_IN18/COMP1_INP/I2C2_SMBA/I2S2_WS/LCD_SEG12/SPI2_NSS/TIM10_CH1/TS_G7_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='ADC_IN19/COMP1_INP/I2S2_CK/LCD_SEG13/SPI2_SCK/TIM9_CH1/TS_G7_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='ADC_IN20/COMP1_INP/LCD_SEG14/SPI2_MISO/TIM9_CH2/TS_G7_IO3/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC_EXTI15/ADC_IN21/COMP1_INP/I2S2_SD/LCD_SEG15/RTC_REFIN/SPI2_MOSI/TIM11_CH1/TS_G7_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC_IN10/COMP1_INP/LCD_SEG18/TIMX_IC1/TS_G8_IO1/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC_IN11/COMP1_INP/LCD_SEG19/TIMX_IC2/TS_G8_IO2/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC_IN12/COMP1_INP/LCD_SEG20/TIMX_IC3/TS_G8_IO3/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC_IN13/COMP1_INP/LCD_SEG21/TIMX_IC4/TS_G8_IO4/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC_IN14/COMP1_INP/LCD_SEG22/TIMX_IC1/TS_G9_IO1/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC_IN15/COMP1_INP/LCD_SEG23/TIMX_IC2/TS_G9_IO2/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='I2S2_MCK/LCD_SEG24/TIM3_CH1/TIMX_IC3/TS_G10_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='I2S3_MCK/LCD_SEG25/TIM3_CH2/TIMX_IC4/TS_G10_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='LCD_SEG26/TIM3_CH3/TIMX_IC1/TS_G10_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC_EXTI9/LCD_SEG27/TIM3_CH4/TIMX_IC2/TS_G10_IO4/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='I2S3_CK/LCD_COM4/LCD_SEG28/LCD_SEG40/SPI3_SCK/TIMX_IC3/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SPI3_MISO/TIMX_IC4/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='I2S3_SD/LCD_COM6/LCD_SEG30/LCD_SEG42/SPI3_MOSI/TIMX_IC1/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/TIMX_IC2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/TIMX_IC3/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC_EXTI15/RCC_OSC32_OUT/TIMX_IC4/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='I2S2_WS/SPI2_NSS/TIM9_CH1/TIMX_IC1/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='I2S2_CK/SPI2_SCK/TIMX_IC2/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='LCD_COM7/LCD_SEG31/LCD_SEG43/TIM3_ETR/TIMX_IC3/UART5_RX/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='SPI2_MISO/TIMX_IC4/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='I2S2_SD/SPI2_MOSI/TIMX_IC1/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='TIMX_IC2/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='TIMX_IC3/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='TIM9_CH2/TIMX_IC4/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='LCD_SEG28/TIMX_IC1/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC_EXTI9/LCD_SEG29/TIMX_IC2/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='LCD_SEG30/TIMX_IC3/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC_EXTI11/LCD_SEG31/TIMX_IC4/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='LCD_SEG32/TIM4_CH1/TIMX_IC1/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='LCD_SEG33/TIM4_CH2/TIMX_IC2/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='LCD_SEG34/TIM4_CH3/TIMX_IC3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC_EXTI15/LCD_SEG35/TIM4_CH4/TIMX_IC4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VLCD',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+',func=Pin.PWRIN,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='106',name='PH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PG0/ADC_IN8b/TS_G2_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/ADC_IN9b/TS_G2_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/ADC_IN10b/TS_G7_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/ADC_IN11b/TS_G7_IO6',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/ADC_IN12b/TS_G7_IO7',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC_EXTI9',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC_EXTI15',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC_IN27/COMP1_INP/TIM5_CH1/TIM5_ETR/TS_G11_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC_IN28/COMP1_INP/TIM5_CH2/TS_G11_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC_IN29/COMP1_INP/TIM5_CH3/TS_G11_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC_IN30/COMP1_INP/DAC_EXTI9/TIM5_CH4/TS_G11_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC_IN31/COMP1_INP/TS_G11_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC_EXTI11/ADC_IN1b/TS_G3_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/ADC_IN2b/TS_G3_IO5',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/ADC_IN3b/TS_G9_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/ADC_IN6b/TS_G9_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC_EXTI15/ADC_IN7b/TS_G2_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/LCD_SEG36/TIM10_CH1/TIM4_ETR/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/LCD_SEG37/TIM11_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/LCD_SEG38/SYS_TRACECK/TIM3_ETR/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/LCD_SEG39/SYS_TRACED0/TIM3_CH1/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/SYS_TRACED1/TIM3_CH2/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/SYS_TRACED2/TIM9_CH1/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/RTC_TAMP3/SYS_TRACED3/SYS_WKUP3/TIM9_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/ADC_IN22/COMP1_INP/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/ADC_IN23/COMP1_INP/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/ADC_IN24/COMP1_INP/DAC_EXTI9/TIM2_CH1/TIM2_ETR/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/ADC_IN25/COMP1_INP/TIM2_CH2/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC_EXTI11/TIM2_CH3/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/SPI1_NSS/TIM2_CH4/TIMX_IC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/SPI1_SCK/TIMX_IC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/SPI1_MISO/TIMX_IC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC_EXTI15/SPI1_MOSI/TIMX_IC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='143',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L476JEYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32L4 STM32L4x6',description='Core: ARM Cortex-M4 Package: WLCSP72 Flash: 512KB Ram: 128KB Frequency: 80MHz Voltage: 1.71..3.6V IO-pins: 57',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L476JGYx'],pins=[
            Pin(num='H8',name='ADC1_IN5/ADC2_IN5/OPAMP1_VINP/RTC_TAMP2/SAI1_EXTCLK/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC1_IN6/ADC2_IN6/LCD_SEG0/OPAMP1_VINM/TIM15_CH1N/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='ADC1_IN7/ADC2_IN7/LCD_SEG1/RCC_LSCO/SAI2_EXTCLK/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC1_IN8/ADC2_IN8/LCD_SEG2/OPAMP1_VOUT/TIM15_CH2/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC1_IN9/ADC2_IN9/DAC1_OUT1/LPTIM2_OUT/SAI1_FS_B/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='ADC1_IN10/ADC2_IN10/DAC1_OUT2/LPTIM2_ETR/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='ADC1_IN11/ADC2_IN11/LCD_SEG3/OPAMP2_VINP/QUADSPI_BK1_IO3/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM1_BKIN_COMP2/TIM3_CH1/TIM8_BKIN/TIM8_BKIN_COMP2/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC1_IN12/ADC2_IN12/LCD_SEG4/OPAMP2_VINM/QUADSPI_BK1_IO2/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='LCD_COM0/LPTIM2_OUT/RCC_MCO/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='DAC1_EXTI9/LCD_COM1/TIM15_BKIN/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='LCD_COM2/TIM17_BKIN/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_BKIN2/TIM1_BKIN2_COMP1/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='CAN1_TX/TIM1_ETR/USART1_DE/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='IR_OUT/SYS_JTMS-SWDIO/USB_OTG_FS_NOE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LCD_SEG17/SAI2_FS_B/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TSC_G3_IO1/UART4_DE/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='ADC1_IN15/ADC2_IN15/COMP1_OUT/LCD_SEG5/OPAMP2_VOUT/QUADSPI_BK1_IO1/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC1_IN16/ADC2_IN16/COMP1_INM/DFSDM_DATIN0/LCD_SEG6/LPTIM2_IN1/QUADSPI_BK1_IO0/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='COMP1_INP/DFSDM_CKIN0/I2C3_SMBA/LPTIM1_OUT/RTC_OUT_ALARM/RTC_OUT_CALIB/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='COMP2_INM/LCD_SEG7/SAI1_SCK_B/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/USART1_DE/USART1_RTS/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='COMP2_INP/LCD_SEG8/SAI1_MCLK_B/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM17_BKIN/TIM3_CH1/TSC_G2_IO1/UART5_DE/UART5_RTS/USART1_CTS/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='COMP2_OUT/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SAI1_SD_B/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM3_CH2/TSC_G2_IO2/UART5_CTS/USART1_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='COMP2_INP/DFSDM_DATIN5/I2C1_SCL/LPTIM1_ETR/SAI1_FS_B/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_BKIN2_COMP2/TSC_G2_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INM/DFSDM_CKIN5/I2C1_SDA/LCD_SEG21/LPTIM1_IN2/SYS_PVD_IN/TIM17_CH1N/TIM4_CH2/TIM8_BKIN/TIM8_BKIN_COMP1/TSC_G2_IO4/UART4_CTS/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='CAN1_RX/DFSDM_DATIN6/I2C1_SCL/LCD_SEG16/SAI1_MCLK_A/SDMMC1_D4/TIM16_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='CAN1_TX/DAC1_EXTI9/DFSDM_CKIN6/I2C1_SDA/IR_OUT/LCD_COM3/SAI1_FS_A/SDMMC1_D5/SPI2_NSS/TIM17_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='COMP1_OUT/DFSDM_DATIN7/I2C2_SCL/LCD_SEG10/LPUART1_RX/QUADSPI_CLK/SAI1_SCK_A/SPI2_SCK/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/COMP2_OUT/DFSDM_CKIN7/I2C2_SDA/LCD_SEG11/LPUART1_TX/QUADSPI_NCS/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='DFSDM_DATIN1/I2C2_SMBA/LCD_SEG12/LPUART1_DE/LPUART1_RTS/SAI2_FS_A/SPI2_NSS/SWPMI1_IO/TIM15_BKIN/TIM1_BKIN/TIM1_BKIN_COMP2/TSC_G1_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='DFSDM_CKIN1/I2C2_SCL/LCD_SEG13/LPUART1_CTS/SAI2_SCK_A/SPI2_SCK/SWPMI1_TX/TIM15_CH1N/TIM1_CH1N/TSC_G1_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='DFSDM_DATIN2/I2C2_SDA/LCD_SEG14/SAI2_MCLK_A/SPI2_MISO/SWPMI1_RX/TIM15_CH1/TIM1_CH2N/TIM8_CH2N/TSC_G1_IO3/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DFSDM_CKIN2/LCD_SEG15/RTC_REFIN/SAI2_SD_A/SPI2_MOSI/SWPMI1_SUSPEND/TIM15_CH2/TIM1_CH3N/TIM8_CH3N/TSC_G1_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='NRST',do_erc=True),
            Pin(num='D7',name='BOOT0',do_erc=True),
            Pin(num='B9',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VREF+/VREFBUF_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='D8',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='A4',name='PG9/DAC1_EXTI9/SAI2_SCK_A/SPI3_SCK/TIM15_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PG10/LPTIM1_IN1/SAI2_FS_A/SPI3_MISO/TIM15_CH1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LPTIM1_IN2/SAI2_MCLK_A/SPI3_MOSI/TIM15_CH2/USART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PG12/LPTIM1_ETR/SAI2_SD_A/SPI3_NSS/USART1_DE/USART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='PG13/I2C1_SDA/USART1_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PG14/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/SDMMC1_CMD/TIM3_ETR/TSC_SYNC/UART5_RX/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='PC0/ADC1_IN1/ADC2_IN1/ADC3_IN1/DFSDM_DATIN4/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPTIM2_IN1/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='PC1/ADC1_IN2/ADC2_IN2/ADC3_IN2/DFSDM_CKIN4/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='PC2/ADC1_IN3/ADC2_IN3/ADC3_IN3/DFSDM_CKOUT/LCD_SEG20/LPTIM1_IN2/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='PC3/ADC1_IN4/ADC2_IN4/ADC3_IN4/LCD_VLCD/LPTIM1_ETR/LPTIM2_ETR/SAI1_SD_A/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='PC4/ADC1_IN13/ADC2_IN13/COMP1_INM/LCD_SEG22/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PC5/ADC1_IN14/ADC2_IN14/COMP1_INP/LCD_SEG23/SYS_WKUP5/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PC6/DFSDM_CKIN3/LCD_SEG24/SAI2_MCLK_A/SDMMC1_D6/TIM3_CH1/TIM8_CH1/TSC_G4_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PC7/DFSDM_DATIN3/LCD_SEG25/SAI2_MCLK_B/SDMMC1_D7/TIM3_CH2/TIM8_CH2/TSC_G4_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC8/LCD_SEG26/SDMMC1_D0/TIM3_CH3/TIM8_CH3/TSC_G4_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='PC9/DAC1_EXTI9/LCD_SEG27/SAI2_EXTCLK/SDMMC1_D1/TIM3_CH4/TIM8_BKIN2/TIM8_BKIN2_COMP1/TIM8_CH4/TSC_G4_IO4/USB_OTG_FS_NOE',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PC10/LCD_COM4/LCD_SEG28/LCD_SEG40/SAI2_SCK_B/SDMMC1_D2/SPI3_SCK/TSC_G3_IO2/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PC11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SAI2_MCLK_B/SDMMC1_D3/SPI3_MISO/TSC_G3_IO3/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PC12/LCD_COM6/LCD_SEG30/LCD_SEG42/SAI2_SD_B/SDMMC1_CK/SPI3_MOSI/TSC_G3_IO4/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PC15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='B6',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='A1',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='A8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='B1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L476MEYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32L4 STM32L4x6',description='Core: ARM Cortex-M4 Package: WLCSP81 Flash: 512KB Ram: 128KB Frequency: 80MHz Voltage: 1.71..3.6V IO-pins: 65',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L476MGYx'],pins=[
            Pin(num='H8',name='ADC1_IN5/ADC2_IN5/OPAMP1_VINP/RTC_TAMP2/SAI1_EXTCLK/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC1_IN6/ADC2_IN6/LCD_SEG0/OPAMP1_VINM/TIM15_CH1N/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='ADC1_IN7/ADC2_IN7/LCD_SEG1/RCC_LSCO/SAI2_EXTCLK/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC1_IN8/ADC2_IN8/LCD_SEG2/OPAMP1_VOUT/TIM15_CH2/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC1_IN9/ADC2_IN9/DAC1_OUT1/LPTIM2_OUT/SAI1_FS_B/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='ADC1_IN10/ADC2_IN10/DAC1_OUT2/LPTIM2_ETR/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='ADC1_IN11/ADC2_IN11/LCD_SEG3/OPAMP2_VINP/QUADSPI_BK1_IO3/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM1_BKIN_COMP2/TIM3_CH1/TIM8_BKIN/TIM8_BKIN_COMP2/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC1_IN12/ADC2_IN12/LCD_SEG4/OPAMP2_VINM/QUADSPI_BK1_IO2/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='LCD_COM0/LPTIM2_OUT/RCC_MCO/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='DAC1_EXTI9/LCD_COM1/TIM15_BKIN/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='LCD_COM2/TIM17_BKIN/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_BKIN2/TIM1_BKIN2_COMP1/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='CAN1_TX/TIM1_ETR/USART1_DE/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='IR_OUT/SYS_JTMS-SWDIO/USB_OTG_FS_NOE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LCD_SEG17/SAI2_FS_B/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TSC_G3_IO1/UART4_DE/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='ADC1_IN15/ADC2_IN15/COMP1_OUT/LCD_SEG5/OPAMP2_VOUT/QUADSPI_BK1_IO1/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC1_IN16/ADC2_IN16/COMP1_INM/DFSDM_DATIN0/LCD_SEG6/LPTIM2_IN1/QUADSPI_BK1_IO0/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='COMP1_INP/DFSDM_CKIN0/I2C3_SMBA/LPTIM1_OUT/RTC_OUT_ALARM/RTC_OUT_CALIB/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='COMP2_INM/LCD_SEG7/SAI1_SCK_B/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/USART1_DE/USART1_RTS/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='COMP2_INP/LCD_SEG8/SAI1_MCLK_B/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM17_BKIN/TIM3_CH1/TSC_G2_IO1/UART5_DE/UART5_RTS/USART1_CTS/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='COMP2_OUT/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SAI1_SD_B/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM3_CH2/TSC_G2_IO2/UART5_CTS/USART1_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='COMP2_INP/DFSDM_DATIN5/I2C1_SCL/LPTIM1_ETR/SAI1_FS_B/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_BKIN2_COMP2/TSC_G2_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INM/DFSDM_CKIN5/I2C1_SDA/LCD_SEG21/LPTIM1_IN2/SYS_PVD_IN/TIM17_CH1N/TIM4_CH2/TIM8_BKIN/TIM8_BKIN_COMP1/TSC_G2_IO4/UART4_CTS/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='CAN1_RX/DFSDM_DATIN6/I2C1_SCL/LCD_SEG16/SAI1_MCLK_A/SDMMC1_D4/TIM16_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='CAN1_TX/DAC1_EXTI9/DFSDM_CKIN6/I2C1_SDA/IR_OUT/LCD_COM3/SAI1_FS_A/SDMMC1_D5/SPI2_NSS/TIM17_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='COMP1_OUT/DFSDM_DATIN7/I2C2_SCL/LCD_SEG10/LPUART1_RX/QUADSPI_CLK/SAI1_SCK_A/SPI2_SCK/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/COMP2_OUT/DFSDM_CKIN7/I2C2_SDA/LCD_SEG11/LPUART1_TX/QUADSPI_NCS/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='DFSDM_DATIN1/I2C2_SMBA/LCD_SEG12/LPUART1_DE/LPUART1_RTS/SAI2_FS_A/SPI2_NSS/SWPMI1_IO/TIM15_BKIN/TIM1_BKIN/TIM1_BKIN_COMP2/TSC_G1_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='DFSDM_CKIN1/I2C2_SCL/LCD_SEG13/LPUART1_CTS/SAI2_SCK_A/SPI2_SCK/SWPMI1_TX/TIM15_CH1N/TIM1_CH1N/TSC_G1_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='DFSDM_DATIN2/I2C2_SDA/LCD_SEG14/SAI2_MCLK_A/SPI2_MISO/SWPMI1_RX/TIM15_CH1/TIM1_CH2N/TIM8_CH2N/TSC_G1_IO3/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DFSDM_CKIN2/LCD_SEG15/RTC_REFIN/SAI2_SD_A/SPI2_MOSI/SWPMI1_SUSPEND/TIM15_CH2/TIM1_CH3N/TIM8_CH3N/TSC_G1_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='NRST',do_erc=True),
            Pin(num='D7',name='BOOT0',do_erc=True),
            Pin(num='B9',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VREF+/VREFBUF_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='D8',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='A4',name='PG9/DAC1_EXTI9/SAI2_SCK_A/SPI3_SCK/TIM15_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PG10/LPTIM1_IN1/SAI2_FS_A/SPI3_MISO/TIM15_CH1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LPTIM1_IN2/SAI2_MCLK_A/SPI3_MOSI/TIM15_CH2/USART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PG12/LPTIM1_ETR/SAI2_SD_A/SPI3_NSS/USART1_DE/USART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='PG13/I2C1_SDA/USART1_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PG14/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='E6',name='PE7/DFSDM_DATIN2/SAI1_SD_B/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='F6',name='PE8/DFSDM_CKIN2/SAI1_SCK_B/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/SDMMC1_CMD/TIM3_ETR/TSC_SYNC/UART5_RX/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='E5',name='PD4/DFSDM_CKIN0/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PD5/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='PD6/DFSDM_DATIN1/SAI1_SD_A/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PD7/DFSDM_CKIN1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='F5',name='PD8/LCD_SEG28/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='PD9/DAC1_EXTI9/LCD_SEG29/SAI2_MCLK_A/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='PC0/ADC1_IN1/ADC2_IN1/ADC3_IN1/DFSDM_DATIN4/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPTIM2_IN1/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='PC1/ADC1_IN2/ADC2_IN2/ADC3_IN2/DFSDM_CKIN4/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='PC2/ADC1_IN3/ADC2_IN3/ADC3_IN3/DFSDM_CKOUT/LCD_SEG20/LPTIM1_IN2/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='PC3/ADC1_IN4/ADC2_IN4/ADC3_IN4/LCD_VLCD/LPTIM1_ETR/LPTIM2_ETR/SAI1_SD_A/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='PC4/ADC1_IN13/ADC2_IN13/COMP1_INM/LCD_SEG22/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PC5/ADC1_IN14/ADC2_IN14/COMP1_INP/LCD_SEG23/SYS_WKUP5/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PC6/DFSDM_CKIN3/LCD_SEG24/SAI2_MCLK_A/SDMMC1_D6/TIM3_CH1/TIM8_CH1/TSC_G4_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PC7/DFSDM_DATIN3/LCD_SEG25/SAI2_MCLK_B/SDMMC1_D7/TIM3_CH2/TIM8_CH2/TSC_G4_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC8/LCD_SEG26/SDMMC1_D0/TIM3_CH3/TIM8_CH3/TSC_G4_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='PC9/DAC1_EXTI9/LCD_SEG27/SAI2_EXTCLK/SDMMC1_D1/TIM3_CH4/TIM8_BKIN2/TIM8_BKIN2_COMP1/TIM8_CH4/TSC_G4_IO4/USB_OTG_FS_NOE',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PC10/LCD_COM4/LCD_SEG28/LCD_SEG40/SAI2_SCK_B/SDMMC1_D2/SPI3_SCK/TSC_G3_IO2/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PC11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SAI2_MCLK_B/SDMMC1_D3/SPI3_MISO/TSC_G3_IO3/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PC12/LCD_COM6/LCD_SEG30/LCD_SEG42/SAI2_SD_B/SDMMC1_CK/SPI3_MOSI/TSC_G3_IO4/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PC15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='E4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='B6',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='A1',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='A8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='B1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L476QEIx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32L4 STM32L4x6',description='Core: ARM Cortex-M4 Package: UFBGA132 Flash: 512KB Ram: 128KB Frequency: 80MHz Voltage: 1.71..3.6V IO-pins: 109',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L476QGIx'],pins=[
            Pin(num='L2',name='ADC1_IN5/ADC2_IN5/OPAMP1_VINP/RTC_TAMP2/SAI1_EXTCLK/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN6/ADC2_IN6/LCD_SEG0/OPAMP1_VINM/TIM15_CH1N/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC1_IN7/ADC2_IN7/LCD_SEG1/RCC_LSCO/SAI2_EXTCLK/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC1_IN8/ADC2_IN8/LCD_SEG2/OPAMP1_VOUT/TIM15_CH2/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC1_IN9/ADC2_IN9/DAC1_OUT1/LPTIM2_OUT/SAI1_FS_B/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC1_IN10/ADC2_IN10/DAC1_OUT2/LPTIM2_ETR/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC1_IN11/ADC2_IN11/LCD_SEG3/OPAMP2_VINP/QUADSPI_BK1_IO3/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM1_BKIN_COMP2/TIM3_CH1/TIM8_BKIN/TIM8_BKIN_COMP2/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='ADC1_IN12/ADC2_IN12/LCD_SEG4/OPAMP2_VINM/QUADSPI_BK1_IO2/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='LCD_COM0/LPTIM2_OUT/RCC_MCO/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC1_EXTI9/LCD_COM1/TIM15_BKIN/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='LCD_COM2/TIM17_BKIN/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_BKIN2/TIM1_BKIN2_COMP1/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='CAN1_TX/TIM1_ETR/USART1_DE/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='IR_OUT/SYS_JTMS-SWDIO/USB_OTG_FS_NOE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LCD_SEG17/SAI2_FS_B/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TSC_G3_IO1/UART4_DE/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC1_IN15/ADC2_IN15/COMP1_OUT/LCD_SEG5/OPAMP2_VOUT/QUADSPI_BK1_IO1/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC1_IN16/ADC2_IN16/COMP1_INM/DFSDM_DATIN0/LCD_SEG6/LPTIM2_IN1/QUADSPI_BK1_IO0/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='COMP1_INP/DFSDM_CKIN0/I2C3_SMBA/LPTIM1_OUT/RTC_OUT_ALARM/RTC_OUT_CALIB/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/LCD_SEG7/SAI1_SCK_B/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/USART1_DE/USART1_RTS/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/LCD_SEG8/SAI1_MCLK_B/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM17_BKIN/TIM3_CH1/TSC_G2_IO1/UART5_DE/UART5_RTS/USART1_CTS/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_OUT/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SAI1_SD_B/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM3_CH2/TSC_G2_IO2/UART5_CTS/USART1_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/DFSDM_DATIN5/I2C1_SCL/LPTIM1_ETR/SAI1_FS_B/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_BKIN2_COMP2/TSC_G2_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INM/DFSDM_CKIN5/FMC_NL/I2C1_SDA/LCD_SEG21/LPTIM1_IN2/SYS_PVD_IN/TIM17_CH1N/TIM4_CH2/TIM8_BKIN/TIM8_BKIN_COMP1/TSC_G2_IO4/UART4_CTS/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='CAN1_RX/DFSDM_DATIN6/I2C1_SCL/LCD_SEG16/SAI1_MCLK_A/SDMMC1_D4/TIM16_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='CAN1_TX/DAC1_EXTI9/DFSDM_CKIN6/I2C1_SDA/IR_OUT/LCD_COM3/SAI1_FS_A/SDMMC1_D5/SPI2_NSS/TIM17_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='COMP1_OUT/DFSDM_DATIN7/I2C2_SCL/LCD_SEG10/LPUART1_RX/QUADSPI_CLK/SAI1_SCK_A/SPI2_SCK/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/COMP2_OUT/DFSDM_CKIN7/I2C2_SDA/LCD_SEG11/LPUART1_TX/QUADSPI_NCS/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='DFSDM_DATIN1/I2C2_SMBA/LCD_SEG12/LPUART1_DE/LPUART1_RTS/SAI2_FS_A/SPI2_NSS/SWPMI1_IO/TIM15_BKIN/TIM1_BKIN/TIM1_BKIN_COMP2/TSC_G1_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='DFSDM_CKIN1/I2C2_SCL/LCD_SEG13/LPUART1_CTS/SAI2_SCK_A/SPI2_SCK/SWPMI1_TX/TIM15_CH1N/TIM1_CH1N/TSC_G1_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='DFSDM_DATIN2/I2C2_SDA/LCD_SEG14/SAI2_MCLK_A/SPI2_MISO/SWPMI1_RX/TIM15_CH1/TIM1_CH2N/TIM8_CH2N/TSC_G1_IO3/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DFSDM_CKIN2/LCD_SEG15/RTC_REFIN/SAI2_SD_A/SPI2_MOSI/SWPMI1_SUSPEND/TIM15_CH2/TIM1_CH3N/TIM8_CH3N/TSC_G1_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/DFSDM_DATIN4/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPTIM2_IN1/LPUART1_RX/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/DFSDM_CKIN4/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/DFSDM_CKOUT/LCD_SEG20/LPTIM1_IN2/SPI2_MISO/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_IN4/ADC2_IN4/ADC3_IN4/LCD_VLCD/LPTIM1_ETR/LPTIM2_ETR/SAI1_SD_A/SPI2_MOSI/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC1_IN13/ADC2_IN13/COMP1_INM/LCD_SEG22/USART3_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC1_IN14/ADC2_IN14/COMP1_INP/LCD_SEG23/SYS_WKUP5/USART3_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='DFSDM_CKIN3/LCD_SEG24/SAI2_MCLK_A/SDMMC1_D6/TIM3_CH1/TIM8_CH1/TSC_G4_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='DFSDM_DATIN3/LCD_SEG25/SAI2_MCLK_B/SDMMC1_D7/TIM3_CH2/TIM8_CH2/TSC_G4_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='LCD_SEG26/SDMMC1_D0/TIM3_CH3/TIM8_CH3/TSC_G4_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC1_EXTI9/LCD_SEG27/SAI2_EXTCLK/SDMMC1_D1/TIM3_CH4/TIM8_BKIN2/TIM8_BKIN2_COMP1/TIM8_CH4/TSC_G4_IO4/USB_OTG_FS_NOE/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='LCD_COM4/LCD_SEG28/LCD_SEG40/SAI2_SCK_B/SDMMC1_D2/SPI3_SCK/TSC_G3_IO2/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SAI2_MCLK_B/SDMMC1_D3/SPI3_MISO/TSC_G3_IO3/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='LCD_COM6/LCD_SEG30/LCD_SEG42/SAI2_SD_B/SDMMC1_CK/SPI3_MOSI/TSC_G3_IO4/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='CAN1_RX/DFSDM_DATIN7/FMC_D2/FMC_DA2/SPI2_NSS/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='CAN1_TX/DFSDM_CKIN7/FMC_D3/FMC_DA3/SPI2_SCK/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='LCD_COM7/LCD_SEG31/LCD_SEG43/SDMMC1_CMD/TIM3_ETR/TSC_SYNC/UART5_RX/USART3_DE/USART3_RTS/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='DFSDM_DATIN0/FMC_CLK/SPI2_MISO/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='DFSDM_CKIN0/FMC_NOE/SPI2_MOSI/USART2_DE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='DFSDM_DATIN1/FMC_NWAIT/SAI1_SD_A/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='DFSDM_CKIN1/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='FMC_D13/FMC_DA13/LCD_SEG28/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='DAC1_EXTI9/FMC_D14/FMC_DA14/LCD_SEG29/SAI2_MCLK_A/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='FMC_D15/FMC_DA15/LCD_SEG30/SAI2_SCK_A/TSC_G6_IO1/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/LCD_SEG31/LPTIM2_ETR/SAI2_SD_A/TSC_G6_IO2/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='FMC_A17/FMC_ALE/LCD_SEG32/LPTIM2_IN1/SAI2_FS_A/TIM4_CH1/TSC_G6_IO3/USART3_DE/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='FMC_A18/LCD_SEG33/LPTIM2_OUT/TIM4_CH2/TSC_G6_IO4/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='FMC_D0/FMC_DA0/LCD_SEG34/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/LCD_SEG35/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+/VREFBUF_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='OPAMP1_VINM/OPAMP1_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='OPAMP2_VINM/OPAMP2_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='H9',name='PG0/FMC_A10/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='PG1/FMC_A11/TSC_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='G10',name='PG2/FMC_A12/SAI2_SCK_B/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='PG3/FMC_A13/SAI2_FS_B/SPI1_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='PG4/FMC_A14/SAI2_MCLK_B/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='PG5/FMC_A15/LPUART1_CTS/SAI2_SD_B/SPI1_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PG6/I2C3_SMBA/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PG7/FMC_INT3/I2C3_SCL/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PG8/I2C3_SDA/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PG9/DAC1_EXTI9/FMC_NCE3/FMC_NE2/SAI2_SCK_A/SPI3_SCK/TIM15_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PG10/FMC_NE3/LPTIM1_IN1/SAI2_FS_A/SPI3_MISO/TIM15_CH1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LPTIM1_IN2/SAI2_MCLK_A/SPI3_MOSI/TIM15_CH2/USART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PG12/FMC_NE4/LPTIM1_ETR/SAI2_SD_A/SPI3_NSS/USART1_DE/USART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG13/FMC_A24/I2C1_SDA/USART1_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PG14/FMC_A25/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2C1_SMBA/LPTIM1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PF3/ADC3_IN6/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PF4/ADC3_IN7/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='PF5/ADC3_IN8/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='PF13/DFSDM_DATIN6/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='PF14/DFSDM_CKIN6/FMC_A8/TSC_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/FMC_NBL0/LCD_SEG36/TIM16_CH1/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/FMC_NBL1/LCD_SEG37/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/FMC_A23/LCD_SEG38/SAI1_MCLK_A/SYS_TRACECLK/TIM3_ETR/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/FMC_A19/LCD_SEG39/SAI1_SD_B/SYS_TRACED0/TIM3_CH1/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/DFSDM_DATIN3/FMC_A20/SAI1_FS_A/SYS_TRACED1/TIM3_CH2/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/DFSDM_CKIN3/FMC_A21/SAI1_SCK_A/SYS_TRACED2/TIM3_CH3/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/FMC_A22/RTC_TAMP3/SAI1_SD_A/SYS_TRACED3/SYS_WKUP3/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/DFSDM_DATIN2/FMC_D4/FMC_DA4/SAI1_SD_B/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/DFSDM_CKIN2/FMC_D5/FMC_DA5/SAI1_SCK_B/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/DAC1_EXTI9/DFSDM_CKOUT/FMC_D6/FMC_DA6/SAI1_FS_B/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/DFSDM_DATIN4/FMC_D7/FMC_DA7/QUADSPI_CLK/SAI1_MCLK_B/TIM1_CH2N/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DFSDM_CKIN4/FMC_D8/FMC_DA8/QUADSPI_NCS/TIM1_CH2/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/DFSDM_DATIN5/FMC_D9/FMC_DA9/QUADSPI_BK1_IO0/SPI1_NSS/TIM1_CH3N/TSC_G5_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/DFSDM_CKIN5/FMC_D10/FMC_DA10/QUADSPI_BK1_IO1/SPI1_SCK/TIM1_CH3/TSC_G5_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/FMC_D11/FMC_DA11/QUADSPI_BK1_IO2/SPI1_MISO/TIM1_BKIN2/TIM1_BKIN2_COMP2/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/QUADSPI_BK1_IO3/SPI1_MOSI/TIM1_BKIN/TIM1_BKIN_COMP1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='C11',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L476RCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32L4 STM32L4x6',description='Core: ARM Cortex-M4 Package: LQFP64 Flash: 256KB Ram: 128KB Frequency: 80MHz Voltage: 1.71..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L476RETx', 'STM32L476RGTx'],pins=[
            Pin(num='14',name='ADC1_IN5/ADC2_IN5/OPAMP1_VINP/RTC_TAMP2/SAI1_EXTCLK/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN6/ADC2_IN6/LCD_SEG0/OPAMP1_VINM/TIM15_CH1N/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN7/ADC2_IN7/LCD_SEG1/RCC_LSCO/SAI2_EXTCLK/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN8/ADC2_IN8/LCD_SEG2/OPAMP1_VOUT/TIM15_CH2/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN9/ADC2_IN9/DAC1_OUT1/LPTIM2_OUT/SAI1_FS_B/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN10/ADC2_IN10/DAC1_OUT2/LPTIM2_ETR/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN11/ADC2_IN11/LCD_SEG3/OPAMP2_VINP/QUADSPI_BK1_IO3/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM1_BKIN_COMP2/TIM3_CH1/TIM8_BKIN/TIM8_BKIN_COMP2/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN12/ADC2_IN12/LCD_SEG4/OPAMP2_VINM/QUADSPI_BK1_IO2/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='LCD_COM0/LPTIM2_OUT/RCC_MCO/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC1_EXTI9/LCD_COM1/TIM15_BKIN/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='LCD_COM2/TIM17_BKIN/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_BKIN2/TIM1_BKIN2_COMP1/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN1_TX/TIM1_ETR/USART1_DE/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_JTMS-SWDIO/USB_OTG_FS_NOE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LCD_SEG17/SAI2_FS_B/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TSC_G3_IO1/UART4_DE/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN15/ADC2_IN15/COMP1_OUT/LCD_SEG5/OPAMP2_VOUT/QUADSPI_BK1_IO1/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN16/ADC2_IN16/COMP1_INM/DFSDM_DATIN0/LCD_SEG6/LPTIM2_IN1/QUADSPI_BK1_IO0/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='COMP1_INP/DFSDM_CKIN0/I2C3_SMBA/LPTIM1_OUT/RTC_OUT_ALARM/RTC_OUT_CALIB/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/LCD_SEG7/SAI1_SCK_B/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/USART1_DE/USART1_RTS/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/LCD_SEG8/SAI1_MCLK_B/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM17_BKIN/TIM3_CH1/TSC_G2_IO1/UART5_DE/UART5_RTS/USART1_CTS/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_OUT/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SAI1_SD_B/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM3_CH2/TSC_G2_IO2/UART5_CTS/USART1_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/DFSDM_DATIN5/I2C1_SCL/LPTIM1_ETR/SAI1_FS_B/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_BKIN2_COMP2/TSC_G2_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INM/DFSDM_CKIN5/I2C1_SDA/LCD_SEG21/LPTIM1_IN2/SYS_PVD_IN/TIM17_CH1N/TIM4_CH2/TIM8_BKIN/TIM8_BKIN_COMP1/TSC_G2_IO4/UART4_CTS/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN1_RX/DFSDM_DATIN6/I2C1_SCL/LCD_SEG16/SAI1_MCLK_A/SDMMC1_D4/TIM16_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN1_TX/DAC1_EXTI9/DFSDM_CKIN6/I2C1_SDA/IR_OUT/LCD_COM3/SAI1_FS_A/SDMMC1_D5/SPI2_NSS/TIM17_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='COMP1_OUT/DFSDM_DATIN7/I2C2_SCL/LCD_SEG10/LPUART1_RX/QUADSPI_CLK/SAI1_SCK_A/SPI2_SCK/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/COMP2_OUT/DFSDM_CKIN7/I2C2_SDA/LCD_SEG11/LPUART1_TX/QUADSPI_NCS/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='DFSDM_DATIN1/I2C2_SMBA/LCD_SEG12/LPUART1_DE/LPUART1_RTS/SAI2_FS_A/SPI2_NSS/SWPMI1_IO/TIM15_BKIN/TIM1_BKIN/TIM1_BKIN_COMP2/TSC_G1_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='DFSDM_CKIN1/I2C2_SCL/LCD_SEG13/LPUART1_CTS/SAI2_SCK_A/SPI2_SCK/SWPMI1_TX/TIM15_CH1N/TIM1_CH1N/TSC_G1_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='DFSDM_DATIN2/I2C2_SDA/LCD_SEG14/SAI2_MCLK_A/SPI2_MISO/SWPMI1_RX/TIM15_CH1/TIM1_CH2N/TIM8_CH2N/TSC_G1_IO3/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DFSDM_CKIN2/LCD_SEG15/RTC_REFIN/SAI2_SD_A/SPI2_MOSI/SWPMI1_SUSPEND/TIM15_CH2/TIM1_CH3N/TIM8_CH3N/TSC_G1_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/SDMMC1_CMD/TIM3_ETR/TSC_SYNC/UART5_RX/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN1/ADC2_IN1/ADC3_IN1/DFSDM_DATIN4/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPTIM2_IN1/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN2/ADC2_IN2/ADC3_IN2/DFSDM_CKIN4/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN3/ADC2_IN3/ADC3_IN3/DFSDM_CKOUT/LCD_SEG20/LPTIM1_IN2/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN4/ADC2_IN4/ADC3_IN4/LCD_VLCD/LPTIM1_ETR/LPTIM2_ETR/SAI1_SD_A/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN13/ADC2_IN13/COMP1_INM/LCD_SEG22/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN14/ADC2_IN14/COMP1_INP/LCD_SEG23/SYS_WKUP5/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/DFSDM_CKIN3/LCD_SEG24/SAI2_MCLK_A/SDMMC1_D6/TIM3_CH1/TIM8_CH1/TSC_G4_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/DFSDM_DATIN3/LCD_SEG25/SAI2_MCLK_B/SDMMC1_D7/TIM3_CH2/TIM8_CH2/TSC_G4_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/LCD_SEG26/SDMMC1_D0/TIM3_CH3/TIM8_CH3/TSC_G4_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC1_EXTI9/LCD_SEG27/SAI2_EXTCLK/SDMMC1_D1/TIM3_CH4/TIM8_BKIN2/TIM8_BKIN2_COMP1/TIM8_CH4/TSC_G4_IO4/USB_OTG_FS_NOE',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/LCD_COM4/LCD_SEG28/LCD_SEG40/SAI2_SCK_B/SDMMC1_D2/SPI3_SCK/TSC_G3_IO2/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SAI2_MCLK_B/SDMMC1_D3/SPI3_MISO/TSC_G3_IO3/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/LCD_COM6/LCD_SEG30/LCD_SEG42/SAI2_SD_B/SDMMC1_CK/SPI3_MOSI/TSC_G3_IO4/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L476VCTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32L4 STM32L4x6',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 256KB Ram: 64KB Frequency: 80MHz Voltage: 1.71..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L476VETx', 'STM32L476VGTx'],pins=[
            Pin(num='23',name='ADC1_IN5/ADC2_IN5/OPAMP1_VINP/RTC_TAMP2/SAI1_EXTCLK/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN6/ADC2_IN6/LCD_SEG0/OPAMP1_VINM/TIM15_CH1N/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN7/ADC2_IN7/LCD_SEG1/RCC_LSCO/SAI2_EXTCLK/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/ADC2_IN8/LCD_SEG2/OPAMP1_VOUT/TIM15_CH2/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN9/ADC2_IN9/DAC1_OUT1/LPTIM2_OUT/SAI1_FS_B/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN10/ADC2_IN10/DAC1_OUT2/LPTIM2_ETR/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN11/ADC2_IN11/LCD_SEG3/OPAMP2_VINP/QUADSPI_BK1_IO3/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM1_BKIN_COMP2/TIM3_CH1/TIM8_BKIN/TIM8_BKIN_COMP2/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN12/ADC2_IN12/LCD_SEG4/OPAMP2_VINM/QUADSPI_BK1_IO2/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='LCD_COM0/LPTIM2_OUT/RCC_MCO/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC1_EXTI9/LCD_COM1/TIM15_BKIN/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='LCD_COM2/TIM17_BKIN/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_BKIN2/TIM1_BKIN2_COMP1/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN1_TX/TIM1_ETR/USART1_DE/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='IR_OUT/SYS_JTMS-SWDIO/USB_OTG_FS_NOE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LCD_SEG17/SAI2_FS_B/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TSC_G3_IO1/UART4_DE/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN15/ADC2_IN15/COMP1_OUT/LCD_SEG5/OPAMP2_VOUT/QUADSPI_BK1_IO1/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN16/ADC2_IN16/COMP1_INM/DFSDM_DATIN0/LCD_SEG6/LPTIM2_IN1/QUADSPI_BK1_IO0/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='COMP1_INP/DFSDM_CKIN0/I2C3_SMBA/LPTIM1_OUT/RTC_OUT_ALARM/RTC_OUT_CALIB/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/LCD_SEG7/SAI1_SCK_B/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/USART1_DE/USART1_RTS/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/LCD_SEG8/SAI1_MCLK_B/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM17_BKIN/TIM3_CH1/TSC_G2_IO1/UART5_DE/UART5_RTS/USART1_CTS/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_OUT/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SAI1_SD_B/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM3_CH2/TSC_G2_IO2/UART5_CTS/USART1_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/DFSDM_DATIN5/I2C1_SCL/LPTIM1_ETR/SAI1_FS_B/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_BKIN2_COMP2/TSC_G2_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INM/DFSDM_CKIN5/FMC_NL/I2C1_SDA/LCD_SEG21/LPTIM1_IN2/SYS_PVD_IN/TIM17_CH1N/TIM4_CH2/TIM8_BKIN/TIM8_BKIN_COMP1/TSC_G2_IO4/UART4_CTS/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN1_RX/DFSDM_DATIN6/I2C1_SCL/LCD_SEG16/SAI1_MCLK_A/SDMMC1_D4/TIM16_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN1_TX/DAC1_EXTI9/DFSDM_CKIN6/I2C1_SDA/IR_OUT/LCD_COM3/SAI1_FS_A/SDMMC1_D5/SPI2_NSS/TIM17_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='COMP1_OUT/DFSDM_DATIN7/I2C2_SCL/LCD_SEG10/LPUART1_RX/QUADSPI_CLK/SAI1_SCK_A/SPI2_SCK/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/COMP2_OUT/DFSDM_CKIN7/I2C2_SDA/LCD_SEG11/LPUART1_TX/QUADSPI_NCS/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='DFSDM_DATIN1/I2C2_SMBA/LCD_SEG12/LPUART1_DE/LPUART1_RTS/SAI2_FS_A/SPI2_NSS/SWPMI1_IO/TIM15_BKIN/TIM1_BKIN/TIM1_BKIN_COMP2/TSC_G1_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='DFSDM_CKIN1/I2C2_SCL/LCD_SEG13/LPUART1_CTS/SAI2_SCK_A/SPI2_SCK/SWPMI1_TX/TIM15_CH1N/TIM1_CH1N/TSC_G1_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='DFSDM_DATIN2/I2C2_SDA/LCD_SEG14/SAI2_MCLK_A/SPI2_MISO/SWPMI1_RX/TIM15_CH1/TIM1_CH2N/TIM8_CH2N/TSC_G1_IO3/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DFSDM_CKIN2/LCD_SEG15/RTC_REFIN/SAI2_SD_A/SPI2_MOSI/SWPMI1_SUSPEND/TIM15_CH2/TIM1_CH3N/TIM8_CH3N/TSC_G1_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/DFSDM_DATIN4/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPTIM2_IN1/LPUART1_RX/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/DFSDM_CKIN4/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/DFSDM_CKOUT/LCD_SEG20/LPTIM1_IN2/SPI2_MISO/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN4/ADC2_IN4/ADC3_IN4/LCD_VLCD/LPTIM1_ETR/LPTIM2_ETR/SAI1_SD_A/SPI2_MOSI/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN13/ADC2_IN13/COMP1_INM/LCD_SEG22/USART3_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN14/ADC2_IN14/COMP1_INP/LCD_SEG23/SYS_WKUP5/USART3_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='DFSDM_CKIN3/LCD_SEG24/SAI2_MCLK_A/SDMMC1_D6/TIM3_CH1/TIM8_CH1/TSC_G4_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='DFSDM_DATIN3/LCD_SEG25/SAI2_MCLK_B/SDMMC1_D7/TIM3_CH2/TIM8_CH2/TSC_G4_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='LCD_SEG26/SDMMC1_D0/TIM3_CH3/TIM8_CH3/TSC_G4_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC1_EXTI9/LCD_SEG27/SAI2_EXTCLK/SDMMC1_D1/TIM3_CH4/TIM8_BKIN2/TIM8_BKIN2_COMP1/TIM8_CH4/TSC_G4_IO4/USB_OTG_FS_NOE/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='LCD_COM4/LCD_SEG28/LCD_SEG40/SAI2_SCK_B/SDMMC1_D2/SPI3_SCK/TSC_G3_IO2/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SAI2_MCLK_B/SDMMC1_D3/SPI3_MISO/TSC_G3_IO3/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='LCD_COM6/LCD_SEG30/LCD_SEG42/SAI2_SD_B/SDMMC1_CK/SPI3_MOSI/TSC_G3_IO4/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+/VREFBUF_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='97',name='PE0/FMC_NBL0/LCD_SEG36/TIM16_CH1/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/FMC_NBL1/LCD_SEG37/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FMC_A23/LCD_SEG38/SAI1_MCLK_A/SYS_TRACECLK/TIM3_ETR/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/LCD_SEG39/SAI1_SD_B/SYS_TRACED0/TIM3_CH1/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DFSDM_DATIN3/FMC_A20/SAI1_FS_A/SYS_TRACED1/TIM3_CH2/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DFSDM_CKIN3/FMC_A21/SAI1_SCK_A/SYS_TRACED2/TIM3_CH3/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FMC_A22/RTC_TAMP3/SAI1_SD_A/SYS_TRACED3/SYS_WKUP3/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/DFSDM_DATIN2/FMC_D4/FMC_DA4/SAI1_SD_B/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/DFSDM_CKIN2/FMC_D5/FMC_DA5/SAI1_SCK_B/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC1_EXTI9/DFSDM_CKOUT/FMC_D6/FMC_DA6/SAI1_FS_B/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/DFSDM_DATIN4/FMC_D7/FMC_DA7/QUADSPI_CLK/SAI1_MCLK_B/TIM1_CH2N/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DFSDM_CKIN4/FMC_D8/FMC_DA8/QUADSPI_NCS/TIM1_CH2/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/DFSDM_DATIN5/FMC_D9/FMC_DA9/QUADSPI_BK1_IO0/SPI1_NSS/TIM1_CH3N/TSC_G5_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/DFSDM_CKIN5/FMC_D10/FMC_DA10/QUADSPI_BK1_IO1/SPI1_SCK/TIM1_CH3/TSC_G5_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FMC_D11/FMC_DA11/QUADSPI_BK1_IO2/SPI1_MISO/TIM1_BKIN2/TIM1_BKIN2_COMP2/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/QUADSPI_BK1_IO3/SPI1_MOSI/TIM1_BKIN/TIM1_BKIN_COMP1',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN1_RX/DFSDM_DATIN7/FMC_D2/FMC_DA2/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN1_TX/DFSDM_CKIN7/FMC_D3/FMC_DA3/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/SDMMC1_CMD/TIM3_ETR/TSC_SYNC/UART5_RX/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/DFSDM_DATIN0/FMC_CLK/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/DFSDM_CKIN0/FMC_NOE/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/DFSDM_DATIN1/FMC_NWAIT/SAI1_SD_A/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/DFSDM_CKIN1/FMC_NE1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FMC_D13/FMC_DA13/LCD_SEG28/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC1_EXTI9/FMC_D14/FMC_DA14/LCD_SEG29/SAI2_MCLK_A/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FMC_D15/FMC_DA15/LCD_SEG30/SAI2_SCK_A/TSC_G6_IO1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/LCD_SEG31/LPTIM2_ETR/SAI2_SD_A/TSC_G6_IO2/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FMC_A17/FMC_ALE/LCD_SEG32/LPTIM2_IN1/SAI2_FS_A/TIM4_CH1/TSC_G6_IO3/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FMC_A18/LCD_SEG33/LPTIM2_OUT/TIM4_CH2/TSC_G6_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FMC_D0/FMC_DA0/LCD_SEG34/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/LCD_SEG35/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L476ZETx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32L4 STM32L4x6',description='Core: ARM Cortex-M4 Package: LQFP144 Flash: 512KB Ram: 128KB Frequency: 80MHz Voltage: 1.71..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,aliases=['STM32L476ZGTx'],pins=[
            Pin(num='34',name='ADC1_IN5/ADC2_IN5/OPAMP1_VINP/RTC_TAMP2/SAI1_EXTCLK/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN6/ADC2_IN6/LCD_SEG0/OPAMP1_VINM/TIM15_CH1N/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN7/ADC2_IN7/LCD_SEG1/RCC_LSCO/SAI2_EXTCLK/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN8/ADC2_IN8/LCD_SEG2/OPAMP1_VOUT/TIM15_CH2/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN9/ADC2_IN9/DAC1_OUT1/LPTIM2_OUT/SAI1_FS_B/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN10/ADC2_IN10/DAC1_OUT2/LPTIM2_ETR/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN11/ADC2_IN11/LCD_SEG3/OPAMP2_VINP/QUADSPI_BK1_IO3/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM1_BKIN_COMP2/TIM3_CH1/TIM8_BKIN/TIM8_BKIN_COMP2/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN12/ADC2_IN12/LCD_SEG4/OPAMP2_VINM/QUADSPI_BK1_IO2/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='LCD_COM0/LPTIM2_OUT/RCC_MCO/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC1_EXTI9/LCD_COM1/TIM15_BKIN/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='LCD_COM2/TIM17_BKIN/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_BKIN2/TIM1_BKIN2_COMP1/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN1_TX/TIM1_ETR/USART1_DE/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='IR_OUT/SYS_JTMS-SWDIO/USB_OTG_FS_NOE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LCD_SEG17/SAI2_FS_B/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TSC_G3_IO1/UART4_DE/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN15/ADC2_IN15/COMP1_OUT/LCD_SEG5/OPAMP2_VOUT/QUADSPI_BK1_IO1/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN16/ADC2_IN16/COMP1_INM/DFSDM_DATIN0/LCD_SEG6/LPTIM2_IN1/QUADSPI_BK1_IO0/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='COMP1_INP/DFSDM_CKIN0/I2C3_SMBA/LPTIM1_OUT/RTC_OUT_ALARM/RTC_OUT_CALIB/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='COMP2_INM/LCD_SEG7/SAI1_SCK_B/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/USART1_DE/USART1_RTS/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='COMP2_INP/LCD_SEG8/SAI1_MCLK_B/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM17_BKIN/TIM3_CH1/TSC_G2_IO1/UART5_DE/UART5_RTS/USART1_CTS/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='COMP2_OUT/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SAI1_SD_B/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM3_CH2/TSC_G2_IO2/UART5_CTS/USART1_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='COMP2_INP/DFSDM_DATIN5/I2C1_SCL/LPTIM1_ETR/SAI1_FS_B/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_BKIN2_COMP2/TSC_G2_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='COMP2_INM/DFSDM_CKIN5/FMC_NL/I2C1_SDA/LCD_SEG21/LPTIM1_IN2/SYS_PVD_IN/TIM17_CH1N/TIM4_CH2/TIM8_BKIN/TIM8_BKIN_COMP1/TSC_G2_IO4/UART4_CTS/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CAN1_RX/DFSDM_DATIN6/I2C1_SCL/LCD_SEG16/SAI1_MCLK_A/SDMMC1_D4/TIM16_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='CAN1_TX/DAC1_EXTI9/DFSDM_CKIN6/I2C1_SDA/IR_OUT/LCD_COM3/SAI1_FS_A/SDMMC1_D5/SPI2_NSS/TIM17_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='COMP1_OUT/DFSDM_DATIN7/I2C2_SCL/LCD_SEG10/LPUART1_RX/QUADSPI_CLK/SAI1_SCK_A/SPI2_SCK/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/COMP2_OUT/DFSDM_CKIN7/I2C2_SDA/LCD_SEG11/LPUART1_TX/QUADSPI_NCS/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='DFSDM_DATIN1/I2C2_SMBA/LCD_SEG12/LPUART1_DE/LPUART1_RTS/SAI2_FS_A/SPI2_NSS/SWPMI1_IO/TIM15_BKIN/TIM1_BKIN/TIM1_BKIN_COMP2/TSC_G1_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='DFSDM_CKIN1/I2C2_SCL/LCD_SEG13/LPUART1_CTS/SAI2_SCK_A/SPI2_SCK/SWPMI1_TX/TIM15_CH1N/TIM1_CH1N/TSC_G1_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='DFSDM_DATIN2/I2C2_SDA/LCD_SEG14/SAI2_MCLK_A/SPI2_MISO/SWPMI1_RX/TIM15_CH1/TIM1_CH2N/TIM8_CH2N/TSC_G1_IO3/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DFSDM_CKIN2/LCD_SEG15/RTC_REFIN/SAI2_SD_A/SPI2_MOSI/SWPMI1_SUSPEND/TIM15_CH2/TIM1_CH3N/TIM8_CH3N/TSC_G1_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/DFSDM_DATIN4/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPTIM2_IN1/LPUART1_RX/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/DFSDM_CKIN4/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/DFSDM_CKOUT/LCD_SEG20/LPTIM1_IN2/SPI2_MISO/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/ADC2_IN4/ADC3_IN4/LCD_VLCD/LPTIM1_ETR/LPTIM2_ETR/SAI1_SD_A/SPI2_MOSI/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN13/ADC2_IN13/COMP1_INM/LCD_SEG22/USART3_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN14/ADC2_IN14/COMP1_INP/LCD_SEG23/SYS_WKUP5/USART3_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DFSDM_CKIN3/LCD_SEG24/SAI2_MCLK_A/SDMMC1_D6/TIM3_CH1/TIM8_CH1/TSC_G4_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DFSDM_DATIN3/LCD_SEG25/SAI2_MCLK_B/SDMMC1_D7/TIM3_CH2/TIM8_CH2/TSC_G4_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='LCD_SEG26/SDMMC1_D0/TIM3_CH3/TIM8_CH3/TSC_G4_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC1_EXTI9/LCD_SEG27/SAI2_EXTCLK/SDMMC1_D1/TIM3_CH4/TIM8_BKIN2/TIM8_BKIN2_COMP1/TIM8_CH4/TSC_G4_IO4/USB_OTG_FS_NOE/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='LCD_COM4/LCD_SEG28/LCD_SEG40/SAI2_SCK_B/SDMMC1_D2/SPI3_SCK/TSC_G3_IO2/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SAI2_MCLK_B/SDMMC1_D3/SPI3_MISO/TSC_G3_IO3/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='LCD_COM6/LCD_SEG30/LCD_SEG42/SAI2_SD_B/SDMMC1_CK/SPI3_MOSI/TSC_G3_IO4/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='CAN1_RX/DFSDM_DATIN7/FMC_D2/FMC_DA2/SPI2_NSS/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CAN1_TX/DFSDM_CKIN7/FMC_D3/FMC_DA3/SPI2_SCK/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='LCD_COM7/LCD_SEG31/LCD_SEG43/SDMMC1_CMD/TIM3_ETR/TSC_SYNC/UART5_RX/USART3_DE/USART3_RTS/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='DFSDM_DATIN0/FMC_CLK/SPI2_MISO/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='DFSDM_CKIN0/FMC_NOE/SPI2_MOSI/USART2_DE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='DFSDM_DATIN1/FMC_NWAIT/SAI1_SD_A/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='DFSDM_CKIN1/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FMC_D13/FMC_DA13/LCD_SEG28/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC1_EXTI9/FMC_D14/FMC_DA14/LCD_SEG29/SAI2_MCLK_A/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FMC_D15/FMC_DA15/LCD_SEG30/SAI2_SCK_A/TSC_G6_IO1/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/LCD_SEG31/LPTIM2_ETR/SAI2_SD_A/TSC_G6_IO2/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FMC_A17/FMC_ALE/LCD_SEG32/LPTIM2_IN1/SAI2_FS_A/TIM4_CH1/TSC_G6_IO3/USART3_DE/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FMC_A18/LCD_SEG33/LPTIM2_OUT/TIM4_CH2/TSC_G6_IO4/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FMC_D0/FMC_DA0/LCD_SEG34/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/LCD_SEG35/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+/VREFBUF_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='56',name='PG0/FMC_A10/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FMC_A11/TSC_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FMC_A12/SAI2_SCK_B/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FMC_A13/SAI2_FS_B/SPI1_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FMC_A14/SAI2_MCLK_B/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FMC_A15/LPUART1_CTS/SAI2_SD_B/SPI1_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/I2C3_SMBA/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/FMC_INT3/I2C3_SCL/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8/I2C3_SDA/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC1_EXTI9/FMC_NCE3/FMC_NE2/SAI2_SCK_A/SPI3_SCK/TIM15_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/FMC_NE3/LPTIM1_IN1/SAI2_FS_A/SPI3_MISO/TIM15_CH1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LPTIM1_IN2/SAI2_MCLK_A/SPI3_MOSI/TIM15_CH2/USART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FMC_NE4/LPTIM1_ETR/SAI2_SD_A/SPI3_NSS/USART1_DE/USART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/FMC_A24/I2C1_SDA/USART1_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/FMC_A25/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2C1_SMBA/LPTIM1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/ADC3_IN6/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/ADC3_IN7/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/ADC3_IN8/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC3_IN9/SAI1_SD_B/TIM5_CH1/TIM5_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC3_IN10/SAI1_MCLK_B/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC3_IN11/SAI1_SCK_B/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC3_IN12/DAC1_EXTI9/SAI1_FS_B/TIM15_CH1/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC3_IN13/TIM15_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/DFSDM_DATIN6/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/DFSDM_CKIN6/FMC_A8/TSC_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/FMC_NBL0/LCD_SEG36/TIM16_CH1/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/FMC_NBL1/LCD_SEG37/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FMC_A23/LCD_SEG38/SAI1_MCLK_A/SYS_TRACECLK/TIM3_ETR/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/LCD_SEG39/SAI1_SD_B/SYS_TRACED0/TIM3_CH1/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DFSDM_DATIN3/FMC_A20/SAI1_FS_A/SYS_TRACED1/TIM3_CH2/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DFSDM_CKIN3/FMC_A21/SAI1_SCK_A/SYS_TRACED2/TIM3_CH3/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FMC_A22/RTC_TAMP3/SAI1_SD_A/SYS_TRACED3/SYS_WKUP3/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/DFSDM_DATIN2/FMC_D4/FMC_DA4/SAI1_SD_B/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/DFSDM_CKIN2/FMC_D5/FMC_DA5/SAI1_SCK_B/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC1_EXTI9/DFSDM_CKOUT/FMC_D6/FMC_DA6/SAI1_FS_B/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/DFSDM_DATIN4/FMC_D7/FMC_DA7/QUADSPI_CLK/SAI1_MCLK_B/TIM1_CH2N/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DFSDM_CKIN4/FMC_D8/FMC_DA8/QUADSPI_NCS/TIM1_CH2/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/DFSDM_DATIN5/FMC_D9/FMC_DA9/QUADSPI_BK1_IO0/SPI1_NSS/TIM1_CH3N/TSC_G5_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/DFSDM_CKIN5/FMC_D10/FMC_DA10/QUADSPI_BK1_IO1/SPI1_SCK/TIM1_CH3/TSC_G5_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FMC_D11/FMC_DA11/QUADSPI_BK1_IO2/SPI1_MISO/TIM1_BKIN2/TIM1_BKIN2_COMP2/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/QUADSPI_BK1_IO3/SPI1_MOSI/TIM1_BKIN/TIM1_BKIN_COMP1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='106',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='143',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L486JGYx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32L4 STM32L4x6',description='Core: ARM Cortex-M4 Package: WLCSP72 Flash: 1024KB Ram: 128KB Frequency: 80MHz Voltage: 1.71..3.6V IO-pins: 57',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='H8',name='ADC1_IN5/ADC2_IN5/OPAMP1_VINP/RTC_TAMP2/SAI1_EXTCLK/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='ADC1_IN6/ADC2_IN6/LCD_SEG0/OPAMP1_VINM/TIM15_CH1N/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='G6',name='ADC1_IN7/ADC2_IN7/LCD_SEG1/RCC_LSCO/SAI2_EXTCLK/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='H7',name='ADC1_IN8/ADC2_IN8/LCD_SEG2/OPAMP1_VOUT/TIM15_CH2/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G5',name='ADC1_IN9/ADC2_IN9/DAC1_OUT1/LPTIM2_OUT/SAI1_FS_B/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='H6',name='ADC1_IN10/ADC2_IN10/DAC1_OUT2/LPTIM2_ETR/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='H5',name='ADC1_IN11/ADC2_IN11/LCD_SEG3/OPAMP2_VINP/QUADSPI_BK1_IO3/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM1_BKIN_COMP2/TIM3_CH1/TIM8_BKIN/TIM8_BKIN_COMP2/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='ADC1_IN12/ADC2_IN12/LCD_SEG4/OPAMP2_VINM/QUADSPI_BK1_IO2/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E2',name='LCD_COM0/LPTIM2_OUT/RCC_MCO/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E3',name='DAC1_EXTI9/LCD_COM1/TIM15_BKIN/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='LCD_COM2/TIM17_BKIN/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_BKIN2/TIM1_BKIN2_COMP1/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='CAN1_TX/TIM1_ETR/USART1_DE/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='IR_OUT/SYS_JTMS-SWDIO/USB_OTG_FS_NOE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LCD_SEG17/SAI2_FS_B/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TSC_G3_IO1/UART4_DE/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='ADC1_IN15/ADC2_IN15/COMP1_OUT/LCD_SEG5/OPAMP2_VOUT/QUADSPI_BK1_IO1/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC1_IN16/ADC2_IN16/COMP1_INM/DFSDM_DATIN0/LCD_SEG6/LPTIM2_IN1/QUADSPI_BK1_IO0/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='COMP1_INP/DFSDM_CKIN0/I2C3_SMBA/LPTIM1_OUT/RTC_OUT_ALARM/RTC_OUT_CALIB/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='COMP2_INM/LCD_SEG7/SAI1_SCK_B/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/USART1_DE/USART1_RTS/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='COMP2_INP/LCD_SEG8/SAI1_MCLK_B/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM17_BKIN/TIM3_CH1/TSC_G2_IO1/UART5_DE/UART5_RTS/USART1_CTS/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='COMP2_OUT/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SAI1_SD_B/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM3_CH2/TSC_G2_IO2/UART5_CTS/USART1_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='COMP2_INP/DFSDM_DATIN5/I2C1_SCL/LPTIM1_ETR/SAI1_FS_B/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_BKIN2_COMP2/TSC_G2_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INM/DFSDM_CKIN5/I2C1_SDA/LCD_SEG21/LPTIM1_IN2/SYS_PVD_IN/TIM17_CH1N/TIM4_CH2/TIM8_BKIN/TIM8_BKIN_COMP1/TSC_G2_IO4/UART4_CTS/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E7',name='CAN1_RX/DFSDM_DATIN6/I2C1_SCL/LCD_SEG16/SAI1_MCLK_A/SDMMC1_D4/TIM16_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='E8',name='CAN1_TX/DAC1_EXTI9/DFSDM_CKIN6/I2C1_SDA/IR_OUT/LCD_COM3/SAI1_FS_A/SDMMC1_D5/SPI2_NSS/TIM17_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='H3',name='COMP1_OUT/DFSDM_DATIN7/I2C2_SCL/LCD_SEG10/LPUART1_RX/QUADSPI_CLK/SAI1_SCK_A/SPI2_SCK/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/COMP2_OUT/DFSDM_CKIN7/I2C2_SDA/LCD_SEG11/LPUART1_TX/QUADSPI_NCS/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='DFSDM_DATIN1/I2C2_SMBA/LCD_SEG12/LPUART1_DE/LPUART1_RTS/SAI2_FS_A/SPI2_NSS/SWPMI1_IO/TIM15_BKIN/TIM1_BKIN/TIM1_BKIN_COMP2/TSC_G1_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='DFSDM_CKIN1/I2C2_SCL/LCD_SEG13/LPUART1_CTS/SAI2_SCK_A/SPI2_SCK/SWPMI1_TX/TIM15_CH1N/TIM1_CH1N/TSC_G1_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='G2',name='DFSDM_DATIN2/I2C2_SDA/LCD_SEG14/SAI2_MCLK_A/SPI2_MISO/SWPMI1_RX/TIM15_CH1/TIM1_CH2N/TIM8_CH2N/TSC_G1_IO3/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='G1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DFSDM_CKIN2/LCD_SEG15/RTC_REFIN/SAI2_SD_A/SPI2_MOSI/SWPMI1_SUSPEND/TIM15_CH2/TIM1_CH3N/TIM8_CH3N/TSC_G1_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='NRST',do_erc=True),
            Pin(num='D7',name='BOOT0',do_erc=True),
            Pin(num='B9',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='G8',name='VREF+/VREFBUF_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='D8',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='A4',name='PG9/DAC1_EXTI9/SAI2_SCK_A/SPI3_SCK/TIM15_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='PG10/LPTIM1_IN1/SAI2_FS_A/SPI3_MISO/TIM15_CH1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LPTIM1_IN2/SAI2_MCLK_A/SPI3_MOSI/TIM15_CH2/USART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='PG12/LPTIM1_ETR/SAI2_SD_A/SPI3_NSS/USART1_DE/USART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='PG13/I2C1_SDA/USART1_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='PG14/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/SDMMC1_CMD/TIM3_ETR/TSC_SYNC/UART5_RX/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='PC0/ADC1_IN1/ADC2_IN1/ADC3_IN1/DFSDM_DATIN4/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPTIM2_IN1/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F8',name='PC1/ADC1_IN2/ADC2_IN2/ADC3_IN2/DFSDM_CKIN4/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F7',name='PC2/ADC1_IN3/ADC2_IN3/ADC3_IN3/DFSDM_CKOUT/LCD_SEG20/LPTIM1_IN2/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='G7',name='PC3/ADC1_IN4/ADC2_IN4/ADC3_IN4/LCD_VLCD/LPTIM1_ETR/LPTIM2_ETR/SAI1_SD_A/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='PC4/ADC1_IN13/ADC2_IN13/COMP1_INM/LCD_SEG22/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PC5/ADC1_IN14/ADC2_IN14/COMP1_INP/LCD_SEG23/SYS_WKUP5/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PC6/DFSDM_CKIN3/LCD_SEG24/SAI2_MCLK_A/SDMMC1_D6/TIM3_CH1/TIM8_CH1/TSC_G4_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PC7/DFSDM_DATIN3/LCD_SEG25/SAI2_MCLK_B/SDMMC1_D7/TIM3_CH2/TIM8_CH2/TSC_G4_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='F2',name='PC8/LCD_SEG26/SDMMC1_D0/TIM3_CH3/TIM8_CH3/TSC_G4_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='PC9/DAC1_EXTI9/LCD_SEG27/SAI2_EXTCLK/SDMMC1_D1/TIM3_CH4/TIM8_BKIN2/TIM8_BKIN2_COMP1/TIM8_CH4/TSC_G4_IO4/USB_OTG_FS_NOE',func=Pin.BIDIR,do_erc=True),
            Pin(num='D3',name='PC10/LCD_COM4/LCD_SEG28/LCD_SEG40/SAI2_SCK_B/SDMMC1_D2/SPI3_SCK/TSC_G3_IO2/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PC11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SAI2_MCLK_B/SDMMC1_D3/SPI3_MISO/TSC_G3_IO3/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='PC12/LCD_COM6/LCD_SEG30/LCD_SEG42/SAI2_SD_B/SDMMC1_CK/SPI3_MOSI/TSC_G3_IO4/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='PC15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='J8',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H9',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='B6',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='A1',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='A8',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='B1',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J9',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='G9',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L486QGIx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32L4 STM32L4x6',description='Core: ARM Cortex-M4 Package: UFBGA132 Flash: 1024KB Ram: 128KB Frequency: 80MHz Voltage: 1.71..3.6V IO-pins: 109',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='L2',name='ADC1_IN5/ADC2_IN5/OPAMP1_VINP/RTC_TAMP2/SAI1_EXTCLK/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M2',name='ADC1_IN6/ADC2_IN6/LCD_SEG0/OPAMP1_VINM/TIM15_CH1N/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='K3',name='ADC1_IN7/ADC2_IN7/LCD_SEG1/RCC_LSCO/SAI2_EXTCLK/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L3',name='ADC1_IN8/ADC2_IN8/LCD_SEG2/OPAMP1_VOUT/TIM15_CH2/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='J4',name='ADC1_IN9/ADC2_IN9/DAC1_OUT1/LPTIM2_OUT/SAI1_FS_B/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='K4',name='ADC1_IN10/ADC2_IN10/DAC1_OUT2/LPTIM2_ETR/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='L4',name='ADC1_IN11/ADC2_IN11/LCD_SEG3/OPAMP2_VINP/QUADSPI_BK1_IO3/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM1_BKIN_COMP2/TIM3_CH1/TIM8_BKIN/TIM8_BKIN_COMP2/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='J5',name='ADC1_IN12/ADC2_IN12/LCD_SEG4/OPAMP2_VINM/QUADSPI_BK1_IO2/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='D11',name='LCD_COM0/LPTIM2_OUT/RCC_MCO/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D10',name='DAC1_EXTI9/LCD_COM1/TIM15_BKIN/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='C12',name='LCD_COM2/TIM17_BKIN/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='B12',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_BKIN2/TIM1_BKIN2_COMP1/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='A12',name='CAN1_TX/TIM1_ETR/USART1_DE/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='A11',name='IR_OUT/SYS_JTMS-SWDIO/USB_OTG_FS_NOE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='A10',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='A9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LCD_SEG17/SAI2_FS_B/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TSC_G3_IO1/UART4_DE/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='M5',name='ADC1_IN15/ADC2_IN15/COMP1_OUT/LCD_SEG5/OPAMP2_VOUT/QUADSPI_BK1_IO1/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='M6',name='ADC1_IN16/ADC2_IN16/COMP1_INM/DFSDM_DATIN0/LCD_SEG6/LPTIM2_IN1/QUADSPI_BK1_IO0/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L6',name='COMP1_INP/DFSDM_CKIN0/I2C3_SMBA/LPTIM1_OUT/RTC_OUT_ALARM/RTC_OUT_CALIB/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='A8',name='COMP2_INM/LCD_SEG7/SAI1_SCK_B/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/USART1_DE/USART1_RTS/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='A7',name='COMP2_INP/LCD_SEG8/SAI1_MCLK_B/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM17_BKIN/TIM3_CH1/TSC_G2_IO1/UART5_DE/UART5_RTS/USART1_CTS/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='C5',name='COMP2_OUT/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SAI1_SD_B/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM3_CH2/TSC_G2_IO2/UART5_CTS/USART1_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B5',name='COMP2_INP/DFSDM_DATIN5/I2C1_SCL/LPTIM1_ETR/SAI1_FS_B/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_BKIN2_COMP2/TSC_G2_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='B4',name='COMP2_INM/DFSDM_CKIN5/FMC_NL/I2C1_SDA/LCD_SEG21/LPTIM1_IN2/SYS_PVD_IN/TIM17_CH1N/TIM4_CH2/TIM8_BKIN/TIM8_BKIN_COMP1/TSC_G2_IO4/UART4_CTS/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='A3',name='CAN1_RX/DFSDM_DATIN6/I2C1_SCL/LCD_SEG16/SAI1_MCLK_A/SDMMC1_D4/TIM16_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='B3',name='CAN1_TX/DAC1_EXTI9/DFSDM_CKIN6/I2C1_SDA/IR_OUT/LCD_COM3/SAI1_FS_A/SDMMC1_D5/SPI2_NSS/TIM17_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='L10',name='COMP1_OUT/DFSDM_DATIN7/I2C2_SCL/LCD_SEG10/LPUART1_RX/QUADSPI_CLK/SAI1_SCK_A/SPI2_SCK/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='L11',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/COMP2_OUT/DFSDM_CKIN7/I2C2_SDA/LCD_SEG11/LPUART1_TX/QUADSPI_NCS/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='L12',name='DFSDM_DATIN1/I2C2_SMBA/LCD_SEG12/LPUART1_DE/LPUART1_RTS/SAI2_FS_A/SPI2_NSS/SWPMI1_IO/TIM15_BKIN/TIM1_BKIN/TIM1_BKIN_COMP2/TSC_G1_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='K12',name='DFSDM_CKIN1/I2C2_SCL/LCD_SEG13/LPUART1_CTS/SAI2_SCK_A/SPI2_SCK/SWPMI1_TX/TIM15_CH1N/TIM1_CH1N/TSC_G1_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='K11',name='DFSDM_DATIN2/I2C2_SDA/LCD_SEG14/SAI2_MCLK_A/SPI2_MISO/SWPMI1_RX/TIM15_CH1/TIM1_CH2N/TIM8_CH2N/TSC_G1_IO3/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='K10',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DFSDM_CKIN2/LCD_SEG15/RTC_REFIN/SAI2_SD_A/SPI2_MOSI/SWPMI1_SUSPEND/TIM15_CH2/TIM1_CH3N/TIM8_CH3N/TSC_G1_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H1',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/DFSDM_DATIN4/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPTIM2_IN1/LPUART1_RX/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='J2',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/DFSDM_CKIN4/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J3',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/DFSDM_CKOUT/LCD_SEG20/LPTIM1_IN2/SPI2_MISO/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='K2',name='ADC1_IN4/ADC2_IN4/ADC3_IN4/LCD_VLCD/LPTIM1_ETR/LPTIM2_ETR/SAI1_SD_A/SPI2_MOSI/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='K5',name='ADC1_IN13/ADC2_IN13/COMP1_INM/LCD_SEG22/USART3_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='L5',name='ADC1_IN14/ADC2_IN14/COMP1_INP/LCD_SEG23/SYS_WKUP5/USART3_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='E12',name='DFSDM_CKIN3/LCD_SEG24/SAI2_MCLK_A/SDMMC1_D6/TIM3_CH1/TIM8_CH1/TSC_G4_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='E11',name='DFSDM_DATIN3/LCD_SEG25/SAI2_MCLK_B/SDMMC1_D7/TIM3_CH2/TIM8_CH2/TSC_G4_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='E10',name='LCD_SEG26/SDMMC1_D0/TIM3_CH3/TIM8_CH3/TSC_G4_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='D12',name='DAC1_EXTI9/LCD_SEG27/SAI2_EXTCLK/SDMMC1_D1/TIM3_CH4/TIM8_BKIN2/TIM8_BKIN2_COMP1/TIM8_CH4/TSC_G4_IO4/USB_OTG_FS_NOE/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='B11',name='LCD_COM4/LCD_SEG28/LCD_SEG40/SAI2_SCK_B/SDMMC1_D2/SPI3_SCK/TSC_G3_IO2/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='C10',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SAI2_MCLK_B/SDMMC1_D3/SPI3_MISO/TSC_G3_IO3/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='B10',name='LCD_COM6/LCD_SEG30/LCD_SEG42/SAI2_SD_B/SDMMC1_CK/SPI3_MOSI/TSC_G3_IO4/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='C1',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='D1',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='E1',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='C9',name='CAN1_RX/DFSDM_DATIN7/FMC_D2/FMC_DA2/SPI2_NSS/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='B9',name='CAN1_TX/DFSDM_CKIN7/FMC_D3/FMC_DA3/SPI2_SCK/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C8',name='LCD_COM7/LCD_SEG31/LCD_SEG43/SDMMC1_CMD/TIM3_ETR/TSC_SYNC/UART5_RX/USART3_DE/USART3_RTS/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B8',name='DFSDM_DATIN0/FMC_CLK/SPI2_MISO/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='B7',name='DFSDM_CKIN0/FMC_NOE/SPI2_MOSI/USART2_DE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='A6',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='B6',name='DFSDM_DATIN1/FMC_NWAIT/SAI1_SD_A/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='A5',name='DFSDM_CKIN1/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='K9',name='FMC_D13/FMC_DA13/LCD_SEG28/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='K8',name='DAC1_EXTI9/FMC_D14/FMC_DA14/LCD_SEG29/SAI2_MCLK_A/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='J12',name='FMC_D15/FMC_DA15/LCD_SEG30/SAI2_SCK_A/TSC_G6_IO1/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='J11',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/LCD_SEG31/LPTIM2_ETR/SAI2_SD_A/TSC_G6_IO2/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J10',name='FMC_A17/FMC_ALE/LCD_SEG32/LPTIM2_IN1/SAI2_FS_A/TIM4_CH1/TSC_G6_IO3/USART3_DE/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='H12',name='FMC_A18/LCD_SEG33/LPTIM2_OUT/TIM4_CH2/TSC_G6_IO4/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='H11',name='FMC_D0/FMC_DA0/LCD_SEG34/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='H10',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/LCD_SEG35/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='H2',name='NRST',do_erc=True),
            Pin(num='A4',name='BOOT0',do_erc=True),
            Pin(num='E2',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='L1',name='VREF+/VREFBUF_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='M3',name='OPAMP1_VINM/OPAMP1_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='M4',name='OPAMP2_VINM/OPAMP2_VINM',func=Pin.BIDIR,do_erc=True),
            Pin(num='F1',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='G1',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='H9',name='PG0/FMC_A10/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='G9',name='PG1/FMC_A11/TSC_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='G10',name='PG2/FMC_A12/SAI2_SCK_B/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='F9',name='PG3/FMC_A13/SAI2_FS_B/SPI1_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='F10',name='PG4/FMC_A14/SAI2_MCLK_B/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='E9',name='PG5/FMC_A15/LPUART1_CTS/SAI2_SD_B/SPI1_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='G4',name='PG6/I2C3_SMBA/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='H4',name='PG7/FMC_INT3/I2C3_SCL/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='J6',name='PG8/I2C3_SDA/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D9',name='PG9/DAC1_EXTI9/FMC_NCE3/FMC_NE2/SAI2_SCK_A/SPI3_SCK/TIM15_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='D8',name='PG10/FMC_NE3/LPTIM1_IN1/SAI2_FS_A/SPI3_MISO/TIM15_CH1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='G3',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LPTIM1_IN2/SAI2_MCLK_A/SPI3_MOSI/TIM15_CH2/USART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='D7',name='PG12/FMC_NE4/LPTIM1_ETR/SAI2_SD_A/SPI3_NSS/USART1_DE/USART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='C7',name='PG13/FMC_A24/I2C1_SDA/USART1_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='C6',name='PG14/FMC_A25/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='K1',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2C1_SMBA/LPTIM1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='D6',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='D5',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='D4',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='E4',name='PF3/ADC3_IN6/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='F3',name='PF4/ADC3_IN7/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='F4',name='PF5/ADC3_IN8/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='K6',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='J7',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='K7',name='PF13/DFSDM_DATIN6/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='J8',name='PF14/DFSDM_CKIN6/FMC_A8/TSC_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='J9',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='C3',name='PE0/FMC_NBL0/LCD_SEG36/TIM16_CH1/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='A2',name='PE1/FMC_NBL1/LCD_SEG37/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='B2',name='PE2/FMC_A23/LCD_SEG38/SAI1_MCLK_A/SYS_TRACECLK/TIM3_ETR/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='A1',name='PE3/FMC_A19/LCD_SEG39/SAI1_SD_B/SYS_TRACED0/TIM3_CH1/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='B1',name='PE4/DFSDM_DATIN3/FMC_A20/SAI1_FS_A/SYS_TRACED1/TIM3_CH2/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='C2',name='PE5/DFSDM_CKIN3/FMC_A21/SAI1_SCK_A/SYS_TRACED2/TIM3_CH3/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='D2',name='PE6/FMC_A22/RTC_TAMP3/SAI1_SD_A/SYS_TRACED3/SYS_WKUP3/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M7',name='PE7/DFSDM_DATIN2/FMC_D4/FMC_DA4/SAI1_SD_B/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='L7',name='PE8/DFSDM_CKIN2/FMC_D5/FMC_DA5/SAI1_SCK_B/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='M8',name='PE9/DAC1_EXTI9/DFSDM_CKOUT/FMC_D6/FMC_DA6/SAI1_FS_B/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='L8',name='PE10/DFSDM_DATIN4/FMC_D7/FMC_DA7/QUADSPI_CLK/SAI1_MCLK_B/TIM1_CH2N/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='M9',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DFSDM_CKIN4/FMC_D8/FMC_DA8/QUADSPI_NCS/TIM1_CH2/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='L9',name='PE12/DFSDM_DATIN5/FMC_D9/FMC_DA9/QUADSPI_BK1_IO0/SPI1_NSS/TIM1_CH3N/TSC_G5_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='M10',name='PE13/DFSDM_CKIN5/FMC_D10/FMC_DA10/QUADSPI_BK1_IO1/SPI1_SCK/TIM1_CH3/TSC_G5_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M11',name='PE14/FMC_D11/FMC_DA11/QUADSPI_BK1_IO2/SPI1_MISO/TIM1_BKIN2/TIM1_BKIN2_COMP2/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='M12',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/QUADSPI_BK1_IO3/SPI1_MOSI/TIM1_BKIN/TIM1_BKIN_COMP1',func=Pin.BIDIR,do_erc=True),
            Pin(num='C4',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G2',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G6',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='G12',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='H3',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='M1',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='G7',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='C11',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='D3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='E3',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F2',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F6',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F7',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F11',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='F12',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='J1',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L486RGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32L4 STM32L4x6',description='Core: ARM Cortex-M4 Package: LQFP64 Flash: 1024KB Ram: 128KB Frequency: 80MHz Voltage: 1.71..3.6V IO-pins: 51',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='14',name='ADC1_IN5/ADC2_IN5/OPAMP1_VINP/RTC_TAMP2/SAI1_EXTCLK/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN6/ADC2_IN6/LCD_SEG0/OPAMP1_VINM/TIM15_CH1N/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN7/ADC2_IN7/LCD_SEG1/RCC_LSCO/SAI2_EXTCLK/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN8/ADC2_IN8/LCD_SEG2/OPAMP1_VOUT/TIM15_CH2/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='ADC1_IN9/ADC2_IN9/DAC1_OUT1/LPTIM2_OUT/SAI1_FS_B/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='ADC1_IN10/ADC2_IN10/DAC1_OUT2/LPTIM2_ETR/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='ADC1_IN11/ADC2_IN11/LCD_SEG3/OPAMP2_VINP/QUADSPI_BK1_IO3/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM1_BKIN_COMP2/TIM3_CH1/TIM8_BKIN/TIM8_BKIN_COMP2/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='ADC1_IN12/ADC2_IN12/LCD_SEG4/OPAMP2_VINM/QUADSPI_BK1_IO2/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='LCD_COM0/LPTIM2_OUT/RCC_MCO/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='DAC1_EXTI9/LCD_COM1/TIM15_BKIN/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='LCD_COM2/TIM17_BKIN/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_BKIN2/TIM1_BKIN2_COMP1/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='CAN1_TX/TIM1_ETR/USART1_DE/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='IR_OUT/SYS_JTMS-SWDIO/USB_OTG_FS_NOE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LCD_SEG17/SAI2_FS_B/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TSC_G3_IO1/UART4_DE/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN15/ADC2_IN15/COMP1_OUT/LCD_SEG5/OPAMP2_VOUT/QUADSPI_BK1_IO1/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN16/ADC2_IN16/COMP1_INM/DFSDM_DATIN0/LCD_SEG6/LPTIM2_IN1/QUADSPI_BK1_IO0/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='COMP1_INP/DFSDM_CKIN0/I2C3_SMBA/LPTIM1_OUT/RTC_OUT_ALARM/RTC_OUT_CALIB/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='COMP2_INM/LCD_SEG7/SAI1_SCK_B/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/USART1_DE/USART1_RTS/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='COMP2_INP/LCD_SEG8/SAI1_MCLK_B/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM17_BKIN/TIM3_CH1/TSC_G2_IO1/UART5_DE/UART5_RTS/USART1_CTS/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='COMP2_OUT/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SAI1_SD_B/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM3_CH2/TSC_G2_IO2/UART5_CTS/USART1_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='COMP2_INP/DFSDM_DATIN5/I2C1_SCL/LPTIM1_ETR/SAI1_FS_B/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_BKIN2_COMP2/TSC_G2_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='COMP2_INM/DFSDM_CKIN5/I2C1_SDA/LCD_SEG21/LPTIM1_IN2/SYS_PVD_IN/TIM17_CH1N/TIM4_CH2/TIM8_BKIN/TIM8_BKIN_COMP1/TSC_G2_IO4/UART4_CTS/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='CAN1_RX/DFSDM_DATIN6/I2C1_SCL/LCD_SEG16/SAI1_MCLK_A/SDMMC1_D4/TIM16_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='CAN1_TX/DAC1_EXTI9/DFSDM_CKIN6/I2C1_SDA/IR_OUT/LCD_COM3/SAI1_FS_A/SDMMC1_D5/SPI2_NSS/TIM17_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='COMP1_OUT/DFSDM_DATIN7/I2C2_SCL/LCD_SEG10/LPUART1_RX/QUADSPI_CLK/SAI1_SCK_A/SPI2_SCK/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/COMP2_OUT/DFSDM_CKIN7/I2C2_SDA/LCD_SEG11/LPUART1_TX/QUADSPI_NCS/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='DFSDM_DATIN1/I2C2_SMBA/LCD_SEG12/LPUART1_DE/LPUART1_RTS/SAI2_FS_A/SPI2_NSS/SWPMI1_IO/TIM15_BKIN/TIM1_BKIN/TIM1_BKIN_COMP2/TSC_G1_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='DFSDM_CKIN1/I2C2_SCL/LCD_SEG13/LPUART1_CTS/SAI2_SCK_A/SPI2_SCK/SWPMI1_TX/TIM15_CH1N/TIM1_CH1N/TSC_G1_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='DFSDM_DATIN2/I2C2_SDA/LCD_SEG14/SAI2_MCLK_A/SPI2_MISO/SWPMI1_RX/TIM15_CH1/TIM1_CH2N/TIM8_CH2N/TSC_G1_IO3/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DFSDM_CKIN2/LCD_SEG15/RTC_REFIN/SAI2_SD_A/SPI2_MOSI/SWPMI1_SUSPEND/TIM15_CH2/TIM1_CH3N/TIM8_CH3N/TSC_G1_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='NRST',do_erc=True),
            Pin(num='60',name='BOOT0',do_erc=True),
            Pin(num='1',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='5',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='6',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='54',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/SDMMC1_CMD/TIM3_ETR/TSC_SYNC/UART5_RX/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='PC0/ADC1_IN1/ADC2_IN1/ADC3_IN1/DFSDM_DATIN4/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPTIM2_IN1/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='PC1/ADC1_IN2/ADC2_IN2/ADC3_IN2/DFSDM_CKIN4/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PC2/ADC1_IN3/ADC2_IN3/ADC3_IN3/DFSDM_CKOUT/LCD_SEG20/LPTIM1_IN2/SPI2_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PC3/ADC1_IN4/ADC2_IN4/ADC3_IN4/LCD_VLCD/LPTIM1_ETR/LPTIM2_ETR/SAI1_SD_A/SPI2_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='PC4/ADC1_IN13/ADC2_IN13/COMP1_INM/LCD_SEG22/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='PC5/ADC1_IN14/ADC2_IN14/COMP1_INP/LCD_SEG23/SYS_WKUP5/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='PC6/DFSDM_CKIN3/LCD_SEG24/SAI2_MCLK_A/SDMMC1_D6/TIM3_CH1/TIM8_CH1/TSC_G4_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PC7/DFSDM_DATIN3/LCD_SEG25/SAI2_MCLK_B/SDMMC1_D7/TIM3_CH2/TIM8_CH2/TSC_G4_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PC8/LCD_SEG26/SDMMC1_D0/TIM3_CH3/TIM8_CH3/TSC_G4_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PC9/DAC1_EXTI9/LCD_SEG27/SAI2_EXTCLK/SDMMC1_D1/TIM3_CH4/TIM8_BKIN2/TIM8_BKIN2_COMP1/TIM8_CH4/TSC_G4_IO4/USB_OTG_FS_NOE',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='PC10/LCD_COM4/LCD_SEG28/LCD_SEG40/SAI2_SCK_B/SDMMC1_D2/SPI3_SCK/TSC_G3_IO2/UART4_TX/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='PC11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SAI2_MCLK_B/SDMMC1_D3/SPI3_MISO/TSC_G3_IO3/UART4_RX/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PC12/LCD_COM6/LCD_SEG30/LCD_SEG42/SAI2_SD_B/SDMMC1_CK/SPI3_MOSI/TSC_G3_IO4/UART5_TX/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PC13/RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PC14/RCC_OSC32_IN',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PC15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='64',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='13',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='48',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='18',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='47',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='63',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='12',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L486VGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32L4 STM32L4x6',description='Core: ARM Cortex-M4 Package: LQFP100 Flash: 1024KB Ram: 128KB Frequency: 80MHz Voltage: 1.71..3.6V IO-pins: 82',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='23',name='ADC1_IN5/ADC2_IN5/OPAMP1_VINP/RTC_TAMP2/SAI1_EXTCLK/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='24',name='ADC1_IN6/ADC2_IN6/LCD_SEG0/OPAMP1_VINM/TIM15_CH1N/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='ADC1_IN7/ADC2_IN7/LCD_SEG1/RCC_LSCO/SAI2_EXTCLK/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN8/ADC2_IN8/LCD_SEG2/OPAMP1_VOUT/TIM15_CH2/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN9/ADC2_IN9/DAC1_OUT1/LPTIM2_OUT/SAI1_FS_B/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='30',name='ADC1_IN10/ADC2_IN10/DAC1_OUT2/LPTIM2_ETR/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='31',name='ADC1_IN11/ADC2_IN11/LCD_SEG3/OPAMP2_VINP/QUADSPI_BK1_IO3/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM1_BKIN_COMP2/TIM3_CH1/TIM8_BKIN/TIM8_BKIN_COMP2/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='32',name='ADC1_IN12/ADC2_IN12/LCD_SEG4/OPAMP2_VINM/QUADSPI_BK1_IO2/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='LCD_COM0/LPTIM2_OUT/RCC_MCO/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='DAC1_EXTI9/LCD_COM1/TIM15_BKIN/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='LCD_COM2/TIM17_BKIN/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_BKIN2/TIM1_BKIN2_COMP1/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='71',name='CAN1_TX/TIM1_ETR/USART1_DE/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='72',name='IR_OUT/SYS_JTMS-SWDIO/USB_OTG_FS_NOE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LCD_SEG17/SAI2_FS_B/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TSC_G3_IO1/UART4_DE/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN15/ADC2_IN15/COMP1_OUT/LCD_SEG5/OPAMP2_VOUT/QUADSPI_BK1_IO1/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN16/ADC2_IN16/COMP1_INM/DFSDM_DATIN0/LCD_SEG6/LPTIM2_IN1/QUADSPI_BK1_IO0/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='COMP1_INP/DFSDM_CKIN0/I2C3_SMBA/LPTIM1_OUT/RTC_OUT_ALARM/RTC_OUT_CALIB/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='COMP2_INM/LCD_SEG7/SAI1_SCK_B/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/USART1_DE/USART1_RTS/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='COMP2_INP/LCD_SEG8/SAI1_MCLK_B/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM17_BKIN/TIM3_CH1/TSC_G2_IO1/UART5_DE/UART5_RTS/USART1_CTS/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='COMP2_OUT/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SAI1_SD_B/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM3_CH2/TSC_G2_IO2/UART5_CTS/USART1_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='COMP2_INP/DFSDM_DATIN5/I2C1_SCL/LPTIM1_ETR/SAI1_FS_B/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_BKIN2_COMP2/TSC_G2_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='COMP2_INM/DFSDM_CKIN5/FMC_NL/I2C1_SDA/LCD_SEG21/LPTIM1_IN2/SYS_PVD_IN/TIM17_CH1N/TIM4_CH2/TIM8_BKIN/TIM8_BKIN_COMP1/TSC_G2_IO4/UART4_CTS/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='95',name='CAN1_RX/DFSDM_DATIN6/I2C1_SCL/LCD_SEG16/SAI1_MCLK_A/SDMMC1_D4/TIM16_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='CAN1_TX/DAC1_EXTI9/DFSDM_CKIN6/I2C1_SDA/IR_OUT/LCD_COM3/SAI1_FS_A/SDMMC1_D5/SPI2_NSS/TIM17_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='COMP1_OUT/DFSDM_DATIN7/I2C2_SCL/LCD_SEG10/LPUART1_RX/QUADSPI_CLK/SAI1_SCK_A/SPI2_SCK/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/COMP2_OUT/DFSDM_CKIN7/I2C2_SDA/LCD_SEG11/LPUART1_TX/QUADSPI_NCS/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='51',name='DFSDM_DATIN1/I2C2_SMBA/LCD_SEG12/LPUART1_DE/LPUART1_RTS/SAI2_FS_A/SPI2_NSS/SWPMI1_IO/TIM15_BKIN/TIM1_BKIN/TIM1_BKIN_COMP2/TSC_G1_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='52',name='DFSDM_CKIN1/I2C2_SCL/LCD_SEG13/LPUART1_CTS/SAI2_SCK_A/SPI2_SCK/SWPMI1_TX/TIM15_CH1N/TIM1_CH1N/TSC_G1_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='DFSDM_DATIN2/I2C2_SDA/LCD_SEG14/SAI2_MCLK_A/SPI2_MISO/SWPMI1_RX/TIM15_CH1/TIM1_CH2N/TIM8_CH2N/TSC_G1_IO3/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DFSDM_CKIN2/LCD_SEG15/RTC_REFIN/SAI2_SD_A/SPI2_MOSI/SWPMI1_SUSPEND/TIM15_CH2/TIM1_CH3N/TIM8_CH3N/TSC_G1_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/DFSDM_DATIN4/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPTIM2_IN1/LPUART1_RX/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='16',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/DFSDM_CKIN4/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/DFSDM_CKOUT/LCD_SEG20/LPTIM1_IN2/SPI2_MISO/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='ADC1_IN4/ADC2_IN4/ADC3_IN4/LCD_VLCD/LPTIM1_ETR/LPTIM2_ETR/SAI1_SD_A/SPI2_MOSI/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='33',name='ADC1_IN13/ADC2_IN13/COMP1_INM/LCD_SEG22/USART3_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='34',name='ADC1_IN14/ADC2_IN14/COMP1_INP/LCD_SEG23/SYS_WKUP5/USART3_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='DFSDM_CKIN3/LCD_SEG24/SAI2_MCLK_A/SDMMC1_D6/TIM3_CH1/TIM8_CH1/TSC_G4_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='DFSDM_DATIN3/LCD_SEG25/SAI2_MCLK_B/SDMMC1_D7/TIM3_CH2/TIM8_CH2/TSC_G4_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='LCD_SEG26/SDMMC1_D0/TIM3_CH3/TIM8_CH3/TSC_G4_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='DAC1_EXTI9/LCD_SEG27/SAI2_EXTCLK/SDMMC1_D1/TIM3_CH4/TIM8_BKIN2/TIM8_BKIN2_COMP1/TIM8_CH4/TSC_G4_IO4/USB_OTG_FS_NOE/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='LCD_COM4/LCD_SEG28/LCD_SEG40/SAI2_SCK_B/SDMMC1_D2/SPI3_SCK/TSC_G3_IO2/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SAI2_MCLK_B/SDMMC1_D3/SPI3_MISO/TSC_G3_IO3/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='LCD_COM6/LCD_SEG30/LCD_SEG42/SAI2_SD_B/SDMMC1_CK/SPI3_MOSI/TSC_G3_IO4/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='NRST',do_erc=True),
            Pin(num='94',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='20',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='21',name='VREF+/VREFBUF_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='13',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='97',name='PE0/FMC_NBL0/LCD_SEG36/TIM16_CH1/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='PE1/FMC_NBL1/LCD_SEG37/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FMC_A23/LCD_SEG38/SAI1_MCLK_A/SYS_TRACECLK/TIM3_ETR/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/LCD_SEG39/SAI1_SD_B/SYS_TRACED0/TIM3_CH1/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DFSDM_DATIN3/FMC_A20/SAI1_FS_A/SYS_TRACED1/TIM3_CH2/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DFSDM_CKIN3/FMC_A21/SAI1_SCK_A/SYS_TRACED2/TIM3_CH3/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FMC_A22/RTC_TAMP3/SAI1_SD_A/SYS_TRACED3/SYS_WKUP3/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='38',name='PE7/DFSDM_DATIN2/FMC_D4/FMC_DA4/SAI1_SD_B/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='39',name='PE8/DFSDM_CKIN2/FMC_D5/FMC_DA5/SAI1_SCK_B/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='PE9/DAC1_EXTI9/DFSDM_CKOUT/FMC_D6/FMC_DA6/SAI1_FS_B/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='PE10/DFSDM_DATIN4/FMC_D7/FMC_DA7/QUADSPI_CLK/SAI1_MCLK_B/TIM1_CH2N/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DFSDM_CKIN4/FMC_D8/FMC_DA8/QUADSPI_NCS/TIM1_CH2/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='PE12/DFSDM_DATIN5/FMC_D9/FMC_DA9/QUADSPI_BK1_IO0/SPI1_NSS/TIM1_CH3N/TSC_G5_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='PE13/DFSDM_CKIN5/FMC_D10/FMC_DA10/QUADSPI_BK1_IO1/SPI1_SCK/TIM1_CH3/TSC_G5_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='PE14/FMC_D11/FMC_DA11/QUADSPI_BK1_IO2/SPI1_MISO/TIM1_BKIN2/TIM1_BKIN2_COMP2/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/QUADSPI_BK1_IO3/SPI1_MOSI/TIM1_BKIN/TIM1_BKIN_COMP1',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='PD0/CAN1_RX/DFSDM_DATIN7/FMC_D2/FMC_DA2/SPI2_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='PD1/CAN1_TX/DFSDM_CKIN7/FMC_D3/FMC_DA3/SPI2_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='83',name='PD2/LCD_COM7/LCD_SEG31/LCD_SEG43/SDMMC1_CMD/TIM3_ETR/TSC_SYNC/UART5_RX/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='84',name='PD3/DFSDM_DATIN0/FMC_CLK/SPI2_MISO/USART2_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='PD4/DFSDM_CKIN0/FMC_NOE/SPI2_MOSI/USART2_DE/USART2_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='PD5/FMC_NWE/USART2_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PD6/DFSDM_DATIN1/FMC_NWAIT/SAI1_SD_A/USART2_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PD7/DFSDM_CKIN1/FMC_NE1/USART2_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PD8/FMC_D13/FMC_DA13/LCD_SEG28/USART3_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='56',name='PD9/DAC1_EXTI9/FMC_D14/FMC_DA14/LCD_SEG29/SAI2_MCLK_A/USART3_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PD10/FMC_D15/FMC_DA15/LCD_SEG30/SAI2_SCK_A/TSC_G6_IO1/USART3_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PD11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/LCD_SEG31/LPTIM2_ETR/SAI2_SD_A/TSC_G6_IO2/USART3_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PD12/FMC_A17/FMC_ALE/LCD_SEG32/LPTIM2_IN1/SAI2_FS_A/TIM4_CH1/TSC_G6_IO3/USART3_DE/USART3_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PD13/FMC_A18/LCD_SEG33/LPTIM2_OUT/TIM4_CH2/TSC_G6_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='61',name='PD14/FMC_D0/FMC_DA0/LCD_SEG34/TIM4_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='62',name='PD15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/LCD_SEG35/TIM4_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='28',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='50',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='75',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='100',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='22',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='73',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='10',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='27',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='49',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='74',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='99',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='19',name='VSSA',func=Pin.PWRIN,do_erc=True)]),
        Part(name='STM32L486ZGTx',dest=TEMPLATE,tool=SKIDL,keywords='ARM Cortex-M4 STM32L4 STM32L4x6',description='Core: ARM Cortex-M4 Package: LQFP144 Flash: 1024KB Ram: 128KB Frequency: 80MHz Voltage: 1.71..3.6V IO-pins: 114',ref_prefix='U',num_units=1,do_erc=True,pins=[
            Pin(num='34',name='ADC1_IN5/ADC2_IN5/OPAMP1_VINP/RTC_TAMP2/SAI1_EXTCLK/SYS_WKUP1/TIM2_CH1/TIM2_ETR/TIM5_CH1/TIM8_ETR/UART4_TX/USART2_CTS/PA0',func=Pin.BIDIR,do_erc=True),
            Pin(num='35',name='ADC1_IN6/ADC2_IN6/LCD_SEG0/OPAMP1_VINM/TIM15_CH1N/TIM2_CH2/TIM5_CH2/UART4_RX/USART2_DE/USART2_RTS/PA1',func=Pin.BIDIR,do_erc=True),
            Pin(num='36',name='ADC1_IN7/ADC2_IN7/LCD_SEG1/RCC_LSCO/SAI2_EXTCLK/SYS_WKUP4/TIM15_CH1/TIM2_CH3/TIM5_CH3/USART2_TX/PA2',func=Pin.BIDIR,do_erc=True),
            Pin(num='37',name='ADC1_IN8/ADC2_IN8/LCD_SEG2/OPAMP1_VOUT/TIM15_CH2/TIM2_CH4/TIM5_CH4/USART2_RX/PA3',func=Pin.BIDIR,do_erc=True),
            Pin(num='40',name='ADC1_IN9/ADC2_IN9/DAC1_OUT1/LPTIM2_OUT/SAI1_FS_B/SPI1_NSS/SPI3_NSS/USART2_CK/PA4',func=Pin.BIDIR,do_erc=True),
            Pin(num='41',name='ADC1_IN10/ADC2_IN10/DAC1_OUT2/LPTIM2_ETR/SPI1_SCK/TIM2_CH1/TIM2_ETR/TIM8_CH1N/PA5',func=Pin.BIDIR,do_erc=True),
            Pin(num='42',name='ADC1_IN11/ADC2_IN11/LCD_SEG3/OPAMP2_VINP/QUADSPI_BK1_IO3/SPI1_MISO/TIM16_CH1/TIM1_BKIN/TIM1_BKIN_COMP2/TIM3_CH1/TIM8_BKIN/TIM8_BKIN_COMP2/USART3_CTS/PA6',func=Pin.BIDIR,do_erc=True),
            Pin(num='43',name='ADC1_IN12/ADC2_IN12/LCD_SEG4/OPAMP2_VINM/QUADSPI_BK1_IO2/SPI1_MOSI/TIM17_CH1/TIM1_CH1N/TIM3_CH2/TIM8_CH1N/PA7',func=Pin.BIDIR,do_erc=True),
            Pin(num='100',name='LCD_COM0/LPTIM2_OUT/RCC_MCO/TIM1_CH1/USART1_CK/USB_OTG_FS_SOF/PA8',func=Pin.BIDIR,do_erc=True),
            Pin(num='101',name='DAC1_EXTI9/LCD_COM1/TIM15_BKIN/TIM1_CH2/USART1_TX/USB_OTG_FS_VBUS/PA9',func=Pin.BIDIR,do_erc=True),
            Pin(num='102',name='LCD_COM2/TIM17_BKIN/TIM1_CH3/USART1_RX/USB_OTG_FS_ID/PA10',func=Pin.BIDIR,do_erc=True),
            Pin(num='103',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/CAN1_RX/TIM1_BKIN2/TIM1_BKIN2_COMP1/TIM1_CH4/USART1_CTS/USB_OTG_FS_DM/PA11',func=Pin.BIDIR,do_erc=True),
            Pin(num='104',name='CAN1_TX/TIM1_ETR/USART1_DE/USART1_RTS/USB_OTG_FS_DP/PA12',func=Pin.BIDIR,do_erc=True),
            Pin(num='105',name='IR_OUT/SYS_JTMS-SWDIO/USB_OTG_FS_NOE/PA13',func=Pin.BIDIR,do_erc=True),
            Pin(num='109',name='SYS_JTCK-SWCLK/PA14',func=Pin.BIDIR,do_erc=True),
            Pin(num='110',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/LCD_SEG17/SAI2_FS_B/SPI1_NSS/SPI3_NSS/SYS_JTDI/TIM2_CH1/TIM2_ETR/TSC_G3_IO1/UART4_DE/UART4_RTS/PA15',func=Pin.BIDIR,do_erc=True),
            Pin(num='46',name='ADC1_IN15/ADC2_IN15/COMP1_OUT/LCD_SEG5/OPAMP2_VOUT/QUADSPI_BK1_IO1/TIM1_CH2N/TIM3_CH3/TIM8_CH2N/USART3_CK/PB0',func=Pin.BIDIR,do_erc=True),
            Pin(num='47',name='ADC1_IN16/ADC2_IN16/COMP1_INM/DFSDM_DATIN0/LCD_SEG6/LPTIM2_IN1/QUADSPI_BK1_IO0/TIM1_CH3N/TIM3_CH4/TIM8_CH3N/USART3_DE/USART3_RTS/PB1',func=Pin.BIDIR,do_erc=True),
            Pin(num='48',name='COMP1_INP/DFSDM_CKIN0/I2C3_SMBA/LPTIM1_OUT/RTC_OUT_ALARM/RTC_OUT_CALIB/PB2',func=Pin.BIDIR,do_erc=True),
            Pin(num='133',name='COMP2_INM/LCD_SEG7/SAI1_SCK_B/SPI1_SCK/SPI3_SCK/SYS_JTDO-SWO/TIM2_CH2/USART1_DE/USART1_RTS/PB3',func=Pin.BIDIR,do_erc=True),
            Pin(num='134',name='COMP2_INP/LCD_SEG8/SAI1_MCLK_B/SPI1_MISO/SPI3_MISO/SYS_JTRST/TIM17_BKIN/TIM3_CH1/TSC_G2_IO1/UART5_DE/UART5_RTS/USART1_CTS/PB4',func=Pin.BIDIR,do_erc=True),
            Pin(num='135',name='COMP2_OUT/I2C1_SMBA/LCD_SEG9/LPTIM1_IN1/SAI1_SD_B/SPI1_MOSI/SPI3_MOSI/TIM16_BKIN/TIM3_CH2/TSC_G2_IO2/UART5_CTS/USART1_CK/PB5',func=Pin.BIDIR,do_erc=True),
            Pin(num='136',name='COMP2_INP/DFSDM_DATIN5/I2C1_SCL/LPTIM1_ETR/SAI1_FS_B/TIM16_CH1N/TIM4_CH1/TIM8_BKIN2/TIM8_BKIN2_COMP2/TSC_G2_IO3/USART1_TX/PB6',func=Pin.BIDIR,do_erc=True),
            Pin(num='137',name='COMP2_INM/DFSDM_CKIN5/FMC_NL/I2C1_SDA/LCD_SEG21/LPTIM1_IN2/SYS_PVD_IN/TIM17_CH1N/TIM4_CH2/TIM8_BKIN/TIM8_BKIN_COMP1/TSC_G2_IO4/UART4_CTS/USART1_RX/PB7',func=Pin.BIDIR,do_erc=True),
            Pin(num='139',name='CAN1_RX/DFSDM_DATIN6/I2C1_SCL/LCD_SEG16/SAI1_MCLK_A/SDMMC1_D4/TIM16_CH1/TIM4_CH3/PB8',func=Pin.BIDIR,do_erc=True),
            Pin(num='140',name='CAN1_TX/DAC1_EXTI9/DFSDM_CKIN6/I2C1_SDA/IR_OUT/LCD_COM3/SAI1_FS_A/SDMMC1_D5/SPI2_NSS/TIM17_CH1/TIM4_CH4/PB9',func=Pin.BIDIR,do_erc=True),
            Pin(num='69',name='COMP1_OUT/DFSDM_DATIN7/I2C2_SCL/LCD_SEG10/LPUART1_RX/QUADSPI_CLK/SAI1_SCK_A/SPI2_SCK/TIM2_CH3/USART3_TX/PB10',func=Pin.BIDIR,do_erc=True),
            Pin(num='70',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/COMP2_OUT/DFSDM_CKIN7/I2C2_SDA/LCD_SEG11/LPUART1_TX/QUADSPI_NCS/TIM2_CH4/USART3_RX/PB11',func=Pin.BIDIR,do_erc=True),
            Pin(num='73',name='DFSDM_DATIN1/I2C2_SMBA/LCD_SEG12/LPUART1_DE/LPUART1_RTS/SAI2_FS_A/SPI2_NSS/SWPMI1_IO/TIM15_BKIN/TIM1_BKIN/TIM1_BKIN_COMP2/TSC_G1_IO1/USART3_CK/PB12',func=Pin.BIDIR,do_erc=True),
            Pin(num='74',name='DFSDM_CKIN1/I2C2_SCL/LCD_SEG13/LPUART1_CTS/SAI2_SCK_A/SPI2_SCK/SWPMI1_TX/TIM15_CH1N/TIM1_CH1N/TSC_G1_IO2/USART3_CTS/PB13',func=Pin.BIDIR,do_erc=True),
            Pin(num='75',name='DFSDM_DATIN2/I2C2_SDA/LCD_SEG14/SAI2_MCLK_A/SPI2_MISO/SWPMI1_RX/TIM15_CH1/TIM1_CH2N/TIM8_CH2N/TSC_G1_IO3/USART3_DE/USART3_RTS/PB14',func=Pin.BIDIR,do_erc=True),
            Pin(num='76',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/DFSDM_CKIN2/LCD_SEG15/RTC_REFIN/SAI2_SD_A/SPI2_MOSI/SWPMI1_SUSPEND/TIM15_CH2/TIM1_CH3N/TIM8_CH3N/TSC_G1_IO4/PB15',func=Pin.BIDIR,do_erc=True),
            Pin(num='26',name='ADC1_IN1/ADC2_IN1/ADC3_IN1/DFSDM_DATIN4/I2C3_SCL/LCD_SEG18/LPTIM1_IN1/LPTIM2_IN1/LPUART1_RX/PC0',func=Pin.BIDIR,do_erc=True),
            Pin(num='27',name='ADC1_IN2/ADC2_IN2/ADC3_IN2/DFSDM_CKIN4/I2C3_SDA/LCD_SEG19/LPTIM1_OUT/LPUART1_TX/PC1',func=Pin.BIDIR,do_erc=True),
            Pin(num='28',name='ADC1_IN3/ADC2_IN3/ADC3_IN3/DFSDM_CKOUT/LCD_SEG20/LPTIM1_IN2/SPI2_MISO/PC2',func=Pin.BIDIR,do_erc=True),
            Pin(num='29',name='ADC1_IN4/ADC2_IN4/ADC3_IN4/LCD_VLCD/LPTIM1_ETR/LPTIM2_ETR/SAI1_SD_A/SPI2_MOSI/PC3',func=Pin.BIDIR,do_erc=True),
            Pin(num='44',name='ADC1_IN13/ADC2_IN13/COMP1_INM/LCD_SEG22/USART3_TX/PC4',func=Pin.BIDIR,do_erc=True),
            Pin(num='45',name='ADC1_IN14/ADC2_IN14/COMP1_INP/LCD_SEG23/SYS_WKUP5/USART3_RX/PC5',func=Pin.BIDIR,do_erc=True),
            Pin(num='96',name='DFSDM_CKIN3/LCD_SEG24/SAI2_MCLK_A/SDMMC1_D6/TIM3_CH1/TIM8_CH1/TSC_G4_IO1/PC6',func=Pin.BIDIR,do_erc=True),
            Pin(num='97',name='DFSDM_DATIN3/LCD_SEG25/SAI2_MCLK_B/SDMMC1_D7/TIM3_CH2/TIM8_CH2/TSC_G4_IO2/PC7',func=Pin.BIDIR,do_erc=True),
            Pin(num='98',name='LCD_SEG26/SDMMC1_D0/TIM3_CH3/TIM8_CH3/TSC_G4_IO3/PC8',func=Pin.BIDIR,do_erc=True),
            Pin(num='99',name='DAC1_EXTI9/LCD_SEG27/SAI2_EXTCLK/SDMMC1_D1/TIM3_CH4/TIM8_BKIN2/TIM8_BKIN2_COMP1/TIM8_CH4/TSC_G4_IO4/USB_OTG_FS_NOE/PC9',func=Pin.BIDIR,do_erc=True),
            Pin(num='111',name='LCD_COM4/LCD_SEG28/LCD_SEG40/SAI2_SCK_B/SDMMC1_D2/SPI3_SCK/TSC_G3_IO2/UART4_TX/USART3_TX/PC10',func=Pin.BIDIR,do_erc=True),
            Pin(num='112',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LCD_COM5/LCD_SEG29/LCD_SEG41/SAI2_MCLK_B/SDMMC1_D3/SPI3_MISO/TSC_G3_IO3/UART4_RX/USART3_RX/PC11',func=Pin.BIDIR,do_erc=True),
            Pin(num='113',name='LCD_COM6/LCD_SEG30/LCD_SEG42/SAI2_SD_B/SDMMC1_CK/SPI3_MOSI/TSC_G3_IO4/UART5_TX/USART3_CK/PC12',func=Pin.BIDIR,do_erc=True),
            Pin(num='7',name='RTC_OUT_ALARM/RTC_OUT_CALIB/RTC_TAMP1/RTC_TS/SYS_WKUP2/PC13',func=Pin.BIDIR,do_erc=True),
            Pin(num='8',name='RCC_OSC32_IN/PC14',func=Pin.BIDIR,do_erc=True),
            Pin(num='9',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/RCC_OSC32_OUT/PC15',func=Pin.BIDIR,do_erc=True),
            Pin(num='114',name='CAN1_RX/DFSDM_DATIN7/FMC_D2/FMC_DA2/SPI2_NSS/PD0',func=Pin.BIDIR,do_erc=True),
            Pin(num='115',name='CAN1_TX/DFSDM_CKIN7/FMC_D3/FMC_DA3/SPI2_SCK/PD1',func=Pin.BIDIR,do_erc=True),
            Pin(num='116',name='LCD_COM7/LCD_SEG31/LCD_SEG43/SDMMC1_CMD/TIM3_ETR/TSC_SYNC/UART5_RX/USART3_DE/USART3_RTS/PD2',func=Pin.BIDIR,do_erc=True),
            Pin(num='117',name='DFSDM_DATIN0/FMC_CLK/SPI2_MISO/USART2_CTS/PD3',func=Pin.BIDIR,do_erc=True),
            Pin(num='118',name='DFSDM_CKIN0/FMC_NOE/SPI2_MOSI/USART2_DE/USART2_RTS/PD4',func=Pin.BIDIR,do_erc=True),
            Pin(num='119',name='FMC_NWE/USART2_TX/PD5',func=Pin.BIDIR,do_erc=True),
            Pin(num='122',name='DFSDM_DATIN1/FMC_NWAIT/SAI1_SD_A/USART2_RX/PD6',func=Pin.BIDIR,do_erc=True),
            Pin(num='123',name='DFSDM_CKIN1/FMC_NE1/USART2_CK/PD7',func=Pin.BIDIR,do_erc=True),
            Pin(num='77',name='FMC_D13/FMC_DA13/LCD_SEG28/USART3_TX/PD8',func=Pin.BIDIR,do_erc=True),
            Pin(num='78',name='DAC1_EXTI9/FMC_D14/FMC_DA14/LCD_SEG29/SAI2_MCLK_A/USART3_RX/PD9',func=Pin.BIDIR,do_erc=True),
            Pin(num='79',name='FMC_D15/FMC_DA15/LCD_SEG30/SAI2_SCK_A/TSC_G6_IO1/USART3_CK/PD10',func=Pin.BIDIR,do_erc=True),
            Pin(num='80',name='ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/FMC_A16/FMC_CLE/LCD_SEG31/LPTIM2_ETR/SAI2_SD_A/TSC_G6_IO2/USART3_CTS/PD11',func=Pin.BIDIR,do_erc=True),
            Pin(num='81',name='FMC_A17/FMC_ALE/LCD_SEG32/LPTIM2_IN1/SAI2_FS_A/TIM4_CH1/TSC_G6_IO3/USART3_DE/USART3_RTS/PD12',func=Pin.BIDIR,do_erc=True),
            Pin(num='82',name='FMC_A18/LCD_SEG33/LPTIM2_OUT/TIM4_CH2/TSC_G6_IO4/PD13',func=Pin.BIDIR,do_erc=True),
            Pin(num='85',name='FMC_D0/FMC_DA0/LCD_SEG34/TIM4_CH3/PD14',func=Pin.BIDIR,do_erc=True),
            Pin(num='86',name='ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D1/FMC_DA1/LCD_SEG35/TIM4_CH4/PD15',func=Pin.BIDIR,do_erc=True),
            Pin(num='25',name='NRST',do_erc=True),
            Pin(num='138',name='BOOT0',do_erc=True),
            Pin(num='6',name='VBAT',func=Pin.PWRIN,do_erc=True),
            Pin(num='31',name='VREF-',func=Pin.PWRIN,do_erc=True),
            Pin(num='32',name='VREF+/VREFBUF_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='23',name='PH0/RCC_OSC_IN',do_erc=True),
            Pin(num='24',name='PH1/RCC_OSC_OUT',do_erc=True),
            Pin(num='56',name='PG0/FMC_A10/TSC_G8_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='57',name='PG1/FMC_A11/TSC_G8_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='87',name='PG2/FMC_A12/SAI2_SCK_B/SPI1_SCK',func=Pin.BIDIR,do_erc=True),
            Pin(num='88',name='PG3/FMC_A13/SAI2_FS_B/SPI1_MISO',func=Pin.BIDIR,do_erc=True),
            Pin(num='89',name='PG4/FMC_A14/SAI2_MCLK_B/SPI1_MOSI',func=Pin.BIDIR,do_erc=True),
            Pin(num='90',name='PG5/FMC_A15/LPUART1_CTS/SAI2_SD_B/SPI1_NSS',func=Pin.BIDIR,do_erc=True),
            Pin(num='91',name='PG6/I2C3_SMBA/LPUART1_DE/LPUART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='92',name='PG7/FMC_INT3/I2C3_SCL/LPUART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='93',name='PG8/I2C3_SDA/LPUART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='124',name='PG9/DAC1_EXTI9/FMC_NCE3/FMC_NE2/SAI2_SCK_A/SPI3_SCK/TIM15_CH1N/USART1_TX',func=Pin.BIDIR,do_erc=True),
            Pin(num='125',name='PG10/FMC_NE3/LPTIM1_IN1/SAI2_FS_A/SPI3_MISO/TIM15_CH1/USART1_RX',func=Pin.BIDIR,do_erc=True),
            Pin(num='126',name='PG11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/LPTIM1_IN2/SAI2_MCLK_A/SPI3_MOSI/TIM15_CH2/USART1_CTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='127',name='PG12/FMC_NE4/LPTIM1_ETR/SAI2_SD_A/SPI3_NSS/USART1_DE/USART1_RTS',func=Pin.BIDIR,do_erc=True),
            Pin(num='128',name='PG13/FMC_A24/I2C1_SDA/USART1_CK',func=Pin.BIDIR,do_erc=True),
            Pin(num='129',name='PG14/FMC_A25/I2C1_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='132',name='PG15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/I2C1_SMBA/LPTIM1_OUT',func=Pin.BIDIR,do_erc=True),
            Pin(num='10',name='PF0/FMC_A0/I2C2_SDA',func=Pin.BIDIR,do_erc=True),
            Pin(num='11',name='PF1/FMC_A1/I2C2_SCL',func=Pin.BIDIR,do_erc=True),
            Pin(num='12',name='PF2/FMC_A2/I2C2_SMBA',func=Pin.BIDIR,do_erc=True),
            Pin(num='13',name='PF3/ADC3_IN6/FMC_A3',func=Pin.BIDIR,do_erc=True),
            Pin(num='14',name='PF4/ADC3_IN7/FMC_A4',func=Pin.BIDIR,do_erc=True),
            Pin(num='15',name='PF5/ADC3_IN8/FMC_A5',func=Pin.BIDIR,do_erc=True),
            Pin(num='18',name='PF6/ADC3_IN9/SAI1_SD_B/TIM5_CH1/TIM5_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='19',name='PF7/ADC3_IN10/SAI1_MCLK_B/TIM5_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='20',name='PF8/ADC3_IN11/SAI1_SCK_B/TIM5_CH3',func=Pin.BIDIR,do_erc=True),
            Pin(num='21',name='PF9/ADC3_IN12/DAC1_EXTI9/SAI1_FS_B/TIM15_CH1/TIM5_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='22',name='PF10/ADC3_IN13/TIM15_CH2',func=Pin.BIDIR,do_erc=True),
            Pin(num='49',name='PF11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11',func=Pin.BIDIR,do_erc=True),
            Pin(num='50',name='PF12/FMC_A6',func=Pin.BIDIR,do_erc=True),
            Pin(num='53',name='PF13/DFSDM_DATIN6/FMC_A7',func=Pin.BIDIR,do_erc=True),
            Pin(num='54',name='PF14/DFSDM_CKIN6/FMC_A8/TSC_G8_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='55',name='PF15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_A9/TSC_G8_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='141',name='PE0/FMC_NBL0/LCD_SEG36/TIM16_CH1/TIM4_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='142',name='PE1/FMC_NBL1/LCD_SEG37/TIM17_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='1',name='PE2/FMC_A23/LCD_SEG38/SAI1_MCLK_A/SYS_TRACECLK/TIM3_ETR/TSC_G7_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='2',name='PE3/FMC_A19/LCD_SEG39/SAI1_SD_B/SYS_TRACED0/TIM3_CH1/TSC_G7_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='3',name='PE4/DFSDM_DATIN3/FMC_A20/SAI1_FS_A/SYS_TRACED1/TIM3_CH2/TSC_G7_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='4',name='PE5/DFSDM_CKIN3/FMC_A21/SAI1_SCK_A/SYS_TRACED2/TIM3_CH3/TSC_G7_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='5',name='PE6/FMC_A22/RTC_TAMP3/SAI1_SD_A/SYS_TRACED3/SYS_WKUP3/TIM3_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='58',name='PE7/DFSDM_DATIN2/FMC_D4/FMC_DA4/SAI1_SD_B/TIM1_ETR',func=Pin.BIDIR,do_erc=True),
            Pin(num='59',name='PE8/DFSDM_CKIN2/FMC_D5/FMC_DA5/SAI1_SCK_B/TIM1_CH1N',func=Pin.BIDIR,do_erc=True),
            Pin(num='60',name='PE9/DAC1_EXTI9/DFSDM_CKOUT/FMC_D6/FMC_DA6/SAI1_FS_B/TIM1_CH1',func=Pin.BIDIR,do_erc=True),
            Pin(num='63',name='PE10/DFSDM_DATIN4/FMC_D7/FMC_DA7/QUADSPI_CLK/SAI1_MCLK_B/TIM1_CH2N/TSC_G5_IO1',func=Pin.BIDIR,do_erc=True),
            Pin(num='64',name='PE11/ADC1_EXTI11/ADC2_EXTI11/ADC3_EXTI11/DFSDM_CKIN4/FMC_D8/FMC_DA8/QUADSPI_NCS/TIM1_CH2/TSC_G5_IO2',func=Pin.BIDIR,do_erc=True),
            Pin(num='65',name='PE12/DFSDM_DATIN5/FMC_D9/FMC_DA9/QUADSPI_BK1_IO0/SPI1_NSS/TIM1_CH3N/TSC_G5_IO3',func=Pin.BIDIR,do_erc=True),
            Pin(num='66',name='PE13/DFSDM_CKIN5/FMC_D10/FMC_DA10/QUADSPI_BK1_IO1/SPI1_SCK/TIM1_CH3/TSC_G5_IO4',func=Pin.BIDIR,do_erc=True),
            Pin(num='67',name='PE14/FMC_D11/FMC_DA11/QUADSPI_BK1_IO2/SPI1_MISO/TIM1_BKIN2/TIM1_BKIN2_COMP2/TIM1_CH4',func=Pin.BIDIR,do_erc=True),
            Pin(num='68',name='PE15/ADC1_EXTI15/ADC2_EXTI15/ADC3_EXTI15/FMC_D12/FMC_DA12/QUADSPI_BK1_IO3/SPI1_MOSI/TIM1_BKIN/TIM1_BKIN_COMP1',func=Pin.BIDIR,do_erc=True),
            Pin(num='17',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='39',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='52',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='62',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='72',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='84',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='108',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='121',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='144',name='VDD',func=Pin.PWRIN,do_erc=True),
            Pin(num='33',name='VDDA',func=Pin.PWRIN,do_erc=True),
            Pin(num='95',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='131',name='VDDIO2',func=Pin.PWRIN,do_erc=True),
            Pin(num='106',name='VDDUSB',func=Pin.PWRIN,do_erc=True),
            Pin(num='16',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='38',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='51',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='61',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='71',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='83',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='94',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='107',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='120',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='130',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='143',name='VSS',func=Pin.PWRIN,do_erc=True),
            Pin(num='30',name='VSSA',func=Pin.PWRIN,do_erc=True)])])